@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -131,6 +131,14 @@ AcpiDmValidateFadtLength (
     UINT32                  Revision,
     UINT32                  Length);
 
+static void
+AcpiDmDumpBuffer (
+    void                    *Table,
+    UINT32                  BufferOffset,
+    UINT32                  Length,
+    UINT32                  AbsoluteOffset,
+    char                    *Header);
+
 
 /*******************************************************************************
  *
@@ -142,7 +150,6 @@ AcpiDmValidateFadtLength (
  *              AbsoluteOffset      - Offset of buffer in the main ACPI table
  *              Header              - Name of the buffer field (printed on the
  *                                    first line only.)
- *              MultiLine           - TRUE if a large, multi-line buffer
  *
  * RETURN:      None
  *
@@ -151,14 +158,13 @@ AcpiDmValidateFadtLength (
  *
  ******************************************************************************/
 
-void
+static void
 AcpiDmDumpBuffer (
     void                    *Table,
     UINT32                  BufferOffset,
     UINT32                  Length,
     UINT32                  AbsoluteOffset,
-    char                    *Header,
-    BOOLEAN                 MultiLine)
+    char                    *Header)
 {
     UINT8                   *Buffer;
     UINT32                  i;
@@ -176,19 +182,10 @@ AcpiDmDumpBuffer (
     {
         if (!(i % 16))
         {
-            if (MultiLine)
-            {
-                /* Insert a backslash - line continuation character */
-
-                AcpiOsPrintf ("\\\n    ");
-            }
-            else
-            {
-                AcpiOsPrintf ("\n");
-                AcpiDmLineHeader (AbsoluteOffset,
-                    ((Length - i) > 16) ? 16 : (Length - i), Header);
-                Header = NULL;
-            }
+            AcpiOsPrintf ("\n");
+            AcpiDmLineHeader (AbsoluteOffset,
+                ((Length - i) > 16) ? 16 : (Length - i), Header);
+            Header = NULL;
         }
 
         AcpiOsPrintf ("%.02X ", *Buffer);
@@ -424,33 +421,27 @@ AcpiDmValidateFadtLength (
     switch (Revision)
     {
     case 0:
-
         AcpiOsPrintf ("// ACPI Warning: Invalid FADT revision: 0\n");
         return;
 
     case 1:
-
         ExpectedLength = ACPI_FADT_V1_SIZE;
         break;
 
     case 2:
-
         ExpectedLength = ACPI_FADT_V2_SIZE;
         break;
 
     case 3:
     case 4:
-
         ExpectedLength = ACPI_FADT_V3_SIZE;
         break;
 
     case 5:
-
         ExpectedLength = ACPI_FADT_V5_SIZE;
         break;
 
     default:
-
         return;
     }
 
@@ -494,12 +485,12 @@ AcpiDmDumpAsf (
     UINT8                   Type;
 
 
-    /* No main table, only subtables */
+    /* No main table, only sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_ASF_INFO, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
                     SubTable->Header.Length, AcpiDmTableInfoAsfHdr);
@@ -515,12 +506,10 @@ AcpiDmDumpAsf (
         switch (Type)
         {
         case ACPI_ASF_TYPE_INFO:
-
             InfoTable = AcpiDmTableInfoAsf0;
             break;
 
         case ACPI_ASF_TYPE_ALERT:
-
             InfoTable = AcpiDmTableInfoAsf1;
             DataInfoTable = AcpiDmTableInfoAsf1a;
             DataTable = ACPI_ADD_PTR (UINT8, SubTable, sizeof (ACPI_ASF_ALERT));
@@ -530,7 +519,6 @@ AcpiDmDumpAsf (
             break;
 
         case ACPI_ASF_TYPE_CONTROL:
-
             InfoTable = AcpiDmTableInfoAsf2;
             DataInfoTable = AcpiDmTableInfoAsf2a;
             DataTable = ACPI_ADD_PTR (UINT8, SubTable, sizeof (ACPI_ASF_REMOTE));
@@ -540,12 +528,10 @@ AcpiDmDumpAsf (
             break;
 
         case ACPI_ASF_TYPE_BOOT:
-
             InfoTable = AcpiDmTableInfoAsf3;
             break;
 
         case ACPI_ASF_TYPE_ADDRESS:
-
             InfoTable = AcpiDmTableInfoAsf4;
             DataTable = ACPI_ADD_PTR (UINT8, SubTable, sizeof (ACPI_ASF_ADDRESS));
             DataLength = ACPI_CAST_PTR (ACPI_ASF_ADDRESS, SubTable)->Devices;
@@ -553,8 +539,7 @@ AcpiDmDumpAsf (
             break;
 
         default:
-
-            AcpiOsPrintf ("\n**** Unknown ASF subtable type 0x%X\n", SubTable->Header.Type);
+            AcpiOsPrintf ("\n**** Unknown ASF sub-table type 0x%X\n", SubTable->Header.Type);
             return;
         }
 
@@ -601,7 +586,7 @@ AcpiDmDumpAsf (
                 DataOffset++;
                 if (DataOffset > Table->Length)
                 {
-                    AcpiOsPrintf ("**** ACPI table terminates in the middle of a data structure! (ASF! table)\n");
+                    AcpiOsPrintf ("**** ACPI table terminates in the middle of a data structure!\n");
                     return;
                 }
             }
@@ -610,13 +595,12 @@ AcpiDmDumpAsf (
             break;
 
         default:
-
             break;
         }
 
         AcpiOsPrintf ("\n");
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         if (!SubTable->Header.Length)
         {
@@ -661,7 +645,7 @@ AcpiDmDumpCpep (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_CPEP_POLLING, Table, Offset);
     while (Offset < Table->Length)
@@ -674,7 +658,7 @@ AcpiDmDumpCpep (
             return;
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Header.Length;
         SubTable = ACPI_ADD_PTR (ACPI_CPEP_POLLING, SubTable,
@@ -713,7 +697,7 @@ AcpiDmDumpCsrt (
 
     /* The main table only contains the ACPI header, thus already handled */
 
-    /* Subtables (Resource Groups) */
+    /* Sub-tables (Resource Groups) */
 
     SubTable = ACPI_ADD_PTR (ACPI_CSRT_GROUP, Table, Offset);
     while (Offset < Table->Length)
@@ -767,7 +751,7 @@ AcpiDmDumpCsrt (
             InfoLength = SubSubTable->Length - SubSubOffset;
 
             AcpiDmDumpBuffer (SubSubTable, SubSubOffset, InfoLength,
-                Offset + SubOffset + SubSubOffset, "ResourceInfo", FALSE);
+                Offset + SubOffset + SubSubOffset, "ResourceInfo");
             SubSubOffset += InfoLength;
 
             /* Point to next sub-subtable */
@@ -777,7 +761,7 @@ AcpiDmDumpCsrt (
                         SubSubTable->Length);
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_CSRT_GROUP, SubTable,
@@ -821,7 +805,7 @@ AcpiDmDumpDbg2 (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_DBG2_DEVICE, Table, Offset);
     while (Offset < Table->Length)
@@ -884,13 +868,10 @@ AcpiDmDumpDbg2 (
 
         /* Dump the OemData (optional) */
 
-        if (SubTable->OemDataOffset)
-        {
-            AcpiDmDumpBuffer (SubTable, SubTable->OemDataOffset, SubTable->OemDataLength,
-                Offset + SubTable->OemDataOffset, "OEM Data", FALSE);
-        }
+        AcpiDmDumpBuffer (SubTable, SubTable->OemDataOffset, SubTable->OemDataLength,
+            Offset + SubTable->OemDataOffset, "OEM Data");
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_DBG2_DEVICE, SubTable,
@@ -936,12 +917,12 @@ AcpiDmDumpDmar (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_DMAR_HEADER, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Length, Offset, SubTable,
@@ -950,43 +931,27 @@ AcpiDmDumpDmar (
         {
             return;
         }
-        AcpiOsPrintf ("\n");
 
         switch (SubTable->Type)
         {
         case ACPI_DMAR_TYPE_HARDWARE_UNIT:
-
             InfoTable = AcpiDmTableInfoDmar0;
             ScopeOffset = sizeof (ACPI_DMAR_HARDWARE_UNIT);
             break;
-
         case ACPI_DMAR_TYPE_RESERVED_MEMORY:
-
             InfoTable = AcpiDmTableInfoDmar1;
             ScopeOffset = sizeof (ACPI_DMAR_RESERVED_MEMORY);
             break;
-
-        case ACPI_DMAR_TYPE_ROOT_ATS:
-
+        case ACPI_DMAR_TYPE_ATSR:
             InfoTable = AcpiDmTableInfoDmar2;
             ScopeOffset = sizeof (ACPI_DMAR_ATSR);
             break;
-
-        case ACPI_DMAR_TYPE_HARDWARE_AFFINITY:
-
+        case ACPI_DMAR_HARDWARE_AFFINITY:
             InfoTable = AcpiDmTableInfoDmar3;
             ScopeOffset = sizeof (ACPI_DMAR_RHSA);
             break;
-
-        case ACPI_DMAR_TYPE_NAMESPACE:
-
-            InfoTable = AcpiDmTableInfoDmar4;
-            ScopeOffset = sizeof (ACPI_DMAR_ANDD);
-            break;
-
         default:
-
-            AcpiOsPrintf ("\n**** Unknown DMAR subtable type 0x%X\n\n", SubTable->Type);
+            AcpiOsPrintf ("\n**** Unknown DMAR sub-table type 0x%X\n\n", SubTable->Type);
             return;
         }
 
@@ -997,16 +962,7 @@ AcpiDmDumpDmar (
             return;
         }
 
-        /*
-         * Dump the optional device scope entries
-         */
-        if ((SubTable->Type == ACPI_DMAR_TYPE_HARDWARE_AFFINITY) ||
-            (SubTable->Type == ACPI_DMAR_TYPE_NAMESPACE))
-        {
-            /* These types do not support device scopes */
-
-            goto NextSubtable;
-        }
+        /* Dump the device scope entries (if any) */
 
         ScopeTable = ACPI_ADD_PTR (ACPI_DMAR_DEVICE_SCOPE, SubTable, ScopeOffset);
         while (ScopeOffset < SubTable->Length)
@@ -1018,7 +974,6 @@ AcpiDmDumpDmar (
             {
                 return;
             }
-            AcpiOsPrintf ("\n");
 
             /* Dump the PCI Path entries for this device scope */
 
@@ -1036,7 +991,6 @@ AcpiDmDumpDmar (
 
                 PathOffset += 2;
                 PciPath += 2;
-                AcpiOsPrintf ("\n");
             }
 
             /* Point to next device scope entry */
@@ -1046,8 +1000,7 @@ AcpiDmDumpDmar (
                 ScopeTable, ScopeTable->Length);
         }
 
-NextSubtable:
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_DMAR_HEADER, SubTable, SubTable->Length);
@@ -1086,7 +1039,7 @@ AcpiDmDumpEinj (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_WHEA_HEADER, Table, Offset);
     while (Offset < Table->Length)
@@ -1099,7 +1052,7 @@ AcpiDmDumpEinj (
             return;
         }
 
-        /* Point to next subtable (each subtable is of fixed length) */
+        /* Point to next sub-table (each subtable is of fixed length) */
 
         Offset += sizeof (ACPI_WHEA_HEADER);
         SubTable = ACPI_ADD_PTR (ACPI_WHEA_HEADER, SubTable,
@@ -1139,7 +1092,7 @@ AcpiDmDumpErst (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_WHEA_HEADER, Table, Offset);
     while (Offset < Table->Length)
@@ -1152,7 +1105,7 @@ AcpiDmDumpErst (
             return;
         }
 
-        /* Point to next subtable (each subtable is of fixed length) */
+        /* Point to next sub-table (each subtable is of fixed length) */
 
         Offset += sizeof (ACPI_WHEA_HEADER);
         SubTable = ACPI_ADD_PTR (ACPI_WHEA_HEADER, SubTable,
@@ -1187,12 +1140,12 @@ AcpiDmDumpFpdt (
 
     /* There is no main table (other than the standard ACPI header) */
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_FPDT_HEADER, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Length, Offset, SubTable,
@@ -1205,18 +1158,13 @@ AcpiDmDumpFpdt (
         switch (SubTable->Type)
         {
         case ACPI_FPDT_TYPE_BOOT:
-
             InfoTable = AcpiDmTableInfoFpdt0;
             break;
-
         case ACPI_FPDT_TYPE_S3PERF:
-
             InfoTable = AcpiDmTableInfoFpdt1;
             break;
-
         default:
-
-            AcpiOsPrintf ("\n**** Unknown FPDT subtable type 0x%X\n\n", SubTable->Type);
+            AcpiOsPrintf ("\n**** Unknown FPDT sub-table type 0x%X\n\n", SubTable->Type);
 
             /* Attempt to continue */
 
@@ -1236,7 +1184,7 @@ AcpiDmDumpFpdt (
         }
 
 NextSubTable:
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_FPDT_HEADER, SubTable, SubTable->Length);
@@ -1244,123 +1192,6 @@ NextSubTable:
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmDumpGtdt
- *
- * PARAMETERS:  Table               - A GTDT table
- *
- * RETURN:      None
- *
- * DESCRIPTION: Format the contents of a GTDT. This table type consists
- *              of an open-ended number of subtables.
- *
- ******************************************************************************/
-
-void
-AcpiDmDumpGtdt (
-    ACPI_TABLE_HEADER       *Table)
-{
-    ACPI_STATUS             Status;
-    ACPI_GTDT_HEADER        *SubTable;
-    UINT32                  Length = Table->Length;
-    UINT32                  Offset = sizeof (ACPI_TABLE_GTDT);
-    ACPI_DMTABLE_INFO       *InfoTable;
-    UINT32                  SubTableLength;
-    UINT32                  GtCount;
-    ACPI_GTDT_TIMER_ENTRY   *GtxTable;
-
-
-    /* Main table */
-
-    Status = AcpiDmDumpTable (Length, 0, Table, 0, AcpiDmTableInfoGtdt);
-    if (ACPI_FAILURE (Status))
-    {
-        return;
-    }
-
-    /* Subtables */
-
-    SubTable = ACPI_ADD_PTR (ACPI_GTDT_HEADER, Table, Offset);
-    while (Offset < Table->Length)
-    {
-        /* Common subtable header */
-
-        AcpiOsPrintf ("\n");
-        Status = AcpiDmDumpTable (Length, Offset, SubTable,
-                    SubTable->Length, AcpiDmTableInfoGtdtHdr);
-        if (ACPI_FAILURE (Status))
-        {
-            return;
-        }
-
-        GtCount = 0;
-        switch (SubTable->Type)
-        {
-        case ACPI_GTDT_TYPE_TIMER_BLOCK:
-
-            SubTableLength = sizeof (ACPI_GTDT_TIMER_BLOCK);
-            GtCount = (ACPI_CAST_PTR (ACPI_GTDT_TIMER_BLOCK,
-                        SubTable))->TimerCount;
-
-            InfoTable = AcpiDmTableInfoGtdt0;
-            break;
-
-        case ACPI_GTDT_TYPE_WATCHDOG:
-
-            SubTableLength = sizeof (ACPI_GTDT_WATCHDOG);
-
-            InfoTable = AcpiDmTableInfoGtdt1;
-            break;
-
-        default:
-
-            /* Cannot continue on unknown type - no length */
-
-            AcpiOsPrintf ("\n**** Unknown GTDT subtable type 0x%X\n", SubTable->Type);
-            return;
-        }
-
-        Status = AcpiDmDumpTable (Length, Offset, SubTable,
-                    SubTable->Length, InfoTable);
-        if (ACPI_FAILURE (Status))
-        {
-            return;
-        }
-
-        /* Point to end of current subtable (each subtable above is of fixed length) */
-
-        Offset += SubTableLength;
-
-        /* If there are any Gt Timer Blocks from above, dump them now */
-
-        if (GtCount)
-        {
-            GtxTable = ACPI_ADD_PTR (ACPI_GTDT_TIMER_ENTRY, SubTable, SubTableLength);
-            SubTableLength += GtCount * sizeof (ACPI_GTDT_TIMER_ENTRY);
-
-            while (GtCount)
-            {
-                AcpiOsPrintf ("\n");
-                Status = AcpiDmDumpTable (Length, Offset, GtxTable,
-                            sizeof (ACPI_GTDT_TIMER_ENTRY), AcpiDmTableInfoGtdt0a);
-                if (ACPI_FAILURE (Status))
-                {
-                    return;
-                }
-                Offset += sizeof (ACPI_GTDT_TIMER_ENTRY);
-                GtxTable++;
-                GtCount--;
-            }
-        }
-
-        /* Point to next subtable */
-
-        SubTable = ACPI_ADD_PTR (ACPI_GTDT_HEADER, SubTable, SubTableLength);
-    }
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AcpiDmDumpHest
@@ -1396,7 +1227,7 @@ AcpiDmDumpHest (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_HEST_HEADER, Table, Offset);
     while (Offset < Table->Length)
@@ -1405,7 +1236,6 @@ AcpiDmDumpHest (
         switch (SubTable->Type)
         {
         case ACPI_HEST_TYPE_IA32_CHECK:
-
             InfoTable = AcpiDmTableInfoHest0;
             SubTableLength = sizeof (ACPI_HEST_IA_MACHINE_CHECK);
             BankCount = (ACPI_CAST_PTR (ACPI_HEST_IA_MACHINE_CHECK,
@@ -1413,7 +1243,6 @@ AcpiDmDumpHest (
             break;
 
         case ACPI_HEST_TYPE_IA32_CORRECTED_CHECK:
-
             InfoTable = AcpiDmTableInfoHest1;
             SubTableLength = sizeof (ACPI_HEST_IA_CORRECTED);
             BankCount = (ACPI_CAST_PTR (ACPI_HEST_IA_CORRECTED,
@@ -1421,40 +1250,34 @@ AcpiDmDumpHest (
             break;
 
         case ACPI_HEST_TYPE_IA32_NMI:
-
             InfoTable = AcpiDmTableInfoHest2;
             SubTableLength = sizeof (ACPI_HEST_IA_NMI);
             break;
 
         case ACPI_HEST_TYPE_AER_ROOT_PORT:
-
             InfoTable = AcpiDmTableInfoHest6;
             SubTableLength = sizeof (ACPI_HEST_AER_ROOT);
             break;
 
         case ACPI_HEST_TYPE_AER_ENDPOINT:
-
             InfoTable = AcpiDmTableInfoHest7;
             SubTableLength = sizeof (ACPI_HEST_AER);
             break;
 
         case ACPI_HEST_TYPE_AER_BRIDGE:
-
             InfoTable = AcpiDmTableInfoHest8;
             SubTableLength = sizeof (ACPI_HEST_AER_BRIDGE);
             break;
 
         case ACPI_HEST_TYPE_GENERIC_ERROR:
-
             InfoTable = AcpiDmTableInfoHest9;
             SubTableLength = sizeof (ACPI_HEST_GENERIC);
             break;
 
         default:
-
             /* Cannot continue on unknown type - no length */
 
-            AcpiOsPrintf ("\n**** Unknown HEST subtable type 0x%X\n", SubTable->Type);
+            AcpiOsPrintf ("\n**** Unknown HEST sub-table type 0x%X\n", SubTable->Type);
             return;
         }
 
@@ -1492,7 +1315,7 @@ AcpiDmDumpHest (
             }
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         SubTable = ACPI_ADD_PTR (ACPI_HEST_HEADER, SubTable, SubTableLength);
     }
@@ -1535,12 +1358,12 @@ AcpiDmDumpIvrs (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_IVRS_HEADER, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
@@ -1553,20 +1376,15 @@ AcpiDmDumpIvrs (
         switch (SubTable->Type)
         {
         case ACPI_IVRS_TYPE_HARDWARE:
-
             InfoTable = AcpiDmTableInfoIvrs0;
             break;
-
         case ACPI_IVRS_TYPE_MEMORY1:
         case ACPI_IVRS_TYPE_MEMORY2:
         case ACPI_IVRS_TYPE_MEMORY3:
-
             InfoTable = AcpiDmTableInfoIvrs1;
             break;
-
         default:
-
-            AcpiOsPrintf ("\n**** Unknown IVRS subtable type 0x%X\n",
+            AcpiOsPrintf ("\n**** Unknown IVRS sub-table type 0x%X\n",
                 SubTable->Type);
 
             /* Attempt to continue */
@@ -1669,7 +1487,7 @@ AcpiDmDumpIvrs (
         }
 
 NextSubTable:
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_IVRS_HEADER, SubTable, SubTable->Length);
@@ -1677,85 +1495,6 @@ NextSubTable:
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmDumpLpit
- *
- * PARAMETERS:  Table               - A LPIT table
- *
- * RETURN:      None
- *
- * DESCRIPTION: Format the contents of a LPIT. This table type consists
- *              of an open-ended number of subtables. Note: There are no
- *              entries in the main table. An LPIT consists of the table
- *              header and then subtables only.
- *
- ******************************************************************************/
-
-void
-AcpiDmDumpLpit (
-    ACPI_TABLE_HEADER       *Table)
-{
-    ACPI_STATUS             Status;
-    ACPI_LPIT_HEADER        *SubTable;
-    UINT32                  Length = Table->Length;
-    UINT32                  Offset = sizeof (ACPI_TABLE_LPIT);
-    ACPI_DMTABLE_INFO       *InfoTable;
-    UINT32                  SubTableLength;
-
-
-    /* Subtables */
-
-    SubTable = ACPI_ADD_PTR (ACPI_LPIT_HEADER, Table, Offset);
-    while (Offset < Table->Length)
-    {
-        /* Common subtable header */
-
-        Status = AcpiDmDumpTable (Length, Offset, SubTable,
-                    sizeof (ACPI_LPIT_HEADER), AcpiDmTableInfoLpitHdr);
-        if (ACPI_FAILURE (Status))
-        {
-            return;
-        }
-
-        switch (SubTable->Type)
-        {
-        case ACPI_LPIT_TYPE_NATIVE_CSTATE:
-
-            InfoTable = AcpiDmTableInfoLpit0;
-            SubTableLength = sizeof (ACPI_LPIT_NATIVE);
-            break;
-
-        case ACPI_LPIT_TYPE_SIMPLE_IO:
-
-            InfoTable = AcpiDmTableInfoLpit1;
-            SubTableLength = sizeof (ACPI_LPIT_IO);
-            break;
-
-        default:
-
-            /* Cannot continue on unknown type - no length */
-
-            AcpiOsPrintf ("\n**** Unknown LPIT subtable type 0x%X\n", SubTable->Type);
-            return;
-        }
-
-        Status = AcpiDmDumpTable (Length, Offset, SubTable,
-                    SubTableLength, InfoTable);
-        if (ACPI_FAILURE (Status))
-        {
-            return;
-        }
-        AcpiOsPrintf ("\n");
-
-        /* Point to next subtable */
-
-        Offset += SubTableLength;
-        SubTable = ACPI_ADD_PTR (ACPI_LPIT_HEADER, SubTable, SubTableLength);
-    }
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AcpiDmDumpMadt
@@ -1788,12 +1527,12 @@ AcpiDmDumpMadt (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_SUBTABLE_HEADER, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Length, Offset, SubTable,
@@ -1806,83 +1545,46 @@ AcpiDmDumpMadt (
         switch (SubTable->Type)
         {
         case ACPI_MADT_TYPE_LOCAL_APIC:
-
             InfoTable = AcpiDmTableInfoMadt0;
             break;
-
         case ACPI_MADT_TYPE_IO_APIC:
-
             InfoTable = AcpiDmTableInfoMadt1;
             break;
-
         case ACPI_MADT_TYPE_INTERRUPT_OVERRIDE:
-
             InfoTable = AcpiDmTableInfoMadt2;
             break;
-
         case ACPI_MADT_TYPE_NMI_SOURCE:
-
             InfoTable = AcpiDmTableInfoMadt3;
             break;
-
         case ACPI_MADT_TYPE_LOCAL_APIC_NMI:
-
             InfoTable = AcpiDmTableInfoMadt4;
             break;
-
         case ACPI_MADT_TYPE_LOCAL_APIC_OVERRIDE:
-
             InfoTable = AcpiDmTableInfoMadt5;
             break;
-
         case ACPI_MADT_TYPE_IO_SAPIC:
-
             InfoTable = AcpiDmTableInfoMadt6;
             break;
-
         case ACPI_MADT_TYPE_LOCAL_SAPIC:
-
             InfoTable = AcpiDmTableInfoMadt7;
             break;
-
         case ACPI_MADT_TYPE_INTERRUPT_SOURCE:
-
             InfoTable = AcpiDmTableInfoMadt8;
             break;
-
         case ACPI_MADT_TYPE_LOCAL_X2APIC:
-
             InfoTable = AcpiDmTableInfoMadt9;
             break;
-
         case ACPI_MADT_TYPE_LOCAL_X2APIC_NMI:
-
             InfoTable = AcpiDmTableInfoMadt10;
             break;
-
         case ACPI_MADT_TYPE_GENERIC_INTERRUPT:
-
             InfoTable = AcpiDmTableInfoMadt11;
             break;
-
         case ACPI_MADT_TYPE_GENERIC_DISTRIBUTOR:
-
             InfoTable = AcpiDmTableInfoMadt12;
             break;
-
-        case ACPI_MADT_TYPE_GENERIC_MSI_FRAME:
-
-            InfoTable = AcpiDmTableInfoMadt13;
-            break;
-
-        case ACPI_MADT_TYPE_GENERIC_REDISTRIBUTOR:
-
-            InfoTable = AcpiDmTableInfoMadt14;
-            break;
-
         default:
-
-            AcpiOsPrintf ("\n**** Unknown MADT subtable type 0x%X\n\n", SubTable->Type);
+            AcpiOsPrintf ("\n**** Unknown MADT sub-table type 0x%X\n\n", SubTable->Type);
 
             /* Attempt to continue */
 
@@ -1902,7 +1604,7 @@ AcpiDmDumpMadt (
         }
 
 NextSubTable:
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_SUBTABLE_HEADER, SubTable, SubTable->Length);
@@ -1939,7 +1641,7 @@ AcpiDmDumpMcfg (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_MCFG_ALLOCATION, Table, Offset);
     while (Offset < Table->Length)
@@ -1959,7 +1661,7 @@ AcpiDmDumpMcfg (
             return;
         }
 
-        /* Point to next subtable (each subtable is of fixed length) */
+        /* Point to next sub-table (each subtable is of fixed length) */
 
         Offset += sizeof (ACPI_MCFG_ALLOCATION);
         SubTable = ACPI_ADD_PTR (ACPI_MCFG_ALLOCATION, SubTable,
@@ -2141,12 +1843,12 @@ AcpiDmDumpMsct (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_MSCT_PROXIMITY, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
@@ -2156,7 +1858,7 @@ AcpiDmDumpMsct (
             return;
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += sizeof (ACPI_MSCT_PROXIMITY);
         SubTable = ACPI_ADD_PTR (ACPI_MSCT_PROXIMITY, SubTable, sizeof (ACPI_MSCT_PROXIMITY));
@@ -2193,12 +1895,12 @@ AcpiDmDumpMtmr (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_MTMR_ENTRY, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
@@ -2208,7 +1910,7 @@ AcpiDmDumpMtmr (
             return;
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += sizeof (ACPI_MTMR_ENTRY);
         SubTable = ACPI_ADD_PTR (ACPI_MTMR_ENTRY, SubTable, sizeof (ACPI_MTMR_ENTRY));
@@ -2235,7 +1937,6 @@ AcpiDmDumpPcct (
 {
     ACPI_STATUS             Status;
     ACPI_PCCT_SUBSPACE      *SubTable;
-    ACPI_DMTABLE_INFO       *InfoTable;
     UINT32                  Length = Table->Length;
     UINT32                  Offset = sizeof (ACPI_TABLE_PCCT);
 
@@ -2248,50 +1949,20 @@ AcpiDmDumpPcct (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_PCCT_SUBSPACE, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
-
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Length, Offset, SubTable,
-                    SubTable->Header.Length, AcpiDmTableInfoPcctHdr);
+                    SubTable->Header.Length, AcpiDmTableInfoPcct0);
         if (ACPI_FAILURE (Status))
         {
             return;
         }
 
-        switch (SubTable->Header.Type)
-        {
-        case ACPI_PCCT_TYPE_GENERIC_SUBSPACE:
-
-            InfoTable = AcpiDmTableInfoPcct0;
-            break;
-
-        case ACPI_PCCT_TYPE_HW_REDUCED_SUBSPACE:
-
-            InfoTable = AcpiDmTableInfoPcct1;
-            break;
-
-        default:
-
-            AcpiOsPrintf (
-                "\n**** Unexpected or unknown PCCT subtable type 0x%X\n\n",
-                SubTable->Header.Type);
-            return;
-        }
-
-        AcpiOsPrintf ("\n");
-        Status = AcpiDmDumpTable (Length, Offset, SubTable,
-                    SubTable->Header.Length, InfoTable);
-        if (ACPI_FAILURE (Status))
-        {
-            return;
-        }
-
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Header.Length;
         SubTable = ACPI_ADD_PTR (ACPI_PCCT_SUBSPACE, SubTable,
@@ -2439,7 +2110,8 @@ AcpiDmDumpPmtt (
             if (DomainCount)
             {
                 AcpiOsPrintf (
-                    "\n**** DomainCount exceeds subtable length\n\n");
+                    "\n**** DomainCount exceeds subtable length\n\n",
+                    MemSubTable->Type);
             }
 
             /* Walk the physical component (DIMM) subtables */
@@ -2539,7 +2211,7 @@ AcpiDmDumpS3pt (
     SubTable = ACPI_ADD_PTR (ACPI_S3PT_HEADER, S3ptTable, Offset);
     while (Offset < S3ptTable->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (S3ptTable->Length, Offset, SubTable,
@@ -2552,18 +2224,13 @@ AcpiDmDumpS3pt (
         switch (SubTable->Type)
         {
         case ACPI_S3PT_TYPE_RESUME:
-
             InfoTable = AcpiDmTableInfoS3pt0;
             break;
-
         case ACPI_S3PT_TYPE_SUSPEND:
-
             InfoTable = AcpiDmTableInfoS3pt1;
             break;
-
         default:
-
-            AcpiOsPrintf ("\n**** Unknown S3PT subtable type 0x%X\n", SubTable->Type);
+            AcpiOsPrintf ("\n**** Unknown S3PT sub-table type 0x%X\n", SubTable->Type);
 
             /* Attempt to continue */
 
@@ -2584,7 +2251,7 @@ AcpiDmDumpS3pt (
         }
 
 NextSubTable:
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_S3PT_HEADER, SubTable, SubTable->Length);
@@ -2610,8 +2277,62 @@ void
 AcpiDmDumpSlic (
     ACPI_TABLE_HEADER       *Table)
 {
-    AcpiDmDumpTable (Table->Length, sizeof (ACPI_TABLE_HEADER), Table,
-                Table->Length - sizeof (*Table), AcpiDmTableInfoSlic);
+    ACPI_STATUS             Status;
+    UINT32                  Offset = sizeof (ACPI_TABLE_SLIC);
+    ACPI_SLIC_HEADER        *SubTable;
+    ACPI_DMTABLE_INFO       *InfoTable;
+
+
+    /* There is no main SLIC table, only subtables */
+
+    SubTable = ACPI_ADD_PTR (ACPI_SLIC_HEADER, Table, Offset);
+    while (Offset < Table->Length)
+    {
+        /* Common sub-table header */
+
+        AcpiOsPrintf ("\n");
+        Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
+                    SubTable->Length, AcpiDmTableInfoSlicHdr);
+        if (ACPI_FAILURE (Status))
+        {
+            return;
+        }
+
+        switch (SubTable->Type)
+        {
+        case ACPI_SLIC_TYPE_PUBLIC_KEY:
+            InfoTable = AcpiDmTableInfoSlic0;
+            break;
+        case ACPI_SLIC_TYPE_WINDOWS_MARKER:
+            InfoTable = AcpiDmTableInfoSlic1;
+            break;
+        default:
+            AcpiOsPrintf ("\n**** Unknown SLIC sub-table type 0x%X\n", SubTable->Type);
+
+            /* Attempt to continue */
+
+            if (!SubTable->Length)
+            {
+                AcpiOsPrintf ("Invalid zero length subtable\n");
+                return;
+            }
+            goto NextSubTable;
+        }
+
+        AcpiOsPrintf ("\n");
+        Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
+                    SubTable->Length, InfoTable);
+        if (ACPI_FAILURE (Status))
+        {
+            return;
+        }
+
+NextSubTable:
+        /* Point to next sub-table */
+
+        Offset += SubTable->Length;
+        SubTable = ACPI_ADD_PTR (ACPI_SLIC_HEADER, SubTable, SubTable->Length);
+    }
 }
 
 
@@ -2723,12 +2444,12 @@ AcpiDmDumpSrat (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_SUBTABLE_HEADER, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
@@ -2741,27 +2462,16 @@ AcpiDmDumpSrat (
         switch (SubTable->Type)
         {
         case ACPI_SRAT_TYPE_CPU_AFFINITY:
-
             InfoTable = AcpiDmTableInfoSrat0;
             break;
-
         case ACPI_SRAT_TYPE_MEMORY_AFFINITY:
-
             InfoTable = AcpiDmTableInfoSrat1;
             break;
-
         case ACPI_SRAT_TYPE_X2APIC_CPU_AFFINITY:
-
             InfoTable = AcpiDmTableInfoSrat2;
             break;
-
-        case ACPI_SRAT_TYPE_GICC_AFFINITY:
-
-            InfoTable = AcpiDmTableInfoSrat3;
-            break;
-
         default:
-            AcpiOsPrintf ("\n**** Unknown SRAT subtable type 0x%X\n", SubTable->Type);
+            AcpiOsPrintf ("\n**** Unknown SRAT sub-table type 0x%X\n", SubTable->Type);
 
             /* Attempt to continue */
 
@@ -2782,7 +2492,7 @@ AcpiDmDumpSrat (
         }
 
 NextSubTable:
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_SUBTABLE_HEADER, SubTable, SubTable->Length);
@@ -2819,12 +2529,12 @@ AcpiDmDumpVrtc (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_VRTC_ENTRY, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
@@ -2834,7 +2544,7 @@ AcpiDmDumpVrtc (
             return;
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += sizeof (ACPI_VRTC_ENTRY);
         SubTable = ACPI_ADD_PTR (ACPI_VRTC_ENTRY, SubTable, sizeof (ACPI_VRTC_ENTRY));
@@ -2871,12 +2581,12 @@ AcpiDmDumpWdat (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_WDAT_ENTRY, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
@@ -2886,7 +2596,7 @@ AcpiDmDumpWdat (
             return;
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += sizeof (ACPI_WDAT_ENTRY);
         SubTable = ACPI_ADD_PTR (ACPI_WDAT_ENTRY, SubTable, sizeof (ACPI_WDAT_ENTRY));
