@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,17 +113,9 @@
  *
  *****************************************************************************/
 
-/*
- * ACPICA getopt() implementation
- *
- * Option strings:
- *    "f"       - Option has no arguments
- *    "f:"      - Option requires an argument
- *    "f+"      - Option has an optional argument
- *    "f^"      - Option has optional single-char sub-options
- *    "f|"      - Option has required single-char sub-options
- */
 
+#include <stdio.h>
+#include <string.h>
 #include "acpi.h"
 #include "accommon.h"
 #include "acapps.h"
@@ -132,60 +124,9 @@
     if (AcpiGbl_Opterr) {fprintf (stderr, "%s%c\n", msg, badchar);}
 
 
-int                 AcpiGbl_Opterr = 1;
-int                 AcpiGbl_Optind = 1;
-int                 AcpiGbl_SubOptChar = 0;
-char                *AcpiGbl_Optarg;
-
-static int          CurrentCharPtr = 1;
-
-
-/*******************************************************************************
- *
- * FUNCTION:    AcpiGetoptArgument
- *
- * PARAMETERS:  argc, argv          - from main
- *
- * RETURN:      0 if an argument was found, -1 otherwise. Sets AcpiGbl_Optarg
- *              to point to the next argument.
- *
- * DESCRIPTION: Get the next argument. Used to obtain arguments for the
- *              two-character options after the original call to AcpiGetopt.
- *              Note: Either the argument starts at the next character after
- *              the option, or it is pointed to by the next argv entry.
- *              (After call to AcpiGetopt, we need to backup to the previous
- *              argv entry).
- *
- ******************************************************************************/
-
-int
-AcpiGetoptArgument (
-    int                     argc,
-    char                    **argv)
-{
-
-    AcpiGbl_Optind--;
-    CurrentCharPtr++;
-
-    if (argv[AcpiGbl_Optind][(int) (CurrentCharPtr+1)] != '\0')
-    {
-        AcpiGbl_Optarg = &argv[AcpiGbl_Optind++][(int) (CurrentCharPtr+1)];
-    }
-    else if (++AcpiGbl_Optind >= argc)
-    {
-        ACPI_OPTION_ERROR ("\nOption requires an argument", 0);
-
-        CurrentCharPtr = 1;
-        return (-1);
-    }
-    else
-    {
-        AcpiGbl_Optarg = argv[AcpiGbl_Optind++];
-    }
-
-    CurrentCharPtr = 1;
-    return (0);
-}
+int   AcpiGbl_Opterr = 1;
+int   AcpiGbl_Optind = 1;
+char  *AcpiGbl_Optarg;
 
 
 /*******************************************************************************
@@ -195,7 +136,7 @@ AcpiGetoptArgument (
  * PARAMETERS:  argc, argv          - from main
  *              opts                - options info list
  *
- * RETURN:      Option character or ACPI_OPT_END
+ * RETURN:      Option character or EOF
  *
  * DESCRIPTION: Get the next option
  *
@@ -207,6 +148,7 @@ AcpiGetopt(
     char                    **argv,
     char                    *opts)
 {
+    static int              CurrentCharPtr = 1;
     int                     CurrentChar;
     char                    *OptsPtr;
 
@@ -217,12 +159,12 @@ AcpiGetopt(
             argv[AcpiGbl_Optind][0] != '-' ||
             argv[AcpiGbl_Optind][1] == '\0')
         {
-            return (ACPI_OPT_END);
+            return (EOF);
         }
         else if (strcmp (argv[AcpiGbl_Optind], "--") == 0)
         {
             AcpiGbl_Optind++;
-            return (ACPI_OPT_END);
+            return (EOF);
         }
     }
 
@@ -256,8 +198,7 @@ AcpiGetopt(
         }
         else if (++AcpiGbl_Optind >= argc)
         {
-            ACPI_OPTION_ERROR (
-                "Option requires an argument: -", CurrentChar);
+            ACPI_OPTION_ERROR ("Option requires an argument: -", CurrentChar);
 
             CurrentCharPtr = 1;
             return ('?');
@@ -270,26 +211,6 @@ AcpiGetopt(
         CurrentCharPtr = 1;
     }
 
-    /* Option has an optional argument? */
-
-    else if (*OptsPtr == '+')
-    {
-        if (argv[AcpiGbl_Optind][(int) (CurrentCharPtr+1)] != '\0')
-        {
-            AcpiGbl_Optarg = &argv[AcpiGbl_Optind++][(int) (CurrentCharPtr+1)];
-        }
-        else if (++AcpiGbl_Optind >= argc)
-        {
-            AcpiGbl_Optarg = NULL;
-        }
-        else
-        {
-            AcpiGbl_Optarg = argv[AcpiGbl_Optind++];
-        }
-
-        CurrentCharPtr = 1;
-    }
-
     /* Option has optional single-char arguments? */
 
     else if (*OptsPtr == '^')
@@ -303,7 +224,6 @@ AcpiGetopt(
             AcpiGbl_Optarg = "^";
         }
 
-        AcpiGbl_SubOptChar = AcpiGbl_Optarg[0];
         AcpiGbl_Optind++;
         CurrentCharPtr = 1;
     }
@@ -318,15 +238,12 @@ AcpiGetopt(
         }
         else
         {
-            ACPI_OPTION_ERROR (
-                "Option requires a single-character suboption: -",
-                CurrentChar);
+            ACPI_OPTION_ERROR ("Option requires a single-character suboption: -", CurrentChar);
 
             CurrentCharPtr = 1;
             return ('?');
         }
 
-        AcpiGbl_SubOptChar = AcpiGbl_Optarg[0];
         AcpiGbl_Optind++;
         CurrentCharPtr = 1;
     }
