@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,46 +111,10 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "aslcompiler.h"
-#include "acnamesp.h"
+#include "dtcompiler.h"
 
 #include <stdio.h>
 #include <time.h>
@@ -175,384 +139,18 @@ CmFlushSourceCode (
     void);
 
 static void
-CmDumpAllEvents (
-    void);
+FlConsumeAnsiComment (
+    FILE                    *Handle,
+    ASL_FILE_STATUS         *Status);
 
 static void
-CmFinishFiles(
-    BOOLEAN                 DeleteAmlFile);
+FlConsumeNewComment (
+    FILE                    *Handle,
+    ASL_FILE_STATUS         *Status);
 
-
-/*******************************************************************************
- *
- * FUNCTION:    CmDoCompile
- *
- * PARAMETERS:  None
- *
- * RETURN:      Status (0 = OK)
- *
- * DESCRIPTION: This procedure performs the entire compile
- *
- ******************************************************************************/
-
-ACPI_STATUS
-CmDoCompile (
-    void)
-{
-    UINT8                   FullCompile;
-    UINT8                   Event;
-    ASL_GLOBAL_FILE_NODE    *FileNode;
-
-
-    FullCompile = UtBeginEvent ("*** Total Compile time ***");
-    Event = UtBeginEvent ("Open input and output files");
-    UtEndEvent (Event);
-
-    Event = UtBeginEvent ("Preprocess input file");
-    if (AslGbl_PreprocessFlag)
-    {
-        /* Enter compiler name as a #define */
-
-        PrAddDefine (ASL_DEFINE, "", FALSE);
-
-        /* Preprocessor */
-
-        PrDoPreprocess ();
-        AslGbl_CurrentLineNumber = 1;
-        AslGbl_LogicalLineNumber = 1;
-
-        if (AslGbl_PreprocessOnly)
-        {
-            UtEndEvent (Event);
-            CmCleanupAndExit ();
-            return (AE_OK);
-        }
-    }
-    UtEndEvent (Event);
-
-
-    /* Build the parse tree */
-
-    Event = UtBeginEvent ("Parse source code and build parse tree");
-    AslCompilerparse();
-    UtEndEvent (Event);
-
-    /* Check for parser-detected syntax errors */
-
-    if (AslGbl_SyntaxError)
-    {
-        fprintf (stderr,
-            "Compiler aborting due to parser-detected syntax error(s)\n");
-
-        /* Flag this error in the FileNode for compilation summary */
-
-        FileNode = FlGetCurrentFileNode ();
-        FileNode->ParserErrorDetected = TRUE;
-        AslGbl_ParserErrorDetected = TRUE;
-        LsDumpParseTree ();
-        goto ErrorExit;
-    }
-
-    /* Did the parse tree get successfully constructed? */
-
-    if (!AslGbl_ParseTreeRoot)
-    {
-        /*
-         * If there are no errors, then we have some sort of
-         * internal problem.
-         */
-        AslError (ASL_ERROR, ASL_MSG_COMPILER_INTERNAL,
-            NULL, "- Could not resolve parse tree root node");
-
-        goto ErrorExit;
-    }
-
-    /* Flush out any remaining source after parse tree is complete */
-
-    Event = UtBeginEvent ("Flush source input");
-    CmFlushSourceCode ();
-
-    /* Prune the parse tree if requested (debug purposes only) */
-
-    if (AslGbl_PruneParseTree)
-    {
-        AslPruneParseTree (AslGbl_PruneDepth, AslGbl_PruneType);
-    }
-
-    /* Optional parse tree dump, compiler debug output only */
-
-    LsDumpParseTree ();
-
-    OpcGetIntegerWidth (AslGbl_ParseTreeRoot->Asl.Child);
-    UtEndEvent (Event);
-
-    /* Pre-process parse tree for any operator transforms */
-
-    Event = UtBeginEvent ("Parse tree transforms");
-    DbgPrint (ASL_DEBUG_OUTPUT, "\nParse tree transforms\n\n");
-    TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_TWICE,
-        TrAmlTransformWalkBegin, TrAmlTransformWalkEnd, NULL);
-    UtEndEvent (Event);
-
-    /* Generate AML opcodes corresponding to the parse tokens */
-
-    Event = UtBeginEvent ("Generate AML opcodes");
-    DbgPrint (ASL_DEBUG_OUTPUT, "Generating AML opcodes\n\n");
-    TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_UPWARD, NULL,
-        OpcAmlOpcodeWalk, NULL);
-    UtEndEvent (Event);
-
-    UtEndEvent (FullCompile);
-    return (AE_OK);
-
-ErrorExit:
-    UtEndEvent (FullCompile);
-    return (AE_ERROR);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    CmDoAslMiddleAndBackEnd
- *
- * PARAMETERS:  None
- *
- * RETURN:      Status of middle-end and back-end
- *
- * DESCRIPTION: Perform compiler middle-end (type checking and semantic
- *              analysis) and back-end (code generation)
- *
- ******************************************************************************/
-
-int
-CmDoAslMiddleAndBackEnd (
-    void)
-{
-    UINT8                   Event;
-    ACPI_STATUS             Status;
-
-
-    /* Interpret and generate all compile-time constants */
-
-    Event = UtBeginEvent ("Constant folding via AML interpreter");
-    DbgPrint (ASL_DEBUG_OUTPUT,
-        "Interpreting compile-time constant expressions\n\n");
-
-    if (AslGbl_FoldConstants)
-    {
-        TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_UPWARD,
-            NULL, OpcAmlConstantWalk, NULL);
-    }
-    else
-    {
-        DbgPrint (ASL_PARSE_OUTPUT, "    Optional folding disabled\n");
-    }
-    UtEndEvent (Event);
-
-    /* Update AML opcodes if necessary, after constant folding */
-
-    Event = UtBeginEvent ("Updating AML opcodes after constant folding");
-    DbgPrint (ASL_DEBUG_OUTPUT,
-        "Updating AML opcodes after constant folding\n\n");
-    TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_UPWARD,
-        NULL, OpcAmlOpcodeUpdateWalk, NULL);
-    UtEndEvent (Event);
-
-    /* Calculate all AML package lengths */
-
-    Event = UtBeginEvent ("Generate AML package lengths");
-    DbgPrint (ASL_DEBUG_OUTPUT, "Generating Package lengths\n\n");
-    TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_UPWARD, NULL,
-        LnPackageLengthWalk, NULL);
-    UtEndEvent (Event);
-
-    if (AslGbl_ParseOnlyFlag)
-    {
-        AePrintErrorLog (ASL_FILE_STDERR);
-        UtDisplaySummary (ASL_FILE_STDERR);
-        if (AslGbl_DebugFlag)
-        {
-            /* Print error summary to the stdout also */
-
-            AePrintErrorLog (ASL_FILE_STDOUT);
-            UtDisplaySummary (ASL_FILE_STDOUT);
-        }
-        return (0);
-    }
-
-    /*
-     * Create an internal namespace and use it as a symbol table
-     */
-
-    /* Namespace loading */
-
-    Event = UtBeginEvent ("Create ACPI Namespace");
-    DbgPrint (ASL_DEBUG_OUTPUT, "Creating ACPI Namespace\n\n");
-    Status = LdLoadNamespace (AslGbl_ParseTreeRoot);
-    UtEndEvent (Event);
-    if (ACPI_FAILURE (Status))
-    {
-        return (-1);
-    }
-
-    /* Namespace cross-reference */
-
-    AslGbl_NamespaceEvent = UtBeginEvent (
-        "Cross reference parse tree and Namespace");
-    DbgPrint (ASL_DEBUG_OUTPUT, "Cross referencing namespace\n\n");
-    Status = XfCrossReferenceNamespace ();
-    if (ACPI_FAILURE (Status))
-    {
-        return (-1);
-    }
-
-    /* Namespace - Check for non-referenced objects */
-
-    LkFindUnreferencedObjects ();
-    UtEndEvent (AslGbl_NamespaceEvent);
-
-    /* Resolve External Declarations */
-
-    Event = UtBeginEvent ("Resolve all Externals");
-    DbgPrint (ASL_DEBUG_OUTPUT, "\nResolve Externals\n\n");
-
-    if (AslGbl_DoExternalsInPlace)
-    {
-        TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_DOWNWARD,
-            ExAmlExternalWalkBegin, NULL, NULL);
-    }
-    else
-    {
-        TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_TWICE,
-            ExAmlExternalWalkBegin, ExAmlExternalWalkEnd, NULL);
-    }
-    UtEndEvent (Event);
-
-    /*
-     * Semantic analysis. This can happen only after the
-     * namespace has been loaded and cross-referenced.
-     *
-     * part one - check control methods
-     */
-    Event = UtBeginEvent ("Analyze control method return types");
-    AslGbl_AnalysisWalkInfo.MethodStack = NULL;
-
-    DbgPrint (ASL_DEBUG_OUTPUT, "Semantic analysis - Method analysis\n\n");
-
-    if (AslGbl_CrossReferenceOutput)
-    {
-        OtPrintHeaders ("Part 1: Object Reference Map "
-            "(Object references from within each control method)");
-    }
-
-    TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_TWICE,
-        MtMethodAnalysisWalkBegin,
-        MtMethodAnalysisWalkEnd, &AslGbl_AnalysisWalkInfo);
-    UtEndEvent (Event);
-
-    /* Generate the object cross-reference file if requested */
-
-    Event = UtBeginEvent ("Generate cross-reference file");
-    OtCreateXrefFile ();
-    UtEndEvent (Event);
-
-    /* Semantic error checking part two - typing of method returns */
-
-    Event = UtBeginEvent ("Determine object types returned by methods");
-    DbgPrint (ASL_DEBUG_OUTPUT, "Semantic analysis - Method typing\n\n");
-    TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_UPWARD,
-        NULL, AnMethodTypingWalkEnd, NULL);
-    UtEndEvent (Event);
-
-    /* Semantic error checking part three - operand type checking */
-
-    Event = UtBeginEvent ("Analyze AML operand types");
-    DbgPrint (ASL_DEBUG_OUTPUT,
-        "Semantic analysis - Operand type checking\n\n");
-    if (AslGbl_DoTypechecking)
-    {
-        TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_UPWARD,
-            NULL, AnOperandTypecheckWalkEnd, &AslGbl_AnalysisWalkInfo);
-    }
-    UtEndEvent (Event);
-
-    /* Semantic error checking part four - other miscellaneous checks */
-
-    Event = UtBeginEvent ("Miscellaneous analysis");
-    DbgPrint (ASL_DEBUG_OUTPUT, "Semantic analysis - miscellaneous\n\n");
-    TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_DOWNWARD,
-        AnOtherSemanticAnalysisWalkBegin,
-        NULL, &AslGbl_AnalysisWalkInfo);
-    UtEndEvent (Event);
-
-    /*
-     * ASL-/ASL+ converter: Gbl_ParseTreeRoot->CommentList contains the
-     * very last comment of a given ASL file because it's the last constructed
-     * node during compilation. We take the very last comment and save it in a
-     * global for it to be used by the disassembler.
-     */
-    if (AcpiGbl_CaptureComments)
-    {
-        AcpiGbl_LastListHead = AslGbl_ParseTreeRoot->Asl.CommentList;
-        AslGbl_ParseTreeRoot->Asl.CommentList = NULL;
-    }
-
-    /* Calculate all AML package lengths */
-
-    Event = UtBeginEvent ("Finish AML package length generation");
-    DbgPrint (ASL_DEBUG_OUTPUT, "Generating Package lengths\n\n");
-    TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_UPWARD, NULL,
-        LnInitLengthsWalk, NULL);
-    TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_UPWARD, NULL,
-        LnPackageLengthWalk, NULL);
-    UtEndEvent (Event);
-
-    /* Code generation - emit the AML */
-
-    Event = UtBeginEvent ("Generate AML code and write output files");
-    DbgPrint (ASL_DEBUG_OUTPUT, "Writing AML byte code\n\n");
-
-    AslGbl_CurrentDB = AslGbl_ParseTreeRoot->Asl.Child;
-
-    while (AslGbl_CurrentDB)
-    {
-        switch  (FlSwitchFileSet(AslGbl_CurrentDB->Asl.Filename))
-        {
-            case SWITCH_TO_DIFFERENT_FILE:
-                /*
-                 * Reset these parameters when definition blocks belong in
-                 * different files. If they belong in the same file, there is
-                 * no need to reset these parameters
-                 */
-                FlSeekFile (ASL_FILE_SOURCE_OUTPUT, 0);
-                AslGbl_SourceLine = 0;
-                AslGbl_NextError = AslGbl_ErrorLog;
-
-                /* fall-through */
-
-            case SWITCH_TO_SAME_FILE:
-
-                CgGenerateAmlOutput ();
-                CmDoOutputFiles ();
-                AslGbl_CurrentDB = AslGbl_CurrentDB->Asl.Next;
-
-                break;
-
-            default: /* FILE_NOT_FOUND */
-
-                /* The requested file could not be found. Get out of here */
-
-                AslGbl_CurrentDB = NULL;
-                break;
-        }
-    }
-    UtEndEvent (Event);
-
-    Event = UtBeginEvent ("Write optional output files");
-    UtEndEvent (Event);
-
-    return (0);
-}
+static void
+CmDumpAllEvents (
+    void);
 
 
 /*******************************************************************************
@@ -587,12 +185,12 @@ AslCompilerSignon (
 
     case ASL_FILE_HEX_OUTPUT:
 
-        if (AslGbl_HexOutputFlag == HEX_OUTPUT_ASM)
+        if (Gbl_HexOutputFlag == HEX_OUTPUT_ASM)
         {
             Prefix = "; ";
         }
-        else if ((AslGbl_HexOutputFlag == HEX_OUTPUT_C) ||
-                 (AslGbl_HexOutputFlag == HEX_OUTPUT_ASL))
+        else if ((Gbl_HexOutputFlag == HEX_OUTPUT_C) ||
+                 (Gbl_HexOutputFlag == HEX_OUTPUT_ASL))
         {
             FlPrintFile (ASL_FILE_HEX_OUTPUT, "/*\n");
             Prefix = " * ";
@@ -607,15 +205,13 @@ AslCompilerSignon (
         break;
 
     default:
-
         /* No other output types supported */
-
         break;
     }
 
     /* Running compiler or disassembler? */
 
-    if (AcpiGbl_DisasmFlag)
+    if (Gbl_DisasmFlag)
     {
         UtilityName = AML_DISASSEMBLER_NAME;
     }
@@ -664,12 +260,12 @@ AslCompilerFileHeader (
 
     case ASL_FILE_HEX_OUTPUT:
 
-        if (AslGbl_HexOutputFlag == HEX_OUTPUT_ASM)
+        if (Gbl_HexOutputFlag == HEX_OUTPUT_ASM)
         {
             Prefix = "; ";
         }
-        else if ((AslGbl_HexOutputFlag == HEX_OUTPUT_C) ||
-                 (AslGbl_HexOutputFlag == HEX_OUTPUT_ASL))
+        else if ((Gbl_HexOutputFlag == HEX_OUTPUT_C) ||
+                 (Gbl_HexOutputFlag == HEX_OUTPUT_ASL))
         {
             Prefix = " * ";
         }
@@ -683,9 +279,7 @@ AslCompilerFileHeader (
         break;
 
     default:
-
         /* No other output types supported */
-
         break;
     }
 
@@ -696,7 +290,7 @@ AslCompilerFileHeader (
 
     FlPrintFile (FileId,
         "%sCompilation of \"%s\" - %s%s\n",
-        Prefix, AslGbl_Files[ASL_FILE_INPUT].Filename, asctime (NewTime),
+        Prefix, Gbl_Files[ASL_FILE_INPUT].Filename, asctime (NewTime),
         Prefix);
 
     switch (FileId)
@@ -704,14 +298,11 @@ AslCompilerFileHeader (
     case ASL_FILE_C_SOURCE_OUTPUT:
     case ASL_FILE_C_OFFSET_OUTPUT:
     case ASL_FILE_C_INCLUDE_OUTPUT:
-
         FlPrintFile (FileId, " */\n");
         break;
 
     default:
-
         /* Nothing to do for other output types */
-
         break;
     }
 }
@@ -746,6 +337,527 @@ CmFlushSourceCode (
 }
 
 
+/*******************************************************************************
+ *
+ * FUNCTION:    FlConsume*
+ *
+ * PARAMETERS:  Handle              - Open input file
+ *              Status              - File current status struct
+ *
+ * RETURN:      Number of lines consumed
+ *
+ * DESCRIPTION: Step over both types of comment during check for ascii chars
+ *
+ ******************************************************************************/
+
+static void
+FlConsumeAnsiComment (
+    FILE                    *Handle,
+    ASL_FILE_STATUS         *Status)
+{
+    UINT8                   Byte;
+    BOOLEAN                 ClosingComment = FALSE;
+
+
+    while (fread (&Byte, 1, 1, Handle) == 1)
+    {
+        /* Scan until comment close is found */
+
+        if (ClosingComment)
+        {
+            if (Byte == '/')
+            {
+                return;
+            }
+
+            if (Byte != '*')
+            {
+                /* Reset */
+
+                ClosingComment = FALSE;
+            }
+        }
+        else if (Byte == '*')
+        {
+            ClosingComment = TRUE;
+        }
+
+        /* Maintain line count */
+
+        if (Byte == 0x0A)
+        {
+            Status->Line++;
+        }
+
+        Status->Offset++;
+    }
+}
+
+
+static void
+FlConsumeNewComment (
+    FILE                    *Handle,
+    ASL_FILE_STATUS         *Status)
+{
+    UINT8                   Byte;
+
+
+    while (fread (&Byte, 1, 1, Handle) == 1)
+    {
+        Status->Offset++;
+
+        /* Comment ends at newline */
+
+        if (Byte == 0x0A)
+        {
+            Status->Line++;
+            return;
+        }
+    }
+}
+
+
+/*******************************************************************************
+ *
+ * FUNCTION:    FlCheckForAcpiTable
+ *
+ * PARAMETERS:  Handle              - Open input file
+ *
+ * RETURN:      Status
+ *
+ * DESCRIPTION: Determine if a file seems to be a binary ACPI table, via the
+ *              following checks on what would be the table header:
+ *              0) File must be at least as long as an ACPI_TABLE_HEADER
+ *              1) The header length field must match the file size
+ *              2) Signature, OemId, OemTableId, AslCompilerId must be ASCII
+ *
+ ******************************************************************************/
+
+ACPI_STATUS
+FlCheckForAcpiTable (
+    FILE                    *Handle)
+{
+    ACPI_TABLE_HEADER       Table;
+    UINT32                  FileSize;
+    size_t                  Actual;
+    UINT32                  i;
+
+
+    /* Read a potential table header */
+
+    Actual = fread (&Table, 1, sizeof (ACPI_TABLE_HEADER), Handle);
+    fseek (Handle, 0, SEEK_SET);
+
+    if (Actual < sizeof (ACPI_TABLE_HEADER))
+    {
+        return (AE_ERROR);
+    }
+
+    /* Header length field must match the file size */
+
+    FileSize = DtGetFileSize (Handle);
+    if (Table.Length != FileSize)
+    {
+        return (AE_ERROR);
+    }
+
+    /*
+     * These fields must be ASCII:
+     * Signature, OemId, OemTableId, AslCompilerId.
+     * We allow a NULL terminator in OemId and OemTableId.
+     */
+    for (i = 0; i < ACPI_NAME_SIZE; i++)
+    {
+        if (!ACPI_IS_ASCII ((UINT8) Table.Signature[i]))
+        {
+            return (AE_ERROR);
+        }
+
+        if (!ACPI_IS_ASCII ((UINT8) Table.AslCompilerId[i]))
+        {
+            return (AE_ERROR);
+        }
+    }
+
+    for (i = 0; (i < ACPI_OEM_ID_SIZE) && (Table.OemId[i]); i++)
+    {
+        if (!ACPI_IS_ASCII ((UINT8) Table.OemId[i]))
+        {
+            return (AE_ERROR);
+        }
+    }
+
+    for (i = 0; (i < ACPI_OEM_TABLE_ID_SIZE) && (Table.OemTableId[i]); i++)
+    {
+        if (!ACPI_IS_ASCII ((UINT8) Table.OemTableId[i]))
+        {
+            return (AE_ERROR);
+        }
+    }
+
+    printf ("Binary file appears to be a valid ACPI table, disassembling\n");
+    return (AE_OK);
+}
+
+
+/*******************************************************************************
+ *
+ * FUNCTION:    FlCheckForAscii
+ *
+ * PARAMETERS:  Handle              - Open input file
+ *              Filename            - Input filename
+ *              DisplayErrors       - TRUE if error messages desired
+ *
+ * RETURN:      Status
+ *
+ * DESCRIPTION: Verify that the input file is entirely ASCII. Ignores characters
+ *              within comments. Note: does not handle nested comments and does
+ *              not handle comment delimiters within string literals. However,
+ *              on the rare chance this happens and an invalid character is
+ *              missed, the parser will catch the error by failing in some
+ *              spectactular manner.
+ *
+ ******************************************************************************/
+
+ACPI_STATUS
+FlCheckForAscii (
+    FILE                    *Handle,
+    char                    *Filename,
+    BOOLEAN                 DisplayErrors)
+{
+    UINT8                   Byte;
+    ACPI_SIZE               BadBytes = 0;
+    BOOLEAN                 OpeningComment = FALSE;
+    ASL_FILE_STATUS         Status;
+
+
+    Status.Line = 1;
+    Status.Offset = 0;
+
+    /* Read the entire file */
+
+    while (fread (&Byte, 1, 1, Handle) == 1)
+    {
+        /* Ignore comment fields (allow non-ascii within) */
+
+        if (OpeningComment)
+        {
+            /* Check for second comment open delimiter */
+
+            if (Byte == '*')
+            {
+                FlConsumeAnsiComment (Handle, &Status);
+            }
+
+            if (Byte == '/')
+            {
+                FlConsumeNewComment (Handle, &Status);
+            }
+
+            /* Reset */
+
+            OpeningComment = FALSE;
+        }
+        else if (Byte == '/')
+        {
+            OpeningComment = TRUE;
+        }
+
+        /* Check for an ASCII character */
+
+        if (!ACPI_IS_ASCII (Byte))
+        {
+            if ((BadBytes < 10) && (DisplayErrors))
+            {
+                AcpiOsPrintf (
+                    "Non-ASCII character [0x%2.2X] found in line %u, file offset 0x%.2X\n",
+                    Byte, Status.Line, Status.Offset);
+            }
+
+            BadBytes++;
+        }
+
+        /* Update line counter */
+
+        else if (Byte == 0x0A)
+        {
+            Status.Line++;
+        }
+
+        Status.Offset++;
+    }
+
+    /* Seek back to the beginning of the source file */
+
+    fseek (Handle, 0, SEEK_SET);
+
+    /* Were there any non-ASCII characters in the file? */
+
+    if (BadBytes)
+    {
+        if (DisplayErrors)
+        {
+            AcpiOsPrintf (
+                "%u non-ASCII characters found in input source text, could be a binary file\n",
+                BadBytes);
+            AslError (ASL_ERROR, ASL_MSG_NON_ASCII, NULL, Filename);
+        }
+
+        return (AE_BAD_CHARACTER);
+    }
+
+    /* File is OK (100% ASCII) */
+
+    return (AE_OK);
+}
+
+
+/*******************************************************************************
+ *
+ * FUNCTION:    CmDoCompile
+ *
+ * PARAMETERS:  None
+ *
+ * RETURN:      Status (0 = OK)
+ *
+ * DESCRIPTION: This procedure performs the entire compile
+ *
+ ******************************************************************************/
+
+int
+CmDoCompile (
+    void)
+{
+    ACPI_STATUS             Status;
+    UINT8                   FullCompile;
+    UINT8                   Event;
+
+
+    FullCompile = UtBeginEvent ("*** Total Compile time ***");
+    Event = UtBeginEvent ("Open input and output files");
+    UtEndEvent (Event);
+
+    Event = UtBeginEvent ("Preprocess input file");
+    if (Gbl_PreprocessFlag)
+    {
+        /* Preprocessor */
+
+        PrDoPreprocess ();
+        if (Gbl_PreprocessOnly)
+        {
+            UtEndEvent (Event);
+            CmCleanupAndExit ();
+            return (0);
+        }
+    }
+    UtEndEvent (Event);
+
+    /* Build the parse tree */
+
+    Event = UtBeginEvent ("Parse source code and build parse tree");
+    AslCompilerparse();
+    UtEndEvent (Event);
+
+    /* Flush out any remaining source after parse tree is complete */
+
+    Event = UtBeginEvent ("Flush source input");
+    CmFlushSourceCode ();
+
+    /* Did the parse tree get successfully constructed? */
+
+    if (!RootNode)
+    {
+        /*
+         * If there are no errors, then we have some sort of
+         * internal problem.
+         */
+        Status = AslCheckForErrorExit ();
+        if (Status == AE_OK)
+        {
+            AslError (ASL_ERROR, ASL_MSG_COMPILER_INTERNAL,
+                NULL, "- Could not resolve parse tree root node");
+        }
+
+        goto ErrorExit;
+    }
+
+    /* Optional parse tree dump, compiler debug output only */
+
+    LsDumpParseTree ();
+
+    OpcGetIntegerWidth (RootNode);
+    UtEndEvent (Event);
+
+    /* Pre-process parse tree for any operator transforms */
+
+    Event = UtBeginEvent ("Parse tree transforms");
+    DbgPrint (ASL_DEBUG_OUTPUT, "\nParse tree transforms\n\n");
+    TrWalkParseTree (RootNode, ASL_WALK_VISIT_DOWNWARD,
+        TrAmlTransformWalk, NULL, NULL);
+    UtEndEvent (Event);
+
+    /* Generate AML opcodes corresponding to the parse tokens */
+
+    Event = UtBeginEvent ("Generate AML opcodes");
+    DbgPrint (ASL_DEBUG_OUTPUT, "\nGenerating AML opcodes\n\n");
+    TrWalkParseTree (RootNode, ASL_WALK_VISIT_UPWARD, NULL,
+        OpcAmlOpcodeWalk, NULL);
+    UtEndEvent (Event);
+
+    /*
+     * Now that the input is parsed, we can open the AML output file.
+     * Note: by default, the name of this file comes from the table descriptor
+     * within the input file.
+     */
+    Event = UtBeginEvent ("Open AML output file");
+    Status = FlOpenAmlOutputFile (Gbl_OutputFilenamePrefix);
+    UtEndEvent (Event);
+    if (ACPI_FAILURE (Status))
+    {
+        AePrintErrorLog (ASL_FILE_STDERR);
+        return (-1);
+    }
+
+    /* Interpret and generate all compile-time constants */
+
+    Event = UtBeginEvent ("Constant folding via AML interpreter");
+    DbgPrint (ASL_DEBUG_OUTPUT,
+        "\nInterpreting compile-time constant expressions\n\n");
+    TrWalkParseTree (RootNode, ASL_WALK_VISIT_DOWNWARD,
+        OpcAmlConstantWalk, NULL, NULL);
+    UtEndEvent (Event);
+
+    /* Update AML opcodes if necessary, after constant folding */
+
+    Event = UtBeginEvent ("Updating AML opcodes after constant folding");
+    DbgPrint (ASL_DEBUG_OUTPUT,
+        "\nUpdating AML opcodes after constant folding\n\n");
+    TrWalkParseTree (RootNode, ASL_WALK_VISIT_UPWARD,
+        NULL, OpcAmlOpcodeUpdateWalk, NULL);
+    UtEndEvent (Event);
+
+    /* Calculate all AML package lengths */
+
+    Event = UtBeginEvent ("Generate AML package lengths");
+    DbgPrint (ASL_DEBUG_OUTPUT, "\nGenerating Package lengths\n\n");
+    TrWalkParseTree (RootNode, ASL_WALK_VISIT_UPWARD, NULL,
+        LnPackageLengthWalk, NULL);
+    UtEndEvent (Event);
+
+    if (Gbl_ParseOnlyFlag)
+    {
+        AePrintErrorLog (ASL_FILE_STDERR);
+        UtDisplaySummary (ASL_FILE_STDERR);
+        if (Gbl_DebugFlag)
+        {
+            /* Print error summary to the stdout also */
+
+            AePrintErrorLog (ASL_FILE_STDOUT);
+            UtDisplaySummary (ASL_FILE_STDOUT);
+        }
+        UtEndEvent (FullCompile);
+        return (0);
+    }
+
+    /*
+     * Create an internal namespace and use it as a symbol table
+     */
+
+    /* Namespace loading */
+
+    Event = UtBeginEvent ("Create ACPI Namespace");
+    Status = LdLoadNamespace (RootNode);
+    UtEndEvent (Event);
+    if (ACPI_FAILURE (Status))
+    {
+        goto ErrorExit;
+    }
+
+    /* Namespace cross-reference */
+
+    AslGbl_NamespaceEvent = UtBeginEvent ("Cross reference parse tree and Namespace");
+    Status = XfCrossReferenceNamespace ();
+    if (ACPI_FAILURE (Status))
+    {
+        goto ErrorExit;
+    }
+
+    /* Namespace - Check for non-referenced objects */
+
+    LkFindUnreferencedObjects ();
+    UtEndEvent (AslGbl_NamespaceEvent);
+
+    /*
+     * Semantic analysis. This can happen only after the
+     * namespace has been loaded and cross-referenced.
+     *
+     * part one - check control methods
+     */
+    Event = UtBeginEvent ("Analyze control method return types");
+    AnalysisWalkInfo.MethodStack = NULL;
+
+    DbgPrint (ASL_DEBUG_OUTPUT, "\nSemantic analysis - Method analysis\n\n");
+    TrWalkParseTree (RootNode, ASL_WALK_VISIT_TWICE,
+        MtMethodAnalysisWalkBegin,
+        MtMethodAnalysisWalkEnd, &AnalysisWalkInfo);
+    UtEndEvent (Event);
+
+    /* Semantic error checking part two - typing of method returns */
+
+    Event = UtBeginEvent ("Determine object types returned by methods");
+    DbgPrint (ASL_DEBUG_OUTPUT, "\nSemantic analysis - Method typing\n\n");
+    TrWalkParseTree (RootNode, ASL_WALK_VISIT_UPWARD,
+        NULL, AnMethodTypingWalkEnd, NULL);
+    UtEndEvent (Event);
+
+    /* Semantic error checking part three - operand type checking */
+
+    Event = UtBeginEvent ("Analyze AML operand types");
+    DbgPrint (ASL_DEBUG_OUTPUT, "\nSemantic analysis - Operand type checking\n\n");
+    TrWalkParseTree (RootNode, ASL_WALK_VISIT_UPWARD,
+        NULL, AnOperandTypecheckWalkEnd, &AnalysisWalkInfo);
+    UtEndEvent (Event);
+
+    /* Semantic error checking part four - other miscellaneous checks */
+
+    Event = UtBeginEvent ("Miscellaneous analysis");
+    DbgPrint (ASL_DEBUG_OUTPUT, "\nSemantic analysis - miscellaneous\n\n");
+    TrWalkParseTree (RootNode, ASL_WALK_VISIT_DOWNWARD,
+        AnOtherSemanticAnalysisWalkBegin,
+        NULL, &AnalysisWalkInfo);
+    UtEndEvent (Event);
+
+    /* Calculate all AML package lengths */
+
+    Event = UtBeginEvent ("Finish AML package length generation");
+    DbgPrint (ASL_DEBUG_OUTPUT, "\nGenerating Package lengths\n\n");
+    TrWalkParseTree (RootNode, ASL_WALK_VISIT_UPWARD, NULL,
+        LnInitLengthsWalk, NULL);
+    TrWalkParseTree (RootNode, ASL_WALK_VISIT_UPWARD, NULL,
+        LnPackageLengthWalk, NULL);
+    UtEndEvent (Event);
+
+    /* Code generation - emit the AML */
+
+    Event = UtBeginEvent ("Generate AML code and write output files");
+    CgGenerateAmlOutput ();
+    UtEndEvent (Event);
+
+    Event = UtBeginEvent ("Write optional output files");
+    CmDoOutputFiles ();
+    UtEndEvent (Event);
+
+    UtEndEvent (FullCompile);
+    CmCleanupAndExit ();
+    return (0);
+
+ErrorExit:
+    UtEndEvent (FullCompile);
+    CmCleanupAndExit ();
+    return (-1);
+}
+
+
 /*******************************************************************************
  *
  * FUNCTION:    CmDoOutputFiles
@@ -771,10 +883,6 @@ CmDoOutputFiles (
     /* Dump the namespace to the .nsp file if requested */
 
     (void) NsDisplayNamespace ();
-
-    /* Dump the device mapping file */
-
-    MpEmitMappingInfo ();
 }
 
 
@@ -796,15 +904,15 @@ CmDumpAllEvents (
 {
     ASL_EVENT_INFO          *Event;
     UINT32                  Delta;
-    UINT32                  MicroSeconds;
-    UINT32                  MilliSeconds;
+    UINT32                  USec;
+    UINT32                  MSec;
     UINT32                  i;
 
 
     Event = AslGbl_Events;
 
     DbgPrint (ASL_DEBUG_OUTPUT, "\n\nElapsed time for major events\n\n");
-    if (AslGbl_CompileTimesFlag)
+    if (Gbl_CompileTimesFlag)
     {
         printf ("\nElapsed time for major events\n\n");
     }
@@ -817,23 +925,23 @@ CmDumpAllEvents (
 
             Delta = (UINT32) (Event->EndTime - Event->StartTime);
 
-            MicroSeconds = Delta / ACPI_100NSEC_PER_USEC;
-            MilliSeconds = Delta / ACPI_100NSEC_PER_MSEC;
+            USec = Delta / ACPI_100NSEC_PER_USEC;
+            MSec = Delta / ACPI_100NSEC_PER_MSEC;
 
             /* Round milliseconds up */
 
-            if ((MicroSeconds - (MilliSeconds * ACPI_USEC_PER_MSEC)) >= 500)
+            if ((USec - (MSec * ACPI_USEC_PER_MSEC)) >= 500)
             {
-                MilliSeconds++;
+                MSec++;
             }
 
             DbgPrint (ASL_DEBUG_OUTPUT, "%8u usec %8u msec - %s\n",
-                MicroSeconds, MilliSeconds, Event->EventName);
+                USec, MSec, Event->EventName);
 
-            if (AslGbl_CompileTimesFlag)
+            if (Gbl_CompileTimesFlag)
             {
                 printf ("%8u usec %8u msec - %s\n",
-                    MicroSeconds, MilliSeconds, Event->EventName);
+                    USec, MSec, Event->EventName);
             }
         }
 
@@ -858,16 +966,12 @@ void
 CmCleanupAndExit (
     void)
 {
+    UINT32                  i;
     BOOLEAN                 DeleteAmlFile = FALSE;
-    ASL_GLOBAL_FILE_NODE    *CurrentFileNode = AslGbl_FilesList;
 
 
-    /* Check if any errors occurred during compile */
-
-    (void) AslCheckForErrorExit ();
-
     AePrintErrorLog (ASL_FILE_STDERR);
-    if (AslGbl_DebugFlag)
+    if (Gbl_DebugFlag)
     {
         /* Print error summary to stdout also */
 
@@ -878,38 +982,38 @@ CmCleanupAndExit (
 
     CmDumpAllEvents ();
 
-    if (AslGbl_CompileTimesFlag)
+    if (Gbl_CompileTimesFlag)
     {
         printf ("\nMiscellaneous compile statistics\n\n");
-        printf ("%11u : %s\n", AslGbl_TotalParseNodes, "Parse nodes");
-        printf ("%11u : %s\n", AslGbl_NsLookupCount, "Namespace searches");
-        printf ("%11u : %s\n", AslGbl_TotalNamedObjects, "Named objects");
-        printf ("%11u : %s\n", AslGbl_TotalMethods, "Control methods");
-        printf ("%11u : %s\n", AslGbl_TotalAllocations, "Memory Allocations");
-        printf ("%11u : %s\n", AslGbl_TotalAllocated, "Total allocated memory");
-        printf ("%11u : %s\n", AslGbl_TotalFolds, "Constant subtrees folded");
+        printf ("%11u : %s\n", TotalParseNodes, "Parse nodes");
+        printf ("%11u : %s\n", Gbl_NsLookupCount, "Namespace searches");
+        printf ("%11u : %s\n", TotalNamedObjects, "Named objects");
+        printf ("%11u : %s\n", TotalMethods, "Control methods");
+        printf ("%11u : %s\n", TotalAllocations, "Memory Allocations");
+        printf ("%11u : %s\n", TotalAllocated, "Total allocated memory");
+        printf ("%11u : %s\n", TotalFolds, "Constant subtrees folded");
         printf ("\n");
     }
 
-    if (AslGbl_NsLookupCount)
+    if (Gbl_NsLookupCount)
     {
         DbgPrint (ASL_DEBUG_OUTPUT,
             "\n\nMiscellaneous compile statistics\n\n");
 
         DbgPrint (ASL_DEBUG_OUTPUT,
             "%32s : %u\n", "Total Namespace searches",
-            AslGbl_NsLookupCount);
+            Gbl_NsLookupCount);
 
         DbgPrint (ASL_DEBUG_OUTPUT,
             "%32s : %u usec\n", "Time per search", ((UINT32)
             (AslGbl_Events[AslGbl_NamespaceEvent].EndTime -
                 AslGbl_Events[AslGbl_NamespaceEvent].StartTime) / 10) /
-                AslGbl_NsLookupCount);
+                Gbl_NsLookupCount);
     }
 
-    if (AslGbl_ExceptionCount[ASL_ERROR] > ASL_MAX_ERROR_COUNT)
+    if (Gbl_ExceptionCount[ASL_ERROR] > ASL_MAX_ERROR_COUNT)
     {
-        printf ("\nMaximum error count (%d) exceeded\n",
+        printf ("\nMaximum error count (%u) exceeded\n",
             ASL_MAX_ERROR_COUNT);
     }
 
@@ -919,88 +1023,19 @@ CmCleanupAndExit (
      * We will delete the AML file if there are errors and the
      * force AML output option has not been used.
      */
-    if (AslGbl_ParserErrorDetected || ((AslGbl_ExceptionCount[ASL_ERROR] > 0) &&
-        (!AslGbl_IgnoreErrors) &&
-        AslGbl_Files[ASL_FILE_AML_OUTPUT].Handle))
+    if ((Gbl_ExceptionCount[ASL_ERROR] > 0) && (!Gbl_IgnoreErrors) &&
+        Gbl_Files[ASL_FILE_AML_OUTPUT].Handle)
     {
         DeleteAmlFile = TRUE;
     }
 
     /* Close all open files */
 
-    while (CurrentFileNode)
-    {
-        switch  (FlSwitchFileSet (CurrentFileNode->Files[ASL_FILE_INPUT].Filename))
-        {
-            case SWITCH_TO_SAME_FILE:
-            case SWITCH_TO_DIFFERENT_FILE:
-
-                CmFinishFiles (DeleteAmlFile);
-                CurrentFileNode = CurrentFileNode->Next;
-                break;
-
-            case FILE_NOT_FOUND:
-            default:
-
-                CurrentFileNode = NULL;
-                break;
-        }
-    }
-
-    /* Final cleanup after compiling one file */
-
-    if (!AslGbl_DoAslConversion)
-    {
-        UtDeleteLocalCaches ();
-    }
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    CmFinishFiles
- *
- * PARAMETERS:  DeleteAmlFile
- *
- * RETURN:      None.
- *
- * DESCRIPTION: Close all open files, delete AML files depending on the
- *              function parameter is true.
- *
- ******************************************************************************/
-
-static void
-CmFinishFiles(
-    BOOLEAN                 DeleteAmlFile)
-{
-    UINT32                  i;
-
-
-    /*
-     * Take care with the preprocessor file (.pre), it might be the same
-     * as the "input" file, depending on where the compiler has terminated
-     * or aborted. Prevent attempt to close the same file twice in
-     * loop below.
-     */
-    if (AslGbl_Files[ASL_FILE_PREPROCESSOR].Handle ==
-        AslGbl_Files[ASL_FILE_INPUT].Handle)
-    {
-        AslGbl_Files[ASL_FILE_PREPROCESSOR].Handle = NULL;
-    }
-
-    /* Close the standard I/O files */
+    Gbl_Files[ASL_FILE_PREPROCESSOR].Handle = NULL; /* the .i file is same as source file */
 
     for (i = ASL_FILE_INPUT; i < ASL_MAX_FILE_TYPE; i++)
     {
-        /*
-         * Some files such as debug output files could be pointing to
-         * stderr or stdout. Leave these alone.
-         */
-        if (AslGbl_Files[i].Handle != stderr &&
-            AslGbl_Files[i].Handle != stdout)
-        {
-            FlCloseFile (i);
-        }
+        FlCloseFile (i);
     }
 
     /* Delete AML file if there are errors */
@@ -1010,9 +1045,10 @@ CmFinishFiles(
         FlDeleteFile (ASL_FILE_AML_OUTPUT);
     }
 
-    /* Delete the preprocessor temp file unless full debug was specified */
+    /* Delete the preprocessor output file (.i) unless -li flag is set */
 
-    if (AslGbl_PreprocessFlag && !AslGbl_KeepPreprocessorTempFile)
+    if (!Gbl_PreprocessorOutputFlag &&
+        Gbl_PreprocessFlag)
     {
         FlDeleteFile (ASL_FILE_PREPROCESSOR);
     }
@@ -1028,8 +1064,10 @@ CmFinishFiles(
      * Note: Handles are cleared by FlCloseFile above, so we look at the
      * filename instead, to determine if the .SRC file was actually
      * created.
+     *
+     * TBD: SourceOutput should be .TMP, then rename if we want to keep it?
      */
-    if (!AslGbl_SourceOutputFlag)
+    if (!Gbl_SourceOutputFlag)
     {
         FlDeleteFile (ASL_FILE_SOURCE_OUTPUT);
     }
