@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,7 @@
  *
  *****************************************************************************/
 
+
 #ifndef __ASLCOMPILER_H
 #define __ASLCOMPILER_H
 
@@ -182,11 +183,6 @@ AslPushInputFileStack (
     FILE                    *InputFile,
     char                    *Filename);
 
-void
-AslParserCleanup (
-    void);
-
-
 /*
  * aslstartup - entered from main()
  */
@@ -198,6 +194,11 @@ typedef
 ACPI_STATUS (*ASL_PATHNAME_CALLBACK) (
     char *);
 
+ACPI_STATUS
+AslDoOnePathname (
+    char                    *Pathname,
+    ASL_PATHNAME_CALLBACK   Callback);
+
 ACPI_STATUS
 AslDoOneFile (
     char                    *Filename);
@@ -230,14 +231,6 @@ void
 CmCleanupAndExit (
     void);
 
-void
-CmDeleteCaches (
-    void);
-
-
-/*
- * aslascii - ascii support
- */
 ACPI_STATUS
 FlCheckForAcpiTable (
     FILE                    *Handle);
@@ -359,35 +352,17 @@ void
 ApCheckRegMethod (
     ACPI_PARSE_OBJECT       *Op);
 
-BOOLEAN
-ApFindNameInScope (
-    char                    *Name,
-    ACPI_PARSE_OBJECT       *Op);
-
 
 /*
  * aslerror - error handling/reporting
  */
 void
-AslAbort (
-    void);
-
-void
 AslError (
     UINT8                   Level,
-    UINT16                  MessageId,
+    UINT8                   MessageId,
     ACPI_PARSE_OBJECT       *Op,
     char                    *ExtraMessage);
 
-ACPI_STATUS
-AslDisableException (
-    char                    *MessageIdString);
-
-BOOLEAN
-AslIsExceptionDisabled (
-    UINT8                   Level,
-    UINT16                  MessageId);
-
 void
 AslCoreSubsystemError (
     ACPI_PARSE_OBJECT       *Op,
@@ -402,7 +377,7 @@ AslCompilererror(
 void
 AslCommonError (
     UINT8                   Level,
-    UINT16                  MessageId,
+    UINT8                   MessageId,
     UINT32                  CurrentLineNumber,
     UINT32                  LogicalLineNumber,
     UINT32                  LogicalByteOffset,
@@ -413,7 +388,7 @@ AslCommonError (
 void
 AslCommonError2 (
     UINT8                   Level,
-    UINT16                  MessageId,
+    UINT8                   MessageId,
     UINT32                  LineNumber,
     UINT32                  Column,
     char                    *SourceLine,
@@ -434,6 +409,10 @@ void
 AeClearErrorLog (
     void);
 
+ACPI_PHYSICAL_ADDRESS
+AeLocalGetRootPointer (
+    void);
+
 
 /*
  * asllisting - generate all "listing" type files
@@ -523,22 +502,6 @@ OpcAmlConstantWalk (
     void                    *Context);
 
 
-/*
- * aslmessages - exception strings
- */
-const char *
-AeDecodeMessageId (
-    UINT16                  MessageId);
-
-const char *
-AeDecodeExceptionLevel (
-    UINT8                   Level);
-
-UINT16
-AeBuildFullExceptionCode (
-    UINT8                   Level,
-    UINT16                  MessageId);
-
 /*
  * asloffset - generate C offset file for BIOS support
  */
@@ -614,27 +577,6 @@ OptOptimizeNamePath (
     ACPI_NAMESPACE_NODE     *TargetNode);
 
 
-/*
- * aslprintf - Printf/Fprintf macros
- */
-void
-OpcDoPrintf (
-    ACPI_PARSE_OBJECT       *Op);
-
-void
-OpcDoFprintf (
-    ACPI_PARSE_OBJECT       *Op);
-
-
-/*
- * aslprune - parse tree pruner
- */
-void
-AslPruneParseTree (
-    UINT32                  PruneDepth,
-    UINT32                  Type);
-
-
 /*
  * aslcodegen - code generation
  */
@@ -757,10 +699,6 @@ ACPI_PARSE_OBJECT *
 TrAllocateNode (
     UINT32                  ParseOpcode);
 
-void
-TrPrintNodeCompileFlags (
-    UINT32                  Flags);
-
 void
 TrReleaseNode (
     ACPI_PARSE_OBJECT       *Op);
@@ -780,20 +718,6 @@ ACPI_PARSE_OBJECT *
 TrCreateLeafNode (
     UINT32                  ParseOpcode);
 
-ACPI_PARSE_OBJECT *
-TrCreateNullTarget (
-    void);
-
-ACPI_PARSE_OBJECT *
-TrCreateAssignmentNode (
-    ACPI_PARSE_OBJECT       *Target,
-    ACPI_PARSE_OBJECT       *Source);
-
-ACPI_PARSE_OBJECT *
-TrCreateTargetOperand (
-    ACPI_PARSE_OBJECT       *OriginalOp,
-    ACPI_PARSE_OBJECT       *ParentOp);
-
 ACPI_PARSE_OBJECT *
 TrCreateValuedLeafNode (
     UINT32                  ParseOpcode,
@@ -847,6 +771,10 @@ TrLinkPeerNodes (
  * aslfiles - File I/O support
  */
 void
+AslAbort (
+    void);
+
+void
 FlAddIncludeDirectory (
     char                    *Dir);
 
@@ -919,13 +847,6 @@ ACPI_STATUS
 FlOpenMiscOutputFiles (
     char                    *InputFilename);
 
-/*
- * aslhwmap - hardware map summary
- */
-void
-MpEmitMappingInfo (
-    void);
-
 
 /*
  * asload - load namespace in prep for cross reference
@@ -942,17 +863,6 @@ void
 LkFindUnreferencedObjects (
     void);
 
-/*
- * aslmain - startup
- */
-void
-Usage (
-    void);
-
-void
-AslFilenameHelp (
-    void);
-
 
 /*
  * aslnamesp - namespace output file generation
@@ -965,13 +875,6 @@ void
 NsSetupNamespaceListing (
     void                    *Handle);
 
-/*
- * asloptions - command line processing
- */
-int
-AslCommandLine (
-    int                     argc,
-    char                    **argv);
 
 /*
  * aslxref - namespace cross reference
@@ -1025,6 +928,10 @@ void
 UtDisplaySummary (
     UINT32                  FileId);
 
+UINT8
+UtHexCharToValue (
+    int                     HexChar);
+
 void
 UtConvertByteToHex (
     UINT8                   RawByte,
@@ -1044,17 +951,13 @@ UtSetParseOpName (
     ACPI_PARSE_OBJECT       *Op);
 
 char *
-UtStringCacheCalloc (
+UtGetStringBuffer (
     UINT32                  Length);
 
 void
 UtExpandLineBuffers (
     void);
 
-void
-UtFreeLineBuffers (
-    void);
-
 ACPI_STATUS
 UtInternalizeName (
     char                    *ExternalName,
@@ -1089,6 +992,11 @@ ACPI_STATUS
 AuValidateUuid (
     char                    *InString);
 
+ACPI_STATUS
+AuConvertStringToUuid (
+    char                    *InString,
+    char                    *UuIdBuffer);
+
 ACPI_STATUS
 AuConvertUuidToString (
     char                    *UuIdBuffer,
@@ -1163,7 +1071,8 @@ RsCheckListForDuplicates (
 
 ASL_RESOURCE_NODE *
 RsDoOneResourceDescriptor (
-    ASL_RESOURCE_INFO       *Info,
+    ACPI_PARSE_OBJECT       *DescriptorTypeOp,
+    UINT32                  CurrentByteOffset,
     UINT8                   *State);
 
 /* Values for State above */
@@ -1187,35 +1096,43 @@ RsDoResourceTemplate (
  */
 ASL_RESOURCE_NODE *
 RsDoEndTagDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoEndDependentDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoMemory24Descriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoMemory32Descriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoMemory32FixedDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoStartDependentDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoStartDependentNoPriDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoVendorSmallDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 
 /*
@@ -1223,27 +1140,33 @@ RsDoVendorSmallDescriptor (
  */
 ASL_RESOURCE_NODE *
 RsDoDmaDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoFixedDmaDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoFixedIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoIrqDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoIrqNoFlagsDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 
 /*
@@ -1251,50 +1174,61 @@ RsDoIrqNoFlagsDescriptor (
  */
 ASL_RESOURCE_NODE *
 RsDoInterruptDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoVendorLargeDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoGeneralRegisterDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoGpioIntDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoGpioIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoI2cSerialBusDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoSpiSerialBusDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoUartSerialBusDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 /*
  * aslrestype2d - DWord address descriptors
  */
 ASL_RESOURCE_NODE *
 RsDoDwordIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoDwordMemoryDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoDwordSpaceDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 
 /*
@@ -1302,15 +1236,18 @@ RsDoDwordSpaceDescriptor (
  */
 ASL_RESOURCE_NODE *
 RsDoExtendedIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoExtendedMemoryDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoExtendedSpaceDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 
 /*
@@ -1318,15 +1255,18 @@ RsDoExtendedSpaceDescriptor (
  */
 ASL_RESOURCE_NODE *
 RsDoQwordIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoQwordMemoryDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoQwordSpaceDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 
 /*
@@ -1334,16 +1274,18 @@ RsDoQwordSpaceDescriptor (
  */
 ASL_RESOURCE_NODE *
 RsDoWordIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoWordSpaceDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoWordBusNumberDescriptor (
-    ASL_RESOURCE_INFO       *Info);
-
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 /*
  * Entry to data table compiler subsystem
