@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,24 +113,15 @@
  *
  *****************************************************************************/
 
+
 #include "aslcompiler.h"
 #include "aslcompiler.y.h"
-#include "acparser.h"
-#include "amlcode.h"
 
 
 #define _COMPONENT          ACPI_COMPILER
         ACPI_MODULE_NAME    ("aslmethod")
 
 
-/* Local prototypes */
-
-static void
-MtCheckNamedObjectInMethod (
-    ACPI_PARSE_OBJECT       *Op,
-    ASL_METHOD_INFO         *MethodInfo);
-
-
 /*******************************************************************************
  *
  * FUNCTION:    MtMethodAnalysisWalkBegin
@@ -165,13 +156,6 @@ MtMethodAnalysisWalkBegin (
     UINT8                   ActualArgs = 0;
 
 
-    /* Build cross-reference output file if requested */
-
-    if (Gbl_CrossReferenceOutput)
-    {
-        OtXrefWalkPart1 (Op, Level, MethodInfo);
-    }
-
     switch (Op->Asl.ParseOpcode)
     {
     case PARSEOP_METHOD:
@@ -180,48 +164,13 @@ MtMethodAnalysisWalkBegin (
 
         /* Create and init method info */
 
-        MethodInfo = UtLocalCalloc (sizeof (ASL_METHOD_INFO));
+        MethodInfo       = UtLocalCalloc (sizeof (ASL_METHOD_INFO));
         MethodInfo->Next = WalkInfo->MethodStack;
         MethodInfo->Op = Op;
 
         WalkInfo->MethodStack = MethodInfo;
 
-        /*
-         * Special handling for _PSx methods. Dependency rules (same scope):
-         *
-         * 1) _PS0 - One of these must exist: _PS1, _PS2, _PS3
-         * 2) _PS1/_PS2/_PS3: A _PS0 must exist
-         */
-        if (ACPI_COMPARE_NAME (METHOD_NAME__PS0, Op->Asl.NameSeg))
-        {
-            /* For _PS0, one of _PS1/_PS2/_PS3 must exist */
-
-            if ((!ApFindNameInScope (METHOD_NAME__PS1, Op)) &&
-                (!ApFindNameInScope (METHOD_NAME__PS2, Op)) &&
-                (!ApFindNameInScope (METHOD_NAME__PS3, Op)))
-            {
-                AslError (ASL_WARNING, ASL_MSG_MISSING_DEPENDENCY, Op,
-                    "_PS0 requires one of _PS1/_PS2/_PS3 in same scope");
-            }
-        }
-        else if (
-            ACPI_COMPARE_NAME (METHOD_NAME__PS1, Op->Asl.NameSeg) ||
-            ACPI_COMPARE_NAME (METHOD_NAME__PS2, Op->Asl.NameSeg) ||
-            ACPI_COMPARE_NAME (METHOD_NAME__PS3, Op->Asl.NameSeg))
-        {
-            /* For _PS1/_PS2/_PS3, a _PS0 must exist */
-
-            if (!ApFindNameInScope (METHOD_NAME__PS0, Op))
-            {
-                sprintf (MsgBuffer,
-                    "%4.4s requires _PS0 in same scope", Op->Asl.NameSeg);
-
-                AslError (ASL_WARNING, ASL_MSG_MISSING_DEPENDENCY, Op,
-                    MsgBuffer);
-            }
-        }
-
-        /* Get the name node */
+        /* Get the name node, ignored here */
 
         Next = Op->Asl.Child;
 
@@ -234,8 +183,6 @@ MtMethodAnalysisWalkBegin (
         /* Get the SerializeRule and SyncLevel nodes, ignored here */
 
         Next = Next->Asl.Next;
-        MethodInfo->ShouldBeSerialized = (UINT8) Next->Asl.Value.Integer;
-
         Next = Next->Asl.Next;
         ArgNode = Next;
 
@@ -265,9 +212,7 @@ MtMethodAnalysisWalkBegin (
                 NextParamType = NextType->Asl.Child;
                 while (NextParamType)
                 {
-                    MethodInfo->ValidArgTypes[ActualArgs] |=
-                        AnMapObjTypeToBtype (NextParamType);
-
+                    MethodInfo->ValidArgTypes[ActualArgs] |= AnMapObjTypeToBtype (NextParamType);
                     NextParamType->Asl.ParseOpcode = PARSEOP_DEFAULT_ARG;
                     NextParamType = NextParamType->Asl.Next;
                 }
@@ -276,7 +221,6 @@ MtMethodAnalysisWalkBegin (
             {
                 MethodInfo->ValidArgTypes[ActualArgs] =
                     AnMapObjTypeToBtype (NextType);
-
                 NextType->Asl.ParseOpcode = PARSEOP_DEFAULT_ARG;
                 ActualArgs++;
             }
@@ -309,6 +253,7 @@ MtMethodAnalysisWalkBegin (
         }
         break;
 
+
     case PARSEOP_METHODCALL:
 
         if (MethodInfo &&
@@ -318,6 +263,7 @@ MtMethodAnalysisWalkBegin (
         }
         break;
 
+
     case PARSEOP_LOCAL0:
     case PARSEOP_LOCAL1:
     case PARSEOP_LOCAL2:
@@ -333,12 +279,11 @@ MtMethodAnalysisWalkBegin (
              * Local was used outside a control method, or there was an error
              * in the method declaration.
              */
-            AslError (ASL_REMARK, ASL_MSG_LOCAL_OUTSIDE_METHOD,
-                Op, Op->Asl.ExternalName);
+            AslError (ASL_REMARK, ASL_MSG_LOCAL_OUTSIDE_METHOD, Op, Op->Asl.ExternalName);
             return (AE_ERROR);
         }
 
-        RegisterNumber = (Op->Asl.AmlOpcode & 0x0007);
+        RegisterNumber = (Op->Asl.AmlOpcode & 0x000F);
 
         /*
          * If the local is being used as a target, mark the local
@@ -363,6 +308,7 @@ MtMethodAnalysisWalkBegin (
         }
         break;
 
+
     case PARSEOP_ARG0:
     case PARSEOP_ARG1:
     case PARSEOP_ARG2:
@@ -377,8 +323,7 @@ MtMethodAnalysisWalkBegin (
              * Arg was used outside a control method, or there was an error
              * in the method declaration.
              */
-            AslError (ASL_REMARK, ASL_MSG_LOCAL_OUTSIDE_METHOD,
-                Op, Op->Asl.ExternalName);
+            AslError (ASL_REMARK, ASL_MSG_LOCAL_OUTSIDE_METHOD, Op, Op->Asl.ExternalName);
             return (AE_ERROR);
         }
 
@@ -401,7 +346,7 @@ MtMethodAnalysisWalkBegin (
          * The only operator that accepts an uninitialized value is ObjectType()
          */
         else if ((!MethodInfo->ArgInitialized[RegisterNumber]) &&
-            (Op->Asl.Parent->Asl.ParseOpcode != PARSEOP_OBJECTTYPE))
+                 (Op->Asl.Parent->Asl.ParseOpcode != PARSEOP_OBJECTTYPE))
         {
             AslError (ASL_ERROR, ASL_MSG_ARG_INIT, Op, ArgName);
         }
@@ -414,6 +359,7 @@ MtMethodAnalysisWalkBegin (
         }
         break;
 
+
     case PARSEOP_RETURN:
 
         if (!MethodInfo)
@@ -446,6 +392,7 @@ MtMethodAnalysisWalkBegin (
         }
         break;
 
+
     case PARSEOP_BREAK:
     case PARSEOP_CONTINUE:
 
@@ -465,6 +412,7 @@ MtMethodAnalysisWalkBegin (
         }
         break;
 
+
     case PARSEOP_STALL:
 
         /* We can range check if the argument is an integer */
@@ -476,16 +424,8 @@ MtMethodAnalysisWalkBegin (
         }
         break;
 
+
     case PARSEOP_DEVICE:
-
-        if (!ApFindNameInDeviceTree (METHOD_NAME__HID, Op) &&
-            !ApFindNameInDeviceTree (METHOD_NAME__ADR, Op))
-        {
-            AslError (ASL_WARNING, ASL_MSG_MISSING_DEPENDENCY, Op,
-                "Device object requires a _HID or _ADR in same scope");
-        }
-        break;
-
     case PARSEOP_EVENT:
     case PARSEOP_MUTEX:
     case PARSEOP_OPERATIONREGION:
@@ -500,11 +440,11 @@ MtMethodAnalysisWalkBegin (
         i = ApCheckForPredefinedName (Op, Op->Asl.NameSeg);
         if (i < ACPI_VALID_RESERVED_NAME_MAX)
         {
-            AslError (ASL_ERROR, ASL_MSG_RESERVED_USE,
-                Op, Op->Asl.ExternalName);
+            AslError (ASL_ERROR, ASL_MSG_RESERVED_USE, Op, Op->Asl.ExternalName);
         }
         break;
 
+
     case PARSEOP_NAME:
 
         /* Typecheck any predefined names statically defined with Name() */
@@ -513,7 +453,7 @@ MtMethodAnalysisWalkBegin (
 
         /* Special typechecking for _HID */
 
-        if (!strcmp (METHOD_NAME__HID, Op->Asl.NameSeg))
+        if (!ACPI_STRCMP (METHOD_NAME__HID, Op->Asl.NameSeg))
         {
             Next = Op->Asl.Child->Asl.Next;
             AnCheckId (Next, ASL_TYPE_HID);
@@ -521,7 +461,7 @@ MtMethodAnalysisWalkBegin (
 
         /* Special typechecking for _CID */
 
-        else if (!strcmp (METHOD_NAME__CID, Op->Asl.NameSeg))
+        else if (!ACPI_STRCMP (METHOD_NAME__CID, Op->Asl.NameSeg))
         {
             Next = Op->Asl.Child->Asl.Next;
 
@@ -540,78 +480,17 @@ MtMethodAnalysisWalkBegin (
                 AnCheckId (Next, ASL_TYPE_CID);
             }
         }
-
         break;
 
+
     default:
-
         break;
     }
 
-    /* Check for named object creation within a non-serialized method */
-
-    MtCheckNamedObjectInMethod (Op, MethodInfo);
     return (AE_OK);
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    MtCheckNamedObjectInMethod
- *
- * PARAMETERS:  Op                  - Current parser op
- *              MethodInfo          - Info for method being parsed
- *
- * RETURN:      None
- *
- * DESCRIPTION: Detect if a non-serialized method is creating a named object,
- *              which could possibly cause problems if two threads execute
- *              the method concurrently. Emit a remark in this case.
- *
- ******************************************************************************/
-
-static void
-MtCheckNamedObjectInMethod (
-    ACPI_PARSE_OBJECT       *Op,
-    ASL_METHOD_INFO         *MethodInfo)
-{
-    const ACPI_OPCODE_INFO  *OpInfo;
-
-
-    /* We don't care about actual method declarations or scopes */
-
-    if ((Op->Asl.AmlOpcode == AML_METHOD_OP) ||
-        (Op->Asl.AmlOpcode == AML_SCOPE_OP))
-    {
-        return;
-    }
-
-    /* Determine if we are creating a named object */
-
-    OpInfo = AcpiPsGetOpcodeInfo (Op->Asl.AmlOpcode);
-    if (OpInfo->Class == AML_CLASS_NAMED_OBJECT)
-    {
-        /*
-         * If we have a named object created within a non-serialized method,
-         * emit a remark that the method should be serialized.
-         *
-         * Reason: If a thread blocks within the method for any reason, and
-         * another thread enters the method, the method will fail because an
-         * attempt will be made to create the same object twice.
-         */
-        if (MethodInfo && !MethodInfo->ShouldBeSerialized)
-        {
-            AslError (ASL_REMARK, ASL_MSG_SERIALIZED_REQUIRED, MethodInfo->Op,
-                "due to creation of named objects within");
-
-            /* Emit message only ONCE per method */
-
-            MethodInfo->ShouldBeSerialized = TRUE;
-        }
-    }
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    MtMethodAnalysisWalkEnd
@@ -639,7 +518,6 @@ MtMethodAnalysisWalkEnd (
     {
     case PARSEOP_METHOD:
     case PARSEOP_RETURN:
-
         if (!MethodInfo)
         {
             printf ("No method info for method! [%s]\n", Op->Asl.Namepath);
@@ -652,7 +530,6 @@ MtMethodAnalysisWalkEnd (
         break;
 
     default:
-
         break;
     }
 
@@ -729,6 +606,7 @@ MtMethodAnalysisWalkEnd (
         ACPI_FREE (MethodInfo);
         break;
 
+
     case PARSEOP_NAME:
 
          /* Special check for two names like _L01 and _E01 in same scope */
@@ -736,6 +614,7 @@ MtMethodAnalysisWalkEnd (
         ApCheckForGpeNameConflict (Op);
         break;
 
+
     case PARSEOP_RETURN:
 
         /*
@@ -761,11 +640,11 @@ MtMethodAnalysisWalkEnd (
          */
         if (Op->Asl.Next)
         {
-            AslError (ASL_WARNING, ASL_MSG_UNREACHABLE_CODE,
-                Op->Asl.Next, NULL);
+            AslError (ASL_WARNING, ASL_MSG_UNREACHABLE_CODE, Op->Asl.Next, NULL);
         }
         break;
 
+
     case PARSEOP_IF:
 
         if ((Op->Asl.CompileFlags & NODE_HAS_NO_EXIT) &&
@@ -781,6 +660,7 @@ MtMethodAnalysisWalkEnd (
         }
         break;
 
+
     case PARSEOP_ELSE:
 
         if ((Op->Asl.CompileFlags & NODE_HAS_NO_EXIT) &&
