@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,44 +111,9 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+
 #include "aslcompiler.h"
 #include "aslcompiler.y.h"
 #include "acnamesp.h"
@@ -191,8 +156,8 @@ NsSetupNamespaceListing (
     void                    *Handle)
 {
 
-    AslGbl_NsOutputFlag = TRUE;
-    AslGbl_Files[ASL_FILE_NAMESPACE_OUTPUT].Handle = Handle;
+    Gbl_NsOutputFlag = TRUE;
+    Gbl_Files[ASL_FILE_NAMESPACE_OUTPUT].Handle = Handle;
 }
 
 
@@ -217,12 +182,12 @@ NsDisplayNamespace (
     ACPI_STATUS             Status;
 
 
-    if (!AslGbl_NsOutputFlag)
+    if (!Gbl_NsOutputFlag)
     {
         return (AE_OK);
     }
 
-    AslGbl_NumNamespaceObjects = 0;
+    Gbl_NumNamespaceObjects = 0;
 
     /* File header */
 
@@ -232,16 +197,16 @@ NsDisplayNamespace (
     /* Walk entire namespace from the root */
 
     Status = AcpiNsWalkNamespace (ACPI_TYPE_ANY, ACPI_ROOT_OBJECT,
-        ACPI_UINT32_MAX, FALSE, NsDoOneNamespaceObject, NULL,
-        NULL, NULL);
+                ACPI_UINT32_MAX, FALSE, NsDoOneNamespaceObject, NULL,
+                NULL, NULL);
 
     /* Print the full pathname for each namespace node */
 
     FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT, "\nNamespace pathnames\n\n");
 
     Status = AcpiNsWalkNamespace (ACPI_TYPE_ANY, ACPI_ROOT_OBJECT,
-        ACPI_UINT32_MAX, FALSE, NsDoOnePathname, NULL,
-        NULL, NULL);
+                ACPI_UINT32_MAX, FALSE, NsDoOnePathname, NULL,
+                NULL, NULL);
 
     return (Status);
 }
@@ -272,11 +237,12 @@ NsDoOneNamespaceObject (
     ACPI_PARSE_OBJECT       *Op;
 
 
-    AslGbl_NumNamespaceObjects++;
+    Gbl_NumNamespaceObjects++;
 
     FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT, "%5u  [%u]  %*s %4.4s - %s",
-        AslGbl_NumNamespaceObjects, Level, (Level * 3), " ",
-        &Node->Name, AcpiUtGetTypeName (Node->Type));
+        Gbl_NumNamespaceObjects, Level, (Level * 3), " ",
+        &Node->Name,
+        AcpiUtGetTypeName (Node->Type));
 
     Op = Node->Op;
     ObjDesc = ACPI_CAST_PTR (ACPI_OPERAND_OBJECT, Node->Object);
@@ -300,6 +266,7 @@ NsDoOneNamespaceObject (
                 ACPI_FORMAT_UINT64 (ObjDesc->Integer.Value));
             break;
 
+
         case ACPI_TYPE_STRING:
 
             FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT,
@@ -308,9 +275,7 @@ NsDoOneNamespaceObject (
             break;
 
         default:
-
             /* Nothing to do for other types */
-
             break;
         }
 
@@ -325,36 +290,34 @@ NsDoOneNamespaceObject (
             {
                 Op = Op->Asl.Child;
             }
-
             if ((Op->Asl.ParseOpcode == PARSEOP_NAMESEG)  ||
                 (Op->Asl.ParseOpcode == PARSEOP_NAMESTRING))
             {
                 Op = Op->Asl.Next;
             }
-
             FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT,
                 "       [Initial Value   0x%8.8X%8.8X]",
                 ACPI_FORMAT_UINT64 (Op->Asl.Value.Integer));
             break;
 
+
         case ACPI_TYPE_STRING:
 
             if (Op->Asl.ParseOpcode == PARSEOP_NAME)
             {
                 Op = Op->Asl.Child;
             }
-
             if ((Op->Asl.ParseOpcode == PARSEOP_NAMESEG)  ||
                 (Op->Asl.ParseOpcode == PARSEOP_NAMESTRING))
             {
                 Op = Op->Asl.Next;
             }
-
             FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT,
                 "        [Initial Value   \"%s\"]",
                 Op->Asl.Value.String);
             break;
 
+
         case ACPI_TYPE_LOCAL_REGION_FIELD:
 
             if ((Op->Asl.ParseOpcode == PARSEOP_NAMESEG)  ||
@@ -362,66 +325,58 @@ NsDoOneNamespaceObject (
             {
                 Op = Op->Asl.Child;
             }
-
             FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT,
                 "   [Offset 0x%04X   Length 0x%04X bits]",
                 Op->Asl.Parent->Asl.ExtraValue, (UINT32) Op->Asl.Value.Integer);
             break;
 
+
         case ACPI_TYPE_BUFFER_FIELD:
 
             switch (Op->Asl.ParseOpcode)
             {
             case PARSEOP_CREATEBYTEFIELD:
-
                 FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT, "   [BYTE  ( 8 bit)]");
                 break;
 
             case PARSEOP_CREATEDWORDFIELD:
-
                 FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT, "   [DWORD (32 bit)]");
                 break;
 
             case PARSEOP_CREATEQWORDFIELD:
-
                 FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT, "   [QWORD (64 bit)]");
                 break;
 
             case PARSEOP_CREATEWORDFIELD:
-
                 FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT, "   [WORD  (16 bit)]");
                 break;
 
             case PARSEOP_CREATEBITFIELD:
-
                 FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT, "   [BIT   ( 1 bit)]");
                 break;
 
             case PARSEOP_CREATEFIELD:
-
                 FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT, "   [Arbitrary Bit Field]");
                 break;
 
             default:
-
                 break;
 
             }
             break;
 
+
         case ACPI_TYPE_PACKAGE:
 
             if (Op->Asl.ParseOpcode == PARSEOP_NAME)
             {
                 Op = Op->Asl.Child;
             }
-
             if ((Op->Asl.ParseOpcode == PARSEOP_NAMESEG)  ||
                 (Op->Asl.ParseOpcode == PARSEOP_NAMESTRING))
             {
                 Op = Op->Asl.Next;
             }
-
             Op = Op->Asl.Child;
 
             if ((Op->Asl.ParseOpcode == PARSEOP_BYTECONST) ||
@@ -433,19 +388,18 @@ NsDoOneNamespaceObject (
             }
             break;
 
+
         case ACPI_TYPE_BUFFER:
 
             if (Op->Asl.ParseOpcode == PARSEOP_NAME)
             {
                 Op = Op->Asl.Child;
             }
-
             if ((Op->Asl.ParseOpcode == PARSEOP_NAMESEG)  ||
                 (Op->Asl.ParseOpcode == PARSEOP_NAMESTRING))
             {
                 Op = Op->Asl.Next;
             }
-
             Op = Op->Asl.Child;
 
             if (Op && (Op->Asl.ParseOpcode == PARSEOP_INTEGER))
@@ -456,6 +410,7 @@ NsDoOneNamespaceObject (
             }
             break;
 
+
         case ACPI_TYPE_METHOD:
 
             FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT,
@@ -463,12 +418,14 @@ NsDoOneNamespaceObject (
                 Op->Asl.AmlSubtreeLength);
             break;
 
+
         case ACPI_TYPE_LOCAL_RESOURCE:
 
             FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT,
                 "  [Desc Offset     0x%.4X Bytes]", Node->Value);
             break;
 
+
         case ACPI_TYPE_LOCAL_RESOURCE_FIELD:
 
             FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT,
@@ -487,10 +444,9 @@ NsDoOneNamespaceObject (
             }
             break;
 
+
         default:
-
             /* Nothing to do for other types */
-
             break;
         }
     }
@@ -525,7 +481,7 @@ NsDoOnePathname (
 
 
     TargetPath.Length = ACPI_ALLOCATE_LOCAL_BUFFER;
-    Status = AcpiNsHandleToPathname (Node, &TargetPath, FALSE);
+    Status = AcpiNsHandleToPathname (Node, &TargetPath);
     if (ACPI_FAILURE (Status))
     {
         return (Status);
@@ -533,5 +489,6 @@ NsDoOnePathname (
 
     FlPrintFile (ASL_FILE_NAMESPACE_OUTPUT, "%s\n", TargetPath.Pointer);
     ACPI_FREE (TargetPath.Pointer);
+
     return (AE_OK);
 }
