@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -129,12 +129,11 @@ static void
 LsEmitOffsetTableEntry (
     UINT32                  FileId,
     ACPI_NAMESPACE_NODE     *Node,
-    UINT32                  NamepathOffset,
     UINT32                  Offset,
+    UINT32                  Length,
     char                    *OpName,
     UINT64                  Value,
-    UINT8                   AmlOpcode,
-    UINT16                  ParentOpcode);
+    UINT8                   AmlOpcode);
 
 
 /*******************************************************************************
@@ -150,9 +149,7 @@ LsEmitOffsetTableEntry (
  * Three types of objects are currently emitted to the offset table:
  *   1) Tagged (named) resource descriptors
  *   2) Named integer objects with constant integer values
- *   3) Named package objects
- *   4) Operation Regions that have constant Offset (address) parameters
- *   5) Control methods
+ *   3) Operation Regions that have constant Offset (address) parameters
  *
  * The offset table allows the BIOS to dynamically update the values of these
  * objects at boot time.
@@ -168,9 +165,8 @@ LsAmlOffsetWalk (
     UINT32                  FileId = (UINT32) ACPI_TO_INTEGER (Context);
     ACPI_NAMESPACE_NODE     *Node;
     UINT32                  Length;
-    UINT32                  NamepathOffset;
-    UINT32                  DataOffset;
-    ACPI_PARSE_OBJECT       *NextOp;
+    UINT32                  OffsetOfOpcode;
+    ACPI_PARSE_OBJECT       *AddressOp;
 
 
     /* Ignore actual data blocks for resource descriptors */
@@ -194,19 +190,14 @@ LsAmlOffsetWalk (
     if ((Node->Type == ACPI_TYPE_LOCAL_RESOURCE) &&
         (Op->Asl.CompileFlags & NODE_IS_RESOURCE_DESC))
     {
-        LsEmitOffsetTableEntry (FileId, Node, 0, Gbl_CurrentAmlOffset,
-            Op->Asl.ParseOpName, 0, Op->Asl.Extra, AML_BUFFER_OP);
-
-        Gbl_CurrentAmlOffset += Op->Asl.FinalAmlLength;
-        return (AE_OK);
+        LsEmitOffsetTableEntry (FileId, Node, Gbl_CurrentAmlOffset,
+            Op->Asl.FinalAmlLength, Op->Asl.ParseOpName, 0, Op->Asl.Extra);
     }
 
-    switch (Op->Asl.AmlOpcode)
+    /* Named object -- Name (NameString, DataRefObject) */
+
+    else if (Op->Asl.AmlOpcode == AML_NAME_OP)
     {
-    case AML_NAME_OP:
-
-        /* Named object -- Name (NameString, DataRefObject) */
-
         if (!Op->Asl.Child)
         {
             FlPrintFile (FileId, "%s NO CHILD!\n", MsgBuffer);
@@ -214,92 +205,17 @@ LsAmlOffsetWalk (
         }
 
         Length = Op->Asl.FinalAmlLength;
-        NamepathOffset = Gbl_CurrentAmlOffset + Length;
 
         /* Get to the NameSeg/NamePath Op (and length of the name) */
 
         Op = Op->Asl.Child;
-
-        /* Get offset of last nameseg and the actual data */
-
-        NamepathOffset = Gbl_CurrentAmlOffset + Length +
-            (Op->Asl.FinalAmlLength - ACPI_NAME_SIZE);
-
-        DataOffset = Gbl_CurrentAmlOffset + Length +
-            Op->Asl.FinalAmlLength;
+        OffsetOfOpcode = Length + Op->Asl.FinalAmlLength;
 
         /* Get actual value associated with the name */
 
         Op = Op->Asl.Next;
         switch (Op->Asl.AmlOpcode)
         {
-        case AML_BYTE_OP:
-        case AML_WORD_OP:
-        case AML_DWORD_OP:
-        case AML_QWORD_OP:
-
-            /* The +1 is to handle the integer size prefix (opcode) */
-
-            LsEmitOffsetTableEntry (FileId, Node, NamepathOffset, (DataOffset + 1),
-                Op->Asl.ParseOpName, Op->Asl.Value.Integer,
-                (UINT8) Op->Asl.AmlOpcode, AML_NAME_OP);
-            break;
-
-        case AML_ONE_OP:
-        case AML_ONES_OP:
-        case AML_ZERO_OP:
-
-            /* For these, offset will point to the opcode */
-
-            LsEmitOffsetTableEntry (FileId, Node, NamepathOffset, DataOffset,
-                Op->Asl.ParseOpName, Op->Asl.Value.Integer,
-                (UINT8) Op->Asl.AmlOpcode, AML_NAME_OP);
-            break;
-
-        case AML_PACKAGE_OP:
-        case AML_VARIABLE_PACKAGE_OP:
-
-            /* Get the package element count */
-
-            NextOp = Op->Asl.Child;
-
-            LsEmitOffsetTableEntry (FileId, Node, NamepathOffset, DataOffset,
-                Op->Asl.ParseOpName, NextOp->Asl.Value.Integer,
-                (UINT8) Op->Asl.AmlOpcode, AML_NAME_OP);
-            break;
-
-         default:
-             break;
-        }
-
-        Gbl_CurrentAmlOffset += Length;
-        return (AE_OK);
-
-    case AML_REGION_OP:
-
-        /* OperationRegion (NameString, RegionSpace, RegionOffset, RegionLength) */
-
-        Length = Op->Asl.FinalAmlLength;
-
-        /* Get the name/namepath node */
-
-        NextOp = Op->Asl.Child;
-
-        /* Get offset of last nameseg and the actual data */
-
-        NamepathOffset = Gbl_CurrentAmlOffset + Length +
-            (NextOp->Asl.FinalAmlLength - ACPI_NAME_SIZE);
-
-        DataOffset = Gbl_CurrentAmlOffset + Length +
-            (NextOp->Asl.FinalAmlLength + 1);
-
-        /* Get the SpaceId node, then the Offset (address) node */
-
-        NextOp = NextOp->Asl.Next;
-        NextOp = NextOp->Asl.Next;
-
-        switch (NextOp->Asl.AmlOpcode)
-        {
         /*
          * We are only interested in integer constants that can be changed
          * at boot time. Note, the One/Ones/Zero opcodes are considered
@@ -310,9 +226,56 @@ LsAmlOffsetWalk (
         case AML_DWORD_OP:
         case AML_QWORD_OP:
 
-            LsEmitOffsetTableEntry (FileId, Node, NamepathOffset, (DataOffset + 1),
-                Op->Asl.ParseOpName, NextOp->Asl.Value.Integer,
-                (UINT8) NextOp->Asl.AmlOpcode, AML_REGION_OP);
+            /* The +1/-1 is to handle the integer size prefix (opcode) */
+
+            LsEmitOffsetTableEntry (FileId, Node,
+                (Gbl_CurrentAmlOffset + OffsetOfOpcode + 1),
+                (Op->Asl.FinalAmlLength - 1), Op->Asl.ParseOpName,
+                Op->Asl.Value.Integer, (UINT8) Op->Asl.AmlOpcode);
+            break;
+
+        default:
+            break;
+        }
+
+        Gbl_CurrentAmlOffset += Length;
+        return (AE_OK);
+    }
+
+    /* OperationRegion (NameString, RegionSpace, RegionOffset, RegionLength) */
+
+    else if (Op->Asl.AmlOpcode == AML_REGION_OP)
+    {
+        Length = Op->Asl.FinalAmlLength;
+
+        /* Get the name/namepath node */
+
+        AddressOp = Op->Asl.Child;
+        OffsetOfOpcode = Length + AddressOp->Asl.FinalAmlLength + 1;
+
+        /* Get the SpaceId node, then the Offset (address) node */
+
+        AddressOp = AddressOp->Asl.Next;
+        AddressOp = AddressOp->Asl.Next;
+
+        switch (AddressOp->Asl.AmlOpcode)
+        {
+        /*
+         * We are only interested in integer constants that can be changed
+         * at boot time. Note, the One/Ones/Zero opcodes are considered
+         * non-changeable, so we ignore them here.
+         */
+        case AML_BYTE_OP:
+        case AML_WORD_OP:
+        case AML_DWORD_OP:
+        case AML_QWORD_OP:
+
+            /* The +1/-1 is to handle the integer size prefix (opcode) */
+
+            LsEmitOffsetTableEntry (FileId, Node,
+                (Gbl_CurrentAmlOffset + OffsetOfOpcode + 1),
+                (AddressOp->Asl.FinalAmlLength - 1), Op->Asl.ParseOpName,
+                AddressOp->Asl.Value.Integer, (UINT8) AddressOp->Asl.AmlOpcode);
 
             Gbl_CurrentAmlOffset += Length;
             return (AE_OK);
@@ -320,78 +283,6 @@ LsAmlOffsetWalk (
         default:
             break;
         }
-        break;
-
-    case AML_METHOD_OP:
-
-        /* Method (Namepath, ...) */
-
-        Length = Op->Asl.FinalAmlLength;
-
-        /* Get the NameSeg/NamePath Op */
-
-        NextOp = Op->Asl.Child;
-
-        /* Get offset of last nameseg and the actual data (flags byte) */
-
-        NamepathOffset = Gbl_CurrentAmlOffset + Length +
-            (NextOp->Asl.FinalAmlLength - ACPI_NAME_SIZE);
-
-        DataOffset = Gbl_CurrentAmlOffset + Length +
-            NextOp->Asl.FinalAmlLength;
-
-        /* Get the flags byte Op */
-
-        NextOp = NextOp->Asl.Next;
-
-        LsEmitOffsetTableEntry (FileId, Node, NamepathOffset, DataOffset,
-            Op->Asl.ParseOpName, NextOp->Asl.Value.Integer,
-            (UINT8) Op->Asl.AmlOpcode, AML_METHOD_OP);
-        break;
-
-    case AML_PROCESSOR_OP:
-
-        /* Processor (Namepath, ProcessorId, Address, Length) */
-
-        Length = Op->Asl.FinalAmlLength;
-        NextOp = Op->Asl.Child;     /* Get Namepath */
-
-        /* Get offset of last nameseg and the actual data (PBlock address) */
-
-        NamepathOffset = Gbl_CurrentAmlOffset + Length +
-            (NextOp->Asl.FinalAmlLength - ACPI_NAME_SIZE);
-
-        DataOffset = Gbl_CurrentAmlOffset + Length +
-            (NextOp->Asl.FinalAmlLength + 1);
-
-        NextOp = NextOp->Asl.Next;  /* Get ProcessorID (BYTE) */
-        NextOp = NextOp->Asl.Next;  /* Get Address (DWORD) */
-
-        LsEmitOffsetTableEntry (FileId, Node, NamepathOffset, DataOffset,
-            Op->Asl.ParseOpName, NextOp->Asl.Value.Integer,
-            (UINT8) AML_DWORD_OP, AML_PROCESSOR_OP);
-        break;
-
-    case AML_DEVICE_OP:
-    case AML_SCOPE_OP:
-    case AML_THERMAL_ZONE_OP:
-
-        /* Device/Scope/ThermalZone (Namepath) */
-
-        Length = Op->Asl.FinalAmlLength;
-        NextOp = Op->Asl.Child;     /* Get Namepath */
-
-        /* Get offset of last nameseg */
-
-        NamepathOffset = Gbl_CurrentAmlOffset + Length +
-            (NextOp->Asl.FinalAmlLength - ACPI_NAME_SIZE);
-
-        LsEmitOffsetTableEntry (FileId, Node, NamepathOffset, 0,
-            Op->Asl.ParseOpName, 0, (UINT8) 0, Op->Asl.AmlOpcode);
-        break;
-
-    default:
-        break;
     }
 
     Gbl_CurrentAmlOffset += Op->Asl.FinalAmlLength;
@@ -406,10 +297,10 @@ LsAmlOffsetWalk (
  * PARAMETERS:  FileId          - ID of current listing file
  *              Node            - Namespace node associated with the name
  *              Offset          - Offset of the value within the AML table
+ *              Length          - Length in bytes of the value
  *              OpName          - Name of the AML opcode
  *              Value           - Current value of the AML field
  *              AmlOpcode       - Opcode associated with the field
- *              ObjectType      - ACPI object type
  *
  * RETURN:      None
  *
@@ -421,12 +312,11 @@ static void
 LsEmitOffsetTableEntry (
     UINT32                  FileId,
     ACPI_NAMESPACE_NODE     *Node,
-    UINT32                  NamepathOffset,
     UINT32                  Offset,
+    UINT32                  Length,
     char                    *OpName,
     UINT64                  Value,
-    UINT8                   AmlOpcode,
-    UINT16                  ParentOpcode)
+    UINT8                   AmlOpcode)
 {
     ACPI_BUFFER             TargetPath;
     ACPI_STATUS             Status;
@@ -435,7 +325,7 @@ LsEmitOffsetTableEntry (
     /* Get the full pathname to the namespace node */
 
     TargetPath.Length = ACPI_ALLOCATE_LOCAL_BUFFER;
-    Status = AcpiNsHandleToPathname (Node, &TargetPath, FALSE);
+    Status = AcpiNsHandleToPathname (Node, &TargetPath);
     if (ACPI_FAILURE (Status))
     {
         return;
@@ -453,9 +343,8 @@ LsEmitOffsetTableEntry (
      * Max Length for Integers is 8 bytes.
      */
     FlPrintFile (FileId,
-        "    {%-29s 0x%4.4X, 0x%8.8X, 0x%2.2X, 0x%8.8X, 0x%8.8X%8.8X}, /* %s */\n",
-        MsgBuffer, ParentOpcode, NamepathOffset, AmlOpcode,
-        Offset, ACPI_FORMAT_UINT64 (Value), OpName);
+        "    {%-29s 0x%8.8X, 0x%2.2X, 0x%8.8X%8.8X}, /* %s */\n",
+        MsgBuffer, Offset, AmlOpcode, ACPI_FORMAT_UINT64 (Value), OpName);
 }
 
 
@@ -476,57 +365,22 @@ LsDoOffsetTableHeader (
     UINT32                  FileId)
 {
 
+    Gbl_CurrentAmlOffset = 0;
+
     FlPrintFile (FileId,
         "#ifndef __AML_OFFSET_TABLE_H\n"
         "#define __AML_OFFSET_TABLE_H\n\n");
 
     FlPrintFile (FileId, "typedef struct {\n"
-        "    char                   *Pathname;      /* Full pathname (from root) to the object */\n"
-        "    unsigned short         ParentOpcode;   /* AML opcode for the parent object */\n"
-        "    unsigned long          NamesegOffset;  /* Offset of last nameseg in the parent namepath */\n"
-        "    unsigned char          Opcode;         /* AML opcode for the data */\n"
-        "    unsigned long          Offset;         /* Offset for the data */\n"
-        "    unsigned long long     Value;          /* Original value of the data (as applicable) */\n"
+        "    char                   *Pathname;\n"
+        "    unsigned long          Offset;\n"
+        "    unsigned char          AmlOpcode;\n"
+        "    unsigned long long     AmlValue;\n"
         "} AML_OFFSET_TABLE_ENTRY;\n\n");
 
     FlPrintFile (FileId,
         "#endif /* __AML_OFFSET_TABLE_H */\n\n");
 
-    FlPrintFile (FileId,
-        "/*\n"
-        " * Information specific to the supported object types:\n"
-        " *\n"
-        " * Integers:\n"
-        " *    Opcode is the integer prefix, indicates length of the data\n"
-        " *        (One of: BYTE, WORD, DWORD, QWORD, ZERO, ONE, ONES)\n"
-        " *    Offset points to the actual integer data\n"
-        " *    Value is the existing value in the AML\n"
-        " *\n"
-        " * Packages:\n"
-        " *    Opcode is the package or var_package opcode\n"
-        " *    Offset points to the package opcode\n"
-        " *    Value is the package element count\n"
-        " *\n"
-        " * Operation Regions:\n"
-        " *    Opcode is the address integer prefix, indicates length of the data\n"
-        " *    Offset points to the region address\n"
-        " *    Value is the existing address value in the AML\n"
-        " *\n"
-        " * Control Methods:\n"
-        " *    Offset points to the method flags byte\n"
-        " *    Value is the existing flags value in the AML\n"
-        " *\n"
-        " * Processors:\n"
-        " *    Offset points to the first byte of the PBlock Address\n"
-        " *\n"
-        " * Resource Descriptors:\n"
-        " *    Opcode is the descriptor type\n"
-        " *    Offset points to the start of the descriptor\n"
-        " *\n"
-        " * Scopes/Devices/ThermalZones:\n"
-        " *    Nameseg offset only\n"
-        " */\n");
-
     FlPrintFile (FileId,
         "AML_OFFSET_TABLE_ENTRY   %s_%s_OffsetTable[] =\n{\n",
         Gbl_TableSignature, Gbl_TableId);
@@ -539,6 +393,6 @@ LsDoOffsetTableFooter (
 {
 
     FlPrintFile (FileId,
-        "    {NULL,0,0,0,0,0} /* Table terminator */\n};\n\n");
+        "    {0,0,0,0} /* Table terminator */\n};\n\n");
     Gbl_CurrentAmlOffset = 0;
 }
