@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2022, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #define ACPI_CREATE_PREDEFINED_TABLE
@@ -216,16 +180,16 @@ ApCheckForPredefinedMethod (
 
     case ACPI_EVENT_RESERVED_NAME:      /* _Lxx/_Exx/_Wxx/_Qxx methods */
 
-        AslGbl_ReservedMethods++;
+        Gbl_ReservedMethods++;
 
         /* NumArguments must be zero for all _Lxx/_Exx/_Wxx/_Qxx methods */
 
         if (MethodInfo->NumArguments != 0)
         {
-            sprintf (AslGbl_MsgBuffer, "%s requires %d", Op->Asl.ExternalName, 0);
+            sprintf (MsgBuffer, "%s requires %u", Op->Asl.ExternalName, 0);
 
             AslError (ASL_WARNING, ASL_MSG_RESERVED_ARG_COUNT_HI, Op,
-                AslGbl_MsgBuffer);
+                MsgBuffer);
         }
         break;
 
@@ -238,25 +202,25 @@ ApCheckForPredefinedMethod (
          * Some methods are allowed to have a "minimum" number of args
          * (_SCP) because their definition in ACPI has changed over time.
          */
-        AslGbl_ReservedMethods++;
+        Gbl_ReservedMethods++;
         ThisName = &AcpiGbl_PredefinedMethods[Index];
         RequiredArgCount = METHOD_GET_ARG_COUNT (ThisName->Info.ArgumentList);
 
         if (MethodInfo->NumArguments != RequiredArgCount)
         {
-            sprintf (AslGbl_MsgBuffer, "%4.4s requires %u",
+            sprintf (MsgBuffer, "%4.4s requires %u",
                 ThisName->Info.Name, RequiredArgCount);
 
             if (MethodInfo->NumArguments < RequiredArgCount)
             {
                 AslError (ASL_WARNING, ASL_MSG_RESERVED_ARG_COUNT_LO, Op,
-                    AslGbl_MsgBuffer);
+                    MsgBuffer);
             }
             else if ((MethodInfo->NumArguments > RequiredArgCount) &&
                 !(ThisName->Info.ArgumentList & ARG_COUNT_IS_MINIMUM))
             {
                 AslError (ASL_WARNING, ASL_MSG_RESERVED_ARG_COUNT_HI, Op,
-                    AslGbl_MsgBuffer);
+                    MsgBuffer);
             }
         }
 
@@ -267,14 +231,14 @@ ApCheckForPredefinedMethod (
         if (MethodInfo->NumReturnNoValue &&
             ThisName->Info.ExpectedBtypes)
         {
-            AcpiUtGetExpectedReturnTypes (AslGbl_StringBuffer,
+            AcpiUtGetExpectedReturnTypes (StringBuffer,
                 ThisName->Info.ExpectedBtypes);
 
-            sprintf (AslGbl_MsgBuffer, "%s required for %4.4s",
-                AslGbl_StringBuffer, ThisName->Info.Name);
+            sprintf (MsgBuffer, "%s required for %4.4s",
+                StringBuffer, ThisName->Info.Name);
 
             AslError (ASL_WARNING, ASL_MSG_RESERVED_RETURN_VALUE, Op,
-                AslGbl_MsgBuffer);
+                MsgBuffer);
         }
         break;
     }
@@ -359,16 +323,10 @@ ApCheckPredefinedReturnValue (
     const ACPI_PREDEFINED_INFO  *ThisName;
 
 
-    /*
-     * Check parent method for a match against the predefined name list.
-     *
-     * Note: Disable compiler errors/warnings because any errors will be
-     * caught when analyzing the parent method. Eliminates duplicate errors.
-     */
-    AslGbl_AllExceptionsDisabled = TRUE;
+    /* Check parent method for a match against the predefined name list */
+
     Index = ApCheckForPredefinedName (MethodInfo->Op,
-        MethodInfo->Op->Asl.NameSeg);
-    AslGbl_AllExceptionsDisabled = FALSE;
+                MethodInfo->Op->Asl.NameSeg);
 
     switch (Index)
     {
@@ -424,6 +382,7 @@ ApCheckPredefinedReturnValue (
             break;
 
         default:
+
             /*
              * All other ops are very difficult or impossible to typecheck at
              * compile time. These include all Localx, Argx, and method
@@ -449,7 +408,7 @@ ApCheckPredefinedReturnValue (
  * DESCRIPTION: Check for a predefined name for a static object (created via
  *              the ASL Name operator). If it is a predefined ACPI name, ensure
  *              that the name does not require any arguments (which would
- *              require a control method implementation of the name), and that
+ *              require a control method implemenation of the name), and that
  *              the type of the object is one of the expected types for the
  *              predefined name.
  *
@@ -492,7 +451,6 @@ ApCheckForPredefinedObject (
         return;
 
     default:
-
         break;
     }
 
@@ -562,8 +520,8 @@ ApCheckForPredefinedName (
 
     if (Name[0] == 0)
     {
-        AslError (ASL_ERROR, ASL_MSG_COMPILER_INTERNAL, Op,
-            "zero length name found");
+        AcpiOsPrintf ("Found a null name, external = %s\n",
+            Op->Asl.ExternalName);
     }
 
     /* All reserved names are prefixed with a single underscore */
@@ -578,7 +536,7 @@ ApCheckForPredefinedName (
     ThisName = AcpiGbl_PredefinedMethods;
     for (i = 0; ThisName->Info.Name[0]; i++)
     {
-        if (ACPI_COMPARE_NAMESEG (Name, ThisName->Info.Name))
+        if (ACPI_COMPARE_NAME (Name, ThisName->Info.Name))
         {
             /* Return index into predefined array */
             return (i);
@@ -592,7 +550,7 @@ ApCheckForPredefinedName (
     ThisName = AcpiGbl_ResourceNames;
     while (ThisName->Info.Name[0])
     {
-        if (ACPI_COMPARE_NAMESEG (Name, ThisName->Info.Name))
+        if (ACPI_COMPARE_NAME (Name, ThisName->Info.Name))
         {
             return (ACPI_PREDEFINED_NAME);
         }
@@ -603,7 +561,7 @@ ApCheckForPredefinedName (
     ThisName = AcpiGbl_ScopeNames;
     while (ThisName->Info.Name[0])
     {
-        if (ACPI_COMPARE_NAMESEG (Name, ThisName->Info.Name))
+        if (ACPI_COMPARE_NAME (Name, ThisName->Info.Name))
         {
             return (ACPI_PREDEFINED_NAME);
         }
@@ -666,7 +624,7 @@ ApCheckForSpecialName (
     {
         /* Ignore if actually emitted by the compiler */
 
-        if (Op->Asl.CompileFlags & OP_COMPILER_EMITTED)
+        if (Op->Asl.CompileFlags & NODE_COMPILER_EMITTED)
         {
             return (ACPI_NOT_RESERVED_NAME);
         }
@@ -674,13 +632,12 @@ ApCheckForSpecialName (
         /*
          * Was not actually emitted by the compiler. This is a special case,
          * however. If the ASL code being compiled was the result of a
-         * disassembly, it may possibly contain valid compiler-emitted names
+         * dissasembly, it may possibly contain valid compiler-emitted names
          * of the form "_T_x". We don't want to issue an error or even a
          * warning and force the user to manually change the names. So, we
          * will issue a remark instead.
          */
-        AslError (ASL_REMARK, ASL_MSG_COMPILER_RESERVED,
-            Op, Op->Asl.ExternalName);
+        AslError (ASL_REMARK, ASL_MSG_COMPILER_RESERVED, Op, Op->Asl.ExternalName);
         return (ACPI_COMPILER_RESERVED_NAME);
     }
 
@@ -689,8 +646,8 @@ ApCheckForSpecialName (
      * warning, since the entire namespace starting with an underscore is
      * reserved by the ACPI spec.
      */
-    AslError (ASL_WARNING, ASL_MSG_UNKNOWN_RESERVED_NAME,
-        Op, Op->Asl.ExternalName);
+    AslError (ASL_WARNING, ASL_MSG_UNKNOWN_RESERVED_NAME, Op,
+        Op->Asl.ExternalName);
 
     return (ACPI_NOT_RESERVED_NAME);
 }
@@ -739,53 +696,33 @@ ApCheckObjectType (
     case PARSEOP_ONE:
     case PARSEOP_ONES:
     case PARSEOP_INTEGER:
-
         ReturnBtype = ACPI_RTYPE_INTEGER;
         TypeName = "Integer";
         break;
 
     case PARSEOP_STRING_LITERAL:
-
         ReturnBtype = ACPI_RTYPE_STRING;
         TypeName = "String";
         break;
 
     case PARSEOP_BUFFER:
-
         ReturnBtype = ACPI_RTYPE_BUFFER;
         TypeName = "Buffer";
         break;
 
     case PARSEOP_PACKAGE:
     case PARSEOP_VAR_PACKAGE:
-
         ReturnBtype = ACPI_RTYPE_PACKAGE;
         TypeName = "Package";
         break;
 
     case PARSEOP_NAMESEG:
     case PARSEOP_NAMESTRING:
-        /*
-         * Ignore any named references within a package object.
-         *
-         * For Package objects, references are allowed instead of any of the
-         * standard data types (Integer/String/Buffer/Package). These
-         * references are resolved at runtime. NAMESEG and NAMESTRING are
-         * impossible to typecheck at compile time because the type of
-         * any named object can be changed at runtime (for example,
-         * CopyObject will change the type of the target object).
-         */
-        if (PackageIndex != ACPI_NOT_PACKAGE_ELEMENT)
-        {
-            return (AE_OK);
-        }
-
         ReturnBtype = ACPI_RTYPE_REFERENCE;
         TypeName = "Reference";
         break;
 
     default:
-
         /* Not one of the supported object types */
 
         TypeName = UtGetOpName (Op->Asl.ParseOpcode);
@@ -804,20 +741,20 @@ TypeErrorExit:
 
     /* Format the expected types and emit an error message */
 
-    AcpiUtGetExpectedReturnTypes (AslGbl_StringBuffer, ExpectedBtypes);
+    AcpiUtGetExpectedReturnTypes (StringBuffer, ExpectedBtypes);
 
     if (PackageIndex == ACPI_NOT_PACKAGE_ELEMENT)
     {
-        sprintf (AslGbl_MsgBuffer, "%4.4s: found %s, %s required",
-            PredefinedName, TypeName, AslGbl_StringBuffer);
+        sprintf (MsgBuffer, "%4.4s: found %s, %s required",
+            PredefinedName, TypeName, StringBuffer);
     }
     else
     {
-        sprintf (AslGbl_MsgBuffer, "%4.4s: found %s at index %u, %s required",
-            PredefinedName, TypeName, PackageIndex, AslGbl_StringBuffer);
+        sprintf (MsgBuffer, "%4.4s: found %s at index %u, %s required",
+            PredefinedName, TypeName, PackageIndex, StringBuffer);
     }
 
-    AslError (ASL_ERROR, ASL_MSG_RESERVED_OPERAND_TYPE, Op, AslGbl_MsgBuffer);
+    AslError (ASL_ERROR, ASL_MSG_RESERVED_OPERAND_TYPE, Op, MsgBuffer);
     return (AE_TYPE);
 }
 
@@ -853,7 +790,7 @@ ApDisplayReservedNames (
     ThisName = AcpiGbl_PredefinedMethods;
     while (ThisName->Info.Name[0])
     {
-        AcpiUtDisplayPredefinedMethod (AslGbl_MsgBuffer, ThisName, FALSE);
+        AcpiUtDisplayPredefinedMethod (MsgBuffer, ThisName, FALSE);
         Count++;
         ThisName = AcpiUtGetNextPredefinedMethod (ThisName);
     }
@@ -869,11 +806,11 @@ ApDisplayReservedNames (
     ThisName = AcpiGbl_ResourceNames;
     while (ThisName->Info.Name[0])
     {
-        NumTypes = AcpiUtGetResourceBitWidth (AslGbl_MsgBuffer,
+        NumTypes = AcpiUtGetResourceBitWidth (MsgBuffer,
             ThisName->Info.ArgumentList);
 
         printf ("%4.4s    Field is %s bits wide%s\n",
-            ThisName->Info.Name, AslGbl_MsgBuffer,
+            ThisName->Info.Name, MsgBuffer,
             (NumTypes > 1) ? " (depending on descriptor type)" : "");
 
         Count++;
