@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,10 +113,10 @@
  *
  *****************************************************************************/
 
+
 #include "aslcompiler.h"
 #include "aslcompiler.y.h"
 #include "acapps.h"
-#include "acconvert.h"
 #include <time.h>
 
 #define _COMPONENT          ACPI_COMPILER
@@ -128,28 +128,9 @@ static ACPI_PARSE_OBJECT *
 TrGetNextNode (
     void);
 
-
-/*******************************************************************************
- *
- * FUNCTION:    TrSetParent
- *
- * PARAMETERS:  Op                  - To be set to new parent
- *              ParentOp            - The parent
- *
- * RETURN:      None, sets Op parent directly
- *
- * DESCRIPTION: Change the parent of a parse op.
- *
- ******************************************************************************/
-
-void
-TrSetParent (
-    ACPI_PARSE_OBJECT       *Op,
-    ACPI_PARSE_OBJECT       *ParentOp)
-{
-
-    Op->Asl.Parent = ParentOp;
-}
+static char *
+TrGetNodeFlagName (
+    UINT32                  Flags);
 
 
 /*******************************************************************************
@@ -170,29 +151,15 @@ static ACPI_PARSE_OBJECT *
 TrGetNextNode (
     void)
 {
-    ASL_CACHE_INFO          *Cache;
 
-
-    if (Gbl_ParseOpCacheNext >= Gbl_ParseOpCacheLast)
+    if (Gbl_NodeCacheNext >= Gbl_NodeCacheLast)
     {
-        /* Allocate a new buffer */
-
-        Cache = UtLocalCalloc (sizeof (Cache->Next) +
-            (sizeof (ACPI_PARSE_OBJECT) * ASL_PARSEOP_CACHE_SIZE));
-
-        /* Link new cache buffer to head of list */
-
-        Cache->Next = Gbl_ParseOpCacheList;
-        Gbl_ParseOpCacheList = Cache;
-
-        /* Setup cache management pointers */
-
-        Gbl_ParseOpCacheNext = ACPI_CAST_PTR (ACPI_PARSE_OBJECT, Cache->Buffer);
-        Gbl_ParseOpCacheLast = Gbl_ParseOpCacheNext + ASL_PARSEOP_CACHE_SIZE;
+        Gbl_NodeCacheNext = UtLocalCalloc (sizeof (ACPI_PARSE_OBJECT) *
+                                ASL_NODE_CACHE_SIZE);
+        Gbl_NodeCacheLast = Gbl_NodeCacheNext + ASL_NODE_CACHE_SIZE;
     }
 
-    Gbl_ParseOpCount++;
-    return (Gbl_ParseOpCacheNext++);
+    return (Gbl_NodeCacheNext++);
 }
 
 
@@ -213,7 +180,6 @@ TrAllocateNode (
     UINT32                  ParseOpcode)
 {
     ACPI_PARSE_OBJECT       *Op;
-    ACPI_PARSE_OBJECT       *LatestNode;
 
 
     Op = TrGetNextNode ();
@@ -226,82 +192,6 @@ TrAllocateNode (
     Op->Asl.Column            = Gbl_CurrentColumn;
 
     UtSetParseOpName (Op);
-
-    /* The following is for capturing comments */
-
-    if(Gbl_CaptureComments)
-    {
-        LatestNode = Gbl_CommentState.Latest_Parse_Node;
-        Op->Asl.InlineComment     = NULL;
-        Op->Asl.EndNodeComment    = NULL;
-        Op->Asl.CommentList       = NULL;
-        Op->Asl.FileChanged       = FALSE;
-
-        /*
-         * Check to see if the file name has changed before resetting the
-         * latest parse node.
-         */
-        if (LatestNode &&
-            (ParseOpcode != PARSEOP_INCLUDE) &&
-            (ParseOpcode != PARSEOP_INCLUDE_END) &&
-            strcmp (LatestNode->Asl.Filename, Op->Asl.Filename))
-        {
-            CvDbgPrint ("latest node: %s\n", LatestNode->Asl.ParseOpName);
-            Op->Asl.FileChanged = TRUE;
-            if (Gbl_IncludeFileStack)
-            {
-                Op->Asl.ParentFilename = Gbl_IncludeFileStack->Filename;
-            }
-            else
-            {
-                Op->Asl.ParentFilename = NULL;
-            }
-        }
-
-        Gbl_CommentState.Latest_Parse_Node = Op;
-        if (Gbl_CommentState.Latest_Parse_Node->Asl.ParseOpName)
-        {
-            CvDbgPrint ("trallocatenode=Set latest parse node to this node.\n");
-            CvDbgPrint ("           Op->Asl.ParseOpName = %s\n",
-                Gbl_CommentState.Latest_Parse_Node->Asl.ParseOpName);
-            CvDbgPrint ("           Op->Asl.ParseOpcode = 0x%x\n", ParseOpcode);
-
-            if (Op->Asl.FileChanged)
-            {
-                CvDbgPrint("    file has been changed!\n");
-            }
-        }
-
-        /*
-         * if this parse op's syntax uses () and {} (i.e. Package(1){0x00}) then
-         * set a flag in the comment state. This facilitates paring comments for
-         * these types of opcodes.
-         */
-        if ((CvParseOpBlockType(Op) == (BLOCK_PAREN | BLOCK_BRACE)) &&
-            (ParseOpcode != PARSEOP_DEFINITION_BLOCK))
-        {
-            CvDbgPrint ("Parsing paren/Brace node now!\n");
-            Gbl_CommentState.ParsingParenBraceNode = Op;
-        }
-
-        if (Gbl_Comment_List_Head)
-        {
-            CvDbgPrint ("Transferring...\n");
-            Op->Asl.CommentList = Gbl_Comment_List_Head;
-            Gbl_Comment_List_Head = NULL;
-            Gbl_Comment_List_Tail = NULL;
-            CvDbgPrint ("    Transferred current comment list to this node.\n");
-            CvDbgPrint ("    %s\n", Op->Asl.CommentList->Comment);
-        }
-        if (Gbl_Inline_Comment_Buffer)
-        {
-            Op->Asl.InlineComment = Gbl_Inline_Comment_Buffer;
-            Gbl_Inline_Comment_Buffer = NULL;
-            CvDbgPrint ("Transferred current inline comment list to this node.\n");
-        }
-
-    }
-
     return (Op);
 }
 
@@ -328,32 +218,12 @@ TrReleaseNode (
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    TrSetCurrentFilename
- *
- * PARAMETERS:  Op                  - An existing parse node
- *
- * RETURN:      None
- *
- * DESCRIPTION: Save the include file filename. Used for debug output only.
- *
- ******************************************************************************/
-
-void
-TrSetCurrentFilename (
-    ACPI_PARSE_OBJECT       *Op)
-{
-    Op->Asl.Filename = Gbl_PreviousIncludeFilename;
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    TrUpdateNode
  *
  * PARAMETERS:  ParseOpcode         - New opcode to be assigned to the node
- *              Op                  - An existing parse node
+ *              Op                - An existing parse node
  *
  * RETURN:      The updated node
  *
@@ -376,7 +246,7 @@ TrUpdateNode (
     }
 
     DbgPrint (ASL_PARSE_OUTPUT,
-        "\nUpdateNode: Old - %s, New - %s\n",
+        "\nUpdateNode: Old - %s, New - %s\n\n",
         UtGetOpName (Op->Asl.ParseOpcode),
         UtGetOpName (ParseOpcode));
 
@@ -387,24 +257,20 @@ TrUpdateNode (
         switch (ParseOpcode)
         {
         case PARSEOP_BYTECONST:
-
             Op->Asl.Value.Integer = ACPI_UINT8_MAX;
             break;
 
         case PARSEOP_WORDCONST:
-
             Op->Asl.Value.Integer = ACPI_UINT16_MAX;
             break;
 
         case PARSEOP_DWORDCONST:
-
             Op->Asl.Value.Integer = ACPI_UINT32_MAX;
             break;
 
         /* Don't need to do the QWORD case */
 
         default:
-
             /* Don't care about others */
             break;
         }
@@ -420,182 +286,98 @@ TrUpdateNode (
     switch (ParseOpcode)
     {
     case PARSEOP_BYTECONST:
-
         UtCheckIntegerRange (Op, 0x00, ACPI_UINT8_MAX);
         Op->Asl.Value.Integer &= ACPI_UINT8_MAX;
         break;
 
     case PARSEOP_WORDCONST:
-
         UtCheckIntegerRange (Op, 0x00, ACPI_UINT16_MAX);
         Op->Asl.Value.Integer &= ACPI_UINT16_MAX;
         break;
 
     case PARSEOP_DWORDCONST:
-
         UtCheckIntegerRange (Op, 0x00, ACPI_UINT32_MAX);
         Op->Asl.Value.Integer &= ACPI_UINT32_MAX;
         break;
 
     default:
-
         /* Don't care about others, don't need to check QWORD */
-
         break;
     }
 
-    /* Converter: if this is a method invocation, turn off capture comments. */
-    if (Gbl_CaptureComments &&
-        (ParseOpcode == PARSEOP_METHODCALL))
-    {
-        Gbl_CommentState.CaptureComments = FALSE;
-    }
-
     return (Op);
 }
 
 
 /*******************************************************************************
  *
- * FUNCTION:    TrPrintNodeCompileFlags
+ * FUNCTION:    TrGetNodeFlagName
  *
  * PARAMETERS:  Flags               - Flags word to be decoded
  *
- * RETURN:      None
+ * RETURN:      Name string. Always returns a valid string pointer.
  *
- * DESCRIPTION: Decode a flags word to text. Displays all flags that are set.
+ * DESCRIPTION: Decode a flags word
  *
  ******************************************************************************/
 
-void
-TrPrintNodeCompileFlags (
+static char *
+TrGetNodeFlagName (
     UINT32                  Flags)
 {
-    UINT32                  i;
-    UINT32                  FlagBit = 1;
-    char                    *FlagName = NULL;
 
-
-    for (i = 0; i < 32; i++)
+    switch (Flags)
     {
-        switch (Flags & FlagBit)
-        {
-        case NODE_VISITED:
+    case NODE_VISITED:
+        return ("NODE_VISITED");
 
-            FlagName = "NODE_VISITED";
-            break;
+    case NODE_AML_PACKAGE:
+        return ("NODE_AML_PACKAGE");
 
-        case NODE_AML_PACKAGE:
+    case NODE_IS_TARGET:
+        return ("NODE_IS_TARGET");
 
-            FlagName = "NODE_AML_PACKAGE";
-            break;
+    case NODE_IS_RESOURCE_DESC:
+        return ("NODE_IS_RESOURCE_DESC");
 
-        case NODE_IS_TARGET:
+    case NODE_IS_RESOURCE_FIELD:
+        return ("NODE_IS_RESOURCE_FIELD");
 
-            FlagName = "NODE_IS_TARGET";
-            break;
+    case NODE_HAS_NO_EXIT:
+        return ("NODE_HAS_NO_EXIT");
 
-        case NODE_IS_RESOURCE_DESC:
+    case NODE_IF_HAS_NO_EXIT:
+        return ("NODE_IF_HAS_NO_EXIT");
 
-            FlagName = "NODE_IS_RESOURCE_DESC";
-            break;
+    case NODE_NAME_INTERNALIZED:
+        return ("NODE_NAME_INTERNALIZED");
 
-        case NODE_IS_RESOURCE_FIELD:
+    case NODE_METHOD_NO_RETVAL:
+        return ("NODE_METHOD_NO_RETVAL");
 
-            FlagName = "NODE_IS_RESOURCE_FIELD";
-            break;
+    case NODE_METHOD_SOME_NO_RETVAL:
+        return ("NODE_METHOD_SOME_NO_RETVAL");
 
-        case NODE_HAS_NO_EXIT:
+    case NODE_RESULT_NOT_USED:
+        return ("NODE_RESULT_NOT_USED");
 
-            FlagName = "NODE_HAS_NO_EXIT";
-            break;
+    case NODE_METHOD_TYPED:
+        return ("NODE_METHOD_TYPED");
 
-        case NODE_IF_HAS_NO_EXIT:
+    case NODE_COMPILE_TIME_CONST:
+        return ("NODE_COMPILE_TIME_CONST");
 
-            FlagName = "NODE_IF_HAS_NO_EXIT";
-            break;
+    case NODE_IS_TERM_ARG:
+        return ("NODE_IS_TERM_ARG");
 
-        case NODE_NAME_INTERNALIZED:
+    case NODE_WAS_ONES_OP:
+        return ("NODE_WAS_ONES_OP");
 
-            FlagName = "NODE_NAME_INTERNALIZED";
-            break;
+    case NODE_IS_NAME_DECLARATION:
+        return ("NODE_IS_NAME_DECLARATION");
 
-        case NODE_METHOD_NO_RETVAL:
-
-            FlagName = "NODE_METHOD_NO_RETVAL";
-            break;
-
-        case NODE_METHOD_SOME_NO_RETVAL:
-
-            FlagName = "NODE_METHOD_SOME_NO_RETVAL";
-            break;
-
-        case NODE_RESULT_NOT_USED:
-
-            FlagName = "NODE_RESULT_NOT_USED";
-            break;
-
-        case NODE_METHOD_TYPED:
-
-            FlagName = "NODE_METHOD_TYPED";
-            break;
-
-        case NODE_COULD_NOT_REDUCE:
-
-            FlagName = "NODE_COULD_NOT_REDUCE";
-            break;
-
-        case NODE_COMPILE_TIME_CONST:
-
-            FlagName = "NODE_COMPILE_TIME_CONST";
-            break;
-
-        case NODE_IS_TERM_ARG:
-
-            FlagName = "NODE_IS_TERM_ARG";
-            break;
-
-        case NODE_WAS_ONES_OP:
-
-            FlagName = "NODE_WAS_ONES_OP";
-            break;
-
-        case NODE_IS_NAME_DECLARATION:
-
-            FlagName = "NODE_IS_NAME_DECLARATION";
-            break;
-
-        case NODE_COMPILER_EMITTED:
-
-            FlagName = "NODE_COMPILER_EMITTED";
-            break;
-
-        case NODE_IS_DUPLICATE:
-
-            FlagName = "NODE_IS_DUPLICATE";
-            break;
-
-        case NODE_IS_RESOURCE_DATA:
-
-            FlagName = "NODE_IS_RESOURCE_DATA";
-            break;
-
-        case NODE_IS_NULL_RETURN:
-
-            FlagName = "NODE_IS_NULL_RETURN";
-            break;
-
-        default:
-            break;
-        }
-
-        if (FlagName)
-        {
-            DbgPrint (ASL_PARSE_OUTPUT, " %s", FlagName);
-            FlagName = NULL;
-        }
-
-        FlagBit <<= 1;
+    default:
+        return ("Multiple Flags (or unknown flag) set");
     }
 }
 
@@ -619,17 +401,15 @@ TrSetNodeFlags (
     UINT32                  Flags)
 {
 
+    DbgPrint (ASL_PARSE_OUTPUT,
+        "\nSetNodeFlags: Op %p, %8.8X %s\n\n", Op, Flags,
+        TrGetNodeFlagName (Flags));
+
     if (!Op)
     {
         return (NULL);
     }
 
-    DbgPrint (ASL_PARSE_OUTPUT,
-        "\nSetNodeFlags: %s Op %p, %8.8X", Op->Asl.ParseOpName, Op, Flags);
-
-    TrPrintNodeCompileFlags (Flags);
-    DbgPrint (ASL_PARSE_OUTPUT, "\n\n");
-
     Op->Asl.CompileFlags |= Flags;
     return (Op);
 }
@@ -694,130 +474,11 @@ TrSetEndLineNumber (
         return;
     }
 
-    Op->Asl.EndLine = Gbl_CurrentLineNumber;
+    Op->Asl.EndLine        = Gbl_CurrentLineNumber;
     Op->Asl.EndLogicalLine = Gbl_LogicalLineNumber;
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    TrCreateAssignmentNode
- *
- * PARAMETERS:  Target              - Assignment target
- *              Source              - Assignment source
- *
- * RETURN:      Pointer to the new node. Aborts on allocation failure
- *
- * DESCRIPTION: Implements the C-style '=' operator. It changes the parse
- *              tree if possible to utilize the last argument of the math
- *              operators which is a target operand -- thus saving invocation
- *              of and additional Store() operator. An optimization.
- *
- ******************************************************************************/
-
-ACPI_PARSE_OBJECT *
-TrCreateAssignmentNode (
-    ACPI_PARSE_OBJECT       *Target,
-    ACPI_PARSE_OBJECT       *Source)
-{
-    ACPI_PARSE_OBJECT       *TargetOp;
-    ACPI_PARSE_OBJECT       *SourceOp1;
-    ACPI_PARSE_OBJECT       *SourceOp2;
-    ACPI_PARSE_OBJECT       *Operator;
-
-
-    DbgPrint (ASL_PARSE_OUTPUT,
-        "\nTrCreateAssignmentNode  Line [%u to %u] Source %s Target %s\n",
-        Source->Asl.LineNumber, Source->Asl.EndLine,
-        UtGetOpName (Source->Asl.ParseOpcode),
-        UtGetOpName (Target->Asl.ParseOpcode));
-
-    TrSetNodeFlags (Target, NODE_IS_TARGET);
-
-    switch (Source->Asl.ParseOpcode)
-    {
-    /*
-     * Only these operators can be optimized because they have
-     * a target operand
-     */
-    case PARSEOP_ADD:
-    case PARSEOP_AND:
-    case PARSEOP_DIVIDE:
-    case PARSEOP_INDEX:
-    case PARSEOP_MOD:
-    case PARSEOP_MULTIPLY:
-    case PARSEOP_NOT:
-    case PARSEOP_OR:
-    case PARSEOP_SHIFTLEFT:
-    case PARSEOP_SHIFTRIGHT:
-    case PARSEOP_SUBTRACT:
-    case PARSEOP_XOR:
-
-        break;
-
-    /* Otherwise, just create a normal Store operator */
-
-    default:
-
-        goto CannotOptimize;
-    }
-
-    /*
-     * Transform the parse tree such that the target is moved to the
-     * last operand of the operator
-     */
-    SourceOp1 = Source->Asl.Child;
-    SourceOp2 = SourceOp1->Asl.Next;
-
-    /* NOT only has one operand, but has a target */
-
-    if (Source->Asl.ParseOpcode == PARSEOP_NOT)
-    {
-        SourceOp2 = SourceOp1;
-    }
-
-    /* DIVIDE has an extra target operand (remainder) */
-
-    if (Source->Asl.ParseOpcode == PARSEOP_DIVIDE)
-    {
-        SourceOp2 = SourceOp2->Asl.Next;
-    }
-
-    TargetOp = SourceOp2->Asl.Next;
-
-    /*
-     * Can't perform this optimization if there already is a target
-     * for the operator (ZERO is a "no target" placeholder).
-     */
-    if (TargetOp->Asl.ParseOpcode != PARSEOP_ZERO)
-    {
-        goto CannotOptimize;
-    }
-
-    /* Link in the target as the final operand */
-
-    SourceOp2->Asl.Next = Target;
-    Target->Asl.Parent = Source;
-
-    return (Source);
-
-
-CannotOptimize:
-
-    Operator = TrAllocateNode (PARSEOP_STORE);
-    TrLinkChildren (Operator, 2, Source, Target);
-
-    /* Set the appropriate line numbers for the new node */
-
-    Operator->Asl.LineNumber        = Target->Asl.LineNumber;
-    Operator->Asl.LogicalLineNumber = Target->Asl.LogicalLineNumber;
-    Operator->Asl.LogicalByteOffset = Target->Asl.LogicalByteOffset;
-    Operator->Asl.Column            = Target->Asl.Column;
-
-    return (Operator);
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    TrCreateLeafNode
@@ -842,40 +503,7 @@ TrCreateLeafNode (
 
     DbgPrint (ASL_PARSE_OUTPUT,
         "\nCreateLeafNode  Ln/Col %u/%u NewNode %p  Op %s\n\n",
-        Op->Asl.LineNumber, Op->Asl.Column, Op, UtGetOpName (ParseOpcode));
-
-    return (Op);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    TrCreateNullTarget
- *
- * PARAMETERS:  None
- *
- * RETURN:      Pointer to the new node. Aborts on allocation failure
- *
- * DESCRIPTION: Create a "null" target node. This is defined by the ACPI
- *              specification to be a zero AML opcode, and indicates that
- *              no target has been specified for the parent operation
- *
- ******************************************************************************/
-
-ACPI_PARSE_OBJECT *
-TrCreateNullTarget (
-    void)
-{
-    ACPI_PARSE_OBJECT       *Op;
-
-
-    Op = TrAllocateNode (PARSEOP_ZERO);
-    Op->Asl.CompileFlags |= (NODE_IS_TARGET | NODE_COMPILE_TIME_CONST);
-
-    DbgPrint (ASL_PARSE_OUTPUT,
-        "\nCreateNullTarget  Ln/Col %u/%u NewNode %p  Op %s\n",
-        Op->Asl.LineNumber, Op->Asl.Column, Op,
-        UtGetOpName (Op->Asl.ParseOpcode));
+        Op->Asl.LineNumber, Op->Asl.Column, Op, UtGetOpName(ParseOpcode));
 
     return (Op);
 }
@@ -907,19 +535,18 @@ TrCreateConstantLeafNode (
     time_t                  CurrentTime;
     char                    *StaticTimeString;
     char                    *TimeString;
+    char                    *Path;
     char                    *Filename;
 
 
     switch (ParseOpcode)
     {
     case PARSEOP___LINE__:
-
         Op = TrAllocateNode (PARSEOP_INTEGER);
         Op->Asl.Value.Integer = Op->Asl.LineNumber;
         break;
 
     case PARSEOP___PATH__:
-
         Op = TrAllocateNode (PARSEOP_STRING_LITERAL);
 
         /* Op.Asl.Filename contains the full pathname to the file */
@@ -928,17 +555,16 @@ TrCreateConstantLeafNode (
         break;
 
     case PARSEOP___FILE__:
-
         Op = TrAllocateNode (PARSEOP_STRING_LITERAL);
 
         /* Get the simple filename from the full path */
 
-        FlSplitInputPathname (Op->Asl.Filename, NULL, &Filename);
+        FlSplitInputPathname (Op->Asl.Filename, &Path, &Filename);
+        ACPI_FREE (Path);
         Op->Asl.Value.String = Filename;
         break;
 
     case PARSEOP___DATE__:
-
         Op = TrAllocateNode (PARSEOP_STRING_LITERAL);
 
         /* Get a copy of the current time */
@@ -953,94 +579,17 @@ TrCreateConstantLeafNode (
         break;
 
     default: /* This would be an internal error */
-
         return (NULL);
     }
 
     DbgPrint (ASL_PARSE_OUTPUT,
-        "\nCreateConstantLeafNode  Ln/Col %u/%u NewNode %p  "
-        "Op %s  Value %8.8X%8.8X  \n",
+        "\nCreateConstantLeafNode  Ln/Col %u/%u NewNode %p  Op %s  Value %8.8X%8.8X  ",
         Op->Asl.LineNumber, Op->Asl.Column, Op, UtGetOpName (ParseOpcode),
         ACPI_FORMAT_UINT64 (Op->Asl.Value.Integer));
     return (Op);
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    TrCreateTargetOperand
- *
- * PARAMETERS:  OriginalOp          - Op to be copied
- *
- * RETURN:      Pointer to the new node. Aborts on allocation failure
- *
- * DESCRIPTION: Copy an existing node (and subtree). Used in ASL+ (C-style)
- *              expressions where the target is the same as one of the
- *              operands. A new node and subtree must be created from the
- *              original so that the parse tree can be linked properly.
- *
- * NOTE:        This code is specific to target operands that are the last
- *              operand in an ASL/AML operator. Meaning that the top-level
- *              parse Op in a possible subtree has a NULL Next pointer.
- *              This simplifies the recursion.
- *
- *              Subtree example:
- *                  DeRefOf (Local1) += 32
- *
- *              This gets converted to:
- *                  Add (DeRefOf (Local1), 32, DeRefOf (Local1))
- *
- *              Each DeRefOf has a single child, Local1. Even more complex
- *              subtrees can be created via the Index and DeRefOf operators.
- *
- ******************************************************************************/
-
-ACPI_PARSE_OBJECT *
-TrCreateTargetOperand (
-    ACPI_PARSE_OBJECT       *OriginalOp,
-    ACPI_PARSE_OBJECT       *ParentOp)
-{
-    ACPI_PARSE_OBJECT       *Op;
-
-
-    if (!OriginalOp)
-    {
-        return (NULL);
-    }
-
-    Op = TrGetNextNode ();
-
-    /* Copy the pertinent values (omit link pointer fields) */
-
-    Op->Asl.Value               = OriginalOp->Asl.Value;
-    Op->Asl.Filename            = OriginalOp->Asl.Filename;
-    Op->Asl.LineNumber          = OriginalOp->Asl.LineNumber;
-    Op->Asl.LogicalLineNumber   = OriginalOp->Asl.LogicalLineNumber;
-    Op->Asl.LogicalByteOffset   = OriginalOp->Asl.LogicalByteOffset;
-    Op->Asl.Column              = OriginalOp->Asl.Column;
-    Op->Asl.Flags               = OriginalOp->Asl.Flags;
-    Op->Asl.CompileFlags        = OriginalOp->Asl.CompileFlags;
-    Op->Asl.AmlOpcode           = OriginalOp->Asl.AmlOpcode;
-    Op->Asl.ParseOpcode         = OriginalOp->Asl.ParseOpcode;
-    Op->Asl.Parent              = ParentOp;
-    UtSetParseOpName (Op);
-
-    /* Copy a possible subtree below this node */
-
-    if (OriginalOp->Asl.Child)
-    {
-        Op->Asl.Child = TrCreateTargetOperand (OriginalOp->Asl.Child, Op);
-    }
-
-    if (OriginalOp->Asl.Next) /* Null for top-level node */
-    {
-        Op->Asl.Next = TrCreateTargetOperand (OriginalOp->Asl.Next, ParentOp);
-    }
-
-    return (Op);
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    TrCreateValuedLeafNode
@@ -1066,8 +615,7 @@ TrCreateValuedLeafNode (
     Op = TrAllocateNode (ParseOpcode);
 
     DbgPrint (ASL_PARSE_OUTPUT,
-        "\nCreateValuedLeafNode  Ln/Col %u/%u NewNode %p  "
-        "Op %s  Value %8.8X%8.8X  ",
+        "\nCreateValuedLeafNode  Ln/Col %u/%u NewNode %p  Op %s  Value %8.8X%8.8X  ",
         Op->Asl.LineNumber, Op->Asl.Column, Op, UtGetOpName(ParseOpcode),
         ACPI_FORMAT_UINT64 (Value));
     Op->Asl.Value.Integer = Value;
@@ -1075,38 +623,30 @@ TrCreateValuedLeafNode (
     switch (ParseOpcode)
     {
     case PARSEOP_STRING_LITERAL:
-
         DbgPrint (ASL_PARSE_OUTPUT, "STRING->%s", Value);
         break;
 
     case PARSEOP_NAMESEG:
-
         DbgPrint (ASL_PARSE_OUTPUT, "NAMESEG->%s", Value);
         break;
 
     case PARSEOP_NAMESTRING:
-
         DbgPrint (ASL_PARSE_OUTPUT, "NAMESTRING->%s", Value);
         break;
 
     case PARSEOP_EISAID:
-
         DbgPrint (ASL_PARSE_OUTPUT, "EISAID->%s", Value);
         break;
 
     case PARSEOP_METHOD:
-
         DbgPrint (ASL_PARSE_OUTPUT, "METHOD");
         break;
 
     case PARSEOP_INTEGER:
-
-        DbgPrint (ASL_PARSE_OUTPUT, "INTEGER->%8.8X%8.8X",
-            ACPI_FORMAT_UINT64 (Value));
+        DbgPrint (ASL_PARSE_OUTPUT, "INTEGER");
         break;
 
     default:
-
         break;
     }
 
@@ -1153,39 +693,27 @@ TrCreateNode (
 
     DbgPrint (ASL_PARSE_OUTPUT,
         "\nCreateNode  Ln/Col %u/%u NewParent %p Child %u Op %s  ",
-        Op->Asl.LineNumber, Op->Asl.Column, Op,
-        NumChildren, UtGetOpName(ParseOpcode));
+        Op->Asl.LineNumber, Op->Asl.Column, Op, NumChildren, UtGetOpName(ParseOpcode));
 
     /* Some extra debug output based on the parse opcode */
 
     switch (ParseOpcode)
     {
-    case PARSEOP_ASL_CODE:
-
-        Gbl_ParseTreeRoot = Op;
-        Op->Asl.ParseOpcode = PARSEOP_DEFAULT_ARG;
-        DbgPrint (ASL_PARSE_OUTPUT, "ASLCODE (Tree Completed)->");
-        break;
-
-    case PARSEOP_DEFINITION_BLOCK:
-
+    case PARSEOP_DEFINITIONBLOCK:
+        RootNode = Op;
         DbgPrint (ASL_PARSE_OUTPUT, "DEFINITION_BLOCK (Tree Completed)->");
         break;
 
     case PARSEOP_OPERATIONREGION:
-
         DbgPrint (ASL_PARSE_OUTPUT, "OPREGION->");
         break;
 
     case PARSEOP_OR:
-
         DbgPrint (ASL_PARSE_OUTPUT, "OR->");
         break;
 
     default:
-
         /* Nothing to do for other opcodes */
-
         break;
     }
 
@@ -1217,39 +745,6 @@ TrCreateNode (
         {
             FirstChild = FALSE;
             Op->Asl.Child = Child;
-
-            /*
-             * For the ASL-/ASL+ converter: if the ParseOp is a connection,
-             * external, offset or accessAs, it means that the comments in the
-             * FirstChild belongs to their parent due to the parsing order in
-             * the .y files. To correct this, take the comments in the
-             * FirstChild place it in the parent. This also means that
-             * legitimate comments for the child gets put to the parent.
-             */
-            if (Gbl_CaptureComments &&
-                ((ParseOpcode == PARSEOP_CONNECTION) ||
-                 (ParseOpcode == PARSEOP_EXTERNAL) ||
-                 (ParseOpcode == PARSEOP_OFFSET) ||
-                 (ParseOpcode == PARSEOP_ACCESSAS)))
-            {
-                Op->Asl.CommentList      = Child->Asl.CommentList;
-                Op->Asl.EndBlkComment    = Child->Asl.EndBlkComment;
-                Op->Asl.InlineComment    = Child->Asl.InlineComment;
-                Op->Asl.FileChanged      = Child->Asl.FileChanged;
-
-                Child->Asl.CommentList   = NULL;
-                Child->Asl.EndBlkComment = NULL;
-                Child->Asl.InlineComment = NULL;
-                Child->Asl.FileChanged   = FALSE;
-
-                /*
-                 * These do not need to be "passed off". They can be copied
-                 * because the code for these opcodes should be printed in the
-                 * same file.
-                 */
-                Op->Asl.Filename         = Child->Asl.Filename;
-                Op->Asl.ParentFilename   = Child->Asl.ParentFilename;
-            }
         }
 
         /* Point all children to parent */
@@ -1263,18 +758,6 @@ TrCreateNode (
             PrevChild->Asl.Next = Child;
         };
 
-        /* Get the comment from last child in the resource template call */
-
-        if (Gbl_CaptureComments &&
-            (Op->Asl.ParseOpcode == PARSEOP_RESOURCETEMPLATE))
-        {
-            CvDbgPrint ("Transferred current comment list to this node.\n");
-            Op->Asl.CommentList = Child->Asl.CommentList;
-            Child->Asl.CommentList = NULL;
-            Op->Asl.InlineComment = Child->Asl.InlineComment;
-            Child->Asl.InlineComment = NULL;
-        }
-
         /*
          * This child might be a list, point all nodes in the list
          * to the same parent
@@ -1289,7 +772,7 @@ TrCreateNode (
     }
     va_end(ap);
 
-    DbgPrint (ASL_PARSE_OUTPUT, "\n");
+    DbgPrint (ASL_PARSE_OUTPUT, "\n\n");
     return (Op);
 }
 
@@ -1299,9 +782,9 @@ TrCreateNode (
  * FUNCTION:    TrLinkChildren
  *
  * PARAMETERS:  Op                - An existing parse node
- *              NumChildren        - Number of children to follow
- *              ...                - A list of child nodes to link to the new
- *                                   node. NumChildren long.
+ *              NumChildren         - Number of children to follow
+ *              ...                 - A list of child nodes to link to the new
+ *                                    node. NumChildren long.
  *
  * RETURN:      The updated (linked) node
  *
@@ -1334,54 +817,24 @@ TrLinkChildren (
 
     switch (Op->Asl.ParseOpcode)
     {
-    case PARSEOP_ASL_CODE:
-
-        Gbl_ParseTreeRoot = Op;
-        Op->Asl.ParseOpcode = PARSEOP_DEFAULT_ARG;
-        DbgPrint (ASL_PARSE_OUTPUT, "ASLCODE (Tree Completed)->");
-        break;
-
-    case PARSEOP_DEFINITION_BLOCK:
-
+    case PARSEOP_DEFINITIONBLOCK:
+        RootNode = Op;
         DbgPrint (ASL_PARSE_OUTPUT, "DEFINITION_BLOCK (Tree Completed)->");
         break;
 
     case PARSEOP_OPERATIONREGION:
-
         DbgPrint (ASL_PARSE_OUTPUT, "OPREGION->");
         break;
 
     case PARSEOP_OR:
-
         DbgPrint (ASL_PARSE_OUTPUT, "OR->");
         break;
 
     default:
-
         /* Nothing to do for other opcodes */
-
         break;
     }
 
-    /* The following is for capturing comments */
-
-    if(Gbl_CaptureComments)
-    {
-        /*
-         * If there are "regular comments" detected at this point,
-         * then is an endBlk comment. Categorize it as so and distribute
-         * all regular comments to this parse node.
-         */
-        if (Gbl_Comment_List_Head)
-        {
-            Op->Asl.EndBlkComment = Gbl_Comment_List_Head;
-            CvDbgPrint ("EndBlk Comment for %s: %s",
-                Op->Asl.ParseOpName, Gbl_Comment_List_Head->Comment);
-            Gbl_Comment_List_Head = NULL;
-            Gbl_Comment_List_Tail = NULL;
-        }
-    }
-
     /* Link the new node to it's children */
 
     PrevChild = NULL;
@@ -1394,7 +847,6 @@ TrLinkChildren (
         {
             AslError (ASL_WARNING, ASL_MSG_COMPILER_INTERNAL, Child,
                 "Child node list invalid");
-            va_end(ap);
             return (Op);
         }
 
@@ -1439,19 +891,11 @@ TrLinkChildren (
             Child = Child->Asl.Next;
             Child->Asl.Parent = Op;
         }
-
         PrevChild = Child;
     }
-
     va_end(ap);
+
     DbgPrint (ASL_PARSE_OUTPUT, "\n\n");
-
-
-    if(Gbl_CaptureComments)
-    {
-        Gbl_CommentState.Latest_Parse_Node = Op;
-        CvDbgPrint ("trlinkchildren=====Set latest parse node to this node.\n");
-    }
     return (Op);
 }
 
@@ -1478,7 +922,7 @@ TrLinkPeerNode (
 
 
     DbgPrint (ASL_PARSE_OUTPUT,
-        "\nLinkPeerNode: 1=%p (%s), 2=%p (%s)\n",
+        "\nLinkPeerNode: 1=%p (%s), 2=%p (%s)\n\n",
         Op1, Op1 ? UtGetOpName(Op1->Asl.ParseOpcode) : NULL,
         Op2, Op2 ? UtGetOpName(Op2->Asl.ParseOpcode) : NULL);
 
@@ -1504,7 +948,7 @@ TrLinkPeerNode (
     if (Op1 == Op2)
     {
         DbgPrint (ASL_DEBUG_OUTPUT,
-            "\n************* Internal error, linking node to itself %p\n",
+            "\n\n************* Internal error, linking node to itself %p\n\n\n",
             Op1);
         AslError (ASL_WARNING, ASL_MSG_COMPILER_INTERNAL, Op1,
             "Linking node to itself");
@@ -1588,7 +1032,7 @@ TrLinkPeerNodes (
     }
     va_end (ap);
 
-    DbgPrint (ASL_PARSE_OUTPUT,"\n");
+    DbgPrint (ASL_PARSE_OUTPUT,"\n\n");
     return (Start);
 }
 
@@ -1615,23 +1059,10 @@ TrLinkChildNode (
 
 
     DbgPrint (ASL_PARSE_OUTPUT,
-        "\nLinkChildNode: Parent=%p (%s), Child=%p (%s)\n",
+        "\nLinkChildNode: Parent=%p (%s), Child=%p (%s)\n\n",
         Op1, Op1 ? UtGetOpName(Op1->Asl.ParseOpcode): NULL,
         Op2, Op2 ? UtGetOpName(Op2->Asl.ParseOpcode): NULL);
 
-    /*
-     * Converter: if TrLinkChildNode is called to link a method call,
-     * turn on capture comments as it signifies that we are done parsing
-     * a method call.
-     */
-    if (Gbl_CaptureComments)
-    {
-        if (Op1->Asl.ParseOpcode == PARSEOP_METHODCALL)
-        {
-            Gbl_CommentState.CaptureComments = TRUE;
-        }
-        Gbl_CommentState.Latest_Parse_Node = Op1;
-    }
     if (!Op1 || !Op2)
     {
         return (Op1);
@@ -1681,7 +1112,7 @@ TrWalkParseTree (
     ACPI_STATUS             Status;
 
 
-    if (!Gbl_ParseTreeRoot)
+    if (!RootNode)
     {
         return (AE_OK);
     }
@@ -1747,6 +1178,7 @@ TrWalkParseTree (
         }
         break;
 
+
     case ASL_WALK_VISIT_UPWARD:
 
         while (Op)
@@ -1801,6 +1233,7 @@ TrWalkParseTree (
         }
         break;
 
+
      case ASL_WALK_VISIT_TWICE:
 
         while (Op)
