@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,44 +111,9 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+
 #include "aslcompiler.h"
 #include "aslcompiler.y.h"
 #include "acparser.h"
@@ -159,13 +124,6 @@
         ACPI_MODULE_NAME    ("aslwalks")
 
 
-/* Local prototypes */
-
-static void
-AnAnalyzeStoreOperator (
-    ACPI_PARSE_OBJECT       *Op);
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AnMethodTypingWalkEnd
@@ -188,14 +146,14 @@ AnMethodTypingWalkEnd (
     UINT32                  Level,
     void                    *Context)
 {
-    UINT32                  ThisOpBtype;
+    UINT32                  ThisNodeBtype;
 
 
     switch (Op->Asl.ParseOpcode)
     {
     case PARSEOP_METHOD:
 
-        Op->Asl.CompileFlags |= OP_METHOD_TYPED;
+        Op->Asl.CompileFlags |= NODE_METHOD_TYPED;
         break;
 
     case PARSEOP_RETURN:
@@ -203,21 +161,18 @@ AnMethodTypingWalkEnd (
         if ((Op->Asl.Child) &&
             (Op->Asl.Child->Asl.ParseOpcode != PARSEOP_DEFAULT_ARG))
         {
-            ThisOpBtype = AnGetBtype (Op->Asl.Child);
+            ThisNodeBtype = AnGetBtype (Op->Asl.Child);
 
             if ((Op->Asl.Child->Asl.ParseOpcode == PARSEOP_METHODCALL) &&
-                (ThisOpBtype == (ACPI_UINT32_MAX -1)))
+                (ThisNodeBtype == (ACPI_UINT32_MAX -1)))
             {
                 /*
                  * The called method is untyped at this time (typically a
                  * forward reference).
                  *
-                 * Check for a recursive method call first. Note: the
-                 * Child->Node will be null if the method has not been
-                 * resolved.
+                 * Check for a recursive method call first.
                  */
-                if (Op->Asl.Child->Asl.Node &&
-                    (Op->Asl.ParentMethod != Op->Asl.Child->Asl.Node->Op))
+                if (Op->Asl.ParentMethod != Op->Asl.Child->Asl.Node->Op)
                 {
                     /* We must type the method here */
 
@@ -225,7 +180,7 @@ AnMethodTypingWalkEnd (
                         ASL_WALK_VISIT_UPWARD, NULL,
                         AnMethodTypingWalkEnd, NULL);
 
-                    ThisOpBtype = AnGetBtype (Op->Asl.Child);
+                    ThisNodeBtype = AnGetBtype (Op->Asl.Child);
                 }
             }
 
@@ -233,13 +188,12 @@ AnMethodTypingWalkEnd (
 
             if (Op->Asl.ParentMethod)
             {
-                Op->Asl.ParentMethod->Asl.AcpiBtype |= ThisOpBtype;
+                Op->Asl.ParentMethod->Asl.AcpiBtype |= ThisNodeBtype;
             }
         }
         break;
 
     default:
-
         break;
     }
 
@@ -294,7 +248,6 @@ AnOperandTypecheckWalkEnd (
         return (AE_OK);
 
     default:
-
         break;
     }
 
@@ -304,9 +257,9 @@ AnOperandTypecheckWalkEnd (
         return (AE_OK);
     }
 
-    ArgOp = Op->Asl.Child;
-    OpcodeClass = OpInfo->Class;
+    ArgOp           = Op->Asl.Child;
     RuntimeArgTypes = OpInfo->RuntimeArgs;
+    OpcodeClass     = OpInfo->Class;
 
 #ifdef ASL_ERROR_NAMED_OBJECT_IN_WHILE
     /*
@@ -365,21 +318,12 @@ AnOperandTypecheckWalkEnd (
             {
                 return (AE_OK);
             }
-
             AnCheckMethodReturnValue (Op, OpInfo, ArgOp,
                 RequiredBtypes, ThisNodeBtype);
         }
         return (AE_OK);
 
-    case AML_EXTERNAL_OP:
-        /*
-         * Not really a "runtime" opcode since it used by disassembler only.
-         * The parser will find any issues with the operands.
-         */
-        return (AE_OK);
-
     default:
-
         break;
     }
 
@@ -390,70 +334,6 @@ AnOperandTypecheckWalkEnd (
         return (AE_OK);
     }
 
-    /*
-     * Special handling for certain opcodes.
-     */
-    switch (Op->Asl.AmlOpcode)
-    {
-        /* BankField has one TermArg */
-
-    case AML_BANK_FIELD_OP:
-
-        OpcodeClass = AML_CLASS_EXECUTE;
-        ArgOp = ArgOp->Asl.Next;
-        ArgOp = ArgOp->Asl.Next;
-        break;
-
-        /* Operation Region has 2 TermArgs */
-
-    case AML_REGION_OP:
-
-        OpcodeClass = AML_CLASS_EXECUTE;
-        ArgOp = ArgOp->Asl.Next;
-        ArgOp = ArgOp->Asl.Next;
-        break;
-
-        /* DataTableRegion has 3 TermArgs */
-
-    case AML_DATA_REGION_OP:
-
-        OpcodeClass = AML_CLASS_EXECUTE;
-        ArgOp = ArgOp->Asl.Next;
-        break;
-
-        /* Buffers/Packages have a length that is a TermArg */
-
-    case AML_BUFFER_OP:
-    case AML_PACKAGE_OP:
-    case AML_VARIABLE_PACKAGE_OP:
-
-            /* If length is a constant, we are done */
-
-        if ((ArgOp->Asl.ParseOpcode == PARSEOP_INTEGER) ||
-            (ArgOp->Asl.ParseOpcode == PARSEOP_RAW_DATA))
-        {
-            return (AE_OK);
-        }
-        break;
-
-        /* Store can write any object to the Debug object */
-
-    case AML_STORE_OP:
-        /*
-         * If this is a Store() to the Debug object, we don't need
-         * to perform any further validation -- because a Store of
-         * any object to Debug is permitted and supported.
-         */
-        if (ArgOp->Asl.Next->Asl.AmlOpcode == AML_DEBUG_OP)
-        {
-            return (AE_OK);
-        }
-        break;
-
-    default:
-        break;
-    }
-
     switch (OpcodeClass)
     {
     case AML_CLASS_EXECUTE:
@@ -461,6 +341,15 @@ AnOperandTypecheckWalkEnd (
     case AML_CLASS_CONTROL:
     case AML_CLASS_RETURN_VALUE:
 
+        /* TBD: Change class or fix typechecking for these */
+
+        if ((Op->Asl.AmlOpcode == AML_BUFFER_OP)        ||
+            (Op->Asl.AmlOpcode == AML_PACKAGE_OP)       ||
+            (Op->Asl.AmlOpcode == AML_VAR_PACKAGE_OP))
+        {
+            break;
+        }
+
         /* Reverse the runtime argument list */
 
         RuntimeArgTypes2 = 0;
@@ -471,23 +360,10 @@ AnOperandTypecheckWalkEnd (
             INCREMENT_ARG_LIST (RuntimeArgTypes);
         }
 
-        /* Typecheck each argument */
-
         while ((ArgType = GET_CURRENT_ARG_TYPE (RuntimeArgTypes2)))
         {
-            /* Get the required type(s) for the argument */
-
             RequiredBtypes = AnMapArgTypeToBtype (ArgType);
 
-            if (!ArgOp)
-            {
-                AslError (ASL_ERROR, ASL_MSG_COMPILER_INTERNAL, Op,
-                    "Null ArgOp in argument loop");
-                AslAbort ();
-            }
-
-            /* Get the actual type of the argument */
-
             ThisNodeBtype = AnGetBtype (ArgOp);
             if (ThisNodeBtype == ACPI_UINT32_MAX)
             {
@@ -508,10 +384,6 @@ AnOperandTypecheckWalkEnd (
                     break;
                 }
 
-            /* Fallthrough */
-
-            case ARGI_STORE_TARGET:
-
                 if (ArgOp->Asl.ParseOpcode == PARSEOP_INTEGER)
                 {
                     /*
@@ -523,22 +395,25 @@ AnOperandTypecheckWalkEnd (
                     if ((ArgOp->Asl.Node->Type == ACPI_TYPE_LOCAL_RESOURCE_FIELD) ||
                         (ArgOp->Asl.Node->Type == ACPI_TYPE_LOCAL_RESOURCE))
                     {
-                        AslError (ASL_ERROR, ASL_MSG_RESOURCE_FIELD,
-                            ArgOp, NULL);
+                        AslError (ASL_ERROR, ASL_MSG_RESOURCE_FIELD, ArgOp, NULL);
                     }
                     else
                     {
-                        AslError (ASL_ERROR, ASL_MSG_INVALID_TYPE,
-                            ArgOp, NULL);
+                        AslError (ASL_ERROR, ASL_MSG_INVALID_TYPE, ArgOp, NULL);
                     }
+                    break;
                 }
+
+                if ((ArgOp->Asl.ParseOpcode == PARSEOP_METHODCALL) ||
+                    (ArgOp->Asl.ParseOpcode == PARSEOP_DEREFOF))
+                {
+                    break;
+                }
+
+                ThisNodeBtype = RequiredBtypes;
                 break;
 
 
-#ifdef __FUTURE_IMPLEMENTATION
-/*
- * Possible future typechecking support
- */
             case ARGI_REFERENCE:            /* References */
             case ARGI_INTEGER_REF:
             case ARGI_OBJECT_REF:
@@ -569,30 +444,29 @@ AnOperandTypecheckWalkEnd (
                 case PARSEOP_ARG5:
                 case PARSEOP_ARG6:
 
-                    /* Hard to analyze argument types, so we won't */
-                    /* for now. Just treat any arg as a typematch */
+                    /* Hard to analyze argument types, sow we won't */
+                    /* For now, just treat any arg as a typematch */
 
                     /* ThisNodeBtype = RequiredBtypes; */
                     break;
 
                 case PARSEOP_DEBUG:
+                    break;
+
                 case PARSEOP_REFOF:
                 case PARSEOP_INDEX:
                 default:
-
                     break;
+
                 }
                 break;
-#endif
+
             case ARGI_INTEGER:
             default:
-
                 break;
             }
 
 
-            /* Check for a type mismatch (required versus actual) */
-
             CommonBtypes = ThisNodeBtype & RequiredBtypes;
 
             if (ArgOp->Asl.ParseOpcode == PARSEOP_METHODCALL)
@@ -616,14 +490,13 @@ AnOperandTypecheckWalkEnd (
             {
                 /* No match -- this is a type mismatch error */
 
-                AnFormatBtype (AslGbl_StringBuffer, ThisNodeBtype);
-                AnFormatBtype (AslGbl_StringBuffer2, RequiredBtypes);
+                AnFormatBtype (StringBuffer, ThisNodeBtype);
+                AnFormatBtype (StringBuffer2, RequiredBtypes);
 
-                sprintf (AslGbl_MsgBuffer, "[%s] found, %s operator requires [%s]",
-                    AslGbl_StringBuffer, OpInfo->Name, AslGbl_StringBuffer2);
+                sprintf (MsgBuffer, "[%s] found, %s operator requires [%s]",
+                            StringBuffer, OpInfo->Name, StringBuffer2);
 
-                AslError (ASL_ERROR, ASL_MSG_INVALID_TYPE,
-                    ArgOp, AslGbl_MsgBuffer);
+                AslError (ASL_ERROR, ASL_MSG_INVALID_TYPE, ArgOp, MsgBuffer);
             }
 
         NextArgument:
@@ -633,7 +506,6 @@ AnOperandTypecheckWalkEnd (
         break;
 
     default:
-
         break;
     }
 
@@ -660,15 +532,14 @@ AnOtherSemanticAnalysisWalkBegin (
     UINT32                  Level,
     void                    *Context)
 {
-    ACPI_PARSE_OBJECT       *ArgOp;
-    ACPI_PARSE_OBJECT       *PrevArgOp = NULL;
+    ACPI_PARSE_OBJECT       *ArgNode;
+    ACPI_PARSE_OBJECT       *PrevArgNode = NULL;
     const ACPI_OPCODE_INFO  *OpInfo;
     ACPI_NAMESPACE_NODE     *Node;
 
 
     OpInfo = AcpiPsGetOpcodeInfo (Op->Asl.AmlOpcode);
 
-
     /*
      * Determine if an execution class operator actually does something by
      * checking if it has a target and/or the function return value is used.
@@ -681,31 +552,30 @@ AnOtherSemanticAnalysisWalkBegin (
         if (OpInfo->Flags & AML_HAS_TARGET)
         {
             /*
-             * Find the target node, it is always the last child. If the target
+             * Find the target node, it is always the last child. If the traget
              * is not specified in the ASL, a default node of type Zero was
              * created by the parser.
              */
-            ArgOp = Op->Asl.Child;
-            while (ArgOp->Asl.Next)
+            ArgNode = Op->Asl.Child;
+            while (ArgNode->Asl.Next)
             {
-                PrevArgOp = ArgOp;
-                ArgOp = ArgOp->Asl.Next;
+                PrevArgNode = ArgNode;
+                ArgNode = ArgNode->Asl.Next;
             }
 
             /* Divide() is the only weird case, it has two targets */
 
             if (Op->Asl.AmlOpcode == AML_DIVIDE_OP)
             {
-                if ((ArgOp->Asl.ParseOpcode == PARSEOP_ZERO) &&
-                    (PrevArgOp) &&
-                    (PrevArgOp->Asl.ParseOpcode == PARSEOP_ZERO))
+                if ((ArgNode->Asl.ParseOpcode == PARSEOP_ZERO) &&
+                    (PrevArgNode) &&
+                    (PrevArgNode->Asl.ParseOpcode == PARSEOP_ZERO))
                 {
                     AslError (ASL_ERROR, ASL_MSG_RESULT_NOT_USED,
                         Op, Op->Asl.ExternalName);
                 }
             }
-
-            else if (ArgOp->Asl.ParseOpcode == PARSEOP_ZERO)
+            else if (ArgNode->Asl.ParseOpcode == PARSEOP_ZERO)
             {
                 AslError (ASL_ERROR, ASL_MSG_RESULT_NOT_USED,
                     Op, Op->Asl.ExternalName);
@@ -722,11 +592,9 @@ AnOtherSemanticAnalysisWalkBegin (
             case PARSEOP_ACQUIRE:
             case PARSEOP_WAIT:
             case PARSEOP_LOADTABLE:
-
                 break;
 
             default:
-
                 AslError (ASL_ERROR, ASL_MSG_RESULT_NOT_USED,
                     Op, Op->Asl.ExternalName);
                 break;
@@ -740,15 +608,6 @@ AnOtherSemanticAnalysisWalkBegin (
      */
     switch (Op->Asl.ParseOpcode)
     {
-    case PARSEOP_STORE:
-
-        if (AslGbl_DoTypechecking)
-        {
-            AnAnalyzeStoreOperator (Op);
-        }
-        break;
-
-
     case PARSEOP_ACQUIRE:
     case PARSEOP_WAIT:
         /*
@@ -760,16 +619,16 @@ AnOtherSemanticAnalysisWalkBegin (
 
         /* First child is the namepath, 2nd child is timeout */
 
-        ArgOp = Op->Asl.Child;
-        ArgOp = ArgOp->Asl.Next;
+        ArgNode = Op->Asl.Child;
+        ArgNode = ArgNode->Asl.Next;
 
         /*
          * Check for the WAIT_FOREVER case - defined by the ACPI spec to be
          * 0xFFFF or greater
          */
-        if (((ArgOp->Asl.ParseOpcode == PARSEOP_WORDCONST) ||
-             (ArgOp->Asl.ParseOpcode == PARSEOP_INTEGER))  &&
-             (ArgOp->Asl.Value.Integer >= (UINT64) ACPI_WAIT_FOREVER))
+        if (((ArgNode->Asl.ParseOpcode == PARSEOP_WORDCONST) ||
+             (ArgNode->Asl.ParseOpcode == PARSEOP_INTEGER))  &&
+             (ArgNode->Asl.Value.Integer >= (UINT64) ACPI_WAIT_FOREVER))
         {
             break;
         }
@@ -780,7 +639,7 @@ AnOtherSemanticAnalysisWalkBegin (
          */
         if (!AnIsResultUsed (Op))
         {
-            AslError (ASL_WARNING, ASL_MSG_TIMEOUT, ArgOp,
+            AslError (ASL_WARNING, ASL_MSG_TIMEOUT, ArgNode,
                 Op->Asl.ExternalName);
         }
         break;
@@ -789,15 +648,15 @@ AnOtherSemanticAnalysisWalkBegin (
         /*
          * Check for a zero Length (NumBits) operand. NumBits is the 3rd operand
          */
-        ArgOp = Op->Asl.Child;
-        ArgOp = ArgOp->Asl.Next;
-        ArgOp = ArgOp->Asl.Next;
+        ArgNode = Op->Asl.Child;
+        ArgNode = ArgNode->Asl.Next;
+        ArgNode = ArgNode->Asl.Next;
 
-        if ((ArgOp->Asl.ParseOpcode == PARSEOP_ZERO) ||
-           ((ArgOp->Asl.ParseOpcode == PARSEOP_INTEGER) &&
-            (ArgOp->Asl.Value.Integer == 0)))
+        if ((ArgNode->Asl.ParseOpcode == PARSEOP_ZERO) ||
+           ((ArgNode->Asl.ParseOpcode == PARSEOP_INTEGER) &&
+            (ArgNode->Asl.Value.Integer == 0)))
         {
-            AslError (ASL_ERROR, ASL_MSG_NON_ZERO, ArgOp, NULL);
+            AslError (ASL_ERROR, ASL_MSG_NON_ZERO, ArgNode, NULL);
         }
         break;
 
@@ -806,24 +665,20 @@ AnOtherSemanticAnalysisWalkBegin (
          * Ensure that the referenced operation region has the correct SPACE_ID.
          * From the grammar/parser, we know the parent is a FIELD definition.
          */
-        ArgOp = Op->Asl.Parent;     /* Field definition */
-        ArgOp = ArgOp->Asl.Child;   /* First child is the OpRegion Name */
-        Node = ArgOp->Asl.Node;     /* OpRegion namespace node */
-        if (!Node)
-        {
-            break;
-        }
+        ArgNode = Op->Asl.Parent;       /* Field definition */
+        ArgNode = ArgNode->Asl.Child;   /* First child is the OpRegion Name */
+        Node = ArgNode->Asl.Node;       /* OpRegion namespace node */
 
-        ArgOp = Node->Op;           /* OpRegion definition */
-        ArgOp = ArgOp->Asl.Child;   /* First child is the OpRegion Name */
-        ArgOp = ArgOp->Asl.Next;    /* Next peer is the SPACE_ID (what we want) */
+        ArgNode = Node->Op;             /* OpRegion definition */
+        ArgNode = ArgNode->Asl.Child;   /* First child is the OpRegion Name */
+        ArgNode = ArgNode->Asl.Next;    /* Next peer is the SPACE_ID (what we want) */
 
         /*
          * The Connection() operator is only valid for the following operation
          * region SpaceIds: GeneralPurposeIo and GenericSerialBus.
          */
-        if ((ArgOp->Asl.Value.Integer != ACPI_ADR_SPACE_GPIO) &&
-            (ArgOp->Asl.Value.Integer != ACPI_ADR_SPACE_GSBUS))
+        if ((ArgNode->Asl.Value.Integer != ACPI_ADR_SPACE_GPIO) &&
+            (ArgNode->Asl.Value.Integer != ACPI_ADR_SPACE_GSBUS))
         {
             AslError (ASL_ERROR, ASL_MSG_CONNECTION_INVALID, Op, NULL);
         }
@@ -834,241 +689,52 @@ AnOtherSemanticAnalysisWalkBegin (
          * Ensure that fields for GeneralPurposeIo and GenericSerialBus
          * contain at least one Connection() operator
          */
-        ArgOp = Op->Asl.Child;      /* 1st child is the OpRegion Name */
-        Node = ArgOp->Asl.Node;     /* OpRegion namespace node */
+        ArgNode = Op->Asl.Child;        /* 1st child is the OpRegion Name */
+        Node = ArgNode->Asl.Node;       /* OpRegion namespace node */
         if (!Node)
         {
             break;
         }
 
-        ArgOp = Node->Op;           /* OpRegion definition */
-        ArgOp = ArgOp->Asl.Child;   /* First child is the OpRegion Name */
-        ArgOp = ArgOp->Asl.Next;    /* Next peer is the SPACE_ID (what we want) */
+        ArgNode = Node->Op;             /* OpRegion definition */
+        ArgNode = ArgNode->Asl.Child;   /* First child is the OpRegion Name */
+        ArgNode = ArgNode->Asl.Next;    /* Next peer is the SPACE_ID (what we want) */
 
         /* We are only interested in GeneralPurposeIo and GenericSerialBus */
 
-        if ((ArgOp->Asl.Value.Integer != ACPI_ADR_SPACE_GPIO) &&
-            (ArgOp->Asl.Value.Integer != ACPI_ADR_SPACE_GSBUS))
+        if ((ArgNode->Asl.Value.Integer != ACPI_ADR_SPACE_GPIO) &&
+            (ArgNode->Asl.Value.Integer != ACPI_ADR_SPACE_GSBUS))
         {
             break;
         }
 
-        ArgOp = Op->Asl.Child;      /* 1st child is the OpRegion Name */
-        ArgOp = ArgOp->Asl.Next;    /* AccessType */
-        ArgOp = ArgOp->Asl.Next;    /* LockRule */
-        ArgOp = ArgOp->Asl.Next;    /* UpdateRule */
-        ArgOp = ArgOp->Asl.Next;    /* Start of FieldUnitList */
+        ArgNode = Op->Asl.Child;        /* 1st child is the OpRegion Name */
+        ArgNode = ArgNode->Asl.Next;    /* AccessType */
+        ArgNode = ArgNode->Asl.Next;    /* LockRule */
+        ArgNode = ArgNode->Asl.Next;    /* UpdateRule */
+        ArgNode = ArgNode->Asl.Next;    /* Start of FieldUnitList */
 
         /* Walk the FieldUnitList */
 
-        while (ArgOp)
+        while (ArgNode)
         {
-            if (ArgOp->Asl.ParseOpcode == PARSEOP_CONNECTION)
+            if (ArgNode->Asl.ParseOpcode == PARSEOP_CONNECTION)
             {
                 break;
             }
-            else if (ArgOp->Asl.ParseOpcode == PARSEOP_NAMESEG)
+            else if (ArgNode->Asl.ParseOpcode == PARSEOP_NAMESEG)
             {
-                AslError (ASL_ERROR, ASL_MSG_CONNECTION_MISSING, ArgOp, NULL);
+                AslError (ASL_ERROR, ASL_MSG_CONNECTION_MISSING, ArgNode, NULL);
                 break;
             }
 
-            ArgOp = ArgOp->Asl.Next;
+            ArgNode = ArgNode->Asl.Next;
         }
         break;
 
     default:
-
         break;
     }
 
     return (AE_OK);
 }
-
-
-/*******************************************************************************
- *
- * FUNCTION:    AnAnalyzeStoreOperator
- *
- * PARAMETERS:  Op                  - Store() operator
- *
- * RETURN:      None
- *
- * DESCRIPTION: Analyze a store operator. Mostly for stores to/from package
- *              objects where there are more restrictions than other data
- *              types.
- *
- ******************************************************************************/
-
-static void
-AnAnalyzeStoreOperator (
-    ACPI_PARSE_OBJECT       *Op)
-{
-    ACPI_NAMESPACE_NODE     *SourceNode;
-    ACPI_NAMESPACE_NODE     *TargetNode;
-    ACPI_PARSE_OBJECT       *SourceOperandOp;
-    ACPI_PARSE_OBJECT       *TargetOperandOp;
-    UINT32                  SourceOperandBtype;
-    UINT32                  TargetOperandBtype;
-
-
-    /* Extract the two operands for STORE */
-
-    SourceOperandOp = Op->Asl.Child;
-    TargetOperandOp = SourceOperandOp->Asl.Next;
-
-    /*
-     * Ignore these Source operand opcodes, they cannot be typechecked,
-     * the actual result is unknown here.
-     */
-    switch (SourceOperandOp->Asl.ParseOpcode)
-    {
-    /* For these, type of the returned value is unknown at compile time */
-
-    case PARSEOP_DEREFOF:
-    case PARSEOP_METHODCALL:
-    case PARSEOP_STORE:
-    case PARSEOP_COPYOBJECT:
-
-        return;
-
-    case PARSEOP_INDEX:
-    case PARSEOP_REFOF:
-
-        if (!AslGbl_EnableReferenceTypechecking)
-        {
-            return;
-        }
-
-        /*
-         * These opcodes always return an object reference, and thus
-         * the result can only be stored to a Local, Arg, or Debug.
-         */
-        if (TargetOperandOp->Asl.AmlOpcode == AML_DEBUG_OP)
-        {
-            return;
-        }
-
-        if ((TargetOperandOp->Asl.AmlOpcode < AML_LOCAL0) ||
-            (TargetOperandOp->Asl.AmlOpcode > AML_ARG6))
-        {
-            AslError (ASL_ERROR, ASL_MSG_INVALID_TYPE, TargetOperandOp,
-                "Source [Reference], Target must be [Local/Arg/Debug]");
-        }
-        return;
-
-    default:
-        break;
-    }
-
-    /*
-     * Ignore these Target operand opcodes, they cannot be typechecked
-     */
-    switch (TargetOperandOp->Asl.ParseOpcode)
-    {
-    case PARSEOP_DEBUG:
-    case PARSEOP_DEREFOF:
-    case PARSEOP_REFOF:
-    case PARSEOP_INDEX:
-    case PARSEOP_STORE:
-
-        return;
-
-    default:
-        break;
-    }
-
-    /*
-     * Ignore typecheck for External() operands of type "UnknownObj",
-     * we don't know the actual type (source or target).
-     */
-    SourceNode = SourceOperandOp->Asl.Node;
-    if (SourceNode &&
-        (SourceNode->Flags & ANOBJ_IS_EXTERNAL) &&
-        (SourceNode->Type == ACPI_TYPE_ANY))
-    {
-        return;
-    }
-
-    TargetNode = TargetOperandOp->Asl.Node;
-    if (TargetNode &&
-        (TargetNode->Flags & ANOBJ_IS_EXTERNAL) &&
-        (TargetNode->Type == ACPI_TYPE_ANY))
-    {
-        return;
-    }
-
-    /*
-     * A NULL node with a namepath AML opcode indicates non-existent
-     * name. Just return, the error message is generated elsewhere.
-     */
-    if ((!SourceNode && (SourceOperandOp->Asl.AmlOpcode == AML_INT_NAMEPATH_OP)) ||
-        (!TargetNode && (TargetOperandOp->Asl.AmlOpcode == AML_INT_NAMEPATH_OP)))
-    {
-        return;
-    }
-
-    /*
-     * Simple check for source same as target via NS node.
-     * -- Could be expanded to locals and args.
-     */
-    if (SourceNode && TargetNode)
-    {
-        if (SourceNode == TargetNode)
-        {
-            AslError (ASL_WARNING, ASL_MSG_DUPLICATE_ITEM,
-                TargetOperandOp, "Source is the same as Target");
-            return;
-        }
-    }
-
-    /* Ignore typecheck if either source or target is a local or arg */
-
-    if ((SourceOperandOp->Asl.AmlOpcode >= AML_LOCAL0) &&
-        (SourceOperandOp->Asl.AmlOpcode <= AML_ARG6))
-    {
-        return; /* Cannot type a local/arg at compile time */
-    }
-
-    if ((TargetOperandOp->Asl.AmlOpcode >= AML_LOCAL0) &&
-        (TargetOperandOp->Asl.AmlOpcode <= AML_ARG6))
-    {
-        return; /* Cannot type a local/arg at compile time */
-    }
-
-    /*
-     * Package objects are a special case because they cannot by implicitly
-     * converted to/from anything. Check for these two illegal cases:
-     *
-     *      Store (non-package, package)
-     *      Store (package, non-package)
-     */
-    SourceOperandBtype = AnGetBtype (SourceOperandOp);
-    TargetOperandBtype = AnGetBtype (TargetOperandOp);
-
-    /* Check source first for (package, non-package) case */
-
-    if (SourceOperandBtype & ACPI_BTYPE_PACKAGE)
-    {
-        /* If Source is PACKAGE-->Target must be PACKAGE */
-
-        if (!(TargetOperandBtype & ACPI_BTYPE_PACKAGE))
-        {
-            AslError (ASL_ERROR, ASL_MSG_INVALID_TYPE, TargetOperandOp,
-                "Source is [Package], Target must be a package also");
-        }
-    }
-
-    /* Else check target for (non-package, package) case */
-
-    else if (TargetOperandBtype & ACPI_BTYPE_PACKAGE)
-    {
-        /* If Target is PACKAGE, Source must be PACKAGE */
-
-        if (!(SourceOperandBtype & ACPI_BTYPE_PACKAGE))
-        {
-            AslError (ASL_ERROR, ASL_MSG_INVALID_TYPE, SourceOperandOp,
-                "Target is [Package], Source must be a package also");
-        }
-    }
-}
