@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,10 +113,12 @@
  *
  *****************************************************************************/
 
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acdebug.h"
 
+#ifdef ACPI_DEBUGGER
 
 #define _COMPONENT          ACPI_CA_DEBUGGER
         ACPI_MODULE_NAME    ("dbhistry")
@@ -124,12 +126,12 @@
 
 #define HI_NO_HISTORY       0
 #define HI_RECORD_HISTORY   1
-#define HISTORY_SIZE        40
+#define HISTORY_SIZE        20
 
 
 typedef struct HistoryInfo
 {
-    char                    *Command;
+    char                    Command[80];
     UINT32                  CmdNum;
 
 } HISTORY_INFO;
@@ -139,7 +141,7 @@ static HISTORY_INFO         AcpiGbl_HistoryBuffer[HISTORY_SIZE];
 static UINT16               AcpiGbl_LoHistory = 0;
 static UINT16               AcpiGbl_NumHistory = 0;
 static UINT16               AcpiGbl_NextHistoryIndex = 0;
-UINT32                      AcpiGbl_NextCmdNum = 1;
+static UINT32               AcpiGbl_NextCmdNum = 1;
 
 
 /*******************************************************************************
@@ -158,41 +160,13 @@ void
 AcpiDbAddToHistory (
     char                    *CommandLine)
 {
-    UINT16                  CmdLen;
-    UINT16                  BufferLen;
 
     /* Put command into the next available slot */
 
-    CmdLen = (UINT16) strlen (CommandLine);
-    if (!CmdLen)
-    {
-        return;
-    }
-
-    if (AcpiGbl_HistoryBuffer[AcpiGbl_NextHistoryIndex].Command != NULL)
-    {
-        BufferLen = (UINT16) strlen (
-            AcpiGbl_HistoryBuffer[AcpiGbl_NextHistoryIndex].Command);
-
-        if (CmdLen > BufferLen)
-        {
-            AcpiOsFree (AcpiGbl_HistoryBuffer[AcpiGbl_NextHistoryIndex].
-                Command);
-            AcpiGbl_HistoryBuffer[AcpiGbl_NextHistoryIndex].Command =
-                AcpiOsAllocate (CmdLen + 1);
-        }
-    }
-    else
-    {
-        AcpiGbl_HistoryBuffer[AcpiGbl_NextHistoryIndex].Command =
-            AcpiOsAllocate (CmdLen + 1);
-    }
-
-    strcpy (AcpiGbl_HistoryBuffer[AcpiGbl_NextHistoryIndex].Command,
+    ACPI_STRCPY (AcpiGbl_HistoryBuffer[AcpiGbl_NextHistoryIndex].Command,
         CommandLine);
 
-    AcpiGbl_HistoryBuffer[AcpiGbl_NextHistoryIndex].CmdNum =
-        AcpiGbl_NextCmdNum;
+    AcpiGbl_HistoryBuffer[AcpiGbl_NextHistoryIndex].CmdNum = AcpiGbl_NextCmdNum;
 
     /* Adjust indexes */
 
@@ -246,12 +220,8 @@ AcpiDbDisplayHistory (
 
     for (i = 0; i < AcpiGbl_NumHistory; i++)
     {
-        if (AcpiGbl_HistoryBuffer[HistoryIndex].Command)
-        {
-            AcpiOsPrintf ("%3ld  %s\n",
-                AcpiGbl_HistoryBuffer[HistoryIndex].CmdNum,
-                AcpiGbl_HistoryBuffer[HistoryIndex].Command);
-        }
+        AcpiOsPrintf ("%ld  %s\n", AcpiGbl_HistoryBuffer[HistoryIndex].CmdNum,
+                                   AcpiGbl_HistoryBuffer[HistoryIndex].Command);
 
         HistoryIndex++;
         if (HistoryIndex >= HISTORY_SIZE)
@@ -279,6 +249,8 @@ char *
 AcpiDbGetFromHistory (
     char                    *CommandNumArg)
 {
+    UINT32                  i;
+    UINT16                  HistoryIndex;
     UINT32                  CmdNum;
 
 
@@ -289,34 +261,9 @@ AcpiDbGetFromHistory (
 
     else
     {
-        CmdNum = strtoul (CommandNumArg, NULL, 0);
+        CmdNum = ACPI_STRTOUL (CommandNumArg, NULL, 0);
     }
 
-    return (AcpiDbGetHistoryByIndex (CmdNum));
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDbGetHistoryByIndex
- *
- * PARAMETERS:  CmdNum              - Index of the desired history entry.
- *                                    Values are 0...(AcpiGbl_NextCmdNum - 1)
- *
- * RETURN:      Pointer to the retrieved command. Null on error.
- *
- * DESCRIPTION: Get a command from the history buffer
- *
- ******************************************************************************/
-
-char *
-AcpiDbGetHistoryByIndex (
-    UINT32                  CmdNum)
-{
-    UINT32                  i;
-    UINT16                  HistoryIndex;
-
-
     /* Search history buffer */
 
     HistoryIndex = AcpiGbl_LoHistory;
@@ -324,12 +271,11 @@ AcpiDbGetHistoryByIndex (
     {
         if (AcpiGbl_HistoryBuffer[HistoryIndex].CmdNum == CmdNum)
         {
-            /* Found the command, return it */
+            /* Found the commnad, return it */
 
             return (AcpiGbl_HistoryBuffer[HistoryIndex].Command);
         }
 
-        /* History buffer is circular */
 
         HistoryIndex++;
         if (HistoryIndex >= HISTORY_SIZE)
@@ -341,3 +287,5 @@ AcpiDbGetHistoryByIndex (
     AcpiOsPrintf ("Invalid history number: %u\n", HistoryIndex);
     return (NULL);
 }
+
+#endif /* ACPI_DEBUGGER */
