@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,7 @@
  *
  *****************************************************************************/
 
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acnamesp.h"
@@ -242,7 +243,8 @@ AcpiDbSetScope (
             goto ErrorExit;
         }
 
-        AcpiGbl_DbScopeBuf[0] = 0;
+        ACPI_STRCPY (AcpiGbl_DbScopeBuf, Name);
+        ACPI_STRCAT (AcpiGbl_DbScopeBuf, "\\");
     }
     else
     {
@@ -254,22 +256,9 @@ AcpiDbSetScope (
         {
             goto ErrorExit;
         }
-    }
 
-    /* Build the final pathname */
-
-    if (AcpiUtSafeStrcat (AcpiGbl_DbScopeBuf, sizeof (AcpiGbl_DbScopeBuf),
-        Name))
-    {
-        Status = AE_BUFFER_OVERFLOW;
-        goto ErrorExit;
-    }
-
-    if (AcpiUtSafeStrcat (AcpiGbl_DbScopeBuf, sizeof (AcpiGbl_DbScopeBuf),
-        "\\"))
-    {
-        Status = AE_BUFFER_OVERFLOW;
-        goto ErrorExit;
+        ACPI_STRCAT (AcpiGbl_DbScopeBuf, Name);
+        ACPI_STRCAT (AcpiGbl_DbScopeBuf, "\\");
     }
 
     AcpiGbl_DbScopeNode = Node;
@@ -337,37 +326,6 @@ AcpiDbDumpNamespace (
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDbDumpNamespacePaths
- *
- * PARAMETERS:  None
- *
- * RETURN:      None
- *
- * DESCRIPTION: Dump entire namespace with full object pathnames and object
- *              type information. Alternative to "namespace" command.
- *
- ******************************************************************************/
-
-void
-AcpiDbDumpNamespacePaths (
-    void)
-{
-
-    AcpiDbSetOutputDestination (ACPI_DB_DUPLICATE_OUTPUT);
-    AcpiOsPrintf ("ACPI Namespace (from root):\n");
-
-    /* Display the entire namespace */
-
-    AcpiDbSetOutputDestination (ACPI_DB_REDIRECTABLE_OUTPUT);
-    AcpiNsDumpObjectPaths (ACPI_TYPE_ANY, ACPI_DISPLAY_SUMMARY,
-        ACPI_UINT32_MAX, ACPI_OWNER_ID_MAX, AcpiGbl_RootNode);
-
-    AcpiDbSetOutputDestination (ACPI_DB_CONSOLE_OUTPUT);
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AcpiDbDumpNamespaceByOwner
@@ -785,7 +743,7 @@ AcpiDbIntegrityWalk (
         return (AE_OK);
     }
 
-    if (!AcpiUtValidAcpiName (Node->Name.Ascii))
+    if (!AcpiUtValidAcpiName (Node->Name.Integer))
     {
         AcpiOsPrintf ("Invalid AcpiName for Node %p\n", Node);
         return (AE_OK);
@@ -897,13 +855,11 @@ AcpiDbFindReferences (
     char                    *ObjectArg)
 {
     ACPI_OPERAND_OBJECT     *ObjDesc;
-    ACPI_SIZE               Address;
 
 
     /* Convert string to object pointer */
 
-    Address = ACPI_STRTOUL (ObjectArg, NULL, 16);
-    ObjDesc = ACPI_TO_POINTER (Address);
+    ObjDesc = ACPI_TO_POINTER (ACPI_STRTOUL (ObjectArg, NULL, 16));
 
     /* Search all nodes in namespace */
 
