@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2016, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,16 +113,19 @@
  *
  *****************************************************************************/
 
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acnamesp.h"
 #include "acdebug.h"
+#include "acdisasm.h"
 
 
+#ifdef ACPI_DEBUGGER
+
 #define _COMPONENT          ACPI_CA_DEBUGGER
         ACPI_MODULE_NAME    ("dbutils")
 
-
 /* Local prototypes */
 
 #ifdef ACPI_OBSOLETE_FUNCTIONS
@@ -135,6 +138,8 @@ AcpiDbDumpBuffer (
     UINT32                  Address);
 #endif
 
+static char                 *Converter = "0123456789ABCDEF";
+
 
 /*******************************************************************************
  *
@@ -164,9 +169,7 @@ AcpiDbMatchArgument (
 
     for (i = 0; Arguments[i].Name; i++)
     {
-        if (strstr (
-            ACPI_CAST_PTR (char, Arguments[i].Name),
-            ACPI_CAST_PTR (char, UserArgument)) == Arguments[i].Name)
+        if (ACPI_STRSTR (Arguments[i].Name, UserArgument) == Arguments[i].Name)
         {
             return (i);
         }
@@ -198,8 +201,7 @@ AcpiDbSetOutputDestination (
 
     AcpiGbl_DbOutputFlags = (UINT8) OutputFlags;
 
-    if ((OutputFlags & ACPI_DB_REDIRECTABLE_OUTPUT) &&
-        AcpiGbl_DbOutputToFile)
+    if ((OutputFlags & ACPI_DB_REDIRECTABLE_OUTPUT) && AcpiGbl_DbOutputToFile)
     {
         AcpiDbgLevel = AcpiGbl_DbDebugLevel;
     }
@@ -249,12 +251,14 @@ AcpiDbDumpExternalObject (
         AcpiOsPrintf ("[Null Object] (Type=0)\n");
         break;
 
+
     case ACPI_TYPE_INTEGER:
 
         AcpiOsPrintf ("[Integer] = %8.8X%8.8X\n",
-            ACPI_FORMAT_UINT64 (ObjDesc->Integer.Value));
+                    ACPI_FORMAT_UINT64 (ObjDesc->Integer.Value));
         break;
 
+
     case ACPI_TYPE_STRING:
 
         AcpiOsPrintf ("[String] Length %.2X = ", ObjDesc->String.Length);
@@ -262,6 +266,7 @@ AcpiDbDumpExternalObject (
         AcpiOsPrintf ("\n");
         break;
 
+
     case ACPI_TYPE_BUFFER:
 
         AcpiOsPrintf ("[Buffer] Length %.2X = ", ObjDesc->Buffer.Length);
@@ -271,10 +276,8 @@ AcpiDbDumpExternalObject (
             {
                 AcpiOsPrintf ("\n");
             }
-
-            AcpiUtDebugDumpBuffer (
-                ACPI_CAST_PTR (UINT8, ObjDesc->Buffer.Pointer),
-                ObjDesc->Buffer.Length, DB_BYTE_DISPLAY, _COMPONENT);
+            AcpiUtDebugDumpBuffer (ACPI_CAST_PTR (UINT8, ObjDesc->Buffer.Pointer),
+                    ObjDesc->Buffer.Length, DB_BYTE_DISPLAY, _COMPONENT);
         }
         else
         {
@@ -282,34 +285,38 @@ AcpiDbDumpExternalObject (
         }
         break;
 
+
     case ACPI_TYPE_PACKAGE:
 
         AcpiOsPrintf ("[Package] Contains %u Elements:\n",
-            ObjDesc->Package.Count);
+                ObjDesc->Package.Count);
 
         for (i = 0; i < ObjDesc->Package.Count; i++)
         {
-            AcpiDbDumpExternalObject (
-                &ObjDesc->Package.Elements[i], Level+1);
+            AcpiDbDumpExternalObject (&ObjDesc->Package.Elements[i], Level+1);
         }
         break;
 
+
     case ACPI_TYPE_LOCAL_REFERENCE:
 
         AcpiOsPrintf ("[Object Reference] = ");
-        AcpiDbDisplayInternalObject (ObjDesc->Reference.Handle, NULL);
+        AcpiDmDisplayInternalObject (ObjDesc->Reference.Handle, NULL);
         break;
 
+
     case ACPI_TYPE_PROCESSOR:
 
         AcpiOsPrintf ("[Processor]\n");
         break;
 
+
     case ACPI_TYPE_POWER:
 
         AcpiOsPrintf ("[Power Resource]\n");
         break;
 
+
     default:
 
         AcpiOsPrintf ("[Unknown Type] %X\n", ObjDesc->Type);
@@ -410,13 +417,12 @@ AcpiDbLocalNsLookup (
      * Lookup the name.
      * (Uses root node as the search starting point)
      */
-    Status = AcpiNsLookup (NULL, InternalPath, ACPI_TYPE_ANY,
-        ACPI_IMODE_EXECUTE, ACPI_NS_NO_UPSEARCH | ACPI_NS_DONT_OPEN_SCOPE,
-        NULL, &Node);
+    Status = AcpiNsLookup (NULL, InternalPath, ACPI_TYPE_ANY, ACPI_IMODE_EXECUTE,
+                    ACPI_NS_NO_UPSEARCH | ACPI_NS_DONT_OPEN_SCOPE, NULL, &Node);
     if (ACPI_FAILURE (Status))
     {
         AcpiOsPrintf ("Could not locate name: %s, %s\n",
-            Name, AcpiFormatException (Status));
+                Name, AcpiFormatException (Status));
     }
 
     ACPI_FREE (InternalPath);
@@ -450,7 +456,7 @@ AcpiDbUint32ToHexString (
 
     if (Value == 0)
     {
-        strcpy (Buffer, "0");
+        ACPI_STRCPY (Buffer, "0");
         return;
     }
 
@@ -458,7 +464,7 @@ AcpiDbUint32ToHexString (
 
     for (i = 7; i >= 0; i--)
     {
-        Buffer[i] = AcpiGbl_UpperHexDigits [Value & 0x0F];
+        Buffer[i] = Converter [Value & 0x0F];
         Value = Value >> 4;
     }
 }
@@ -580,6 +586,8 @@ AcpiDbDumpBuffer (
 
     AcpiDbgLevel |= ACPI_LV_TABLES;
     AcpiUtDebugDumpBuffer (ACPI_TO_POINTER (Address), 64, DB_BYTE_DISPLAY,
-        ACPI_UINT32_MAX);
+            ACPI_UINT32_MAX);
 }
 #endif
+
+#endif /* ACPI_DEBUGGER */
