@@ -9,7 +9,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2022, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -112,50 +112,15 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+#define __DSCONTROL_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "amlcode.h"
 #include "acdispat.h"
 #include "acinterp.h"
-#include "acdebug.h"
 
 #define _COMPONENT          ACPI_DISPATCHER
         ACPI_MODULE_NAME    ("dscontrol")
@@ -193,6 +158,7 @@ AcpiDsExecBeginControlOp (
     switch (Op->Common.AmlOpcode)
     {
     case AML_WHILE_OP:
+
         /*
          * If this is an additional iteration of a while loop, continue.
          * There is no need to allocate a new control state.
@@ -210,9 +176,10 @@ AcpiDsExecBeginControlOp (
             }
         }
 
-        ACPI_FALLTHROUGH;
+        /*lint -fallthrough */
 
     case AML_IF_OP:
+
         /*
          * IF/WHILE: Create a new control state to manage these
          * constructs. We need to manage these as a stack, in order
@@ -228,14 +195,10 @@ AcpiDsExecBeginControlOp (
          * Save a pointer to the predicate for multiple executions
          * of a loop
          */
-        ControlState->Control.AmlPredicateStart =
-            WalkState->ParserState.Aml - 1;
-        ControlState->Control.PackageEnd =
-            WalkState->ParserState.PkgEnd;
-        ControlState->Control.Opcode =
-            Op->Common.AmlOpcode;
-        ControlState->Control.LoopTimeout = AcpiOsGetTimer () +
-           ((UINT64) AcpiGbl_MaxLoopIterations * ACPI_100NSEC_PER_SEC);
+        ControlState->Control.AmlPredicateStart = WalkState->ParserState.Aml - 1;
+        ControlState->Control.PackageEnd = WalkState->ParserState.PkgEnd;
+        ControlState->Control.Opcode = Op->Common.AmlOpcode;
+
 
         /* Push the control state on this walk's control stack */
 
@@ -259,7 +222,6 @@ AcpiDsExecBeginControlOp (
         break;
 
     default:
-
         break;
     }
 
@@ -314,10 +276,12 @@ AcpiDsExecEndControlOp (
         AcpiUtDeleteGenericState (ControlState);
         break;
 
+
     case AML_ELSE_OP:
 
         break;
 
+
     case AML_WHILE_OP:
 
         ACPI_DEBUG_PRINT ((ACPI_DB_DISPATCH, "[WHILE_OP] Op=%p\n", Op));
@@ -328,15 +292,15 @@ AcpiDsExecEndControlOp (
             /* Predicate was true, the body of the loop was just executed */
 
             /*
-             * This infinite loop detection mechanism allows the interpreter
-             * to escape possibly infinite loops. This can occur in poorly
-             * written AML when the hardware does not respond within a while
-             * loop and the loop does not implement a timeout.
+             * This loop counter mechanism allows the interpreter to escape
+             * possibly infinite loops. This can occur in poorly written AML
+             * when the hardware does not respond within a while loop and the
+             * loop does not implement a timeout.
              */
-            if (ACPI_TIME_AFTER (AcpiOsGetTimer (),
-                    ControlState->Control.LoopTimeout))
+            ControlState->Control.LoopCount++;
+            if (ControlState->Control.LoopCount > ACPI_MAX_LOOP_ITERATIONS)
             {
-                Status = AE_AML_LOOP_TIMEOUT;
+                Status = AE_AML_INFINITE_LOOP;
                 break;
             }
 
@@ -345,8 +309,7 @@ AcpiDsExecEndControlOp (
              * another time
              */
             Status = AE_CTRL_PENDING;
-            WalkState->AmlLastWhile =
-                ControlState->Control.AmlPredicateStart;
+            WalkState->AmlLastWhile = ControlState->Control.AmlPredicateStart;
             break;
         }
 
@@ -361,6 +324,7 @@ AcpiDsExecEndControlOp (
         AcpiUtDeleteGenericState (ControlState);
         break;
 
+
     case AML_RETURN_OP:
 
         ACPI_DEBUG_PRINT ((ACPI_DB_DISPATCH,
@@ -390,8 +354,7 @@ AcpiDsExecEndControlOp (
              * an arg or local), resolve it now because it may
              * cease to exist at the end of the method.
              */
-            Status = AcpiExResolveToValue (
-                &WalkState->Operands [0], WalkState);
+            Status = AcpiExResolveToValue (&WalkState->Operands [0], WalkState);
             if (ACPI_FAILURE (Status))
             {
                 return (Status);
@@ -420,15 +383,11 @@ AcpiDsExecEndControlOp (
              * Allow references created by the Index operator to return
              * unchanged.
              */
-            if ((ACPI_GET_DESCRIPTOR_TYPE (WalkState->Results->Results.ObjDesc[0]) ==
-                    ACPI_DESC_TYPE_OPERAND) &&
-                ((WalkState->Results->Results.ObjDesc [0])->Common.Type ==
-                    ACPI_TYPE_LOCAL_REFERENCE) &&
-                ((WalkState->Results->Results.ObjDesc [0])->Reference.Class !=
-                    ACPI_REFCLASS_INDEX))
+            if ((ACPI_GET_DESCRIPTOR_TYPE (WalkState->Results->Results.ObjDesc[0]) == ACPI_DESC_TYPE_OPERAND) &&
+                ((WalkState->Results->Results.ObjDesc [0])->Common.Type == ACPI_TYPE_LOCAL_REFERENCE) &&
+                ((WalkState->Results->Results.ObjDesc [0])->Reference.Class != ACPI_REFCLASS_INDEX))
             {
-                Status = AcpiExResolveToValue (
-                    &WalkState->Results->Results.ObjDesc [0], WalkState);
+                Status = AcpiExResolveToValue (&WalkState->Results->Results.ObjDesc [0], WalkState);
                 if (ACPI_FAILURE (Status))
                 {
                     return (Status);
@@ -446,9 +405,9 @@ AcpiDsExecEndControlOp (
                 AcpiUtRemoveReference (WalkState->Operands [0]);
             }
 
-            WalkState->Operands[0] = NULL;
-            WalkState->NumOperands = 0;
-            WalkState->ReturnDesc = NULL;
+            WalkState->Operands [0]     = NULL;
+            WalkState->NumOperands      = 0;
+            WalkState->ReturnDesc       = NULL;
         }
 
 
@@ -461,25 +420,36 @@ AcpiDsExecEndControlOp (
         Status = AE_CTRL_TERMINATE;
         break;
 
+
     case AML_NOOP_OP:
 
         /* Just do nothing! */
-
         break;
 
-    case AML_BREAKPOINT_OP:
 
-        AcpiDbSignalBreakPoint (WalkState);
+    case AML_BREAK_POINT_OP:
+
+        /*
+         * Set the single-step flag. This will cause the debugger (if present)
+         * to break to the console within the AML debugger at the start of the
+         * next AML instruction.
+         */
+        ACPI_DEBUGGER_EXEC (
+            AcpiGbl_CmSingleStep = TRUE);
+        ACPI_DEBUGGER_EXEC (
+            AcpiOsPrintf ("**break** Executed AML BreakPoint opcode\n"));
 
         /* Call to the OSL in case OS wants a piece of the action */
 
         Status = AcpiOsSignal (ACPI_SIGNAL_BREAKPOINT,
-            "Executed AML Breakpoint opcode");
+                    "Executed AML Breakpoint opcode");
         break;
 
+
     case AML_BREAK_OP:
     case AML_CONTINUE_OP: /* ACPI 2.0 */
 
+
         /* Pop and delete control states until we find a while */
 
         while (WalkState->ControlState &&
@@ -498,8 +468,7 @@ AcpiDsExecEndControlOp (
 
         /* Was: WalkState->AmlLastWhile = WalkState->ControlState->Control.AmlPredicateStart; */
 
-        WalkState->AmlLastWhile =
-            WalkState->ControlState->Control.PackageEnd;
+        WalkState->AmlLastWhile = WalkState->ControlState->Control.PackageEnd;
 
         /* Return status depending on opcode */
 
@@ -513,6 +482,7 @@ AcpiDsExecEndControlOp (
         }
         break;
 
+
     default:
 
         ACPI_ERROR ((AE_INFO, "Unknown control opcode=0x%X Op=%p",
