@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,8 @@
  *
  *****************************************************************************/
 
+#define __DSOBJECT_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acparser.h"
@@ -174,10 +176,10 @@ AcpiDsBuildInternalObject (
         if (!Op->Common.Node)
         {
             Status = AcpiNsLookup (WalkState->ScopeInfo,
-                Op->Common.Value.String,
-                ACPI_TYPE_ANY, ACPI_IMODE_EXECUTE,
-                ACPI_NS_SEARCH_PARENT | ACPI_NS_DONT_OPEN_SCOPE, NULL,
-                ACPI_CAST_INDIRECT_PTR (ACPI_NAMESPACE_NODE, &(Op->Common.Node)));
+                        Op->Common.Value.String,
+                        ACPI_TYPE_ANY, ACPI_IMODE_EXECUTE,
+                        ACPI_NS_SEARCH_PARENT | ACPI_NS_DONT_OPEN_SCOPE, NULL,
+                        ACPI_CAST_INDIRECT_PTR (ACPI_NAMESPACE_NODE, &(Op->Common.Node)));
             if (ACPI_FAILURE (Status))
             {
                 /* Check if we are resolving a named reference within a package */
@@ -185,7 +187,7 @@ AcpiDsBuildInternalObject (
                 if ((Status == AE_NOT_FOUND) && (AcpiGbl_EnableInterpreterSlack) &&
 
                     ((Op->Common.Parent->Common.AmlOpcode == AML_PACKAGE_OP) ||
-                     (Op->Common.Parent->Common.AmlOpcode == AML_VARIABLE_PACKAGE_OP)))
+                     (Op->Common.Parent->Common.AmlOpcode == AML_VAR_PACKAGE_OP)))
                 {
                     /*
                      * We didn't find the target and we are populating elements
@@ -214,7 +216,7 @@ AcpiDsBuildInternalObject (
         /* Special object resolution for elements of a package */
 
         if ((Op->Common.Parent->Common.AmlOpcode == AML_PACKAGE_OP) ||
-            (Op->Common.Parent->Common.AmlOpcode == AML_VARIABLE_PACKAGE_OP))
+            (Op->Common.Parent->Common.AmlOpcode == AML_VAR_PACKAGE_OP))
         {
             /*
              * Attempt to resolve the node to a value before we insert it into
@@ -233,8 +235,8 @@ AcpiDsBuildInternalObject (
             ObjDesc = ACPI_CAST_PTR (ACPI_OPERAND_OBJECT, Op->Common.Node);
 
             Status = AcpiExResolveNodeToValue (
-                ACPI_CAST_INDIRECT_PTR (ACPI_NAMESPACE_NODE, &ObjDesc),
-                WalkState);
+                        ACPI_CAST_INDIRECT_PTR (ACPI_NAMESPACE_NODE, &ObjDesc),
+                        WalkState);
             if (ACPI_FAILURE (Status))
             {
                 return_ACPI_STATUS (Status);
@@ -294,14 +296,14 @@ AcpiDsBuildInternalObject (
     /* Create and init a new internal ACPI object */
 
     ObjDesc = AcpiUtCreateInternalObject (
-        (AcpiPsGetOpcodeInfo (Op->Common.AmlOpcode))->ObjectType);
+                (AcpiPsGetOpcodeInfo (Op->Common.AmlOpcode))->ObjectType);
     if (!ObjDesc)
     {
         return_ACPI_STATUS (AE_NO_MEMORY);
     }
 
-    Status = AcpiDsInitObjectFromOp (
-        WalkState, Op, Op->Common.AmlOpcode, &ObjDesc);
+    Status = AcpiDsInitObjectFromOp (WalkState, Op, Op->Common.AmlOpcode,
+                &ObjDesc);
     if (ACPI_FAILURE (Status))
     {
         AcpiUtRemoveReference (ObjDesc);
@@ -408,8 +410,8 @@ AcpiDsBuildInternalBufferObj (
     }
     else
     {
-        ObjDesc->Buffer.Pointer =
-            ACPI_ALLOCATE_ZEROED (ObjDesc->Buffer.Length);
+        ObjDesc->Buffer.Pointer = ACPI_ALLOCATE_ZEROED (
+                                        ObjDesc->Buffer.Length);
         if (!ObjDesc->Buffer.Pointer)
         {
             AcpiUtDeleteObjectDesc (ObjDesc);
@@ -420,8 +422,8 @@ AcpiDsBuildInternalBufferObj (
 
         if (ByteList)
         {
-            memcpy (ObjDesc->Buffer.Pointer, ByteList->Named.Data,
-                ByteListLength);
+            ACPI_MEMCPY (ObjDesc->Buffer.Pointer, ByteList->Named.Data,
+                         ByteListLength);
         }
     }
 
@@ -483,7 +485,7 @@ AcpiDsBuildInternalPackageObj (
 
     Parent = Op->Common.Parent;
     while ((Parent->Common.AmlOpcode == AML_PACKAGE_OP) ||
-           (Parent->Common.AmlOpcode == AML_VARIABLE_PACKAGE_OP))
+           (Parent->Common.AmlOpcode == AML_VAR_PACKAGE_OP))
     {
         Parent = Parent->Common.Parent;
     }
@@ -540,8 +542,8 @@ AcpiDsBuildInternalPackageObj (
                  * invocation, so we special case it here
                  */
                 Arg->Common.AmlOpcode = AML_INT_NAMEPATH_OP;
-                Status = AcpiDsBuildInternalObject (
-                    WalkState, Arg, &ObjDesc->Package.Elements[i]);
+                Status = AcpiDsBuildInternalObject (WalkState, Arg,
+                            &ObjDesc->Package.Elements[i]);
             }
             else
             {
@@ -553,8 +555,8 @@ AcpiDsBuildInternalPackageObj (
         }
         else
         {
-            Status = AcpiDsBuildInternalObject (
-                WalkState, Arg, &ObjDesc->Package.Elements[i]);
+            Status = AcpiDsBuildInternalObject (WalkState, Arg,
+                        &ObjDesc->Package.Elements[i]);
         }
 
         if (*ObjDescPtr)
@@ -610,9 +612,8 @@ AcpiDsBuildInternalPackageObj (
             Arg = Arg->Common.Next;
         }
 
-        ACPI_INFO ((
-            "Actual Package length (%u) is larger than "
-            "NumElements field (%u), truncated",
+        ACPI_INFO ((AE_INFO,
+            "Actual Package length (%u) is larger than NumElements field (%u), truncated",
             i, ElementCount));
     }
     else if (i < ElementCount)
@@ -622,8 +623,7 @@ AcpiDsBuildInternalPackageObj (
          * Note: this is not an error, the package is padded out with NULLs.
          */
         ACPI_DEBUG_PRINT ((ACPI_DB_INFO,
-            "Package List length (%u) smaller than NumElements "
-            "count (%u), padded with null elements\n",
+            "Package List length (%u) smaller than NumElements count (%u), padded with null elements\n",
             i, ElementCount));
     }
 
@@ -679,8 +679,8 @@ AcpiDsCreateNode (
 
     /* Build an internal object for the argument(s) */
 
-    Status = AcpiDsBuildInternalObject (
-        WalkState, Op->Common.Value.Arg, &ObjDesc);
+    Status = AcpiDsBuildInternalObject (WalkState, Op->Common.Value.Arg,
+                &ObjDesc);
     if (ACPI_FAILURE (Status))
     {
         return_ACPI_STATUS (Status);
@@ -749,25 +749,29 @@ AcpiDsInitObjectFromOp (
     switch (ObjDesc->Common.Type)
     {
     case ACPI_TYPE_BUFFER:
+
         /*
          * Defer evaluation of Buffer TermArg operand
          */
-        ObjDesc->Buffer.Node = ACPI_CAST_PTR (
-            ACPI_NAMESPACE_NODE, WalkState->Operands[0]);
-        ObjDesc->Buffer.AmlStart = Op->Named.Data;
+        ObjDesc->Buffer.Node      = ACPI_CAST_PTR (ACPI_NAMESPACE_NODE,
+                                        WalkState->Operands[0]);
+        ObjDesc->Buffer.AmlStart  = Op->Named.Data;
         ObjDesc->Buffer.AmlLength = Op->Named.Length;
         break;
 
+
     case ACPI_TYPE_PACKAGE:
+
         /*
          * Defer evaluation of Package TermArg operand
          */
-        ObjDesc->Package.Node = ACPI_CAST_PTR (
-            ACPI_NAMESPACE_NODE, WalkState->Operands[0]);
-        ObjDesc->Package.AmlStart = Op->Named.Data;
+        ObjDesc->Package.Node      = ACPI_CAST_PTR (ACPI_NAMESPACE_NODE,
+                                        WalkState->Operands[0]);
+        ObjDesc->Package.AmlStart  = Op->Named.Data;
         ObjDesc->Package.AmlLength = Op->Named.Length;
         break;
 
+
     case ACPI_TYPE_INTEGER:
 
         switch (OpInfo->Type)
@@ -820,6 +824,7 @@ AcpiDsInitObjectFromOp (
             }
             break;
 
+
         case AML_TYPE_LITERAL:
 
             ObjDesc->Integer.Value = Op->Common.Value.Integer;
@@ -837,8 +842,8 @@ AcpiDsInitObjectFromOp (
 #endif
             break;
 
-        default:
 
+        default:
             ACPI_ERROR ((AE_INFO, "Unknown Integer type 0x%X",
                 OpInfo->Type));
             Status = AE_AML_OPERAND_TYPE;
@@ -846,10 +851,11 @@ AcpiDsInitObjectFromOp (
         }
         break;
 
+
     case ACPI_TYPE_STRING:
 
         ObjDesc->String.Pointer = Op->Common.Value.String;
-        ObjDesc->String.Length = (UINT32) strlen (Op->Common.Value.String);
+        ObjDesc->String.Length = (UINT32) ACPI_STRLEN (Op->Common.Value.String);
 
         /*
          * The string is contained in the ACPI table, don't ever try
@@ -858,40 +864,43 @@ AcpiDsInitObjectFromOp (
         ObjDesc->Common.Flags |= AOPOBJ_STATIC_POINTER;
         break;
 
+
     case ACPI_TYPE_METHOD:
         break;
 
+
     case ACPI_TYPE_LOCAL_REFERENCE:
 
         switch (OpInfo->Type)
         {
         case AML_TYPE_LOCAL_VARIABLE:
 
-            /* Local ID (0-7) is (AML opcode - base AML_FIRST_LOCAL_OP) */
+            /* Local ID (0-7) is (AML opcode - base AML_LOCAL_OP) */
 
-            ObjDesc->Reference.Value = ((UINT32) Opcode) - AML_FIRST_LOCAL_OP;
+            ObjDesc->Reference.Value = ((UINT32) Opcode) - AML_LOCAL_OP;
             ObjDesc->Reference.Class = ACPI_REFCLASS_LOCAL;
 
 #ifndef ACPI_NO_METHOD_EXECUTION
             Status = AcpiDsMethodDataGetNode (ACPI_REFCLASS_LOCAL,
-                ObjDesc->Reference.Value, WalkState,
-                ACPI_CAST_INDIRECT_PTR (ACPI_NAMESPACE_NODE,
-                    &ObjDesc->Reference.Object));
+                        ObjDesc->Reference.Value, WalkState,
+                        ACPI_CAST_INDIRECT_PTR (ACPI_NAMESPACE_NODE,
+                            &ObjDesc->Reference.Object));
 #endif
             break;
 
+
         case AML_TYPE_METHOD_ARGUMENT:
 
-            /* Arg ID (0-6) is (AML opcode - base AML_FIRST_ARG_OP) */
+            /* Arg ID (0-6) is (AML opcode - base AML_ARG_OP) */
 
-            ObjDesc->Reference.Value = ((UINT32) Opcode) - AML_FIRST_ARG_OP;
+            ObjDesc->Reference.Value = ((UINT32) Opcode) - AML_ARG_OP;
             ObjDesc->Reference.Class = ACPI_REFCLASS_ARG;
 
 #ifndef ACPI_NO_METHOD_EXECUTION
             Status = AcpiDsMethodDataGetNode (ACPI_REFCLASS_ARG,
-                ObjDesc->Reference.Value, WalkState,
-                ACPI_CAST_INDIRECT_PTR (ACPI_NAMESPACE_NODE,
-                    &ObjDesc->Reference.Object));
+                        ObjDesc->Reference.Value, WalkState,
+                        ACPI_CAST_INDIRECT_PTR (ACPI_NAMESPACE_NODE,
+                            &ObjDesc->Reference.Object));
 #endif
             break;
 
@@ -923,6 +932,7 @@ AcpiDsInitObjectFromOp (
         }
         break;
 
+
     default:
 
         ACPI_ERROR ((AE_INFO, "Unimplemented data type: 0x%X",
