@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2016, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,9 @@
  *
  *****************************************************************************/
 
+
+#define __EXCONVRT_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acinterp.h"
@@ -183,7 +186,6 @@ AcpiExConvertToInteger (
         break;
 
     default:
-
         return_ACPI_STATUS (AE_TYPE);
     }
 
@@ -203,20 +205,21 @@ AcpiExConvertToInteger (
     switch (ObjDesc->Common.Type)
     {
     case ACPI_TYPE_STRING:
+
         /*
          * Convert string to an integer - for most cases, the string must be
          * hexadecimal as per the ACPI specification. The only exception (as
          * of ACPI 3.0) is that the ToInteger() operator allows both decimal
          * and hexadecimal strings (hex prefixed with "0x").
          */
-        Status = AcpiUtStrtoul64 ((char *) Pointer, Flags,
-            AcpiGbl_IntegerByteWidth, &Result);
+        Status = AcpiUtStrtoul64 ((char *) Pointer, Flags, &Result);
         if (ACPI_FAILURE (Status))
         {
             return_ACPI_STATUS (Status);
         }
         break;
 
+
     case ACPI_TYPE_BUFFER:
 
         /* Check for zero-length buffer */
@@ -248,10 +251,10 @@ AcpiExConvertToInteger (
         }
         break;
 
+
     default:
 
         /* No other types can get here */
-
         break;
     }
 
@@ -311,6 +314,7 @@ AcpiExConvertToBuffer (
 
 
     case ACPI_TYPE_INTEGER:
+
         /*
          * Create a new Buffer object.
          * Need enough space for one integer
@@ -324,10 +328,14 @@ AcpiExConvertToBuffer (
         /* Copy the integer to the buffer, LSB first */
 
         NewBuf = ReturnDesc->Buffer.Pointer;
-        memcpy (NewBuf, &ObjDesc->Integer.Value, AcpiGbl_IntegerByteWidth);
+        ACPI_MEMCPY (NewBuf,
+                        &ObjDesc->Integer.Value,
+                        AcpiGbl_IntegerByteWidth);
         break;
 
+
     case ACPI_TYPE_STRING:
+
         /*
          * Create a new Buffer object
          * Size will be the string length
@@ -337,8 +345,8 @@ AcpiExConvertToBuffer (
          * ASL/AML code that depends on the null being transferred to the new
          * buffer.
          */
-        ReturnDesc = AcpiUtCreateBufferObject ((ACPI_SIZE)
-            ObjDesc->String.Length + 1);
+        ReturnDesc = AcpiUtCreateBufferObject (
+                        (ACPI_SIZE) ObjDesc->String.Length + 1);
         if (!ReturnDesc)
         {
             return_ACPI_STATUS (AE_NO_MEMORY);
@@ -347,12 +355,12 @@ AcpiExConvertToBuffer (
         /* Copy the string to the buffer */
 
         NewBuf = ReturnDesc->Buffer.Pointer;
-        strncpy ((char *) NewBuf, (char *) ObjDesc->String.Pointer,
+        ACPI_STRNCPY ((char *) NewBuf, (char *) ObjDesc->String.Pointer,
             ObjDesc->String.Length);
         break;
 
-    default:
 
+    default:
         return_ACPI_STATUS (AE_TYPE);
     }
 
@@ -408,18 +416,15 @@ AcpiExConvertToAscii (
         switch (DataWidth)
         {
         case 1:
-
             DecimalLength = ACPI_MAX8_DECIMAL_DIGITS;
             break;
 
         case 4:
-
             DecimalLength = ACPI_MAX32_DECIMAL_DIGITS;
             break;
 
         case 8:
         default:
-
             DecimalLength = ACPI_MAX64_DECIMAL_DIGITS;
             break;
         }
@@ -461,8 +466,7 @@ AcpiExConvertToAscii (
         {
             /* Get one hex digit, most significant digits first */
 
-            String[k] = (UINT8)
-                AcpiUtHexToAsciiChar (Integer, ACPI_MUL_4 (j));
+            String[k] = (UINT8) AcpiUtHexToAsciiChar (Integer, ACPI_MUL_4 (j));
             k++;
         }
         break;
@@ -529,6 +533,7 @@ AcpiExConvertToString (
         *ResultDesc = ObjDesc;
         return_ACPI_STATUS (AE_OK);
 
+
     case ACPI_TYPE_INTEGER:
 
         switch (Type)
@@ -563,8 +568,8 @@ AcpiExConvertToString (
 
         /* Convert integer to string */
 
-        StringLength = AcpiExConvertToAscii (
-            ObjDesc->Integer.Value, Base, NewBuf, AcpiGbl_IntegerByteWidth);
+        StringLength = AcpiExConvertToAscii (ObjDesc->Integer.Value, Base,
+                            NewBuf, AcpiGbl_IntegerByteWidth);
 
         /* Null terminate at the correct place */
 
@@ -572,6 +577,7 @@ AcpiExConvertToString (
         NewBuf [StringLength] = 0;
         break;
 
+
     case ACPI_TYPE_BUFFER:
 
         /* Setup string length, base, and separator */
@@ -653,7 +659,8 @@ AcpiExConvertToString (
         for (i = 0; i < ObjDesc->Buffer.Length; i++)
         {
             NewBuf += AcpiExConvertToAscii (
-                (UINT64) ObjDesc->Buffer.Pointer[i], Base, NewBuf, 1);
+                        (UINT64) ObjDesc->Buffer.Pointer[i], Base,
+                        NewBuf, 1);
             *NewBuf++ = Separator; /* each separated by a comma or space */
         }
 
@@ -669,7 +676,6 @@ AcpiExConvertToString (
         break;
 
     default:
-
         return_ACPI_STATUS (AE_TYPE);
     }
 
@@ -729,7 +735,6 @@ AcpiExConvertToTargetType (
             break;
 
         default:
-
             /* No conversion allowed for these types */
 
             if (DestinationType != SourceDesc->Common.Type)
@@ -743,8 +748,8 @@ AcpiExConvertToTargetType (
         }
         break;
 
+
     case ARGI_TARGETREF:
-    case ARGI_STORE_TARGET:
 
         switch (DestinationType)
         {
@@ -756,18 +761,21 @@ AcpiExConvertToTargetType (
              * These types require an Integer operand. We can convert
              * a Buffer or a String to an Integer if necessary.
              */
-            Status = AcpiExConvertToInteger (SourceDesc, ResultDesc, 16);
+            Status = AcpiExConvertToInteger (SourceDesc, ResultDesc,
+                        16);
             break;
 
+
         case ACPI_TYPE_STRING:
             /*
              * The operand must be a String. We can convert an
              * Integer or Buffer if necessary
              */
             Status = AcpiExConvertToString (SourceDesc, ResultDesc,
-                ACPI_IMPLICIT_CONVERT_HEX);
+                        ACPI_IMPLICIT_CONVERT_HEX);
             break;
 
+
         case ACPI_TYPE_BUFFER:
             /*
              * The operand must be a Buffer. We can convert an
@@ -776,24 +784,24 @@ AcpiExConvertToTargetType (
             Status = AcpiExConvertToBuffer (SourceDesc, ResultDesc);
             break;
 
-        default:
 
-            ACPI_ERROR ((AE_INFO,
-                "Bad destination type during conversion: 0x%X",
+        default:
+            ACPI_ERROR ((AE_INFO, "Bad destination type during conversion: 0x%X",
                 DestinationType));
             Status = AE_AML_INTERNAL;
             break;
         }
         break;
 
+
     case ARGI_REFERENCE:
         /*
          * CreateXxxxField cases - we are storing the field object into the name
          */
         break;
 
-    default:
 
+    default:
         ACPI_ERROR ((AE_INFO,
             "Unknown Target type ID 0x%X AmlOpcode 0x%X DestType %s",
             GET_CURRENT_ARG_TYPE (WalkState->OpInfo->RuntimeArgs),
