@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,9 @@
  *
  *****************************************************************************/
 
+
+#define __EXFLDIO_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acinterp.h"
@@ -361,13 +364,13 @@ AcpiExAccessRegion (
     }
 
     ACPI_DEBUG_PRINT_RAW ((ACPI_DB_BFIELD,
-        " Region [%s:%X], Width %X, ByteBase %X, Offset %X at %8.8X%8.8X\n",
+        " Region [%s:%X], Width %X, ByteBase %X, Offset %X at %p\n",
         AcpiUtGetRegionName (RgnDesc->Region.SpaceId),
         RgnDesc->Region.SpaceId,
         ObjDesc->CommonField.AccessByteWidth,
         ObjDesc->CommonField.BaseByteOffset,
         FieldDatumByteOffset,
-        ACPI_FORMAT_UINT64 (RgnDesc->Region.Address + RegionOffset)));
+        ACPI_CAST_PTR (void, (RgnDesc->Region.Address + RegionOffset))));
 
     /* Invoke the appropriate AddressSpace/OpRegion handler */
 
@@ -549,7 +552,9 @@ AcpiExFieldDatumIo (
         Status = AE_OK;
         break;
 
+
     case ACPI_TYPE_LOCAL_BANK_FIELD:
+
         /*
          * Ensure that the BankValue is not beyond the capacity of
          * the register
@@ -579,6 +584,7 @@ AcpiExFieldDatumIo (
 
         /*lint -fallthrough */
 
+
     case ACPI_TYPE_LOCAL_REGION_FIELD:
         /*
          * For simple RegionFields, we just directly access the owning
@@ -588,7 +594,10 @@ AcpiExFieldDatumIo (
                     ReadWrite);
         break;
 
+
     case ACPI_TYPE_LOCAL_INDEX_FIELD:
+
+
         /*
          * Ensure that the IndexValue is not beyond the capacity of
          * the register
@@ -638,6 +647,7 @@ AcpiExFieldDatumIo (
         }
         break;
 
+
     default:
 
         ACPI_ERROR ((AE_INFO, "Wrong object type in field I/O %u",
