@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2022, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,44 +111,10 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+#define __EXOPARG1_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acparser.h"
@@ -286,31 +252,37 @@ AcpiExOpcode_1A_0T_0R (
         Status = AcpiExReleaseMutex (Operand[0], WalkState);
         break;
 
+
     case AML_RESET_OP:      /*  Reset (EventObject) */
 
         Status = AcpiExSystemResetEvent (Operand[0]);
         break;
 
+
     case AML_SIGNAL_OP:     /*  Signal (EventObject) */
 
         Status = AcpiExSystemSignalEvent (Operand[0]);
         break;
 
+
     case AML_SLEEP_OP:      /*  Sleep (MsecTime) */
 
         Status = AcpiExSystemDoSleep (Operand[0]->Integer.Value);
         break;
 
+
     case AML_STALL_OP:      /*  Stall (UsecTime) */
 
         Status = AcpiExSystemDoStall ((UINT32) Operand[0]->Integer.Value);
         break;
 
+
     case AML_UNLOAD_OP:     /*  Unload (Handle) */
 
         Status = AcpiExUnloadTable (Operand[0]);
         break;
 
+
     default:                /*  Unknown opcode  */
 
         ACPI_ERROR ((AE_INFO, "Unknown AML opcode 0x%X",
@@ -323,7 +295,6 @@ AcpiExOpcode_1A_0T_0R (
 }
 
 
-#ifdef _OBSOLETE_CODE /* Was originally used for Load() operator */
 /*******************************************************************************
  *
  * FUNCTION:    AcpiExOpcode_1A_1T_0R
@@ -353,12 +324,10 @@ AcpiExOpcode_1A_1T_0R (
 
     switch (WalkState->Opcode)
     {
-#ifdef _OBSOLETE_CODE
     case AML_LOAD_OP:
 
         Status = AcpiExLoadOp (Operand[0], Operand[1], WalkState);
         break;
-#endif
 
     default:                        /* Unknown opcode */
 
@@ -373,7 +342,7 @@ Cleanup:
 
     return_ACPI_STATUS (Status);
 }
-#endif
+
 
 /*******************************************************************************
  *
@@ -385,8 +354,6 @@ Cleanup:
  *
  * DESCRIPTION: Execute opcode with one argument, one target, and a
  *              return value.
- *              January 2022: Added Load operator, with new ACPI 6.4
- *              semantics.
  *
  ******************************************************************************/
 
@@ -416,9 +383,8 @@ AcpiExOpcode_1A_1T_1R (
     case AML_FIND_SET_LEFT_BIT_OP:
     case AML_FIND_SET_RIGHT_BIT_OP:
     case AML_FROM_BCD_OP:
-    case AML_LOAD_OP:
     case AML_TO_BCD_OP:
-    case AML_CONDITIONAL_REF_OF_OP:
+    case AML_COND_REF_OF_OP:
 
         /* Create a return object of type Integer for these opcodes */
 
@@ -436,6 +402,7 @@ AcpiExOpcode_1A_1T_1R (
             ReturnDesc->Integer.Value = ~Operand[0]->Integer.Value;
             break;
 
+
         case AML_FIND_SET_LEFT_BIT_OP:  /* FindSetLeftBit (Operand, Result) */
 
             ReturnDesc->Integer.Value = Operand[0]->Integer.Value;
@@ -445,7 +412,7 @@ AcpiExOpcode_1A_1T_1R (
              * endian unsigned value, so this boundary condition is valid.
              */
             for (Temp32 = 0; ReturnDesc->Integer.Value &&
-                    Temp32 < ACPI_INTEGER_BIT_SIZE; ++Temp32)
+                             Temp32 < ACPI_INTEGER_BIT_SIZE; ++Temp32)
             {
                 ReturnDesc->Integer.Value >>= 1;
             }
@@ -453,6 +420,7 @@ AcpiExOpcode_1A_1T_1R (
             ReturnDesc->Integer.Value = Temp32;
             break;
 
+
         case AML_FIND_SET_RIGHT_BIT_OP: /* FindSetRightBit (Operand, Result) */
 
             ReturnDesc->Integer.Value = Operand[0]->Integer.Value;
@@ -462,7 +430,7 @@ AcpiExOpcode_1A_1T_1R (
              * endian unsigned value, so this boundary condition is valid.
              */
             for (Temp32 = 0; ReturnDesc->Integer.Value &&
-                     Temp32 < ACPI_INTEGER_BIT_SIZE; ++Temp32)
+                             Temp32 < ACPI_INTEGER_BIT_SIZE; ++Temp32)
             {
                 ReturnDesc->Integer.Value <<= 1;
             }
@@ -473,7 +441,9 @@ AcpiExOpcode_1A_1T_1R (
                 Temp32 == 0 ? 0 : (ACPI_INTEGER_BIT_SIZE + 1) - Temp32;
             break;
 
+
         case AML_FROM_BCD_OP:           /* FromBcd (BCDValue, Result)  */
+
             /*
              * The 64-bit ACPI integer can hold 16 4-bit BCD characters
              * (if table is 32-bit, integer can hold 8 BCD characters)
@@ -518,17 +488,6 @@ AcpiExOpcode_1A_1T_1R (
             }
             break;
 
-        case AML_LOAD_OP:               /* Result1 = Load (Operand[0], Result1) */
-
-            ReturnDesc->Integer.Value = 0;
-            Status = AcpiExLoadOp (Operand[0], ReturnDesc, WalkState);
-            if (ACPI_SUCCESS (Status))
-            {
-                /* Return -1 (non-zero) indicates success */
-
-                ReturnDesc->Integer.Value = 0xFFFFFFFFFFFFFFFF;
-            }
-            break;
 
         case AML_TO_BCD_OP:             /* ToBcd (Operand, Result)  */
 
@@ -561,7 +520,9 @@ AcpiExOpcode_1A_1T_1R (
             }
             break;
 
-        case AML_CONDITIONAL_REF_OF_OP:     /* CondRefOf (SourceObject, Result)  */
+
+        case AML_COND_REF_OF_OP:        /* CondRefOf (SourceObject, Result)  */
+
             /*
              * This op is a little strange because the internal return value is
              * different than the return value stored in the result descriptor
@@ -580,7 +541,7 @@ AcpiExOpcode_1A_1T_1R (
             /* Get the object reference, store it, and remove our reference */
 
             Status = AcpiExGetObjectReference (Operand[0],
-                &ReturnDesc2, WalkState);
+                        &ReturnDesc2, WalkState);
             if (ACPI_FAILURE (Status))
             {
                 goto Cleanup;
@@ -596,14 +557,14 @@ AcpiExOpcode_1A_1T_1R (
 
 
         default:
-
             /* No other opcodes get here */
-
             break;
         }
         break;
 
+
     case AML_STORE_OP:              /* Store (Source, Target) */
+
         /*
          * A store operand is typically a number, string, buffer or lvalue
          * Be careful about deleting the source object,
@@ -630,63 +591,64 @@ AcpiExOpcode_1A_1T_1R (
         }
         return_ACPI_STATUS (Status);
 
+
     /*
      * ACPI 2.0 Opcodes
      */
-    case AML_COPY_OBJECT_OP:        /* CopyObject (Source, Target) */
+    case AML_COPY_OP:               /* Copy (Source, Target) */
 
-        Status = AcpiUtCopyIobjectToIobject (
-            Operand[0], &ReturnDesc, WalkState);
+        Status = AcpiUtCopyIobjectToIobject (Operand[0], &ReturnDesc,
+                    WalkState);
         break;
 
-    case AML_TO_DECIMAL_STRING_OP:  /* ToDecimalString (Data, Result) */
 
-        Status = AcpiExConvertToString (
-            Operand[0], &ReturnDesc, ACPI_EXPLICIT_CONVERT_DECIMAL);
+    case AML_TO_DECSTRING_OP:       /* ToDecimalString (Data, Result) */
+
+        Status = AcpiExConvertToString (Operand[0], &ReturnDesc,
+                    ACPI_EXPLICIT_CONVERT_DECIMAL);
         if (ReturnDesc == Operand[0])
         {
             /* No conversion performed, add ref to handle return value */
-
             AcpiUtAddReference (ReturnDesc);
         }
         break;
 
-    case AML_TO_HEX_STRING_OP:      /* ToHexString (Data, Result) */
 
-        Status = AcpiExConvertToString (
-            Operand[0], &ReturnDesc, ACPI_EXPLICIT_CONVERT_HEX);
+    case AML_TO_HEXSTRING_OP:       /* ToHexString (Data, Result) */
+
+        Status = AcpiExConvertToString (Operand[0], &ReturnDesc,
+                    ACPI_EXPLICIT_CONVERT_HEX);
         if (ReturnDesc == Operand[0])
         {
             /* No conversion performed, add ref to handle return value */
-
             AcpiUtAddReference (ReturnDesc);
         }
         break;
 
+
     case AML_TO_BUFFER_OP:          /* ToBuffer (Data, Result) */
 
         Status = AcpiExConvertToBuffer (Operand[0], &ReturnDesc);
         if (ReturnDesc == Operand[0])
         {
             /* No conversion performed, add ref to handle return value */
-
             AcpiUtAddReference (ReturnDesc);
         }
         break;
 
+
     case AML_TO_INTEGER_OP:         /* ToInteger (Data, Result) */
 
-        /* Perform "explicit" conversion */
-
-        Status = AcpiExConvertToInteger (Operand[0], &ReturnDesc, 0);
+        Status = AcpiExConvertToInteger (Operand[0], &ReturnDesc,
+                    ACPI_ANY_BASE);
         if (ReturnDesc == Operand[0])
         {
             /* No conversion performed, add ref to handle return value */
-
             AcpiUtAddReference (ReturnDesc);
         }
         break;
 
+
     case AML_SHIFT_LEFT_BIT_OP:     /* ShiftLeftBit (Source, BitNum)  */
     case AML_SHIFT_RIGHT_BIT_OP:    /* ShiftRightBit (Source, BitNum) */
 
@@ -698,6 +660,7 @@ AcpiExOpcode_1A_1T_1R (
         Status = AE_SUPPORT;
         goto Cleanup;
 
+
     default:                        /* Unknown opcode */
 
         ACPI_ERROR ((AE_INFO, "Unknown AML opcode 0x%X",
@@ -766,7 +729,7 @@ AcpiExOpcode_1A_0T_1R (
 
     switch (WalkState->Opcode)
     {
-    case AML_LOGICAL_NOT_OP:        /* LNot (Operand) */
+    case AML_LNOT_OP:               /* LNot (Operand) */
 
         ReturnDesc = AcpiUtCreateIntegerObject ((UINT64) 0);
         if (!ReturnDesc)
@@ -785,8 +748,10 @@ AcpiExOpcode_1A_0T_1R (
         }
         break;
 
+
     case AML_DECREMENT_OP:          /* Decrement (Operand)  */
     case AML_INCREMENT_OP:          /* Increment (Operand)  */
+
         /*
          * Create a new integer. Can't just get the base integer and
          * increment it because it may be an Arg or Field.
@@ -817,8 +782,7 @@ AcpiExOpcode_1A_0T_1R (
          * NOTE:  We use LNOT_OP here in order to force resolution of the
          * reference operand to an actual integer.
          */
-        Status = AcpiExResolveOperands (AML_LOGICAL_NOT_OP,
-            &TempDesc, WalkState);
+        Status = AcpiExResolveOperands (AML_LNOT_OP, &TempDesc, WalkState);
         if (ACPI_FAILURE (Status))
         {
             ACPI_EXCEPTION ((AE_INFO, Status,
@@ -834,11 +798,11 @@ AcpiExOpcode_1A_0T_1R (
          */
         if (WalkState->Opcode == AML_INCREMENT_OP)
         {
-            ReturnDesc->Integer.Value = TempDesc->Integer.Value + 1;
+            ReturnDesc->Integer.Value = TempDesc->Integer.Value +1;
         }
         else
         {
-            ReturnDesc->Integer.Value = TempDesc->Integer.Value - 1;
+            ReturnDesc->Integer.Value = TempDesc->Integer.Value -1;
         }
 
         /* Finished with this Integer object */
@@ -852,7 +816,9 @@ AcpiExOpcode_1A_0T_1R (
         Status = AcpiExStore (ReturnDesc, Operand[0], WalkState);
         break;
 
-    case AML_OBJECT_TYPE_OP:            /* ObjectType (SourceObject) */
+
+    case AML_TYPE_OP:               /* ObjectType (SourceObject) */
+
         /*
          * Note: The operand is not resolved at this point because we want to
          * get the associated object, not its value. For example, we don't
@@ -878,7 +844,9 @@ AcpiExOpcode_1A_0T_1R (
         }
         break;
 
+
     case AML_SIZE_OF_OP:            /* SizeOf (SourceObject)  */
+
         /*
          * Note: The operand is not resolved at this point because we want to
          * get the associated object, not its value.
@@ -886,8 +854,8 @@ AcpiExOpcode_1A_0T_1R (
 
         /* Get the base object */
 
-        Status = AcpiExResolveMultiple (
-            WalkState, Operand[0], &Type, &TempDesc);
+        Status = AcpiExResolveMultiple (WalkState,
+                    Operand[0], &Type, &TempDesc);
         if (ACPI_FAILURE (Status))
         {
             goto Cleanup;
@@ -905,12 +873,10 @@ AcpiExOpcode_1A_0T_1R (
         switch (Type)
         {
         case ACPI_TYPE_INTEGER:
-
             Value = AcpiGbl_IntegerByteWidth;
             break;
 
         case ACPI_TYPE_STRING:
-
             Value = TempDesc->String.Length;
             break;
 
@@ -931,12 +897,9 @@ AcpiExOpcode_1A_0T_1R (
             break;
 
         default:
-
             ACPI_ERROR ((AE_INFO,
-                "Operand must be Buffer/Integer/String/Package"
-                " - found type %s",
+                "Operand must be Buffer/Integer/String/Package - found type %s",
                 AcpiUtGetTypeName (Type)));
-
             Status = AE_AML_OPERAND_TYPE;
             goto Cleanup;
         }
@@ -961,8 +924,7 @@ AcpiExOpcode_1A_0T_1R (
 
     case AML_REF_OF_OP:             /* RefOf (SourceObject) */
 
-        Status = AcpiExGetObjectReference (
-            Operand[0], &ReturnDesc, WalkState);
+        Status = AcpiExGetObjectReference (Operand[0], &ReturnDesc, WalkState);
         if (ACPI_FAILURE (Status))
         {
             goto Cleanup;
@@ -977,7 +939,7 @@ AcpiExOpcode_1A_0T_1R (
         if (ACPI_GET_DESCRIPTOR_TYPE (Operand[0]) == ACPI_DESC_TYPE_NAMED)
         {
             TempDesc = AcpiNsGetAttachedObject (
-                (ACPI_NAMESPACE_NODE *) Operand[0]);
+                           (ACPI_NAMESPACE_NODE *) Operand[0]);
             if (TempDesc &&
                  ((TempDesc->Common.Type == ACPI_TYPE_STRING) ||
                   (TempDesc->Common.Type == ACPI_TYPE_LOCAL_REFERENCE)))
@@ -1009,9 +971,9 @@ AcpiExOpcode_1A_0T_1R (
                     /* Set Operand[0] to the value of the local/arg */
 
                     Status = AcpiDsMethodDataGetValue (
-                        Operand[0]->Reference.Class,
-                        Operand[0]->Reference.Value,
-                        WalkState, &TempDesc);
+                                Operand[0]->Reference.Class,
+                                Operand[0]->Reference.Value,
+                                WalkState, &TempDesc);
                     if (ACPI_FAILURE (Status))
                     {
                         goto Cleanup;
@@ -1042,11 +1004,9 @@ AcpiExOpcode_1A_0T_1R (
                 break;
 
             case ACPI_TYPE_STRING:
-
                 break;
 
             default:
-
                 Status = AE_AML_OPERAND_TYPE;
                 goto Cleanup;
             }
@@ -1064,20 +1024,20 @@ AcpiExOpcode_1A_0T_1R (
                  * 2) Dereference the node to an actual object. Could be a
                  *    Field, so we need to resolve the node to a value.
                  */
-                Status = AcpiNsGetNodeUnlocked (WalkState->ScopeInfo->Scope.Node,
-                    Operand[0]->String.Pointer,
-                    ACPI_NS_SEARCH_PARENT,
-                    ACPI_CAST_INDIRECT_PTR (
-                        ACPI_NAMESPACE_NODE, &ReturnDesc));
+                Status = AcpiNsGetNode (WalkState->ScopeInfo->Scope.Node,
+                            Operand[0]->String.Pointer,
+                            ACPI_NS_SEARCH_PARENT,
+                            ACPI_CAST_INDIRECT_PTR (
+                                ACPI_NAMESPACE_NODE, &ReturnDesc));
                 if (ACPI_FAILURE (Status))
                 {
                     goto Cleanup;
                 }
 
                 Status = AcpiExResolveNodeToValue (
-                    ACPI_CAST_INDIRECT_PTR (
-                        ACPI_NAMESPACE_NODE, &ReturnDesc),
-                    WalkState);
+                            ACPI_CAST_INDIRECT_PTR (
+                                ACPI_NAMESPACE_NODE, &ReturnDesc),
+                            WalkState);
                 goto Cleanup;
             }
         }
@@ -1090,27 +1050,11 @@ AcpiExOpcode_1A_0T_1R (
              * This is a DerefOf (ObjectReference)
              * Get the actual object from the Node (This is the dereference).
              * This case may only happen when a LocalX or ArgX is
-             * dereferenced above, or for references to device and
-             * thermal objects.
+             * dereferenced above.
              */
-            switch (((ACPI_NAMESPACE_NODE *) Operand[0])->Type)
-            {
-            case ACPI_TYPE_DEVICE:
-            case ACPI_TYPE_THERMAL:
-
-                /* These types have no node subobject, return the NS node */
-
-                ReturnDesc = Operand[0];
-                break;
-
-            default:
-                /* For most types, get the object attached to the node */
-
-                ReturnDesc = AcpiNsGetAttachedObject (
-                    (ACPI_NAMESPACE_NODE *) Operand[0]);
-                AcpiUtAddReference (ReturnDesc);
-                break;
-            }
+            ReturnDesc = AcpiNsGetAttachedObject (
+                            (ACPI_NAMESPACE_NODE *) Operand[0]);
+            AcpiUtAddReference (ReturnDesc);
         }
         else
         {
@@ -1121,6 +1065,7 @@ AcpiExOpcode_1A_0T_1R (
             switch (Operand[0]->Reference.Class)
             {
             case ACPI_REFCLASS_INDEX:
+
                 /*
                  * The target type for the Index operator must be
                  * either a Buffer or a Package
@@ -1152,83 +1097,50 @@ AcpiExOpcode_1A_0T_1R (
                     }
                     break;
 
+
                 case ACPI_TYPE_PACKAGE:
+
                     /*
                      * Return the referenced element of the package. We must
                      * add another reference to the referenced object, however.
                      */
                     ReturnDesc = *(Operand[0]->Reference.Where);
-                    if (!ReturnDesc)
+                    if (ReturnDesc)
                     {
-                        /*
-                         * Element is NULL, do not allow the dereference.
-                         * This provides compatibility with other ACPI
-                         * implementations.
-                         */
-                        return_ACPI_STATUS (AE_AML_UNINITIALIZED_ELEMENT);
+                        AcpiUtAddReference (ReturnDesc);
                     }
-
-                    AcpiUtAddReference (ReturnDesc);
                     break;
 
+
                 default:
 
                     ACPI_ERROR ((AE_INFO,
                         "Unknown Index TargetType 0x%X in reference object %p",
                         Operand[0]->Reference.TargetType, Operand[0]));
-
                     Status = AE_AML_OPERAND_TYPE;
                     goto Cleanup;
                 }
                 break;
 
+
             case ACPI_REFCLASS_REFOF:
 
                 ReturnDesc = Operand[0]->Reference.Object;
 
                 if (ACPI_GET_DESCRIPTOR_TYPE (ReturnDesc) ==
-                    ACPI_DESC_TYPE_NAMED)
+                        ACPI_DESC_TYPE_NAMED)
                 {
                     ReturnDesc = AcpiNsGetAttachedObject (
-                        (ACPI_NAMESPACE_NODE *) ReturnDesc);
-                    if (!ReturnDesc)
-                    {
-                        break;
-                    }
-
-                   /*
-                    * June 2013:
-                    * BufferFields/FieldUnits require additional resolution
-                    */
-                    switch (ReturnDesc->Common.Type)
-                    {
-                    case ACPI_TYPE_BUFFER_FIELD:
-                    case ACPI_TYPE_LOCAL_REGION_FIELD:
-                    case ACPI_TYPE_LOCAL_BANK_FIELD:
-                    case ACPI_TYPE_LOCAL_INDEX_FIELD:
-
-                        Status = AcpiExReadDataFromField (
-                            WalkState, ReturnDesc, &TempDesc);
-                        if (ACPI_FAILURE (Status))
-                        {
-                            return_ACPI_STATUS (Status);
-                        }
-
-                        ReturnDesc = TempDesc;
-                        break;
-
-                    default:
-
-                        /* Add another reference to the object */
-
-                        AcpiUtAddReference (ReturnDesc);
-                        break;
-                    }
+                                    (ACPI_NAMESPACE_NODE *) ReturnDesc);
                 }
+
+                /* Add another reference to the object! */
+
+                AcpiUtAddReference (ReturnDesc);
                 break;
 
-            default:
 
+            default:
                 ACPI_ERROR ((AE_INFO,
                     "Unknown class in reference(%p) - 0x%2.2X",
                     Operand[0], Operand[0]->Reference.Class));
@@ -1239,11 +1151,11 @@ AcpiExOpcode_1A_0T_1R (
         }
         break;
 
+
     default:
 
         ACPI_ERROR ((AE_INFO, "Unknown AML opcode 0x%X",
             WalkState->Opcode));
-
         Status = AE_AML_BAD_OPCODE;
         goto Cleanup;
     }
