@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,8 @@
  *
  *****************************************************************************/
 
+#define __EXSTORE_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acdispat.h"
@@ -132,12 +134,6 @@ AcpiExStoreObjectToIndex (
     ACPI_OPERAND_OBJECT     *DestDesc,
     ACPI_WALK_STATE         *WalkState);
 
-static ACPI_STATUS
-AcpiExStoreDirectToNode (
-    ACPI_OPERAND_OBJECT     *SourceDesc,
-    ACPI_NAMESPACE_NODE     *Node,
-    ACPI_WALK_STATE         *WalkState);
-
 
 /*******************************************************************************
  *
@@ -189,8 +185,8 @@ AcpiExStore (
          * Storing an object into a Named node.
          */
         Status = AcpiExStoreObjectToNode (SourceDesc,
-            (ACPI_NAMESPACE_NODE *) DestDesc, WalkState,
-            ACPI_IMPLICIT_CONVERSION);
+                    (ACPI_NAMESPACE_NODE *) DestDesc, WalkState,
+                    ACPI_IMPLICIT_CONVERSION);
 
         return_ACPI_STATUS (Status);
     }
@@ -200,7 +196,6 @@ AcpiExStore (
     switch (DestDesc->Common.Type)
     {
     case ACPI_TYPE_LOCAL_REFERENCE:
-
         break;
 
     case ACPI_TYPE_INTEGER:
@@ -219,7 +214,7 @@ AcpiExStore (
         /* Destination is not a Reference object */
 
         ACPI_ERROR ((AE_INFO,
-            "Target is not a Reference or Constant object - [%s] %p",
+            "Target is not a Reference or Constant object - %s [%p]",
             AcpiUtGetObjectTypeName (DestDesc), DestDesc));
 
         return_ACPI_STATUS (AE_AML_OPERAND_TYPE);
@@ -240,10 +235,11 @@ AcpiExStore (
         /* Storing an object into a Name "container" */
 
         Status = AcpiExStoreObjectToNode (SourceDesc,
-            RefDesc->Reference.Object,
-            WalkState, ACPI_IMPLICIT_CONVERSION);
+                    RefDesc->Reference.Object,
+                    WalkState, ACPI_IMPLICIT_CONVERSION);
         break;
 
+
     case ACPI_REFCLASS_INDEX:
 
         /* Storing to an Index (pointer into a packager or buffer) */
@@ -251,27 +247,31 @@ AcpiExStore (
         Status = AcpiExStoreObjectToIndex (SourceDesc, RefDesc, WalkState);
         break;
 
+
     case ACPI_REFCLASS_LOCAL:
     case ACPI_REFCLASS_ARG:
 
         /* Store to a method local/arg  */
 
         Status = AcpiDsStoreObjectToLocal (RefDesc->Reference.Class,
-            RefDesc->Reference.Value, SourceDesc, WalkState);
+                    RefDesc->Reference.Value, SourceDesc, WalkState);
         break;
 
+
     case ACPI_REFCLASS_DEBUG:
+
         /*
          * Storing to the Debug object causes the value stored to be
          * displayed and otherwise has no effect -- see ACPI Specification
          */
         ACPI_DEBUG_PRINT ((ACPI_DB_EXEC,
-            "**** Write to Debug Object: Object %p [%s] ****:\n\n",
+            "**** Write to Debug Object: Object %p %s ****:\n\n",
             SourceDesc, AcpiUtGetObjectTypeName (SourceDesc)));
 
         ACPI_DEBUG_OBJECT (SourceDesc, 0, 0);
         break;
 
+
     default:
 
         ACPI_ERROR ((AE_INFO, "Unknown Reference Class 0x%2.2X",
@@ -346,8 +346,7 @@ AcpiExStoreObjectToIndex (
         {
             /* Normal object, copy it */
 
-            Status = AcpiUtCopyIobjectToIobject (
-                SourceDesc, &NewDesc, WalkState);
+            Status = AcpiUtCopyIobjectToIobject (SourceDesc, &NewDesc, WalkState);
             if (ACPI_FAILURE (Status))
             {
                 return_ACPI_STATUS (Status);
@@ -381,7 +380,9 @@ AcpiExStoreObjectToIndex (
 
         break;
 
+
     case ACPI_TYPE_BUFFER_FIELD:
+
         /*
          * Store into a Buffer or String (not actually a real BufferField)
          * at a location defined by an Index.
@@ -429,7 +430,7 @@ AcpiExStoreObjectToIndex (
             /* All other types are invalid */
 
             ACPI_ERROR ((AE_INFO,
-                "Source must be type [Integer/Buffer/String], found [%s]",
+                "Source must be Integer/Buffer/String type, not %s",
                 AcpiUtGetObjectTypeName (SourceDesc)));
             return_ACPI_STATUS (AE_AML_OPERAND_TYPE);
         }
@@ -439,10 +440,11 @@ AcpiExStoreObjectToIndex (
         ObjDesc->Buffer.Pointer[IndexDesc->Reference.Value] = Value;
         break;
 
+
     default:
         ACPI_ERROR ((AE_INFO,
-            "Target is not of type [Package/BufferField]"));
-        Status = AE_AML_TARGET_TYPE;
+            "Target is not a Package or BufferField"));
+        Status = AE_AML_OPERAND_TYPE;
         break;
     }
 
@@ -463,20 +465,16 @@ AcpiExStoreObjectToIndex (
  *
  * DESCRIPTION: Store the object to the named object.
  *
- * The assignment of an object to a named object is handled here.
- * The value passed in will replace the current value (if any)
- * with the input value.
+ *              The Assignment of an object to a named object is handled here
+ *              The value passed in will replace the current value (if any)
+ *              with the input value.
  *
- * When storing into an object the data is converted to the
- * target object type then stored in the object. This means
- * that the target object type (for an initialized target) will
- * not be changed by a store operation. A CopyObject can change
- * the target type, however.
+ *              When storing into an object the data is converted to the
+ *              target object type then stored in the object. This means
+ *              that the target object type (for an initialized target) will
+ *              not be changed by a store operation.
  *
- * The ImplicitConversion flag is set to NO/FALSE only when
- * storing to an ArgX -- as per the rules of the ACPI spec.
- *
- * Assumes parameters are already validated.
+ *              Assumes parameters are already validated.
  *
  ******************************************************************************/
 
@@ -501,75 +499,9 @@ AcpiExStoreObjectToNode (
     TargetType = AcpiNsGetType (Node);
     TargetDesc = AcpiNsGetAttachedObject (Node);
 
-    ACPI_DEBUG_PRINT ((ACPI_DB_EXEC, "Storing %p [%s] to node %p [%s]\n",
+    ACPI_DEBUG_PRINT ((ACPI_DB_EXEC, "Storing %p(%s) into node %p(%s)\n",
         SourceDesc, AcpiUtGetObjectTypeName (SourceDesc),
-        Node, AcpiUtGetTypeName (TargetType)));
-
-    /* Only limited target types possible for everything except CopyObject */
-
-    if (WalkState->Opcode != AML_COPY_OBJECT_OP)
-    {
-        /*
-         * Only CopyObject allows all object types to be overwritten. For
-         * TargetRef(s), there are restrictions on the object types that
-         * are allowed.
-         *
-         * Allowable operations/typing for Store:
-         *
-         * 1) Simple Store
-         *      Integer     --> Integer (Named/Local/Arg)
-         *      String      --> String  (Named/Local/Arg)
-         *      Buffer      --> Buffer  (Named/Local/Arg)
-         *      Package     --> Package (Named/Local/Arg)
-         *
-         * 2) Store with implicit conversion
-         *      Integer     --> String or Buffer  (Named)
-         *      String      --> Integer or Buffer (Named)
-         *      Buffer      --> Integer or String (Named)
-         */
-        switch (TargetType)
-        {
-        case ACPI_TYPE_PACKAGE:
-            /*
-             * Here, can only store a package to an existing package.
-             * Storing a package to a Local/Arg is OK, and handled
-             * elsewhere.
-             */
-            if (WalkState->Opcode == AML_STORE_OP)
-            {
-                if (SourceDesc->Common.Type != ACPI_TYPE_PACKAGE)
-                {
-                    ACPI_ERROR ((AE_INFO,
-                        "Cannot assign type [%s] to [Package] "
-                        "(source must be type Pkg)",
-                        AcpiUtGetObjectTypeName (SourceDesc)));
-
-                    return_ACPI_STATUS (AE_AML_TARGET_TYPE);
-                }
-                break;
-            }
-
-        /* Fallthrough */
-
-        case ACPI_TYPE_DEVICE:
-        case ACPI_TYPE_EVENT:
-        case ACPI_TYPE_MUTEX:
-        case ACPI_TYPE_REGION:
-        case ACPI_TYPE_POWER:
-        case ACPI_TYPE_PROCESSOR:
-        case ACPI_TYPE_THERMAL:
-
-            ACPI_ERROR ((AE_INFO,
-                "Target must be [Buffer/Integer/String/Reference]"
-                ", found [%s] (%4.4s)",
-                AcpiUtGetTypeName (Node->Type), Node->Name.Ascii));
-
-            return_ACPI_STATUS (AE_AML_TARGET_TYPE);
-
-        default:
-            break;
-        }
-    }
+              Node, AcpiUtGetTypeName (TargetType)));
 
     /*
      * Resolve the source object to an actual value
@@ -581,34 +513,51 @@ AcpiExStoreObjectToNode (
         return_ACPI_STATUS (Status);
     }
 
+    /* If no implicit conversion, drop into the default case below */
+
+    if ((!ImplicitConversion) ||
+          ((WalkState->Opcode == AML_COPY_OP) &&
+           (TargetType != ACPI_TYPE_LOCAL_REGION_FIELD) &&
+           (TargetType != ACPI_TYPE_LOCAL_BANK_FIELD) &&
+           (TargetType != ACPI_TYPE_LOCAL_INDEX_FIELD)))
+    {
+        /*
+         * Force execution of default (no implicit conversion). Note:
+         * CopyObject does not perform an implicit conversion, as per the ACPI
+         * spec -- except in case of region/bank/index fields -- because these
+         * objects must retain their original type permanently.
+         */
+        TargetType = ACPI_TYPE_ANY;
+    }
+
     /* Do the actual store operation */
 
     switch (TargetType)
     {
-        /*
-         * The simple data types all support implicit source operand
-         * conversion before the store.
-         */
+    case ACPI_TYPE_BUFFER_FIELD:
+    case ACPI_TYPE_LOCAL_REGION_FIELD:
+    case ACPI_TYPE_LOCAL_BANK_FIELD:
+    case ACPI_TYPE_LOCAL_INDEX_FIELD:
+
+        /* For fields, copy the source data to the target field. */
+
+        Status = AcpiExWriteDataToField (SourceDesc, TargetDesc,
+                    &WalkState->ResultObj);
+        break;
+
+
     case ACPI_TYPE_INTEGER:
     case ACPI_TYPE_STRING:
     case ACPI_TYPE_BUFFER:
 
-        if ((WalkState->Opcode == AML_COPY_OBJECT_OP) ||
-            !ImplicitConversion)
-        {
-            /*
-             * However, CopyObject and Stores to ArgX do not perform
-             * an implicit conversion, as per the ACPI specification.
-             * A direct store is performed instead.
-             */
-            Status = AcpiExStoreDirectToNode (SourceDesc, Node, WalkState);
-            break;
-        }
-
-        /* Store with implicit source operand conversion support */
-
+        /*
+         * These target types are all of type Integer/String/Buffer, and
+         * therefore support implicit conversion before the store.
+         *
+         * Copy and/or convert the source object to a new target object
+         */
         Status = AcpiExStoreObjectToObject (SourceDesc, TargetDesc,
-            &NewDesc, WalkState);
+                    &NewDesc, WalkState);
         if (ACPI_FAILURE (Status))
         {
             return_ACPI_STATUS (Status);
@@ -621,96 +570,47 @@ AcpiExStoreObjectToNode (
              * the Name's type to that of the value being stored in it.
              * SourceDesc reference count is incremented by AttachObject.
              *
-             * Note: This may change the type of the node if an explicit
-             * store has been performed such that the node/object type
-             * has been changed.
+             * Note: This may change the type of the node if an explicit store
+             * has been performed such that the node/object type has been
+             * changed.
              */
-            Status = AcpiNsAttachObject (
-                Node, NewDesc, NewDesc->Common.Type);
+            Status = AcpiNsAttachObject (Node, NewDesc, NewDesc->Common.Type);
 
             ACPI_DEBUG_PRINT ((ACPI_DB_EXEC,
-                "Store type [%s] into [%s] via Convert/Attach\n",
+                "Store %s into %s via Convert/Attach\n",
                 AcpiUtGetObjectTypeName (SourceDesc),
                 AcpiUtGetObjectTypeName (NewDesc)));
         }
         break;
 
-    case ACPI_TYPE_BUFFER_FIELD:
-    case ACPI_TYPE_LOCAL_REGION_FIELD:
-    case ACPI_TYPE_LOCAL_BANK_FIELD:
-    case ACPI_TYPE_LOCAL_INDEX_FIELD:
-        /*
-         * For all fields, always write the source data to the target
-         * field. Any required implicit source operand conversion is
-         * performed in the function below as necessary. Note, field
-         * objects must retain their original type permanently.
-         */
-        Status = AcpiExWriteDataToField (SourceDesc, TargetDesc,
-            &WalkState->ResultObj);
-        break;
 
     default:
+
+        ACPI_DEBUG_PRINT ((ACPI_DB_EXEC,
+            "Storing [%s] (%p) directly into node [%s] (%p)"
+            " with no implicit conversion\n",
+            AcpiUtGetObjectTypeName (SourceDesc), SourceDesc,
+            AcpiUtGetObjectTypeName (TargetDesc), Node));
+
         /*
-         * CopyObject operator: No conversions for all other types.
-         * Instead, directly store a copy of the source object.
+         * No conversions for all other types. Directly store a copy of
+         * the source object. NOTE: This is a departure from the ACPI
+         * spec, which states "If conversion is impossible, abort the
+         * running control method".
          *
-         * This is the ACPI spec-defined behavior for the CopyObject
-         * operator. (Note, for this default case, all normal
-         * Store/Target operations exited above with an error).
+         * This code implements "If conversion is impossible, treat the
+         * Store operation as a CopyObject".
          */
-        Status = AcpiExStoreDirectToNode (SourceDesc, Node, WalkState);
+        Status = AcpiUtCopyIobjectToIobject (SourceDesc, &NewDesc, WalkState);
+        if (ACPI_FAILURE (Status))
+        {
+            return_ACPI_STATUS (Status);
+        }
+
+        Status = AcpiNsAttachObject (Node, NewDesc, NewDesc->Common.Type);
+        AcpiUtRemoveReference (NewDesc);
         break;
     }
 
     return_ACPI_STATUS (Status);
 }
-
-
-/*******************************************************************************
- *
- * FUNCTION:    AcpiExStoreDirectToNode
- *
- * PARAMETERS:  SourceDesc              - Value to be stored
- *              Node                    - Named object to receive the value
- *              WalkState               - Current walk state
- *
- * RETURN:      Status
- *
- * DESCRIPTION: "Store" an object directly to a node. This involves a copy
- *              and an attach.
- *
- ******************************************************************************/
-
-static ACPI_STATUS
-AcpiExStoreDirectToNode (
-    ACPI_OPERAND_OBJECT     *SourceDesc,
-    ACPI_NAMESPACE_NODE     *Node,
-    ACPI_WALK_STATE         *WalkState)
-{
-    ACPI_STATUS             Status;
-    ACPI_OPERAND_OBJECT     *NewDesc;
-
-
-    ACPI_FUNCTION_TRACE (ExStoreDirectToNode);
-
-
-    ACPI_DEBUG_PRINT ((ACPI_DB_EXEC,
-        "Storing [%s] (%p) directly into node [%s] (%p)"
-        " with no implicit conversion\n",
-        AcpiUtGetObjectTypeName (SourceDesc), SourceDesc,
-        AcpiUtGetTypeName (Node->Type), Node));
-
-    /* Copy the source object to a new object */
-
-    Status = AcpiUtCopyIobjectToIobject (SourceDesc, &NewDesc, WalkState);
-    if (ACPI_FAILURE (Status))
-    {
-        return_ACPI_STATUS (Status);
-    }
-
-    /* Attach the new object to the node */
-
-    Status = AcpiNsAttachObject (Node, NewDesc, NewDesc->Common.Type);
-    AcpiUtRemoveReference (NewDesc);
-    return_ACPI_STATUS (Status);
-}
