@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -130,11 +130,6 @@ AcpiHwEnableWakeupGpeBlock (
     ACPI_GPE_BLOCK_INFO     *GpeBlock,
     void                    *Context);
 
-static ACPI_STATUS
-AcpiHwGpeEnableWrite (
-    UINT8                   EnableMask,
-    ACPI_GPE_REGISTER_INFO  *GpeRegisterInfo);
-
 
 /******************************************************************************
  *
@@ -169,8 +164,6 @@ AcpiHwGetGpeRegisterBit (
  * RETURN:      Status
  *
  * DESCRIPTION: Enable or disable a single GPE in the parent enable register.
- *              The EnableMask field of the involved GPE register must be
- *              updated by the caller if necessary.
  *
  ******************************************************************************/
 
@@ -180,7 +173,7 @@ AcpiHwLowSetGpe (
     UINT32                  Action)
 {
     ACPI_GPE_REGISTER_INFO  *GpeRegisterInfo;
-    ACPI_STATUS             Status = AE_OK;
+    ACPI_STATUS             Status;
     UINT32                  EnableMask;
     UINT32                  RegisterBit;
 
@@ -211,9 +204,9 @@ AcpiHwLowSetGpe (
     {
     case ACPI_GPE_CONDITIONAL_ENABLE:
 
-        /* Only enable if the corresponding EnableMask bit is set */
+        /* Only enable if the EnableForRun bit is set */
 
-        if (!(RegisterBit & GpeRegisterInfo->EnableMask))
+        if (!(RegisterBit & GpeRegisterInfo->EnableForRun))
         {
             return (AE_BAD_PARAMETER);
         }
@@ -221,27 +214,21 @@ AcpiHwLowSetGpe (
         /*lint -fallthrough */
 
     case ACPI_GPE_ENABLE:
-
         ACPI_SET_BIT (EnableMask, RegisterBit);
         break;
 
     case ACPI_GPE_DISABLE:
-
         ACPI_CLEAR_BIT (EnableMask, RegisterBit);
         break;
 
     default:
-
         ACPI_ERROR ((AE_INFO, "Invalid GPE Action, %u", Action));
         return (AE_BAD_PARAMETER);
     }
 
-    if (!(RegisterBit & GpeRegisterInfo->MaskForRun))
-    {
-        /* Write the updated enable mask */
+    /* Write the updated enable mask */
 
-        Status = AcpiHwWrite (EnableMask, &GpeRegisterInfo->EnableAddress);
-    }
+    Status = AcpiHwWrite (EnableMask, &GpeRegisterInfo->EnableAddress);
     return (Status);
 }
 
@@ -283,7 +270,9 @@ AcpiHwClearGpe (
      */
     RegisterBit = AcpiHwGetGpeRegisterBit (GpeEventInfo);
 
-    Status = AcpiHwWrite (RegisterBit, &GpeRegisterInfo->StatusAddress);
+    Status = AcpiHwWrite (RegisterBit,
+                    &GpeRegisterInfo->StatusAddress);
+
     return (Status);
 }
 
@@ -321,14 +310,6 @@ AcpiHwGetGpeStatus (
         return (AE_BAD_PARAMETER);
     }
 
-    /* GPE currently handled? */
-
-    if (ACPI_GPE_DISPATCH_TYPE (GpeEventInfo->Flags) !=
-        ACPI_GPE_DISPATCH_NONE)
-    {
-        LocalEventStatus |= ACPI_EVENT_FLAG_HAS_HANDLER;
-    }
-
     /* Get the info block for the entire GPE register */
 
     GpeRegisterInfo = GpeEventInfo->RegisterInfo;
@@ -344,13 +325,6 @@ AcpiHwGetGpeStatus (
         LocalEventStatus |= ACPI_EVENT_FLAG_ENABLED;
     }
 
-    /* GPE currently masked? (masked for runtime?) */
-
-    if (RegisterBit & GpeRegisterInfo->MaskForRun)
-    {
-        LocalEventStatus |= ACPI_EVENT_FLAG_MASKED;
-    }
-
     /* GPE enabled for wake? */
 
     if (RegisterBit & GpeRegisterInfo->EnableForWake)
@@ -358,19 +332,6 @@ AcpiHwGetGpeStatus (
         LocalEventStatus |= ACPI_EVENT_FLAG_WAKE_ENABLED;
     }
 
-    /* GPE currently enabled (enable bit == 1)? */
-
-    Status = AcpiHwRead (&InByte, &GpeRegisterInfo->EnableAddress);
-    if (ACPI_FAILURE (Status))
-    {
-        return (Status);
-    }
-
-    if (RegisterBit & InByte)
-    {
-        LocalEventStatus |= ACPI_EVENT_FLAG_ENABLE_SET;
-    }
-
     /* GPE currently active (status bit == 1)? */
 
     Status = AcpiHwRead (&InByte, &GpeRegisterInfo->StatusAddress);
@@ -381,7 +342,7 @@ AcpiHwGetGpeStatus (
 
     if (RegisterBit & InByte)
     {
-        LocalEventStatus |= ACPI_EVENT_FLAG_STATUS_SET;
+        LocalEventStatus |= ACPI_EVENT_FLAG_SET;
     }
 
     /* Set return value */
@@ -391,34 +352,6 @@ AcpiHwGetGpeStatus (
 }
 
 
-/******************************************************************************
- *
- * FUNCTION:    AcpiHwGpeEnableWrite
- *
- * PARAMETERS:  EnableMask          - Bit mask to write to the GPE register
- *              GpeRegisterInfo     - Gpe Register info
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Write the enable mask byte to the given GPE register.
- *
- ******************************************************************************/
-
-static ACPI_STATUS
-AcpiHwGpeEnableWrite (
-    UINT8                   EnableMask,
-    ACPI_GPE_REGISTER_INFO  *GpeRegisterInfo)
-{
-    ACPI_STATUS             Status;
-
-
-    GpeRegisterInfo->EnableMask = EnableMask;
-
-    Status = AcpiHwWrite (EnableMask, &GpeRegisterInfo->EnableAddress);
-    return (Status);
-}
-
-
 /******************************************************************************
  *
  * FUNCTION:    AcpiHwDisableGpeBlock
@@ -448,7 +381,7 @@ AcpiHwDisableGpeBlock (
     {
         /* Disable all GPEs in this register */
 
-        Status = AcpiHwGpeEnableWrite (0x00, &GpeBlock->RegisterInfo[i]);
+        Status = AcpiHwWrite (0x00, &GpeBlock->RegisterInfo[i].EnableAddress);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -521,8 +454,6 @@ AcpiHwEnableRuntimeGpeBlock (
 {
     UINT32                  i;
     ACPI_STATUS             Status;
-    ACPI_GPE_REGISTER_INFO  *GpeRegisterInfo;
-    UINT8                   EnableMask;
 
 
     /* NOTE: assumes that all GPEs are currently disabled */
@@ -531,17 +462,15 @@ AcpiHwEnableRuntimeGpeBlock (
 
     for (i = 0; i < GpeBlock->RegisterCount; i++)
     {
-        GpeRegisterInfo = &GpeBlock->RegisterInfo[i];
-        if (!GpeRegisterInfo->EnableForRun)
+        if (!GpeBlock->RegisterInfo[i].EnableForRun)
         {
             continue;
         }
 
         /* Enable all "runtime" GPEs in this register */
 
-        EnableMask = GpeRegisterInfo->EnableForRun &
-            ~GpeRegisterInfo->MaskForRun;
-        Status = AcpiHwGpeEnableWrite (EnableMask, GpeRegisterInfo);
+        Status = AcpiHwWrite (GpeBlock->RegisterInfo[i].EnableForRun,
+                    &GpeBlock->RegisterInfo[i].EnableAddress);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
@@ -574,21 +503,21 @@ AcpiHwEnableWakeupGpeBlock (
 {
     UINT32                  i;
     ACPI_STATUS             Status;
-    ACPI_GPE_REGISTER_INFO  *GpeRegisterInfo;
 
 
     /* Examine each GPE Register within the block */
 
     for (i = 0; i < GpeBlock->RegisterCount; i++)
     {
-        GpeRegisterInfo = &GpeBlock->RegisterInfo[i];
+        if (!GpeBlock->RegisterInfo[i].EnableForWake)
+        {
+            continue;
+        }
 
-        /*
-         * Enable all "wake" GPEs in this register and disable the
-         * remaining ones.
-         */
-        Status = AcpiHwGpeEnableWrite (GpeRegisterInfo->EnableForWake,
-            GpeRegisterInfo);
+        /* Enable all "wake" GPEs in this register */
+
+        Status = AcpiHwWrite (GpeBlock->RegisterInfo[i].EnableForWake,
+                    &GpeBlock->RegisterInfo[i].EnableAddress);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
