@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,46 +111,8 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
-#define EXPORT_ACPI_INTERFACES
-
 #include "acpi.h"
 #include "accommon.h"
 #include "acnamesp.h"
@@ -200,15 +162,9 @@ AcpiReset (
          * For I/O space, write directly to the OSL. This bypasses the port
          * validation mechanism, which may block a valid write to the reset
          * register.
-         *
-         * NOTE:
-         * The ACPI spec requires the reset register width to be 8, so we
-         * hardcode it here and ignore the FADT value. This maintains
-         * compatibility with other ACPI implementations that have allowed
-         * BIOS code with bad register width values to go unnoticed.
          */
         Status = AcpiOsWritePort ((ACPI_IO_ADDRESS) ResetReg->Address,
-            AcpiGbl_FADT.ResetValue, ACPI_RESET_REGISTER_WIDTH);
+                    AcpiGbl_FADT.ResetValue, ResetReg->BitWidth);
     }
     else
     {
@@ -247,13 +203,82 @@ AcpiRead (
     UINT64                  *ReturnValue,
     ACPI_GENERIC_ADDRESS    *Reg)
 {
+    UINT32                  Value;
+    UINT32                  Width;
+    UINT64                  Address;
     ACPI_STATUS             Status;
 
 
     ACPI_FUNCTION_NAME (AcpiRead);
 
 
-    Status = AcpiHwRead (ReturnValue, Reg);
+    if (!ReturnValue)
+    {
+        return (AE_BAD_PARAMETER);
+    }
+
+    /* Validate contents of the GAS register. Allow 64-bit transfers */
+
+    Status = AcpiHwValidateRegister (Reg, 64, &Address);
+    if (ACPI_FAILURE (Status))
+    {
+        return (Status);
+    }
+
+    /* Initialize entire 64-bit return value to zero */
+
+    *ReturnValue = 0;
+    Value = 0;
+
+    /*
+     * Two address spaces supported: Memory or IO. PCI_Config is
+     * not supported here because the GAS structure is insufficient
+     */
+    if (Reg->SpaceId == ACPI_ADR_SPACE_SYSTEM_MEMORY)
+    {
+        Status = AcpiOsReadMemory ((ACPI_PHYSICAL_ADDRESS)
+                    Address, ReturnValue, Reg->BitWidth);
+        if (ACPI_FAILURE (Status))
+        {
+            return (Status);
+        }
+    }
+    else /* ACPI_ADR_SPACE_SYSTEM_IO, validated earlier */
+    {
+        Width = Reg->BitWidth;
+        if (Width == 64)
+        {
+            Width = 32; /* Break into two 32-bit transfers */
+        }
+
+        Status = AcpiHwReadPort ((ACPI_IO_ADDRESS)
+                    Address, &Value, Width);
+        if (ACPI_FAILURE (Status))
+        {
+            return (Status);
+        }
+        *ReturnValue = Value;
+
+        if (Reg->BitWidth == 64)
+        {
+            /* Read the top 32 bits */
+
+            Status = AcpiHwReadPort ((ACPI_IO_ADDRESS)
+                        (Address + 4), &Value, 32);
+            if (ACPI_FAILURE (Status))
+            {
+                return (Status);
+            }
+            *ReturnValue |= ((UINT64) Value << 32);
+        }
+    }
+
+    ACPI_DEBUG_PRINT ((ACPI_DB_IO,
+        "Read:  %8.8X%8.8X width %2d from %8.8X%8.8X (%s)\n",
+        ACPI_FORMAT_UINT64 (*ReturnValue), Reg->BitWidth,
+        ACPI_FORMAT_UINT64 (Address),
+        AcpiUtGetRegionName (Reg->SpaceId)));
+
     return (Status);
 }
 
@@ -278,13 +303,67 @@ AcpiWrite (
     UINT64                  Value,
     ACPI_GENERIC_ADDRESS    *Reg)
 {
+    UINT32                  Width;
+    UINT64                  Address;
     ACPI_STATUS             Status;
 
 
     ACPI_FUNCTION_NAME (AcpiWrite);
 
 
-    Status = AcpiHwWrite (Value, Reg);
+    /* Validate contents of the GAS register. Allow 64-bit transfers */
+
+    Status = AcpiHwValidateRegister (Reg, 64, &Address);
+    if (ACPI_FAILURE (Status))
+    {
+        return (Status);
+    }
+
+    /*
+     * Two address spaces supported: Memory or IO. PCI_Config is
+     * not supported here because the GAS structure is insufficient
+     */
+    if (Reg->SpaceId == ACPI_ADR_SPACE_SYSTEM_MEMORY)
+    {
+        Status = AcpiOsWriteMemory ((ACPI_PHYSICAL_ADDRESS)
+                    Address, Value, Reg->BitWidth);
+        if (ACPI_FAILURE (Status))
+        {
+            return (Status);
+        }
+    }
+    else /* ACPI_ADR_SPACE_SYSTEM_IO, validated earlier */
+    {
+        Width = Reg->BitWidth;
+        if (Width == 64)
+        {
+            Width = 32; /* Break into two 32-bit transfers */
+        }
+
+        Status = AcpiHwWritePort ((ACPI_IO_ADDRESS)
+                    Address, ACPI_LODWORD (Value), Width);
+        if (ACPI_FAILURE (Status))
+        {
+            return (Status);
+        }
+
+        if (Reg->BitWidth == 64)
+        {
+            Status = AcpiHwWritePort ((ACPI_IO_ADDRESS)
+                        (Address + 4), ACPI_HIDWORD (Value), 32);
+            if (ACPI_FAILURE (Status))
+            {
+                return (Status);
+            }
+        }
+    }
+
+    ACPI_DEBUG_PRINT ((ACPI_DB_IO,
+        "Wrote: %8.8X%8.8X width %2d   to %8.8X%8.8X (%s)\n",
+        ACPI_FORMAT_UINT64 (Value), Reg->BitWidth,
+        ACPI_FORMAT_UINT64 (Address),
+        AcpiUtGetRegionName (Reg->SpaceId)));
+
     return (Status);
 }
 
@@ -342,7 +421,7 @@ AcpiReadBitRegister (
     /* Read the entire parent register */
 
     Status = AcpiHwRegisterRead (BitRegInfo->ParentRegister,
-        &RegisterValue);
+                &RegisterValue);
     if (ACPI_FAILURE (Status))
     {
         return_ACPI_STATUS (Status);
@@ -351,7 +430,7 @@ AcpiReadBitRegister (
     /* Normalize the value that was read, mask off other bits */
 
     Value = ((RegisterValue & BitRegInfo->AccessBitMask)
-        >> BitRegInfo->BitPosition);
+                >> BitRegInfo->BitPosition);
 
     ACPI_DEBUG_PRINT ((ACPI_DB_IO,
         "BitReg %X, ParentReg %X, Actual %8.8X, ReturnValue %8.8X\n",
@@ -423,7 +502,7 @@ AcpiWriteBitRegister (
          * interested in
          */
         Status = AcpiHwRegisterRead (BitRegInfo->ParentRegister,
-            &RegisterValue);
+                    &RegisterValue);
         if (ACPI_FAILURE (Status))
         {
             goto UnlockAndExit;
@@ -437,7 +516,7 @@ AcpiWriteBitRegister (
             BitRegInfo->AccessBitMask, Value);
 
         Status = AcpiHwRegisterWrite (BitRegInfo->ParentRegister,
-            RegisterValue);
+                    RegisterValue);
     }
     else
     {
@@ -457,7 +536,7 @@ AcpiWriteBitRegister (
         if (RegisterValue)
         {
             Status = AcpiHwRegisterWrite (ACPI_REGISTER_PM1_STATUS,
-                RegisterValue);
+                        RegisterValue);
         }
     }
 
@@ -549,19 +628,12 @@ AcpiGetSleepTypeData (
      * Evaluate the \_Sx namespace object containing the register values
      * for this state
      */
-    Info->RelativePathname = AcpiGbl_SleepStateNames[SleepState];
-
+    Info->RelativePathname = ACPI_CAST_PTR (
+        char, AcpiGbl_SleepStateNames[SleepState]);
     Status = AcpiNsEvaluate (Info);
     if (ACPI_FAILURE (Status))
     {
-        if (Status == AE_NOT_FOUND)
-        {
-            /* The _Sx states are optional, ignore NOT_FOUND */
-
-            goto FinalCleanup;
-        }
-
-        goto WarningCleanup;
+        goto Cleanup;
     }
 
     /* Must have a return object */
@@ -571,7 +643,7 @@ AcpiGetSleepTypeData (
         ACPI_ERROR ((AE_INFO, "No Sleep State object returned from [%s]",
             Info->RelativePathname));
         Status = AE_AML_NO_RETURN_VALUE;
-        goto WarningCleanup;
+        goto Cleanup;
     }
 
     /* Return object must be of type Package */
@@ -580,7 +652,7 @@ AcpiGetSleepTypeData (
     {
         ACPI_ERROR ((AE_INFO, "Sleep State return object is not a Package"));
         Status = AE_AML_OPERAND_TYPE;
-        goto ReturnValueCleanup;
+        goto Cleanup1;
     }
 
     /*
@@ -592,12 +664,10 @@ AcpiGetSleepTypeData (
     switch (Info->ReturnObject->Package.Count)
     {
     case 0:
-
         Status = AE_AML_PACKAGE_LIMIT;
         break;
 
     case 1:
-
         if (Elements[0]->Common.Type != ACPI_TYPE_INTEGER)
         {
             Status = AE_AML_OPERAND_TYPE;
@@ -612,7 +682,6 @@ AcpiGetSleepTypeData (
 
     case 2:
     default:
-
         if ((Elements[0]->Common.Type != ACPI_TYPE_INTEGER) ||
             (Elements[1]->Common.Type != ACPI_TYPE_INTEGER))
         {
@@ -627,18 +696,16 @@ AcpiGetSleepTypeData (
         break;
     }
 
-ReturnValueCleanup:
+Cleanup1:
     AcpiUtRemoveReference (Info->ReturnObject);
 
-WarningCleanup:
+Cleanup:
     if (ACPI_FAILURE (Status))
     {
         ACPI_EXCEPTION ((AE_INFO, Status,
-            "While evaluating Sleep State [%s]",
-            Info->RelativePathname));
+            "While evaluating Sleep State [%s]", Info->RelativePathname));
     }
 
-FinalCleanup:
     ACPI_FREE (Info);
     return_ACPI_STATUS (Status);
 }
