@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #define ACPI_CREATE_PREDEFINED_TABLE
@@ -273,16 +237,6 @@ AcpiNsCheckReturnValue (
         goto Exit;
     }
 
-    /*
-     *
-     * 4) If there is no return value and it is optional, just return
-     * AE_OK (_WAK).
-     */
-    if (!(*ReturnObjectPtr))
-    {
-        goto Exit;
-    }
-
     /*
      * For returned Package objects, check the type of all sub-objects.
      * Note: Package may have been newly created by call above.
@@ -293,13 +247,7 @@ AcpiNsCheckReturnValue (
         Status = AcpiNsCheckPackage (Info, ReturnObjectPtr);
         if (ACPI_FAILURE (Status))
         {
-            /* We might be able to fix some errors */
-
-            if ((Status != AE_AML_OPERAND_TYPE) &&
-                (Status != AE_AML_OPERAND_VALUE))
-            {
-                goto Exit;
-            }
+            goto Exit;
         }
     }
 
@@ -357,7 +305,7 @@ AcpiNsCheckObjectType (
 {
     ACPI_OPERAND_OBJECT         *ReturnObject = *ReturnObjectPtr;
     ACPI_STATUS                 Status = AE_OK;
-    char                        TypeBuffer[96]; /* Room for 10 types */
+    char                        TypeBuffer[48]; /* Room for 5 types */
 
 
     /* A Namespace node should not get here, but make sure */
@@ -411,13 +359,7 @@ TypeErrorExit:
 
     AcpiUtGetExpectedReturnTypes (TypeBuffer, ExpectedBtypes);
 
-    if (!ReturnObject)
-    {
-        ACPI_WARN_PREDEFINED ((AE_INFO, Info->FullPathname, Info->NodeFlags,
-            "Expected return object of type %s",
-            TypeBuffer));
-    }
-    else if (PackageIndex == ACPI_NOT_PACKAGE_ELEMENT)
+    if (PackageIndex == ACPI_NOT_PACKAGE_ELEMENT)
     {
         ACPI_WARN_PREDEFINED ((AE_INFO, Info->FullPathname, Info->NodeFlags,
             "Return type mismatch - found %s, expected %s",
@@ -507,32 +449,26 @@ AcpiNsGetBitmappedType (
     switch (ReturnObject->Common.Type)
     {
     case ACPI_TYPE_INTEGER:
-
         ReturnBtype = ACPI_RTYPE_INTEGER;
         break;
 
     case ACPI_TYPE_BUFFER:
-
         ReturnBtype = ACPI_RTYPE_BUFFER;
         break;
 
     case ACPI_TYPE_STRING:
-
         ReturnBtype = ACPI_RTYPE_STRING;
         break;
 
     case ACPI_TYPE_PACKAGE:
-
         ReturnBtype = ACPI_RTYPE_PACKAGE;
         break;
 
     case ACPI_TYPE_LOCAL_REFERENCE:
-
         ReturnBtype = ACPI_RTYPE_REFERENCE;
         break;
 
     default:
-
         /* Not one of the supported objects, must be incorrect */
 
         ReturnBtype = ACPI_RTYPE_ANY;
