@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2022, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
@@ -178,12 +142,6 @@ AcpiNsCheckPackageElements (
     UINT32                      Count2,
     UINT32                      StartIndex);
 
-static ACPI_STATUS
-AcpiNsCustomPackage (
-    ACPI_EVALUATE_INFO          *Info,
-    ACPI_OPERAND_OBJECT         **Elements,
-    UINT32                      Count);
-
 
 /*******************************************************************************
  *
@@ -214,7 +172,7 @@ AcpiNsCheckPackage (
     UINT32                      i;
 
 
-    ACPI_FUNCTION_TRACE (NsCheckPackage);
+    ACPI_FUNCTION_NAME (NsCheckPackage);
 
 
     /* The package info for this name is in the next table entry */
@@ -245,31 +203,27 @@ AcpiNsCheckPackage (
     {
         if (Package->RetInfo.Type == ACPI_PTYPE1_VAR)
         {
-            return_ACPI_STATUS (AE_OK);
+            return (AE_OK);
         }
 
         ACPI_WARN_PREDEFINED ((AE_INFO, Info->FullPathname, Info->NodeFlags,
             "Return Package has no elements (empty)"));
 
-        return_ACPI_STATUS (AE_AML_OPERAND_VALUE);
+        return (AE_AML_OPERAND_VALUE);
     }
 
     /*
      * Decode the type of the expected package contents
      *
      * PTYPE1 packages contain no subpackages
-     * PTYPE2 packages contain subpackages
+     * PTYPE2 packages contain sub-packages
      */
     switch (Package->RetInfo.Type)
     {
-    case ACPI_PTYPE_CUSTOM:
-
-        Status = AcpiNsCustomPackage (Info, Elements, Count);
-        break;
-
     case ACPI_PTYPE1_FIXED:
+
         /*
-         * The package count is fixed and there are no subpackages
+         * The package count is fixed and there are no sub-packages
          *
          * If package is too small, exit.
          * If package is larger than expected, issue warning but continue
@@ -290,31 +244,34 @@ AcpiNsCheckPackage (
         /* Validate all elements of the returned package */
 
         Status = AcpiNsCheckPackageElements (Info, Elements,
-            Package->RetInfo.ObjectType1, Package->RetInfo.Count1,
-            Package->RetInfo.ObjectType2, Package->RetInfo.Count2, 0);
+                    Package->RetInfo.ObjectType1, Package->RetInfo.Count1,
+                    Package->RetInfo.ObjectType2, Package->RetInfo.Count2, 0);
         break;
 
+
     case ACPI_PTYPE1_VAR:
+
         /*
-         * The package count is variable, there are no subpackages, and all
+         * The package count is variable, there are no sub-packages, and all
          * elements must be of the same type
          */
         for (i = 0; i < Count; i++)
         {
             Status = AcpiNsCheckObjectType (Info, Elements,
-                Package->RetInfo.ObjectType1, i);
+                        Package->RetInfo.ObjectType1, i);
             if (ACPI_FAILURE (Status))
             {
-                return_ACPI_STATUS (Status);
+                return (Status);
             }
-
             Elements++;
         }
         break;
 
+
     case ACPI_PTYPE1_OPTION:
+
         /*
-         * The package count is variable, there are no subpackages. There are
+         * The package count is variable, there are no sub-packages. There are
          * a fixed number of required elements, and a variable number of
          * optional elements.
          *
@@ -335,10 +292,10 @@ AcpiNsCheckPackage (
                 /* These are the required package elements (0, 1, or 2) */
 
                 Status = AcpiNsCheckObjectType (Info, Elements,
-                    Package->RetInfo3.ObjectType[i], i);
+                            Package->RetInfo3.ObjectType[i], i);
                 if (ACPI_FAILURE (Status))
                 {
-                    return_ACPI_STATUS (Status);
+                    return (Status);
                 }
             }
             else
@@ -346,45 +303,46 @@ AcpiNsCheckPackage (
                 /* These are the optional package elements */
 
                 Status = AcpiNsCheckObjectType (Info, Elements,
-                    Package->RetInfo3.TailObjectType, i);
+                            Package->RetInfo3.TailObjectType, i);
                 if (ACPI_FAILURE (Status))
                 {
-                    return_ACPI_STATUS (Status);
+                    return (Status);
                 }
             }
-
             Elements++;
         }
         break;
 
+
     case ACPI_PTYPE2_REV_FIXED:
 
         /* First element is the (Integer) revision */
 
-        Status = AcpiNsCheckObjectType (
-            Info, Elements, ACPI_RTYPE_INTEGER, 0);
+        Status = AcpiNsCheckObjectType (Info, Elements,
+                    ACPI_RTYPE_INTEGER, 0);
         if (ACPI_FAILURE (Status))
         {
-            return_ACPI_STATUS (Status);
+            return (Status);
         }
 
         Elements++;
         Count--;
 
-        /* Examine the subpackages */
+        /* Examine the sub-packages */
 
         Status = AcpiNsCheckPackageList (Info, Package, Elements, Count);
         break;
 
+
     case ACPI_PTYPE2_PKG_COUNT:
 
-        /* First element is the (Integer) count of subpackages to follow */
+        /* First element is the (Integer) count of sub-packages to follow */
 
-        Status = AcpiNsCheckObjectType (
-            Info, Elements, ACPI_RTYPE_INTEGER, 0);
+        Status = AcpiNsCheckObjectType (Info, Elements,
+                    ACPI_RTYPE_INTEGER, 0);
         if (ACPI_FAILURE (Status))
         {
-            return_ACPI_STATUS (Status);
+            return (Status);
         }
 
         /*
@@ -400,21 +358,23 @@ AcpiNsCheckPackage (
         Count = ExpectedCount;
         Elements++;
 
-        /* Examine the subpackages */
+        /* Examine the sub-packages */
 
         Status = AcpiNsCheckPackageList (Info, Package, Elements, Count);
         break;
 
+
     case ACPI_PTYPE2:
     case ACPI_PTYPE2_FIXED:
     case ACPI_PTYPE2_MIN:
     case ACPI_PTYPE2_COUNT:
     case ACPI_PTYPE2_FIX_VAR:
+
         /*
          * These types all return a single Package that consists of a
-         * variable number of subpackages.
+         * variable number of sub-Packages.
          *
-         * First, ensure that the first element is a subpackage. If not,
+         * First, ensure that the first element is a sub-Package. If not,
          * the BIOS may have incorrectly returned the object as a single
          * package instead of a Package of Packages (a common error if
          * there is only one entry). We may be able to repair this by
@@ -424,11 +384,10 @@ AcpiNsCheckPackage (
         {
             /* Create the new outer package and populate it */
 
-            Status = AcpiNsWrapWithPackage (
-                Info, ReturnObject, ReturnObjectPtr);
+            Status = AcpiNsWrapWithPackage (Info, ReturnObject, ReturnObjectPtr);
             if (ACPI_FAILURE (Status))
             {
-                return_ACPI_STATUS (Status);
+                return (Status);
             }
 
             /* Update locals to point to the new package (of 1 element) */
@@ -438,57 +397,11 @@ AcpiNsCheckPackage (
             Count = 1;
         }
 
-        /* Examine the subpackages */
+        /* Examine the sub-packages */
 
         Status = AcpiNsCheckPackageList (Info, Package, Elements, Count);
         break;
 
-    case ACPI_PTYPE2_VAR_VAR:
-        /*
-         * Returns a variable list of packages, each with a variable list
-         * of objects.
-         */
-        break;
-
-    case ACPI_PTYPE2_UUID_PAIR:
-
-        /* The package must contain pairs of (UUID + type) */
-
-        if (Count & 1)
-        {
-            ExpectedCount = Count + 1;
-            goto PackageTooSmall;
-        }
-
-        while (Count > 0)
-        {
-            Status = AcpiNsCheckObjectType(Info, Elements,
-                Package->RetInfo.ObjectType1, 0);
-            if (ACPI_FAILURE(Status))
-            {
-                return_ACPI_STATUS (Status);
-            }
-
-            /* Validate length of the UUID buffer */
-
-            if ((*Elements)->Buffer.Length != 16)
-            {
-                ACPI_WARN_PREDEFINED ((AE_INFO, Info->FullPathname,
-                    Info->NodeFlags, "Invalid length for UUID Buffer"));
-                return_ACPI_STATUS (AE_AML_OPERAND_VALUE);
-            }
-
-            Status = AcpiNsCheckObjectType(Info, Elements + 1,
-                Package->RetInfo.ObjectType2, 0);
-            if (ACPI_FAILURE(Status))
-            {
-                return_ACPI_STATUS (Status);
-            }
-
-            Elements += 2;
-            Count -= 2;
-        }
-        break;
 
     default:
 
@@ -498,10 +411,10 @@ AcpiNsCheckPackage (
             "Invalid internal return type in table entry: %X",
             Package->RetInfo.Type));
 
-        return_ACPI_STATUS (AE_AML_INTERNAL);
+        return (AE_AML_INTERNAL);
     }
 
-    return_ACPI_STATUS (Status);
+    return (Status);
 
 
 PackageTooSmall:
@@ -512,7 +425,7 @@ PackageTooSmall:
         "Return Package is too small - found %u elements, expected %u",
         Count, ExpectedCount));
 
-    return_ACPI_STATUS (AE_AML_OPERAND_VALUE);
+    return (AE_AML_OPERAND_VALUE);
 }
 
 
@@ -548,9 +461,9 @@ AcpiNsCheckPackageList (
 
 
     /*
-     * Validate each subpackage in the parent Package
+     * Validate each sub-Package in the parent Package
      *
-     * NOTE: assumes list of subpackages contains no NULL elements.
+     * NOTE: assumes list of sub-packages contains no NULL elements.
      * Any NULL elements should have been removed by earlier call
      * to AcpiNsRemoveNullElements.
      */
@@ -563,13 +476,13 @@ AcpiNsCheckPackageList (
         /* Each sub-object must be of type Package */
 
         Status = AcpiNsCheckObjectType (Info, &SubPackage,
-            ACPI_RTYPE_PACKAGE, i);
+                    ACPI_RTYPE_PACKAGE, i);
         if (ACPI_FAILURE (Status))
         {
             return (Status);
         }
 
-        /* Examine the different types of expected subpackages */
+        /* Examine the different types of expected sub-packages */
 
         Info->ParentPackage = SubPackage;
         switch (Package->RetInfo.Type)
@@ -587,16 +500,17 @@ AcpiNsCheckPackageList (
             }
 
             Status = AcpiNsCheckPackageElements (Info, SubElements,
-                Package->RetInfo.ObjectType1,
-                Package->RetInfo.Count1,
-                Package->RetInfo.ObjectType2,
-                Package->RetInfo.Count2, 0);
+                        Package->RetInfo.ObjectType1,
+                        Package->RetInfo.Count1,
+                        Package->RetInfo.ObjectType2,
+                        Package->RetInfo.Count2, 0);
             if (ACPI_FAILURE (Status))
             {
                 return (Status);
             }
             break;
 
+
         case ACPI_PTYPE2_FIX_VAR:
             /*
              * Each subpackage has a fixed number of elements and an
@@ -609,25 +523,20 @@ AcpiNsCheckPackageList (
             }
 
             Status = AcpiNsCheckPackageElements (Info, SubElements,
-                Package->RetInfo.ObjectType1,
-                Package->RetInfo.Count1,
-                Package->RetInfo.ObjectType2,
-                SubPackage->Package.Count - Package->RetInfo.Count1, 0);
+                        Package->RetInfo.ObjectType1,
+                        Package->RetInfo.Count1,
+                        Package->RetInfo.ObjectType2,
+                        SubPackage->Package.Count - Package->RetInfo.Count1, 0);
             if (ACPI_FAILURE (Status))
             {
                 return (Status);
             }
             break;
 
-        case ACPI_PTYPE2_VAR_VAR:
-            /*
-             * Each subpackage has a fixed or variable number of elements
-             */
-            break;
 
         case ACPI_PTYPE2_FIXED:
 
-            /* Each subpackage has a fixed length */
+            /* Each sub-package has a fixed length */
 
             ExpectedCount = Package->RetInfo2.Count;
             if (SubPackage->Package.Count < ExpectedCount)
@@ -635,12 +544,12 @@ AcpiNsCheckPackageList (
                 goto PackageTooSmall;
             }
 
-            /* Check the type of each subpackage element */
+            /* Check the type of each sub-package element */
 
             for (j = 0; j < ExpectedCount; j++)
             {
                 Status = AcpiNsCheckObjectType (Info, &SubElements[j],
-                    Package->RetInfo2.ObjectType[j], j);
+                            Package->RetInfo2.ObjectType[j], j);
                 if (ACPI_FAILURE (Status))
                 {
                     return (Status);
@@ -648,9 +557,10 @@ AcpiNsCheckPackageList (
             }
             break;
 
+
         case ACPI_PTYPE2_MIN:
 
-            /* Each subpackage has a variable but minimum length */
+            /* Each sub-package has a variable but minimum length */
 
             ExpectedCount = Package->RetInfo.Count1;
             if (SubPackage->Package.Count < ExpectedCount)
@@ -658,24 +568,26 @@ AcpiNsCheckPackageList (
                 goto PackageTooSmall;
             }
 
-            /* Check the type of each subpackage element */
+            /* Check the type of each sub-package element */
 
             Status = AcpiNsCheckPackageElements (Info, SubElements,
-                Package->RetInfo.ObjectType1,
-                SubPackage->Package.Count, 0, 0, 0);
+                        Package->RetInfo.ObjectType1,
+                        SubPackage->Package.Count, 0, 0, 0);
             if (ACPI_FAILURE (Status))
             {
                 return (Status);
             }
             break;
 
+
         case ACPI_PTYPE2_COUNT:
+
             /*
              * First element is the (Integer) count of elements, including
              * the count field (the ACPI name is NumElements)
              */
             Status = AcpiNsCheckObjectType (Info, SubElements,
-                ACPI_RTYPE_INTEGER, 0);
+                        ACPI_RTYPE_INTEGER, 0);
             if (ACPI_FAILURE (Status))
             {
                 return (Status);
@@ -690,13 +602,11 @@ AcpiNsCheckPackageList (
             {
                 goto PackageTooSmall;
             }
-
             if (SubPackage->Package.Count < Package->RetInfo.Count1)
             {
                 ExpectedCount = Package->RetInfo.Count1;
                 goto PackageTooSmall;
             }
-
             if (ExpectedCount == 0)
             {
                 /*
@@ -709,21 +619,20 @@ AcpiNsCheckPackageList (
                 (*SubElements)->Integer.Value = ExpectedCount;
             }
 
-            /* Check the type of each subpackage element */
+            /* Check the type of each sub-package element */
 
             Status = AcpiNsCheckPackageElements (Info, (SubElements + 1),
-                Package->RetInfo.ObjectType1,
-                (ExpectedCount - 1), 0, 0, 1);
+                        Package->RetInfo.ObjectType1,
+                        (ExpectedCount - 1), 0, 0, 1);
             if (ACPI_FAILURE (Status))
             {
                 return (Status);
             }
             break;
 
+
         default: /* Should not get here, type was validated by caller */
 
-            ACPI_ERROR ((AE_INFO, "Invalid Package type: %X",
-                Package->RetInfo.Type));
             return (AE_AML_INTERNAL);
         }
 
@@ -735,102 +644,16 @@ AcpiNsCheckPackageList (
 
 PackageTooSmall:
 
-    /* The subpackage count was smaller than required */
+    /* The sub-package count was smaller than required */
 
     ACPI_WARN_PREDEFINED ((AE_INFO, Info->FullPathname, Info->NodeFlags,
-        "Return SubPackage[%u] is too small - found %u elements, expected %u",
+        "Return Sub-Package[%u] is too small - found %u elements, expected %u",
         i, SubPackage->Package.Count, ExpectedCount));
 
     return (AE_AML_OPERAND_VALUE);
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    AcpiNsCustomPackage
- *
- * PARAMETERS:  Info                - Method execution information block
- *              Elements            - Pointer to the package elements array
- *              Count               - Element count for the package
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Check a returned package object for the correct count and
- *              correct type of all sub-objects.
- *
- * NOTE: Currently used for the _BIX method only. When needed for two or more
- * methods, probably a detect/dispatch mechanism will be required.
- *
- ******************************************************************************/
-
-static ACPI_STATUS
-AcpiNsCustomPackage (
-    ACPI_EVALUATE_INFO          *Info,
-    ACPI_OPERAND_OBJECT         **Elements,
-    UINT32                      Count)
-{
-    UINT32                      ExpectedCount;
-    UINT32                      Version;
-    ACPI_STATUS                 Status = AE_OK;
-
-
-    ACPI_FUNCTION_NAME (NsCustomPackage);
-
-
-    /* Get version number, must be Integer */
-
-    if ((*Elements)->Common.Type != ACPI_TYPE_INTEGER)
-    {
-        ACPI_WARN_PREDEFINED ((AE_INFO, Info->FullPathname, Info->NodeFlags,
-            "Return Package has invalid object type for version number"));
-        return_ACPI_STATUS (AE_AML_OPERAND_TYPE);
-    }
-
-    Version = (UINT32) (*Elements)->Integer.Value;
-    ExpectedCount = 21;         /* Version 1 */
-
-    if (Version == 0)
-    {
-        ExpectedCount = 20;     /* Version 0 */
-    }
-
-    if (Count < ExpectedCount)
-    {
-        ACPI_WARN_PREDEFINED ((AE_INFO, Info->FullPathname, Info->NodeFlags,
-            "Return Package is too small - found %u elements, expected %u",
-            Count, ExpectedCount));
-        return_ACPI_STATUS (AE_AML_OPERAND_VALUE);
-    }
-    else if (Count > ExpectedCount)
-    {
-        ACPI_DEBUG_PRINT ((ACPI_DB_REPAIR,
-            "%s: Return Package is larger than needed - "
-            "found %u, expected %u\n",
-            Info->FullPathname, Count, ExpectedCount));
-    }
-
-    /* Validate all elements of the returned package */
-
-    Status = AcpiNsCheckPackageElements (Info, Elements,
-        ACPI_RTYPE_INTEGER, 16,
-        ACPI_RTYPE_STRING, 4, 0);
-    if (ACPI_FAILURE (Status))
-    {
-        return_ACPI_STATUS (Status);
-    }
-
-    /* Version 1 has a single trailing integer */
-
-    if (Version > 0)
-    {
-        Status = AcpiNsCheckPackageElements (Info, Elements + 20,
-            ACPI_RTYPE_INTEGER, 1, 0, 0, 20);
-    }
-
-    return_ACPI_STATUS (Status);
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AcpiNsCheckPackageElements
@@ -865,8 +688,6 @@ AcpiNsCheckPackageElements (
     UINT32                      i;
 
 
-    ACPI_FUNCTION_TRACE (NsCheckPackageElements);
-
     /*
      * Up to two groups of package elements are supported by the data
      * structure. All elements in each group must be of the same type.
@@ -875,26 +696,24 @@ AcpiNsCheckPackageElements (
     for (i = 0; i < Count1; i++)
     {
         Status = AcpiNsCheckObjectType (Info, ThisElement,
-            Type1, i + StartIndex);
+                    Type1, i + StartIndex);
         if (ACPI_FAILURE (Status))
         {
-            return_ACPI_STATUS (Status);
+            return (Status);
         }
-
         ThisElement++;
     }
 
     for (i = 0; i < Count2; i++)
     {
         Status = AcpiNsCheckObjectType (Info, ThisElement,
-            Type2, (i + Count1 + StartIndex));
+                    Type2, (i + Count1 + StartIndex));
         if (ACPI_FAILURE (Status))
         {
-            return_ACPI_STATUS (Status);
+            return (Status);
         }
-
         ThisElement++;
     }
 
-    return_ACPI_STATUS (AE_OK);
+    return (AE_OK);
 }
