@@ -9,7 +9,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -112,44 +112,10 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+#define __NSREPAIR2_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acnamesp.h"
@@ -169,7 +135,7 @@ ACPI_STATUS (*ACPI_REPAIR_FUNCTION) (
 
 typedef struct acpi_repair_info
 {
-    char                    Name[ACPI_NAMESEG_SIZE];
+    char                    Name[ACPI_NAME_SIZE];
     ACPI_REPAIR_FUNCTION    RepairFunction;
 
 } ACPI_REPAIR_INFO;
@@ -191,11 +157,6 @@ AcpiNsRepair_CID (
     ACPI_EVALUATE_INFO      *Info,
     ACPI_OPERAND_OBJECT     **ReturnObjectPtr);
 
-static ACPI_STATUS
-AcpiNsRepair_CST (
-    ACPI_EVALUATE_INFO      *Info,
-    ACPI_OPERAND_OBJECT     **ReturnObjectPtr);
-
 static ACPI_STATUS
 AcpiNsRepair_FDE (
     ACPI_EVALUATE_INFO      *Info,
@@ -206,11 +167,6 @@ AcpiNsRepair_HID (
     ACPI_EVALUATE_INFO      *Info,
     ACPI_OPERAND_OBJECT     **ReturnObjectPtr);
 
-static ACPI_STATUS
-AcpiNsRepair_PRT (
-    ACPI_EVALUATE_INFO      *Info,
-    ACPI_OPERAND_OBJECT     **ReturnObjectPtr);
-
 static ACPI_STATUS
 AcpiNsRepair_PSS (
     ACPI_EVALUATE_INFO      *Info,
@@ -225,22 +181,11 @@ static ACPI_STATUS
 AcpiNsCheckSortedList (
     ACPI_EVALUATE_INFO      *Info,
     ACPI_OPERAND_OBJECT     *ReturnObject,
-    UINT32                  StartIndex,
     UINT32                  ExpectedCount,
     UINT32                  SortIndex,
     UINT8                   SortDirection,
     char                    *SortKeyName);
 
-/* Values for SortDirection above */
-
-#define ACPI_SORT_ASCENDING     0
-#define ACPI_SORT_DESCENDING    1
-
-static void
-AcpiNsRemoveElement (
-    ACPI_OPERAND_OBJECT     *ObjDesc,
-    UINT32                  Index);
-
 static void
 AcpiNsSortList (
     ACPI_OPERAND_OBJECT     **Elements,
@@ -248,6 +193,11 @@ AcpiNsSortList (
     UINT32                  Index,
     UINT8                   SortDirection);
 
+/* Values for SortDirection above */
+
+#define ACPI_SORT_ASCENDING     0
+#define ACPI_SORT_DESCENDING    1
+
 
 /*
  * This table contains the names of the predefined methods for which we can
@@ -257,11 +207,9 @@ AcpiNsSortList (
  *
  * _ALR: Sort the list ascending by AmbientIlluminance
  * _CID: Strings: uppercase all, remove any leading asterisk
- * _CST: Sort the list ascending by C state type
  * _FDE: Convert Buffer of BYTEs to a Buffer of DWORDs
  * _GTM: Convert Buffer of BYTEs to a Buffer of DWORDs
  * _HID: Strings: uppercase all, remove any leading asterisk
- * _PRT: Fix reversed SourceName and SourceIndex
  * _PSS: Sort the list descending by Power
  * _TSS: Sort the list descending by Power
  *
@@ -276,11 +224,9 @@ static const ACPI_REPAIR_INFO       AcpiNsRepairableNames[] =
 {
     {"_ALR", AcpiNsRepair_ALR},
     {"_CID", AcpiNsRepair_CID},
-    {"_CST", AcpiNsRepair_CST},
     {"_FDE", AcpiNsRepair_FDE},
     {"_GTM", AcpiNsRepair_FDE},     /* _GTM has same repair as _FDE */
     {"_HID", AcpiNsRepair_HID},
-    {"_PRT", AcpiNsRepair_PRT},
     {"_PSS", AcpiNsRepair_PSS},
     {"_TSS", AcpiNsRepair_TSS},
     {{0,0,0,0}, NULL}               /* Table terminator */
@@ -358,11 +304,10 @@ AcpiNsMatchComplexRepair (
     ThisName = AcpiNsRepairableNames;
     while (ThisName->RepairFunction)
     {
-        if (ACPI_COMPARE_NAMESEG (Node->Name.Ascii, ThisName->Name))
+        if (ACPI_COMPARE_NAME (Node->Name.Ascii, ThisName->Name))
         {
             return (ThisName);
         }
-
         ThisName++;
     }
 
@@ -394,8 +339,8 @@ AcpiNsRepair_ALR (
     ACPI_STATUS             Status;
 
 
-    Status = AcpiNsCheckSortedList (Info, ReturnObject, 0, 2, 1,
-        ACPI_SORT_ASCENDING, "AmbientIlluminance");
+    Status = AcpiNsCheckSortedList (Info, ReturnObject, 2, 1,
+                ACPI_SORT_ASCENDING, "AmbientIlluminance");
 
     return (Status);
 }
@@ -448,8 +393,7 @@ AcpiNsRepair_FDE (
 
         if (ReturnObject->Buffer.Length != ACPI_FDE_BYTE_BUFFER_SIZE)
         {
-            ACPI_WARN_PREDEFINED ((AE_INFO,
-                Info->FullPathname, Info->NodeFlags,
+            ACPI_WARN_PREDEFINED ((AE_INFO, Info->FullPathname, Info->NodeFlags,
                 "Incorrect return buffer length %u, expected %u",
                 ReturnObject->Buffer.Length, ACPI_FDE_DWORD_BUFFER_SIZE));
 
@@ -458,8 +402,7 @@ AcpiNsRepair_FDE (
 
         /* Create the new (larger) buffer object */
 
-        BufferObject = AcpiUtCreateBufferObject (
-            ACPI_FDE_DWORD_BUFFER_SIZE);
+        BufferObject = AcpiUtCreateBufferObject (ACPI_FDE_DWORD_BUFFER_SIZE);
         if (!BufferObject)
         {
             return (AE_NO_MEMORY);
@@ -468,8 +411,7 @@ AcpiNsRepair_FDE (
         /* Expand each byte to a DWORD */
 
         ByteBuffer = ReturnObject->Buffer.Pointer;
-        DwordBuffer = ACPI_CAST_PTR (UINT32,
-            BufferObject->Buffer.Pointer);
+        DwordBuffer = ACPI_CAST_PTR (UINT32, BufferObject->Buffer.Pointer);
 
         for (i = 0; i < ACPI_FDE_FIELD_COUNT; i++)
         {
@@ -484,7 +426,6 @@ AcpiNsRepair_FDE (
         break;
 
     default:
-
         return (AE_AML_OPERAND_TYPE);
     }
 
@@ -556,12 +497,16 @@ AcpiNsRepair_CID (
             return (Status);
         }
 
+        /* Take care with reference counts */
+
         if (OriginalElement != *ElementPtr)
         {
-            /* Update reference count of new object */
+            /* Element was replaced */
 
             (*ElementPtr)->Common.ReferenceCount =
                 OriginalRefCount;
+
+            AcpiUtRemoveReference (OriginalElement);
         }
 
         ElementPtr++;
@@ -571,101 +516,6 @@ AcpiNsRepair_CID (
 }
 
 
-/******************************************************************************
- *
- * FUNCTION:    AcpiNsRepair_CST
- *
- * PARAMETERS:  Info                - Method execution information block
- *              ReturnObjectPtr     - Pointer to the object returned from the
- *                                    evaluation of a method or object
- *
- * RETURN:      Status. AE_OK if object is OK or was repaired successfully
- *
- * DESCRIPTION: Repair for the _CST object:
- *              1. Sort the list ascending by C state type
- *              2. Ensure type cannot be zero
- *              3. A subpackage count of zero means _CST is meaningless
- *              4. Count must match the number of C state subpackages
- *
- *****************************************************************************/
-
-static ACPI_STATUS
-AcpiNsRepair_CST (
-    ACPI_EVALUATE_INFO      *Info,
-    ACPI_OPERAND_OBJECT     **ReturnObjectPtr)
-{
-    ACPI_OPERAND_OBJECT     *ReturnObject = *ReturnObjectPtr;
-    ACPI_OPERAND_OBJECT     **OuterElements;
-    UINT32                  OuterElementCount;
-    ACPI_OPERAND_OBJECT     *ObjDesc;
-    ACPI_STATUS             Status;
-    BOOLEAN                 Removing;
-    UINT32                  i;
-
-
-    ACPI_FUNCTION_NAME (NsRepair_CST);
-
-
-    /*
-     * Check if the C-state type values are proportional.
-     */
-    OuterElementCount = ReturnObject->Package.Count - 1;
-    i = 0;
-    while (i < OuterElementCount)
-    {
-        OuterElements = &ReturnObject->Package.Elements[i + 1];
-        Removing = FALSE;
-
-        if ((*OuterElements)->Package.Count == 0)
-        {
-            ACPI_WARN_PREDEFINED ((AE_INFO,
-                Info->FullPathname, Info->NodeFlags,
-                "SubPackage[%u] - removing entry due to zero count", i));
-            Removing = TRUE;
-            goto RemoveElement;
-        }
-
-        ObjDesc = (*OuterElements)->Package.Elements[1]; /* Index1 = Type */
-        if ((UINT32) ObjDesc->Integer.Value == 0)
-        {
-            ACPI_WARN_PREDEFINED ((AE_INFO,
-                Info->FullPathname, Info->NodeFlags,
-                "SubPackage[%u] - removing entry due to invalid Type(0)", i));
-            Removing = TRUE;
-        }
-
-RemoveElement:
-        if (Removing)
-        {
-            AcpiNsRemoveElement (ReturnObject, i + 1);
-            OuterElementCount--;
-        }
-        else
-        {
-            i++;
-        }
-    }
-
-    /* Update top-level package count, Type "Integer" checked elsewhere */
-
-    ObjDesc = ReturnObject->Package.Elements[0];
-    ObjDesc->Integer.Value = OuterElementCount;
-
-    /*
-     * Entries (subpackages) in the _CST Package must be sorted by the
-     * C-state type, in ascending order.
-     */
-    Status = AcpiNsCheckSortedList (Info, ReturnObject, 1, 4, 1,
-        ACPI_SORT_ASCENDING, "C-State Type");
-    if (ACPI_FAILURE (Status))
-    {
-        return (Status);
-    }
-
-    return (AE_OK);
-}
-
-
 /******************************************************************************
  *
  * FUNCTION:    AcpiNsRepair_HID
@@ -704,8 +554,7 @@ AcpiNsRepair_HID (
 
     if (ReturnObject->String.Length == 0)
     {
-        ACPI_WARN_PREDEFINED ((AE_INFO,
-            Info->FullPathname, Info->NodeFlags,
+        ACPI_WARN_PREDEFINED ((AE_INFO, Info->FullPathname, Info->NodeFlags,
             "Invalid zero-length _HID or _CID string"));
 
         /* Return AE_OK anyway, let driver handle it */
@@ -748,7 +597,7 @@ AcpiNsRepair_HID (
      */
     for (Dest = NewString->String.Pointer; *Source; Dest++, Source++)
     {
-        *Dest = (char) toupper ((int) *Source);
+        *Dest = (char) ACPI_TOUPPER (*Source);
     }
 
     AcpiUtRemoveReference (ReturnObject);
@@ -757,152 +606,6 @@ AcpiNsRepair_HID (
 }
 
 
-/******************************************************************************
- *
- * FUNCTION:    AcpiNsRepair_PRT
- *
- * PARAMETERS:  Info                - Method execution information block
- *              ReturnObjectPtr     - Pointer to the object returned from the
- *                                    evaluation of a method or object
- *
- * RETURN:      Status. AE_OK if object is OK or was repaired successfully
- *
- * DESCRIPTION: Repair for the _PRT object. If necessary, fix reversed
- *              SourceName and SourceIndex field, a common BIOS bug.
- *
- *****************************************************************************/
-
-static ACPI_STATUS
-AcpiNsRepair_PRT (
-    ACPI_EVALUATE_INFO      *Info,
-    ACPI_OPERAND_OBJECT     **ReturnObjectPtr)
-{
-    ACPI_OPERAND_OBJECT     *PackageObject = *ReturnObjectPtr;
-    ACPI_OPERAND_OBJECT     **TopObjectList;
-    ACPI_OPERAND_OBJECT     **SubObjectList;
-    ACPI_OPERAND_OBJECT     *ObjDesc;
-    ACPI_OPERAND_OBJECT     *SubPackage;
-    UINT32                  ElementCount;
-    UINT32                  Index;
-
-
-    /* Each element in the _PRT package is a subpackage */
-
-    TopObjectList = PackageObject->Package.Elements;
-    ElementCount = PackageObject->Package.Count;
-
-    /* Examine each subpackage */
-
-    for (Index = 0; Index < ElementCount; Index++, TopObjectList++)
-    {
-        SubPackage = *TopObjectList;
-        SubObjectList = SubPackage->Package.Elements;
-
-        /* Check for minimum required element count */
-
-        if (SubPackage->Package.Count < 4)
-        {
-            continue;
-        }
-
-        /*
-         * If the BIOS has erroneously reversed the _PRT SourceName (index 2)
-         * and the SourceIndex (index 3), fix it. _PRT is important enough to
-         * workaround this BIOS error. This also provides compatibility with
-         * other ACPI implementations.
-         */
-        ObjDesc = SubObjectList[3];
-        if (!ObjDesc || (ObjDesc->Common.Type != ACPI_TYPE_INTEGER))
-        {
-            SubObjectList[3] = SubObjectList[2];
-            SubObjectList[2] = ObjDesc;
-            Info->ReturnFlags |= ACPI_OBJECT_REPAIRED;
-
-            ACPI_WARN_PREDEFINED ((AE_INFO,
-                Info->FullPathname, Info->NodeFlags,
-                "PRT[%X]: Fixed reversed SourceName and SourceIndex",
-                Index));
-        }
-    }
-
-    return (AE_OK);
-}
-
-
-/******************************************************************************
- *
- * FUNCTION:    AcpiNsRepair_PSS
- *
- * PARAMETERS:  Info                - Method execution information block
- *              ReturnObjectPtr     - Pointer to the object returned from the
- *                                    evaluation of a method or object
- *
- * RETURN:      Status. AE_OK if object is OK or was repaired successfully
- *
- * DESCRIPTION: Repair for the _PSS object. If necessary, sort the object list
- *              by the CPU frequencies. Check that the power dissipation values
- *              are all proportional to CPU frequency (i.e., sorting by
- *              frequency should be the same as sorting by power.)
- *
- *****************************************************************************/
-
-static ACPI_STATUS
-AcpiNsRepair_PSS (
-    ACPI_EVALUATE_INFO      *Info,
-    ACPI_OPERAND_OBJECT     **ReturnObjectPtr)
-{
-    ACPI_OPERAND_OBJECT     *ReturnObject = *ReturnObjectPtr;
-    ACPI_OPERAND_OBJECT     **OuterElements;
-    UINT32                  OuterElementCount;
-    ACPI_OPERAND_OBJECT     **Elements;
-    ACPI_OPERAND_OBJECT     *ObjDesc;
-    UINT32                  PreviousValue;
-    ACPI_STATUS             Status;
-    UINT32                  i;
-
-
-    /*
-     * Entries (subpackages) in the _PSS Package must be sorted by power
-     * dissipation, in descending order. If it appears that the list is
-     * incorrectly sorted, sort it. We sort by CpuFrequency, since this
-     * should be proportional to the power.
-     */
-    Status = AcpiNsCheckSortedList (Info, ReturnObject, 0, 6, 0,
-        ACPI_SORT_DESCENDING, "CpuFrequency");
-    if (ACPI_FAILURE (Status))
-    {
-        return (Status);
-    }
-
-    /*
-     * We now know the list is correctly sorted by CPU frequency. Check if
-     * the power dissipation values are proportional.
-     */
-    PreviousValue = ACPI_UINT32_MAX;
-    OuterElements = ReturnObject->Package.Elements;
-    OuterElementCount = ReturnObject->Package.Count;
-
-    for (i = 0; i < OuterElementCount; i++)
-    {
-        Elements = (*OuterElements)->Package.Elements;
-        ObjDesc = Elements[1]; /* Index1 = PowerDissipation */
-
-        if ((UINT32) ObjDesc->Integer.Value > PreviousValue)
-        {
-            ACPI_WARN_PREDEFINED ((AE_INFO,
-                Info->FullPathname, Info->NodeFlags,
-                "SubPackage[%u,%u] - suspicious power dissipation values",
-                i-1, i));
-        }
-
-        PreviousValue = (UINT32) ObjDesc->Integer.Value;
-        OuterElements++;
-    }
-
-    return (AE_OK);
-}
-
-
 /******************************************************************************
  *
  * FUNCTION:    AcpiNsRepair_TSS
@@ -943,22 +646,94 @@ AcpiNsRepair_TSS (
         return (AE_OK);
     }
 
-    Status = AcpiNsCheckSortedList (Info, ReturnObject, 0, 5, 1,
-        ACPI_SORT_DESCENDING, "PowerDissipation");
+    Status = AcpiNsCheckSortedList (Info, ReturnObject, 5, 1,
+                ACPI_SORT_DESCENDING, "PowerDissipation");
 
     return (Status);
 }
 
 
+/******************************************************************************
+ *
+ * FUNCTION:    AcpiNsRepair_PSS
+ *
+ * PARAMETERS:  Info                - Method execution information block
+ *              ReturnObjectPtr     - Pointer to the object returned from the
+ *                                    evaluation of a method or object
+ *
+ * RETURN:      Status. AE_OK if object is OK or was repaired successfully
+ *
+ * DESCRIPTION: Repair for the _PSS object. If necessary, sort the object list
+ *              by the CPU frequencies. Check that the power dissipation values
+ *              are all proportional to CPU frequency (i.e., sorting by
+ *              frequency should be the same as sorting by power.)
+ *
+ *****************************************************************************/
+
+static ACPI_STATUS
+AcpiNsRepair_PSS (
+    ACPI_EVALUATE_INFO      *Info,
+    ACPI_OPERAND_OBJECT     **ReturnObjectPtr)
+{
+    ACPI_OPERAND_OBJECT     *ReturnObject = *ReturnObjectPtr;
+    ACPI_OPERAND_OBJECT     **OuterElements;
+    UINT32                  OuterElementCount;
+    ACPI_OPERAND_OBJECT     **Elements;
+    ACPI_OPERAND_OBJECT     *ObjDesc;
+    UINT32                  PreviousValue;
+    ACPI_STATUS             Status;
+    UINT32                  i;
+
+
+    /*
+     * Entries (sub-packages) in the _PSS Package must be sorted by power
+     * dissipation, in descending order. If it appears that the list is
+     * incorrectly sorted, sort it. We sort by CpuFrequency, since this
+     * should be proportional to the power.
+     */
+    Status =AcpiNsCheckSortedList (Info, ReturnObject, 6, 0,
+                ACPI_SORT_DESCENDING, "CpuFrequency");
+    if (ACPI_FAILURE (Status))
+    {
+        return (Status);
+    }
+
+    /*
+     * We now know the list is correctly sorted by CPU frequency. Check if
+     * the power dissipation values are proportional.
+     */
+    PreviousValue = ACPI_UINT32_MAX;
+    OuterElements = ReturnObject->Package.Elements;
+    OuterElementCount = ReturnObject->Package.Count;
+
+    for (i = 0; i < OuterElementCount; i++)
+    {
+        Elements = (*OuterElements)->Package.Elements;
+        ObjDesc = Elements[1]; /* Index1 = PowerDissipation */
+
+        if ((UINT32) ObjDesc->Integer.Value > PreviousValue)
+        {
+            ACPI_WARN_PREDEFINED ((AE_INFO, Info->FullPathname, Info->NodeFlags,
+                "SubPackage[%u,%u] - suspicious power dissipation values",
+                i-1, i));
+        }
+
+        PreviousValue = (UINT32) ObjDesc->Integer.Value;
+        OuterElements++;
+    }
+
+    return (AE_OK);
+}
+
+
 /******************************************************************************
  *
  * FUNCTION:    AcpiNsCheckSortedList
  *
  * PARAMETERS:  Info                - Method execution information block
  *              ReturnObject        - Pointer to the top-level returned object
- *              StartIndex          - Index of the first subpackage
- *              ExpectedCount       - Minimum length of each subpackage
- *              SortIndex           - Subpackage entry to sort on
+ *              ExpectedCount       - Minimum length of each sub-package
+ *              SortIndex           - Sub-package entry to sort on
  *              SortDirection       - Ascending or descending
  *              SortKeyName         - Name of the SortIndex field
  *
@@ -974,7 +749,6 @@ static ACPI_STATUS
 AcpiNsCheckSortedList (
     ACPI_EVALUATE_INFO      *Info,
     ACPI_OPERAND_OBJECT     *ReturnObject,
-    UINT32                  StartIndex,
     UINT32                  ExpectedCount,
     UINT32                  SortIndex,
     UINT8                   SortDirection,
@@ -999,19 +773,17 @@ AcpiNsCheckSortedList (
     }
 
     /*
-     * NOTE: assumes list of subpackages contains no NULL elements.
+     * NOTE: assumes list of sub-packages contains no NULL elements.
      * Any NULL elements should have been removed by earlier call
      * to AcpiNsRemoveNullElements.
      */
+    OuterElements = ReturnObject->Package.Elements;
     OuterElementCount = ReturnObject->Package.Count;
-    if (!OuterElementCount || StartIndex >= OuterElementCount)
+    if (!OuterElementCount)
     {
         return (AE_AML_PACKAGE_LIMIT);
     }
 
-    OuterElements = &ReturnObject->Package.Elements[StartIndex];
-    OuterElementCount -= StartIndex;
-
     PreviousValue = 0;
     if (SortDirection == ACPI_SORT_DESCENDING)
     {
@@ -1029,7 +801,7 @@ AcpiNsCheckSortedList (
             return (AE_AML_OPERAND_TYPE);
         }
 
-        /* Each subpackage must have the minimum length */
+        /* Each sub-package must have the minimum length */
 
         if ((*OuterElements)->Package.Count < ExpectedCount)
         {
@@ -1053,7 +825,7 @@ AcpiNsCheckSortedList (
             ((SortDirection == ACPI_SORT_DESCENDING) &&
                 (ObjDesc->Integer.Value > PreviousValue)))
         {
-            AcpiNsSortList (&ReturnObject->Package.Elements[StartIndex],
+            AcpiNsSortList (ReturnObject->Package.Elements,
                 OuterElementCount, SortIndex, SortDirection);
 
             Info->ReturnFlags |= ACPI_OBJECT_REPAIRED;
@@ -1126,62 +898,3 @@ AcpiNsSortList (
         }
     }
 }
-
-
-/******************************************************************************
- *
- * FUNCTION:    AcpiNsRemoveElement
- *
- * PARAMETERS:  ObjDesc             - Package object element list
- *              Index               - Index of element to remove
- *
- * RETURN:      None
- *
- * DESCRIPTION: Remove the requested element of a package and delete it.
- *
- *****************************************************************************/
-
-static void
-AcpiNsRemoveElement (
-    ACPI_OPERAND_OBJECT     *ObjDesc,
-    UINT32                  Index)
-{
-    ACPI_OPERAND_OBJECT     **Source;
-    ACPI_OPERAND_OBJECT     **Dest;
-    UINT32                  Count;
-    UINT32                  NewCount;
-    UINT32                  i;
-
-
-    ACPI_FUNCTION_NAME (NsRemoveElement);
-
-
-    Count = ObjDesc->Package.Count;
-    NewCount = Count - 1;
-
-    Source = ObjDesc->Package.Elements;
-    Dest = Source;
-
-    /* Examine all elements of the package object, remove matched index */
-
-    for (i = 0; i < Count; i++)
-    {
-        if (i == Index)
-        {
-            AcpiUtRemoveReference (*Source); /* Remove one ref for being in pkg */
-            AcpiUtRemoveReference (*Source);
-        }
-        else
-        {
-            *Dest = *Source;
-            Dest++;
-        }
-
-        Source++;
-    }
-
-    /* NULL terminate list and update the package count */
-
-    *Dest = NULL;
-    ObjDesc->Package.Count = NewCount;
-}
