@@ -9,7 +9,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -112,45 +112,10 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
-#define EXPORT_ACPI_INTERFACES
+
+#define __NSXFEVAL_C__
 
 #include "acpi.h"
 #include "accommon.h"
@@ -198,7 +163,7 @@ AcpiEvaluateObjectTyped (
     ACPI_OBJECT_TYPE        ReturnType)
 {
     ACPI_STATUS             Status;
-    BOOLEAN                 FreeBufferOnError = FALSE;
+    BOOLEAN                 MustFree = FALSE;
 
 
     ACPI_FUNCTION_TRACE (AcpiEvaluateObjectTyped);
@@ -213,13 +178,12 @@ AcpiEvaluateObjectTyped (
 
     if (ReturnBuffer->Length == ACPI_ALLOCATE_BUFFER)
     {
-        FreeBufferOnError = TRUE;
+        MustFree = TRUE;
     }
 
     /* Evaluate the object */
 
-    Status = AcpiEvaluateObject (Handle, Pathname,
-        ExternalParams, ReturnBuffer);
+    Status = AcpiEvaluateObject (Handle, Pathname, ExternalParams, ReturnBuffer);
     if (ACPI_FAILURE (Status))
     {
         return_ACPI_STATUS (Status);
@@ -254,15 +218,10 @@ AcpiEvaluateObjectTyped (
         AcpiUtGetTypeName (((ACPI_OBJECT *) ReturnBuffer->Pointer)->Type),
         AcpiUtGetTypeName (ReturnType)));
 
-    if (FreeBufferOnError)
+    if (MustFree)
     {
-        /*
-         * Free a buffer created via ACPI_ALLOCATE_BUFFER.
-         * Note: We use AcpiOsFree here because AcpiOsAllocate was used
-         * to allocate the buffer. This purposefully bypasses the
-         * (optionally enabled) allocation tracking mechanism since we
-         * only want to track internal allocations.
-         */
+        /* Caller used ACPI_ALLOCATE_BUFFER, free the return buffer */
+
         AcpiOsFree (ReturnBuffer->Pointer);
         ReturnBuffer->Pointer = NULL;
     }
@@ -413,12 +372,13 @@ AcpiEvaluateObject (
     }
 
 
-#ifdef _FUTURE_FEATURE
+#if 0
 
     /*
      * Begin incoming argument count analysis. Check for too few args
      * and too many args.
      */
+
     switch (AcpiNsGetType (Info->Node))
     {
     case ACPI_TYPE_METHOD:
@@ -506,74 +466,69 @@ AcpiEvaluateObject (
      * If we are expecting a return value, and all went well above,
      * copy the return value to an external object.
      */
-    if (!ReturnBuffer)
+    if (ReturnBuffer)
     {
-        goto CleanupReturnObject;
-    }
-
-    if (!Info->ReturnObject)
-    {
-        ReturnBuffer->Length = 0;
-        goto Cleanup;
-    }
-
-    if (ACPI_GET_DESCRIPTOR_TYPE (Info->ReturnObject) ==
-        ACPI_DESC_TYPE_NAMED)
-    {
-        /*
-         * If we received a NS Node as a return object, this means that
-         * the object we are evaluating has nothing interesting to
-         * return (such as a mutex, etc.)  We return an error because
-         * these types are essentially unsupported by this interface.
-         * We don't check up front because this makes it easier to add
-         * support for various types at a later date if necessary.
-         */
-        Status = AE_TYPE;
-        Info->ReturnObject = NULL;   /* No need to delete a NS Node */
-        ReturnBuffer->Length = 0;
-    }
-
-    if (ACPI_FAILURE (Status))
-    {
-        goto CleanupReturnObject;
-    }
-
-    /* Dereference Index and RefOf references */
-
-    AcpiNsResolveReferences (Info);
-
-    /* Get the size of the returned object */
-
-    Status = AcpiUtGetObjectSize (Info->ReturnObject,
-        &BufferSpaceNeeded);
-    if (ACPI_SUCCESS (Status))
-    {
-        /* Validate/Allocate/Clear caller buffer */
-
-        Status = AcpiUtInitializeBuffer (ReturnBuffer,
-            BufferSpaceNeeded);
-        if (ACPI_FAILURE (Status))
+        if (!Info->ReturnObject)
         {
-            /*
-             * Caller's buffer is too small or a new one can't
-             * be allocated
-             */
-            ACPI_DEBUG_PRINT ((ACPI_DB_INFO,
-                "Needed buffer size %X, %s\n",
-                (UINT32) BufferSpaceNeeded,
-                AcpiFormatException (Status)));
+            ReturnBuffer->Length = 0;
         }
         else
         {
-            /* We have enough space for the object, build it */
+            if (ACPI_GET_DESCRIPTOR_TYPE (Info->ReturnObject) ==
+                ACPI_DESC_TYPE_NAMED)
+            {
+                /*
+                 * If we received a NS Node as a return object, this means that
+                 * the object we are evaluating has nothing interesting to
+                 * return (such as a mutex, etc.)  We return an error because
+                 * these types are essentially unsupported by this interface.
+                 * We don't check up front because this makes it easier to add
+                 * support for various types at a later date if necessary.
+                 */
+                Status = AE_TYPE;
+                Info->ReturnObject = NULL;   /* No need to delete a NS Node */
+                ReturnBuffer->Length = 0;
+            }
 
-            Status = AcpiUtCopyIobjectToEobject (
-                Info->ReturnObject, ReturnBuffer);
+            if (ACPI_SUCCESS (Status))
+            {
+                /* Dereference Index and RefOf references */
+
+                AcpiNsResolveReferences (Info);
+
+                /* Get the size of the returned object */
+
+                Status = AcpiUtGetObjectSize (Info->ReturnObject,
+                            &BufferSpaceNeeded);
+                if (ACPI_SUCCESS (Status))
+                {
+                    /* Validate/Allocate/Clear caller buffer */
+
+                    Status = AcpiUtInitializeBuffer (ReturnBuffer,
+                                BufferSpaceNeeded);
+                    if (ACPI_FAILURE (Status))
+                    {
+                        /*
+                         * Caller's buffer is too small or a new one can't
+                         * be allocated
+                         */
+                        ACPI_DEBUG_PRINT ((ACPI_DB_INFO,
+                            "Needed buffer size %X, %s\n",
+                            (UINT32) BufferSpaceNeeded,
+                            AcpiFormatException (Status)));
+                    }
+                    else
+                    {
+                        /* We have enough space for the object, build it */
+
+                        Status = AcpiUtCopyIobjectToEobject (Info->ReturnObject,
+                                    ReturnBuffer);
+                    }
+                }
+            }
         }
     }
 
-CleanupReturnObject:
-
     if (Info->ReturnObject)
     {
         /*
@@ -667,7 +622,6 @@ AcpiNsResolveReferences (
         break;
 
     default:
-
         return;
     }
 
@@ -691,9 +645,9 @@ AcpiNsResolveReferences (
  * PARAMETERS:  Type                - ACPI_OBJECT_TYPE to search for
  *              StartObject         - Handle in namespace where search begins
  *              MaxDepth            - Depth to which search is to reach
- *              DescendingCallback  - Called during tree descent
+ *              PreOrderVisit       - Called during tree pre-order visit
  *                                    when an object of "Type" is found
- *              AscendingCallback   - Called during tree ascent
+ *              PostOrderVisit      - Called during tree post-order visit
  *                                    when an object of "Type" is found
  *              Context             - Passed to user function(s) above
  *              ReturnValue         - Location where return value of
@@ -722,8 +676,8 @@ AcpiWalkNamespace (
     ACPI_OBJECT_TYPE        Type,
     ACPI_HANDLE             StartObject,
     UINT32                  MaxDepth,
-    ACPI_WALK_CALLBACK      DescendingCallback,
-    ACPI_WALK_CALLBACK      AscendingCallback,
+    ACPI_WALK_CALLBACK      PreOrderVisit,
+    ACPI_WALK_CALLBACK      PostOrderVisit,
     void                    *Context,
     void                    **ReturnValue)
 {
@@ -737,7 +691,7 @@ AcpiWalkNamespace (
 
     if ((Type > ACPI_TYPE_LOCAL_MAX) ||
         (!MaxDepth)                  ||
-        (!DescendingCallback && !AscendingCallback))
+        (!PreOrderVisit && !PostOrderVisit))
     {
         return_ACPI_STATUS (AE_BAD_PARAMETER);
     }
@@ -771,19 +725,10 @@ AcpiWalkNamespace (
         goto UnlockAndExit;
     }
 
-    /* Now we can validate the starting node */
-
-    if (!AcpiNsValidateHandle (StartObject))
-    {
-        Status = AE_BAD_PARAMETER;
-        goto UnlockAndExit2;
-    }
-
     Status = AcpiNsWalkNamespace (Type, StartObject, MaxDepth,
-        ACPI_NS_WALK_UNLOCK, DescendingCallback,
-        AscendingCallback, Context, ReturnValue);
+                ACPI_NS_WALK_UNLOCK, PreOrderVisit,
+                PostOrderVisit, Context, ReturnValue);
 
-UnlockAndExit2:
     (void) AcpiUtReleaseMutex (ACPI_MTX_NAMESPACE);
 
 UnlockAndExit:
@@ -870,7 +815,7 @@ AcpiNsGetDeviceCallback (
             return (AE_CTRL_DEPTH);
         }
 
-        NoMatch = strcmp (Hid->String, Info->Hid);
+        NoMatch = ACPI_STRCMP (Hid->String, Info->Hid);
         ACPI_FREE (Hid);
 
         if (NoMatch)
@@ -894,7 +839,7 @@ AcpiNsGetDeviceCallback (
             Found = FALSE;
             for (i = 0; i < Cid->Count; i++)
             {
-                if (strcmp (Cid->Ids[i].String, Info->Hid) == 0)
+                if (ACPI_STRCMP (Cid->Ids[i].String, Info->Hid) == 0)
                 {
                     /* Found a matching CID */
 
@@ -932,8 +877,8 @@ AcpiNsGetDeviceCallback (
 
     /* We have a valid device, invoke the user function */
 
-    Status = Info->UserFunction (ObjHandle, NestingLevel,
-        Info->Context, ReturnValue);
+    Status = Info->UserFunction (ObjHandle, NestingLevel, Info->Context,
+                ReturnValue);
     return (Status);
 }
 
@@ -988,8 +933,8 @@ AcpiGetDevices (
      * We're going to call their callback from OUR callback, so we need
      * to know what it is, and their context parameter.
      */
-    Info.Hid = HID;
-    Info.Context = Context;
+    Info.Hid          = HID;
+    Info.Context      = Context;
     Info.UserFunction = UserFunction;
 
     /*
@@ -1005,8 +950,8 @@ AcpiGetDevices (
     }
 
     Status = AcpiNsWalkNamespace (ACPI_TYPE_DEVICE, ACPI_ROOT_OBJECT,
-        ACPI_UINT32_MAX, ACPI_NS_WALK_UNLOCK,
-        AcpiNsGetDeviceCallback, NULL, &Info, ReturnValue);
+                ACPI_UINT32_MAX, ACPI_NS_WALK_UNLOCK,
+                AcpiNsGetDeviceCallback, NULL, &Info, ReturnValue);
 
     (void) AcpiUtReleaseMutex (ACPI_MTX_NAMESPACE);
     return_ACPI_STATUS (Status);
