@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,51 +111,16 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+#define __PSARGS_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acparser.h"
 #include "amlcode.h"
 #include "acnamesp.h"
 #include "acdispat.h"
-#include "acconvert.h"
 
 #define _COMPONENT          ACPI_PARSER
         ACPI_MODULE_NAME    ("psargs")
@@ -317,7 +282,7 @@ AcpiPsGetNextNamestring (
         End += 1 + (2 * ACPI_NAME_SIZE);
         break;
 
-    case AML_MULTI_NAME_PREFIX:
+    case AML_MULTI_NAME_PREFIX_OP:
 
         /* Multiple name segments, 4 chars each, count in next byte */
 
@@ -396,8 +361,8 @@ AcpiPsGetNextNamepath (
      * the upsearch)
      */
     Status = AcpiNsLookup (WalkState->ScopeInfo, Path,
-        ACPI_TYPE_ANY, ACPI_IMODE_EXECUTE,
-        ACPI_NS_SEARCH_PARENT | ACPI_NS_DONT_OPEN_SCOPE, NULL, &Node);
+                ACPI_TYPE_ANY, ACPI_IMODE_EXECUTE,
+                ACPI_NS_SEARCH_PARENT | ACPI_NS_DONT_OPEN_SCOPE, NULL, &Node);
 
     /*
      * If this name is a control method invocation, we must
@@ -407,28 +372,25 @@ AcpiPsGetNextNamepath (
         PossibleMethodCall &&
         (Node->Type == ACPI_TYPE_METHOD))
     {
-        if ((GET_CURRENT_ARG_TYPE (WalkState->ArgTypes) == ARGP_SUPERNAME) ||
-            (GET_CURRENT_ARG_TYPE (WalkState->ArgTypes) == ARGP_TARGET))
+        if (WalkState->Opcode == AML_UNLOAD_OP)
         {
             /*
-             * AcpiPsGetNextNamestring has increased the AML pointer past
-             * the method invocation namestring, so we need to restore the
-             * saved AML pointer back to the original method invocation
-             * namestring.
+             * AcpiPsGetNextNamestring has increased the AML pointer,
+             * so we need to restore the saved AML pointer for method call.
              */
             WalkState->ParserState.Aml = Start;
             WalkState->ArgCount = 1;
             AcpiPsInitOp (Arg, AML_INT_METHODCALL_OP);
+            return_ACPI_STATUS (AE_OK);
         }
 
         /* This name is actually a control method invocation */
 
         MethodDesc = AcpiNsGetAttachedObject (Node);
         ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-            "Control Method invocation %4.4s - %p Desc %p Path=%p\n",
-            Node->Name.Ascii, Node, MethodDesc, Path));
+            "Control Method - %p Desc %p Path=%p\n", Node, MethodDesc, Path));
 
-        NameOp = AcpiPsAllocOp (AML_INT_NAMEPATH_OP, Start);
+        NameOp = AcpiPsAllocOp (AML_INT_NAMEPATH_OP);
         if (!NameOp)
         {
             return_ACPI_STATUS (AE_NO_MEMORY);
@@ -471,14 +433,14 @@ AcpiPsGetNextNamepath (
         /* 1) NotFound is ok during load pass 1/2 (allow forward references) */
 
         if ((WalkState->ParseFlags & ACPI_PARSE_MODE_MASK) !=
-            ACPI_PARSE_EXECUTE)
+                ACPI_PARSE_EXECUTE)
         {
             Status = AE_OK;
         }
 
         /* 2) NotFound during a CondRefOf(x) is ok by definition */
 
-        else if (WalkState->Op->Common.AmlOpcode == AML_CONDITIONAL_REF_OF_OP)
+        else if (WalkState->Op->Common.AmlOpcode == AML_COND_REF_OF_OP)
         {
             Status = AE_OK;
         }
@@ -490,7 +452,7 @@ AcpiPsGetNextNamepath (
          */
         else if ((Arg->Common.Parent) &&
             ((Arg->Common.Parent->Common.AmlOpcode == AML_PACKAGE_OP) ||
-             (Arg->Common.Parent->Common.AmlOpcode == AML_VARIABLE_PACKAGE_OP)))
+             (Arg->Common.Parent->Common.AmlOpcode == AML_VAR_PACKAGE_OP)))
         {
             Status = AE_OK;
         }
@@ -503,7 +465,7 @@ AcpiPsGetNextNamepath (
         ACPI_ERROR_NAMESPACE (Path, Status);
 
         if ((WalkState->ParseFlags & ACPI_PARSE_MODE_MASK) ==
-            ACPI_PARSE_EXECUTE)
+                ACPI_PARSE_EXECUTE)
         {
             /* Report a control method execution error */
 
@@ -557,6 +519,7 @@ AcpiPsGetNextSimpleArg (
         Length = 1;
         break;
 
+
     case ARGP_WORDDATA:
 
         /* Get 2 bytes from the AML stream */
@@ -566,6 +529,7 @@ AcpiPsGetNextSimpleArg (
         Length = 2;
         break;
 
+
     case ARGP_DWORDDATA:
 
         /* Get 4 bytes from the AML stream */
@@ -575,6 +539,7 @@ AcpiPsGetNextSimpleArg (
         Length = 4;
         break;
 
+
     case ARGP_QWORDDATA:
 
         /* Get 8 bytes from the AML stream */
@@ -584,6 +549,7 @@ AcpiPsGetNextSimpleArg (
         Length = 8;
         break;
 
+
     case ARGP_CHARLIST:
 
         /* Get a pointer to the string, point past the string */
@@ -601,6 +567,7 @@ AcpiPsGetNextSimpleArg (
         Length++;
         break;
 
+
     case ARGP_NAME:
     case ARGP_NAMESTRING:
 
@@ -608,6 +575,7 @@ AcpiPsGetNextSimpleArg (
         Arg->Common.Value.Name = AcpiPsGetNextNamestring (ParserState);
         return_VOID;
 
+
     default:
 
         ACPI_ERROR ((AE_INFO, "Invalid ArgType 0x%X", ArgType));
@@ -636,7 +604,7 @@ static ACPI_PARSE_OBJECT *
 AcpiPsGetNextField (
     ACPI_PARSE_STATE        *ParserState)
 {
-    UINT8                   *Aml;
+    UINT32                  AmlOffset;
     ACPI_PARSE_OBJECT       *Field;
     ACPI_PARSE_OBJECT       *Arg = NULL;
     UINT16                  Opcode;
@@ -652,8 +620,8 @@ AcpiPsGetNextField (
     ACPI_FUNCTION_TRACE (PsGetNextField);
 
 
-    ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
-    Aml = ParserState->Aml;
+    AmlOffset = (UINT32) ACPI_PTR_DIFF (
+        ParserState->Aml, ParserState->AmlStart);
 
     /* Determine field type */
 
@@ -691,15 +659,16 @@ AcpiPsGetNextField (
 
     /* Allocate a new field op */
 
-    Field = AcpiPsAllocOp (Opcode, Aml);
+    Field = AcpiPsAllocOp (Opcode);
     if (!Field)
     {
         return_PTR (NULL);
     }
 
+    Field->Common.AmlOffset = AmlOffset;
+
     /* Decode the field type */
 
-    ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
     switch (Opcode)
     {
     case AML_INT_NAMEDFIELD_OP:
@@ -710,23 +679,6 @@ AcpiPsGetNextField (
         AcpiPsSetName (Field, Name);
         ParserState->Aml += ACPI_NAME_SIZE;
 
-
-        ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
-
-#ifdef ACPI_ASL_COMPILER
-        /*
-         * Because the package length isn't represented as a parse tree object,
-         * take comments surrounding this and add to the previously created
-         * parse node.
-         */
-        if (Field->Common.InlineComment)
-        {
-            Field->Common.NameComment = Field->Common.InlineComment;
-        }
-        Field->Common.InlineComment  = AcpiGbl_CurrentInlineComment;
-        AcpiGbl_CurrentInlineComment = NULL;
-#endif
-
         /* Get the length which is encoded as a package length */
 
         Field->Common.Value.Size = AcpiPsGetNextPackageLength (ParserState);
@@ -778,22 +730,19 @@ AcpiPsGetNextField (
          * Argument for Connection operator can be either a Buffer
          * (resource descriptor), or a NameString.
          */
-        Aml = ParserState->Aml;
         if (ACPI_GET8 (ParserState->Aml) == AML_BUFFER_OP)
         {
             ParserState->Aml++;
 
-            ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
             PkgEnd = ParserState->Aml;
             PkgLength = AcpiPsGetNextPackageLength (ParserState);
             PkgEnd += PkgLength;
 
-            ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
             if (ParserState->Aml < PkgEnd)
             {
                 /* Non-empty list */
 
-                Arg = AcpiPsAllocOp (AML_INT_BYTELIST_OP, Aml);
+                Arg = AcpiPsAllocOp (AML_INT_BYTELIST_OP);
                 if (!Arg)
                 {
                     AcpiPsFreeOp (Field);
@@ -805,36 +754,30 @@ AcpiPsGetNextField (
                 Opcode = ACPI_GET8 (ParserState->Aml);
                 ParserState->Aml++;
 
-                ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
                 switch (Opcode)
                 {
                 case AML_BYTE_OP:       /* AML_BYTEDATA_ARG */
-
                     BufferLength = ACPI_GET8 (ParserState->Aml);
                     ParserState->Aml += 1;
                     break;
 
                 case AML_WORD_OP:       /* AML_WORDDATA_ARG */
-
                     BufferLength = ACPI_GET16 (ParserState->Aml);
                     ParserState->Aml += 2;
                     break;
 
                 case AML_DWORD_OP:      /* AML_DWORDATA_ARG */
-
                     BufferLength = ACPI_GET32 (ParserState->Aml);
                     ParserState->Aml += 4;
                     break;
 
                 default:
-
                     BufferLength = 0;
                     break;
                 }
 
                 /* Fill in bytelist data */
 
-                ASL_CV_CAPTURE_COMMENTS_ONLY (ParserState);
                 Arg->Named.Value.Size = BufferLength;
                 Arg->Named.Data = ParserState->Aml;
             }
@@ -845,7 +788,7 @@ AcpiPsGetNextField (
         }
         else
         {
-            Arg = AcpiPsAllocOp (AML_INT_NAMEPATH_OP, Aml);
+            Arg = AcpiPsAllocOp (AML_INT_NAMEPATH_OP);
             if (!Arg)
             {
                 AcpiPsFreeOp (Field);
@@ -906,10 +849,6 @@ AcpiPsGetNextArg (
     ACPI_FUNCTION_TRACE_PTR (PsGetNextArg, ParserState);
 
 
-    ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-        "Expected argument type ARGP: %s (%2.2X)\n",
-        AcpiUtGetArgumentTypeName (ArgType), ArgType));
-
     switch (ArgType)
     {
     case ARGP_BYTEDATA:
@@ -921,15 +860,15 @@ AcpiPsGetNextArg (
 
         /* Constants, strings, and namestrings are all the same size */
 
-        Arg = AcpiPsAllocOp (AML_BYTE_OP, ParserState->Aml);
+        Arg = AcpiPsAllocOp (AML_BYTE_OP);
         if (!Arg)
         {
             return_ACPI_STATUS (AE_NO_MEMORY);
         }
-
         AcpiPsGetNextSimpleArg (ParserState, ArgType, Arg);
         break;
 
+
     case ARGP_PKGLENGTH:
 
         /* Package length, nothing returned */
@@ -937,6 +876,7 @@ AcpiPsGetNextArg (
         ParserState->PkgEnd = AcpiPsGetNextPackageEnd (ParserState);
         break;
 
+
     case ARGP_FIELDLIST:
 
         if (ParserState->Aml < ParserState->PkgEnd)
@@ -968,14 +908,14 @@ AcpiPsGetNextArg (
         }
         break;
 
+
     case ARGP_BYTELIST:
 
         if (ParserState->Aml < ParserState->PkgEnd)
         {
             /* Non-empty list */
 
-            Arg = AcpiPsAllocOp (AML_INT_BYTELIST_OP,
-                ParserState->Aml);
+            Arg = AcpiPsAllocOp (AML_INT_BYTELIST_OP);
             if (!Arg)
             {
                 return_ACPI_STATUS (AE_NO_MEMORY);
@@ -993,12 +933,10 @@ AcpiPsGetNextArg (
         }
         break;
 
-    case ARGP_SIMPLENAME:
-    case ARGP_NAME_OR_REF:
 
-        ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-            "**** SimpleName/NameOrRef: %s (%2.2X)\n",
-            AcpiUtGetArgumentTypeName (ArgType), ArgType));
+    case ARGP_TARGET:
+    case ARGP_SUPERNAME:
+    case ARGP_SIMPLENAME:
 
         Subop = AcpiPsPeekOpcode (ParserState);
         if (Subop == 0                  ||
@@ -1008,14 +946,32 @@ AcpiPsGetNextArg (
         {
             /* NullName or NameString */
 
-            Arg = AcpiPsAllocOp (AML_INT_NAMEPATH_OP, ParserState->Aml);
+            Arg = AcpiPsAllocOp (AML_INT_NAMEPATH_OP);
             if (!Arg)
             {
                 return_ACPI_STATUS (AE_NO_MEMORY);
             }
 
-            Status = AcpiPsGetNextNamepath (WalkState, ParserState,
-                Arg, ACPI_NOT_METHOD_CALL);
+            /* To support SuperName arg of Unload */
+
+            if (WalkState->Opcode == AML_UNLOAD_OP)
+            {
+                Status = AcpiPsGetNextNamepath (WalkState, ParserState, Arg, 1);
+
+                /*
+                 * If the SuperName arg of Unload is a method call,
+                 * we have restored the AML pointer, just free this Arg
+                 */
+                if (Arg->Common.AmlOpcode == AML_INT_METHODCALL_OP)
+                {
+                    AcpiPsFreeOp (Arg);
+                    Arg = NULL;
+                }
+            }
+            else
+            {
+                Status = AcpiPsGetNextNamepath (WalkState, ParserState, Arg, 0);
+            }
         }
         else
         {
@@ -1025,58 +981,16 @@ AcpiPsGetNextArg (
         }
         break;
 
-    case ARGP_TARGET:
-    case ARGP_SUPERNAME:
-
-        ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-            "**** Target/Supername: %s (%2.2X)\n",
-            AcpiUtGetArgumentTypeName (ArgType), ArgType));
-
-        Subop = AcpiPsPeekOpcode (ParserState);
-        if (Subop == 0                  ||
-            AcpiPsIsLeadingChar (Subop) ||
-            ACPI_IS_ROOT_PREFIX (Subop) ||
-            ACPI_IS_PARENT_PREFIX (Subop))
-        {
-            /* NULL target (zero). Convert to a NULL namepath */
-
-            Arg = AcpiPsAllocOp (AML_INT_NAMEPATH_OP, ParserState->Aml);
-            if (!Arg)
-            {
-                return_ACPI_STATUS (AE_NO_MEMORY);
-            }
-
-            Status = AcpiPsGetNextNamepath (WalkState, ParserState,
-                Arg, ACPI_POSSIBLE_METHOD_CALL);
-
-            if (Arg->Common.AmlOpcode == AML_INT_METHODCALL_OP)
-            {
-                AcpiPsFreeOp (Arg);
-                Arg = NULL;
-                WalkState->ArgCount = 1;
-            }
-        }
-        else
-        {
-            /* Single complex argument, nothing returned */
-
-            WalkState->ArgCount = 1;
-        }
-        break;
 
     case ARGP_DATAOBJ:
     case ARGP_TERMARG:
 
-
-    ACPI_DEBUG_PRINT ((ACPI_DB_PARSE,
-        "**** TermArg/DataObj: %s (%2.2X)\n",
-        AcpiUtGetArgumentTypeName (ArgType), ArgType));
-
         /* Single complex argument, nothing returned */
 
         WalkState->ArgCount = 1;
         break;
 
+
     case ARGP_DATAOBJLIST:
     case ARGP_TERMLIST:
     case ARGP_OBJLIST:
@@ -1089,6 +1003,7 @@ AcpiPsGetNextArg (
         }
         break;
 
+
     default:
 
         ACPI_ERROR ((AE_INFO, "Invalid ArgType: 0x%X", ArgType));
