@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,44 +111,10 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+#define __RSCALC_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acresrc.h"
@@ -272,17 +238,16 @@ AcpiRsStreamOptionLength (
 
 
     /*
-     * The ResourceSourceIndex and ResourceSource are optional elements of
-     * some Large-type resource descriptors.
+     * The ResourceSourceIndex and ResourceSource are optional elements of some
+     * Large-type resource descriptors.
      */
 
     /*
-     * If the length of the actual resource descriptor is greater than the
-     * ACPI spec-defined minimum length, it means that a ResourceSourceIndex
-     * exists and is followed by a (required) null terminated string. The
-     * string length (including the null terminator) is the resource length
-     * minus the minimum length, minus one byte for the ResourceSourceIndex
-     * itself.
+     * If the length of the actual resource descriptor is greater than the ACPI
+     * spec-defined minimum length, it means that a ResourceSourceIndex exists
+     * and is followed by a (required) null terminated string. The string length
+     * (including the null terminator) is the resource length minus the minimum
+     * length, minus one byte for the ResourceSourceIndex itself.
      */
     if (ResourceLength > MinimumAmlResourceLength)
     {
@@ -304,7 +269,6 @@ AcpiRsStreamOptionLength (
  * FUNCTION:    AcpiRsGetAmlLength
  *
  * PARAMETERS:  Resource            - Pointer to the resource linked list
- *              ResourceListSize    - Size of the resource linked list
  *              SizeNeeded          - Where the required size is returned
  *
  * RETURN:      Status
@@ -318,11 +282,9 @@ AcpiRsStreamOptionLength (
 ACPI_STATUS
 AcpiRsGetAmlLength (
     ACPI_RESOURCE           *Resource,
-    ACPI_SIZE               ResourceListSize,
     ACPI_SIZE               *SizeNeeded)
 {
     ACPI_SIZE               AmlSizeNeeded = 0;
-    ACPI_RESOURCE           *ResourceEnd;
     ACPI_RS_LENGTH          TotalSize;
 
 
@@ -331,8 +293,7 @@ AcpiRsGetAmlLength (
 
     /* Traverse entire list of internal resource descriptors */
 
-    ResourceEnd = ACPI_ADD_PTR (ACPI_RESOURCE, Resource, ResourceListSize);
-    while (Resource < ResourceEnd)
+    while (Resource)
     {
         /* Validate the descriptor type */
 
@@ -418,9 +379,9 @@ AcpiRsGetAmlLength (
              * 16-Bit Address Resource:
              * Add the size of the optional ResourceSource info
              */
-            TotalSize = (ACPI_RS_LENGTH) (TotalSize +
-                AcpiRsStructOptionLength (
-                    &Resource->Data.Address16.ResourceSource));
+            TotalSize = (ACPI_RS_LENGTH)
+                (TotalSize + AcpiRsStructOptionLength (
+                                &Resource->Data.Address16.ResourceSource));
             break;
 
 
@@ -429,9 +390,9 @@ AcpiRsGetAmlLength (
              * 32-Bit Address Resource:
              * Add the size of the optional ResourceSource info
              */
-            TotalSize = (ACPI_RS_LENGTH) (TotalSize +
-                AcpiRsStructOptionLength (
-                    &Resource->Data.Address32.ResourceSource));
+            TotalSize = (ACPI_RS_LENGTH)
+                (TotalSize + AcpiRsStructOptionLength (
+                                &Resource->Data.Address32.ResourceSource));
             break;
 
 
@@ -440,9 +401,9 @@ AcpiRsGetAmlLength (
              * 64-Bit Address Resource:
              * Add the size of the optional ResourceSource info
              */
-            TotalSize = (ACPI_RS_LENGTH) (TotalSize +
-                AcpiRsStructOptionLength (
-                    &Resource->Data.Address64.ResourceSource));
+            TotalSize = (ACPI_RS_LENGTH)
+                (TotalSize + AcpiRsStructOptionLength (
+                                &Resource->Data.Address64.ResourceSource));
             break;
 
 
@@ -452,7 +413,8 @@ AcpiRsGetAmlLength (
              * Add the size of each additional optional interrupt beyond the
              * required 1 (4 bytes for each UINT32 interrupt number)
              */
-            TotalSize = (ACPI_RS_LENGTH) (TotalSize +
+            TotalSize = (ACPI_RS_LENGTH)
+                (TotalSize +
                 ((Resource->Data.ExtendedIrq.InterruptCount - 1) * 4) +
 
                 /* Add the size of the optional ResourceSource info */
@@ -464,27 +426,16 @@ AcpiRsGetAmlLength (
 
         case ACPI_RESOURCE_TYPE_GPIO:
 
-            TotalSize = (ACPI_RS_LENGTH) (TotalSize +
-                (Resource->Data.Gpio.PinTableLength * 2) +
+            TotalSize = (ACPI_RS_LENGTH) (TotalSize + (Resource->Data.Gpio.PinTableLength * 2) +
                 Resource->Data.Gpio.ResourceSource.StringLength +
                 Resource->Data.Gpio.VendorLength);
 
             break;
 
-        case ACPI_RESOURCE_TYPE_PIN_FUNCTION:
-
-            TotalSize = (ACPI_RS_LENGTH) (TotalSize +
-                (Resource->Data.PinFunction.PinTableLength * 2) +
-                Resource->Data.PinFunction.ResourceSource.StringLength +
-                Resource->Data.PinFunction.VendorLength);
-
-            break;
-
 
         case ACPI_RESOURCE_TYPE_SERIAL_BUS:
 
-            TotalSize = AcpiGbl_AmlResourceSerialBusSizes [
-                Resource->Data.CommonSerialBus.Type];
+            TotalSize = AcpiGbl_AmlResourceSerialBusSizes [Resource->Data.CommonSerialBus.Type];
 
             TotalSize = (ACPI_RS_LENGTH) (TotalSize +
                 Resource->Data.I2cSerialBus.ResourceSource.StringLength +
@@ -492,44 +443,8 @@ AcpiRsGetAmlLength (
 
             break;
 
-        case ACPI_RESOURCE_TYPE_PIN_CONFIG:
-
-            TotalSize = (ACPI_RS_LENGTH) (TotalSize +
-                (Resource->Data.PinConfig.PinTableLength * 2) +
-                Resource->Data.PinConfig.ResourceSource.StringLength +
-                Resource->Data.PinConfig.VendorLength);
-
-            break;
-
-        case ACPI_RESOURCE_TYPE_PIN_GROUP:
-
-            TotalSize = (ACPI_RS_LENGTH) (TotalSize +
-                (Resource->Data.PinGroup.PinTableLength * 2) +
-                Resource->Data.PinGroup.ResourceLabel.StringLength +
-                Resource->Data.PinGroup.VendorLength);
-
-            break;
-
-        case ACPI_RESOURCE_TYPE_PIN_GROUP_FUNCTION:
-
-            TotalSize = (ACPI_RS_LENGTH) (TotalSize +
-                Resource->Data.PinGroupFunction.ResourceSource.StringLength +
-                Resource->Data.PinGroupFunction.ResourceSourceLabel.StringLength +
-                Resource->Data.PinGroupFunction.VendorLength);
-
-            break;
-
-        case ACPI_RESOURCE_TYPE_PIN_GROUP_CONFIG:
-
-            TotalSize = (ACPI_RS_LENGTH) (TotalSize +
-                Resource->Data.PinGroupConfig.ResourceSource.StringLength +
-                Resource->Data.PinGroupConfig.ResourceSourceLabel.StringLength +
-                Resource->Data.PinGroupConfig.VendorLength);
-
-            break;
 
         default:
-
             break;
         }
 
@@ -699,98 +614,26 @@ AcpiRsGetListLength (
 
             if (AmlResource->Gpio.VendorLength)
             {
-                ExtraStructBytes +=
-                    AmlResource->Gpio.VendorOffset -
-                    AmlResource->Gpio.PinTableOffset +
-                    AmlResource->Gpio.VendorLength;
+                ExtraStructBytes += AmlResource->Gpio.VendorOffset -
+                    AmlResource->Gpio.PinTableOffset + AmlResource->Gpio.VendorLength;
             }
             else
             {
-                ExtraStructBytes +=
-                    AmlResource->LargeHeader.ResourceLength +
+                ExtraStructBytes += AmlResource->LargeHeader.ResourceLength +
                     sizeof (AML_RESOURCE_LARGE_HEADER) -
                     AmlResource->Gpio.PinTableOffset;
             }
             break;
 
-        case ACPI_RESOURCE_NAME_PIN_FUNCTION:
-
-            /* Vendor data is optional */
-
-            if (AmlResource->PinFunction.VendorLength)
-            {
-                ExtraStructBytes +=
-                    AmlResource->PinFunction.VendorOffset -
-                    AmlResource->PinFunction.PinTableOffset +
-                    AmlResource->PinFunction.VendorLength;
-            }
-            else
-            {
-                ExtraStructBytes +=
-                    AmlResource->LargeHeader.ResourceLength +
-                    sizeof (AML_RESOURCE_LARGE_HEADER) -
-                    AmlResource->PinFunction.PinTableOffset;
-            }
-            break;
-
         case ACPI_RESOURCE_NAME_SERIAL_BUS:
 
             MinimumAmlResourceLength = AcpiGbl_ResourceAmlSerialBusSizes[
                 AmlResource->CommonSerialBus.Type];
-            ExtraStructBytes +=
-                AmlResource->CommonSerialBus.ResourceLength -
+            ExtraStructBytes += AmlResource->CommonSerialBus.ResourceLength -
                 MinimumAmlResourceLength;
             break;
 
-        case ACPI_RESOURCE_NAME_PIN_CONFIG:
-
-            /* Vendor data is optional */
-
-            if (AmlResource->PinConfig.VendorLength)
-            {
-                ExtraStructBytes +=
-                    AmlResource->PinConfig.VendorOffset -
-                    AmlResource->PinConfig.PinTableOffset +
-                    AmlResource->PinConfig.VendorLength;
-            }
-            else
-            {
-                ExtraStructBytes +=
-                    AmlResource->LargeHeader.ResourceLength +
-                    sizeof (AML_RESOURCE_LARGE_HEADER) -
-                    AmlResource->PinConfig.PinTableOffset;
-            }
-            break;
-
-        case ACPI_RESOURCE_NAME_PIN_GROUP:
-
-            ExtraStructBytes +=
-                AmlResource->PinGroup.VendorOffset -
-                AmlResource->PinGroup.PinTableOffset +
-                AmlResource->PinGroup.VendorLength;
-
-            break;
-
-        case ACPI_RESOURCE_NAME_PIN_GROUP_FUNCTION:
-
-            ExtraStructBytes +=
-                AmlResource->PinGroupFunction.VendorOffset -
-                AmlResource->PinGroupFunction.ResSourceOffset +
-                AmlResource->PinGroupFunction.VendorLength;
-
-            break;
-
-        case ACPI_RESOURCE_NAME_PIN_GROUP_CONFIG:
-
-            ExtraStructBytes +=
-                AmlResource->PinGroupConfig.VendorOffset -
-                AmlResource->PinGroupConfig.ResSourceOffset +
-                AmlResource->PinGroupConfig.VendorLength;
-
-            break;
-
         default:
-
             break;
         }
 
@@ -800,8 +643,7 @@ AcpiRsGetListLength (
          * Important: Round the size up for the appropriate alignment. This
          * is a requirement on IA64.
          */
-        if (AcpiUtGetResourceType (AmlBuffer) ==
-            ACPI_RESOURCE_NAME_SERIAL_BUS)
+        if (AcpiUtGetResourceType (AmlBuffer) == ACPI_RESOURCE_NAME_SERIAL_BUS)
         {
             BufferSize = AcpiGbl_ResourceStructSerialBusSizes[
                 AmlResource->CommonSerialBus.Type] + ExtraStructBytes;
@@ -809,10 +651,10 @@ AcpiRsGetListLength (
         else
         {
             BufferSize = AcpiGbl_ResourceStructSizes[ResourceIndex] +
-                ExtraStructBytes;
+                        ExtraStructBytes;
         }
-
         BufferSize = (UINT32) ACPI_ROUND_UP_TO_NATIVE_WORD (BufferSize);
+
         *SizeNeeded += BufferSize;
 
         ACPI_DEBUG_PRINT ((ACPI_DB_RESOURCES,
@@ -884,7 +726,7 @@ AcpiRsGetPciRoutingTableLength (
 
     for (Index = 0; Index < NumberOfElements; Index++)
     {
-        /* Dereference the subpackage */
+        /* Dereference the sub-package */
 
         PackageElement = *TopObjectList;
 
@@ -906,9 +748,7 @@ AcpiRsGetPciRoutingTableLength (
 
         NameFound = FALSE;
 
-        for (TableIndex = 0;
-             TableIndex < PackageElement->Package.Count && !NameFound;
-             TableIndex++)
+        for (TableIndex = 0; TableIndex < 4 && !NameFound; TableIndex++)
         {
             if (*SubObjectList && /* Null object allowed */
 
@@ -949,7 +789,7 @@ AcpiRsGetPciRoutingTableLength (
             else
             {
                 TempSizeNeeded += AcpiNsGetPathnameLength (
-                    (*SubObjectList)->Reference.Node);
+                                    (*SubObjectList)->Reference.Node);
             }
         }
         else
