@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,44 +111,11 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+
+#define __RSUTILS_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acnamesp.h"
@@ -281,8 +248,7 @@ AcpiRsMoveData (
         case ACPI_RSC_MOVE_GPIO_RES:
         case ACPI_RSC_MOVE_SERIAL_VEN:
         case ACPI_RSC_MOVE_SERIAL_RES:
-
-            memcpy (Destination, Source, ItemCount);
+            ACPI_MEMCPY (Destination, Source, ItemCount);
             return;
 
         /*
@@ -292,28 +258,21 @@ AcpiRsMoveData (
          */
         case ACPI_RSC_MOVE16:
         case ACPI_RSC_MOVE_GPIO_PIN:
-
-            ACPI_MOVE_16_TO_16 (
-                &ACPI_CAST_PTR (UINT16, Destination)[i],
-                &ACPI_CAST_PTR (UINT16, Source)[i]);
+            ACPI_MOVE_16_TO_16 (&ACPI_CAST_PTR (UINT16, Destination)[i],
+                                &ACPI_CAST_PTR (UINT16, Source)[i]);
             break;
 
         case ACPI_RSC_MOVE32:
-
-            ACPI_MOVE_32_TO_32 (
-                &ACPI_CAST_PTR (UINT32, Destination)[i],
-                &ACPI_CAST_PTR (UINT32, Source)[i]);
+            ACPI_MOVE_32_TO_32 (&ACPI_CAST_PTR (UINT32, Destination)[i],
+                                &ACPI_CAST_PTR (UINT32, Source)[i]);
             break;
 
         case ACPI_RSC_MOVE64:
-
-            ACPI_MOVE_64_TO_64 (
-                &ACPI_CAST_PTR (UINT64, Destination)[i],
-                &ACPI_CAST_PTR (UINT64, Source)[i]);
+            ACPI_MOVE_64_TO_64 (&ACPI_CAST_PTR (UINT64, Destination)[i],
+                                &ACPI_CAST_PTR (UINT64, Source)[i]);
             break;
 
         default:
-
             return;
         }
     }
@@ -359,18 +318,18 @@ AcpiRsSetResourceLength (
     {
         /* Large descriptor -- bytes 1-2 contain the 16-bit length */
 
-        ACPI_MOVE_16_TO_16 (
-            &Aml->LargeHeader.ResourceLength, &ResourceLength);
+        ACPI_MOVE_16_TO_16 (&Aml->LargeHeader.ResourceLength, &ResourceLength);
     }
     else
     {
-        /*
-         * Small descriptor -- bits 2:0 of byte 0 contain the length
-         * Clear any existing length, preserving descriptor type bits
-         */
+        /* Small descriptor -- bits 2:0 of byte 0 contain the length */
+
         Aml->SmallHeader.DescriptorType = (UINT8)
-            ((Aml->SmallHeader.DescriptorType &
-                ~ACPI_RESOURCE_NAME_SMALL_LENGTH_MASK)
+
+            /* Clear any existing length, preserving descriptor type bits */
+
+            ((Aml->SmallHeader.DescriptorType & ~ACPI_RESOURCE_NAME_SMALL_LENGTH_MASK)
+
             | ResourceLength);
     }
 }
@@ -489,8 +448,8 @@ AcpiRsGetResourceSource (
     AmlResourceSource = ACPI_ADD_PTR (UINT8, Aml, MinimumLength);
 
     /*
-     * ResourceSource is present if the length of the descriptor is longer
-     * than the minimum length.
+     * ResourceSource is present if the length of the descriptor is longer than
+     * the minimum length.
      *
      * Note: Some resource descriptors will have an additional null, so
      * we add 1 to the minimum length.
@@ -508,8 +467,8 @@ AcpiRsGetResourceSource (
              * String destination pointer is not specified; Set the String
              * pointer to the end of the current ResourceSource structure.
              */
-            ResourceSource->StringPtr = ACPI_ADD_PTR (
-                char, ResourceSource, sizeof (ACPI_RESOURCE_SOURCE));
+            ResourceSource->StringPtr = ACPI_ADD_PTR (char, ResourceSource,
+                sizeof (ACPI_RESOURCE_SOURCE));
         }
 
         /*
@@ -519,17 +478,15 @@ AcpiRsGetResourceSource (
          *
          * Zero the entire area of the buffer.
          */
-        TotalLength = (UINT32) strlen (
+        TotalLength = (UINT32) ACPI_STRLEN (
             ACPI_CAST_PTR (char, &AmlResourceSource[1])) + 1;
-
         TotalLength = (UINT32) ACPI_ROUND_UP_TO_NATIVE_WORD (TotalLength);
 
-        memset (ResourceSource->StringPtr, 0, TotalLength);
+        ACPI_MEMSET (ResourceSource->StringPtr, 0, TotalLength);
 
         /* Copy the ResourceSource string to the destination */
 
-        ResourceSource->StringLength = AcpiRsStrcpy (
-            ResourceSource->StringPtr,
+        ResourceSource->StringLength = AcpiRsStrcpy (ResourceSource->StringPtr,
             ACPI_CAST_PTR (char, &AmlResourceSource[1]));
 
         return ((ACPI_RS_LENGTH) TotalLength);
@@ -590,15 +547,14 @@ AcpiRsSetResourceSource (
 
         /* Copy the ResourceSource string */
 
-        strcpy (ACPI_CAST_PTR (char, &AmlResourceSource[1]),
+        ACPI_STRCPY (ACPI_CAST_PTR (char, &AmlResourceSource[1]),
             ResourceSource->StringPtr);
 
         /*
          * Add the length of the string (+ 1 for null terminator) to the
          * final descriptor length
          */
-        DescriptorLength += ((ACPI_RSDESC_SIZE)
-            ResourceSource->StringLength + 1);
+        DescriptorLength += ((ACPI_RSDESC_SIZE) ResourceSource->StringLength + 1);
     }
 
     /* Return the new total length of the AML descriptor */
@@ -641,8 +597,8 @@ AcpiRsGetPrtMethodData (
 
     /* Execute the method, no parameters */
 
-    Status = AcpiUtEvaluateObject (
-        Node, METHOD_NAME__PRT, ACPI_BTYPE_PACKAGE, &ObjDesc);
+    Status = AcpiUtEvaluateObject (Node, METHOD_NAME__PRT,
+                ACPI_BTYPE_PACKAGE, &ObjDesc);
     if (ACPI_FAILURE (Status))
     {
         return_ACPI_STATUS (Status);
@@ -695,8 +651,8 @@ AcpiRsGetCrsMethodData (
 
     /* Execute the method, no parameters */
 
-    Status = AcpiUtEvaluateObject (
-        Node, METHOD_NAME__CRS, ACPI_BTYPE_BUFFER, &ObjDesc);
+    Status = AcpiUtEvaluateObject (Node, METHOD_NAME__CRS,
+                ACPI_BTYPE_BUFFER, &ObjDesc);
     if (ACPI_FAILURE (Status))
     {
         return_ACPI_STATUS (Status);
@@ -750,8 +706,8 @@ AcpiRsGetPrsMethodData (
 
     /* Execute the method, no parameters */
 
-    Status = AcpiUtEvaluateObject (
-        Node, METHOD_NAME__PRS, ACPI_BTYPE_BUFFER, &ObjDesc);
+    Status = AcpiUtEvaluateObject (Node, METHOD_NAME__PRS,
+                ACPI_BTYPE_BUFFER, &ObjDesc);
     if (ACPI_FAILURE (Status))
     {
         return_ACPI_STATUS (Status);
@@ -805,8 +761,8 @@ AcpiRsGetAeiMethodData (
 
     /* Execute the method, no parameters */
 
-    Status = AcpiUtEvaluateObject (
-        Node, METHOD_NAME__AEI, ACPI_BTYPE_BUFFER, &ObjDesc);
+    Status = AcpiUtEvaluateObject (Node, METHOD_NAME__AEI,
+                ACPI_BTYPE_BUFFER, &ObjDesc);
     if (ACPI_FAILURE (Status))
     {
         return_ACPI_STATUS (Status);
@@ -848,7 +804,7 @@ AcpiRsGetAeiMethodData (
 ACPI_STATUS
 AcpiRsGetMethodData (
     ACPI_HANDLE             Handle,
-    const char              *Path,
+    char                    *Path,
     ACPI_BUFFER             *RetBuffer)
 {
     ACPI_OPERAND_OBJECT     *ObjDesc;
@@ -862,8 +818,7 @@ AcpiRsGetMethodData (
 
     /* Execute the method, no parameters */
 
-    Status = AcpiUtEvaluateObject (
-        ACPI_CAST_PTR (ACPI_NAMESPACE_NODE, Handle),
+    Status = AcpiUtEvaluateObject (ACPI_CAST_PTR (ACPI_NAMESPACE_NODE, Handle),
         Path, ACPI_BTYPE_BUFFER, &ObjDesc);
     if (ACPI_FAILURE (Status))
     {
@@ -939,7 +894,7 @@ AcpiRsSetSrsMethodData (
      * Convert the linked list into a byte stream
      */
     Buffer.Length = ACPI_ALLOCATE_LOCAL_BUFFER;
-    Status = AcpiRsCreateAmlResources (InBuffer, &Buffer);
+    Status = AcpiRsCreateAmlResources (InBuffer->Pointer, &Buffer);
     if (ACPI_FAILURE (Status))
     {
         goto Cleanup;
