@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,8 @@
  *
  *****************************************************************************/
 
+#define __UTEVAL_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acnamesp.h"
@@ -144,7 +146,7 @@
 ACPI_STATUS
 AcpiUtEvaluateObject (
     ACPI_NAMESPACE_NODE     *PrefixNode,
-    const char              *Path,
+    char                    *Path,
     UINT32                  ExpectedReturnBtypes,
     ACPI_OPERAND_OBJECT     **ReturnDesc)
 {
@@ -206,27 +208,22 @@ AcpiUtEvaluateObject (
     switch ((Info->ReturnObject)->Common.Type)
     {
     case ACPI_TYPE_INTEGER:
-
         ReturnBtype = ACPI_BTYPE_INTEGER;
         break;
 
     case ACPI_TYPE_BUFFER:
-
         ReturnBtype = ACPI_BTYPE_BUFFER;
         break;
 
     case ACPI_TYPE_STRING:
-
         ReturnBtype = ACPI_BTYPE_STRING;
         break;
 
     case ACPI_TYPE_PACKAGE:
-
         ReturnBtype = ACPI_BTYPE_PACKAGE;
         break;
 
     default:
-
         ReturnBtype = 0;
         break;
     }
@@ -291,7 +288,7 @@ Cleanup:
 
 ACPI_STATUS
 AcpiUtEvaluateNumericObject (
-    const char              *ObjectName,
+    char                    *ObjectName,
     ACPI_NAMESPACE_NODE     *DeviceNode,
     UINT64                  *Value)
 {
@@ -303,7 +300,7 @@ AcpiUtEvaluateNumericObject (
 
 
     Status = AcpiUtEvaluateObject (DeviceNode, ObjectName,
-        ACPI_BTYPE_INTEGER, &ObjDesc);
+                ACPI_BTYPE_INTEGER, &ObjDesc);
     if (ACPI_FAILURE (Status))
     {
         return_ACPI_STATUS (Status);
@@ -330,8 +327,7 @@ AcpiUtEvaluateNumericObject (
  * RETURN:      Status
  *
  * DESCRIPTION: Executes _STA for selected device and stores results in
- *              *Flags. If _STA does not exist, then the device is assumed
- *              to be present/functional/enabled (as per the ACPI spec).
+ *              *Flags.
  *
  *              NOTE: Internal function, no parameter validation
  *
@@ -350,16 +346,11 @@ AcpiUtExecute_STA (
 
 
     Status = AcpiUtEvaluateObject (DeviceNode, METHOD_NAME__STA,
-        ACPI_BTYPE_INTEGER, &ObjDesc);
+                ACPI_BTYPE_INTEGER, &ObjDesc);
     if (ACPI_FAILURE (Status))
     {
         if (AE_NOT_FOUND == Status)
         {
-            /*
-             * if _STA does not exist, then (as per the ACPI specification),
-             * the returned flags will indicate that the device is present,
-             * functional, and enabled.
-             */
             ACPI_DEBUG_PRINT ((ACPI_DB_EXEC,
                 "_STA on %4.4s was not found, assuming device is present\n",
                 AcpiUtGetNodeName (DeviceNode)));
@@ -423,8 +414,8 @@ AcpiUtExecutePowerMethods (
          * return type is an Integer.
          */
         Status = AcpiUtEvaluateObject (DeviceNode,
-            ACPI_CAST_PTR (char, MethodNames[i]),
-            ACPI_BTYPE_INTEGER, &ObjDesc);
+                    ACPI_CAST_PTR (char, MethodNames[i]),
+                    ACPI_BTYPE_INTEGER, &ObjDesc);
         if (ACPI_SUCCESS (Status))
         {
             OutValues[i] = (UINT8) ObjDesc->Integer.Value;
