@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -149,7 +149,6 @@
 #define ACPI_LARGE_NAMESPACE_NODE
 #define ACPI_DATA_TABLE_DISASSEMBLY
 #define ACPI_SINGLE_THREADED
-#define ACPI_32BIT_PHYSICAL_ADDRESS
 #endif
 
 /* AcpiExec configuration. Multithreaded with full AML debugger */
@@ -161,55 +160,31 @@
 #define ACPI_DBG_TRACK_ALLOCATIONS
 #endif
 
-/*
- * AcpiBin/AcpiDump/AcpiHelp/AcpiNames/AcpiSrc/AcpiXtract/Example configuration.
- * All single threaded.
- */
-#if (defined ACPI_BIN_APP)      || \
-    (defined ACPI_DUMP_APP)     || \
-    (defined ACPI_HELP_APP)     || \
-    (defined ACPI_NAMES_APP)    || \
-    (defined ACPI_SRC_APP)      || \
-    (defined ACPI_XTRACT_APP)   || \
-    (defined ACPI_EXAMPLE_APP)
+/* AcpiNames configuration. Single threaded with debugger output enabled. */
+
+#ifdef ACPI_NAMES_APP
+#define ACPI_DEBUGGER
 #define ACPI_APPLICATION
 #define ACPI_SINGLE_THREADED
 #endif
 
-/* AcpiHelp configuration. Error messages disabled. */
+/*
+ * AcpiBin/AcpiHelp/AcpiSrc configuration. All single threaded, with
+ * no debug output.
+ */
+#if (defined ACPI_BIN_APP)   || \
+    (defined ACPI_SRC_APP)   || \
+    (defined ACPI_XTRACT_APP)
+#define ACPI_APPLICATION
+#define ACPI_SINGLE_THREADED
+#endif
 
 #ifdef ACPI_HELP_APP
+#define ACPI_APPLICATION
+#define ACPI_SINGLE_THREADED
 #define ACPI_NO_ERROR_MESSAGES
 #endif
 
-/* AcpiNames configuration. Debug output enabled. */
-
-#ifdef ACPI_NAMES_APP
-#define ACPI_DEBUG_OUTPUT
-#endif
-
-/* AcpiExec/AcpiNames/Example configuration. Native RSDP used. */
-
-#if (defined ACPI_EXEC_APP)     || \
-    (defined ACPI_EXAMPLE_APP)  || \
-    (defined ACPI_NAMES_APP)
-#define ACPI_USE_NATIVE_RSDP_POINTER
-#endif
-
-/* AcpiDump configuration. Native mapping used if provied by OSPMs */
-
-#ifdef ACPI_DUMP_APP
-#define ACPI_USE_NATIVE_MEMORY_MAPPING
-#define USE_NATIVE_ALLOCATE_ZEROED
-#endif
-
-/* AcpiNames/Example configuration. Hardware disabled */
-
-#if (defined ACPI_EXAMPLE_APP)  || \
-    (defined ACPI_NAMES_APP)
-#define ACPI_REDUCED_HARDWARE 1
-#endif
-
 /* Linkable ACPICA library */
 
 #ifdef ACPI_LIBRARY
@@ -244,9 +219,6 @@
 #if defined(_LINUX) || defined(__linux__)
 #include "aclinux.h"
 
-#elif defined(_APPLE) || defined(__APPLE__)
-#include "acmacosx.h"
-
 #elif defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 #include "acfreebsd.h"
 
@@ -280,9 +252,6 @@
 #elif defined(_AED_EFI)
 #include "acefi.h"
 
-#elif defined(_GNU_EFI)
-#include "acefi.h"
-
 #elif defined(__HAIKU__)
 #include "achaiku.h"
 
@@ -495,17 +464,4 @@ typedef char *va_list;
 
 #endif /* ACPI_USE_SYSTEM_CLIBRARY */
 
-#ifndef ACPI_FILE
-#ifdef ACPI_APPLICATION
-#include <stdio.h>
-#define ACPI_FILE              FILE *
-#define ACPI_FILE_OUT          stdout
-#define ACPI_FILE_ERR          stderr
-#else
-#define ACPI_FILE              void *
-#define ACPI_FILE_OUT          NULL
-#define ACPI_FILE_ERR          NULL
-#endif /* ACPI_APPLICATION */
-#endif /* ACPI_FILE */
-
 #endif /* __ACENV_H__ */
