@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -142,8 +142,6 @@
 #define     AH_DECODE_AML_OPCODE        5
 #define     AH_DISPLAY_DEVICE_IDS       6
 #define     AH_DECODE_EXCEPTION         7
-#define     AH_DECODE_ASL_AML           8
-#define     AH_DISPLAY_UUIDS            9
 
 #define     AH_MAX_ASL_LINE_LENGTH      70
 #define     AH_MAX_AML_LINE_LENGTH      100
@@ -178,11 +176,17 @@ typedef struct ah_asl_keyword
 
 } AH_ASL_KEYWORD;
 
+typedef struct ah_device_id
+{
+    char            *Name;
+    char            *Description;
+
+} AH_DEVICE_ID;
+
 
 extern const AH_AML_OPCODE          AmlOpcodeInfo[];
 extern const AH_ASL_OPERATOR        AslOperatorInfo[];
 extern const AH_ASL_KEYWORD         AslKeywordInfo[];
-extern const AH_UUID                AcpiUuids[];
 extern BOOLEAN                      AhDisplayAll;
 
 void
@@ -206,10 +210,6 @@ AhFindPredefinedNames (
     char                    *Name);
 
 void
-AhFindAslAndAmlOperators (
-    char                    *Name);
-
-UINT32
 AhFindAslOperators (
     char                    *Name);
 
@@ -219,10 +219,6 @@ AhFindAslKeywords (
 
 void
 AhDisplayDeviceIds (
-    char                    *Name);
-
-void
-AhDisplayUuids (
     void);
 
 #endif /* __ACPIHELP_H */
