@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2018, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,45 +111,8 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
-#define DEFINE_AHELP_GLOBALS
 #include "acpihelp.h"
 
 
@@ -159,17 +122,6 @@ static void
 AhDisplayUsage (
     void);
 
-#define AH_UTILITY_NAME             "ACPI Help Utility"
-#define AH_SUPPORTED_OPTIONS        "adeghikmopstuv^"
-
-
-#if defined ACPI_OPTION
-#undef ACPI_OPTION
-#endif
-
-#define ACPI_OPTION(Name, Description) \
-    AcpiOsPrintf ("  %-24s%s\n", Name, Description);
-
 
 /******************************************************************************
  *
@@ -184,35 +136,24 @@ AhDisplayUsage (
     void)
 {
 
-    ACPI_USAGE_HEADER ("acpihelp <options> [Name/Prefix | HexValue]");
+    ACPI_USAGE_HEADER ("acpihelp <options> [NamePrefix | HexValue]");
     ACPI_OPTION ("-h",                      "Display help");
-    ACPI_OPTION ("-v",                      "Display version information");
-    ACPI_OPTION ("-vd",                     "Display build date and time");
 
-    ACPI_USAGE_TEXT ("\nAML Names and Encodings (ACPI Machine Language):\n");
-    ACPI_OPTION ("-a [Name/Prefix | *]",    "Display both ASL operator and AML opcode name(s)");
-    ACPI_OPTION ("-g [Name/Prefix | *]",    "Display AML grammar elements(s)");
-    ACPI_OPTION ("-m [Name/Prefix | *]",    "Display AML opcode name(s)");
+    printf ("\nACPI Names and Symbols:\n");
+    ACPI_OPTION ("-k [NamePrefix]",         "Find/Display ASL non-operator keyword(s)");
+    ACPI_OPTION ("-m [NamePrefix]",         "Find/Display AML opcode name(s)");
+    ACPI_OPTION ("-p [NamePrefix]",         "Find/Display ASL predefined method name(s)");
+    ACPI_OPTION ("-s [NamePrefix]",         "Find/Display ASL operator name(s)");
 
-    ACPI_USAGE_TEXT ("\nACPI Values:\n");
+    printf ("\nACPI Values:\n");
     ACPI_OPTION ("-e [HexValue]",           "Decode ACPICA exception code");
+    ACPI_OPTION ("-i",                      "Display known ACPI Device IDs (_HID)");
     ACPI_OPTION ("-o [HexValue]",           "Decode hex AML opcode");
 
-    ACPI_USAGE_TEXT ("\nASL Names and Symbols (ACPI Source Language):\n");
-    ACPI_OPTION ("-k [Name/Prefix | *]",    "Display ASL non-operator keyword(s)");
-    ACPI_OPTION ("-p [Name/Prefix | *]",    "Display ASL predefined method name(s)");
-    ACPI_OPTION ("-s [Name/Prefix | *]",    "Display ASL operator name(s)");
-
-    ACPI_USAGE_TEXT ("\nOther miscellaneous ACPI Names:\n");
-    ACPI_OPTION ("-i [Name/Prefix | *]",    "Display ACPI/PNP Hardware ID(s)");
-    ACPI_OPTION ("-d",                      "Display iASL Preprocessor directives");
-    ACPI_OPTION ("-t",                      "Display supported ACPI tables");
-    ACPI_OPTION ("-u",                      "Display ACPI-related UUIDs");
-
-    ACPI_USAGE_TEXT ("\nName/Prefix or HexValue not specified means \"Display All\"\n");
-    ACPI_USAGE_TEXT ("\nDefault search with valid Name/Prefix and no options:\n");
-    ACPI_USAGE_TEXT ("    Find ASL/AML operator names - if NamePrefix does not start with underscore\n");
-    ACPI_USAGE_TEXT ("    Find ASL predefined method names - if NamePrefix starts with underscore\n");
+    printf ("\nNamePrefix/HexValue not specified means \"Display All\"\n");
+    printf ("\nDefault search with NamePrefix and no options:\n");
+    printf ("    Find ASL operator names - if NamePrefix does not start with underscore\n");
+    printf ("    Find ASL predefined method names - if NamePrefix starts with underscore\n");
 }
 
 
@@ -234,9 +175,7 @@ main (
     int                     j;
 
 
-    AcpiOsInitialize ();
-    ACPI_DEBUG_INITIALIZE (); /* For debug version only */
-    printf (ACPI_COMMON_SIGNON (AH_UTILITY_NAME));
+    printf (ACPI_COMMON_SIGNON ("ACPI Help Utility"));
     DecodeType = AH_DECODE_DEFAULT;
 
     if (argc < 2)
@@ -247,91 +186,38 @@ main (
 
     /* Command line options */
 
-    while ((j = AcpiGetopt (argc, argv, AH_SUPPORTED_OPTIONS)) != ACPI_OPT_END) switch (j)
+    while ((j = AcpiGetopt (argc, argv, "ehikmops")) != EOF) switch (j)
     {
-    case 'a':
-
-        DecodeType = AH_DECODE_ASL_AML;
-        break;
-
-    case 'd':
-
-        DecodeType = AH_DISPLAY_DIRECTIVES;
-        break;
-
     case 'e':
-
         DecodeType = AH_DECODE_EXCEPTION;
         break;
 
-    case 'g':
-
-        DecodeType = AH_DECODE_AML_TYPE;
-        break;
-
     case 'i':
-
         DecodeType = AH_DISPLAY_DEVICE_IDS;
         break;
 
     case 'k':
-
         DecodeType = AH_DECODE_ASL_KEYWORD;
         break;
 
     case 'm':
-
         DecodeType = AH_DECODE_AML;
         break;
 
     case 'o':
-
         DecodeType = AH_DECODE_AML_OPCODE;
         break;
 
     case 'p':
-
         DecodeType = AH_DECODE_PREDEFINED_NAME;
         break;
 
     case 's':
-
         DecodeType = AH_DECODE_ASL;
         break;
 
-    case 't':
-
-        DecodeType = AH_DISPLAY_TABLES;
-        break;
-
-    case 'u':
-
-        DecodeType = AH_DISPLAY_UUIDS;
-        break;
-
-    case 'v': /* -v: (Version): signon already emitted, just exit */
-
-        switch (AcpiGbl_Optarg[0])
-        {
-        case '^':  /* -v: (Version) */
-
-            return (1);
-
-        case 'd':
-
-            printf (ACPI_COMMON_BUILD_TIME);
-            return (1);
-
-        default:
-
-            printf ("Unknown option: -v%s\n", AcpiGbl_Optarg);
-            return (-1);
-        }
-        break;
-
     case 'h':
     default:
-
         AhDisplayUsage ();
         return (-1);
     }
@@ -342,68 +228,35 @@ main (
 
     switch (DecodeType)
     {
-    case AH_DECODE_ASL_AML:
-
-        AhFindAslAndAmlOperators (Name);
-        break;
-
     case AH_DECODE_AML:
-
         AhFindAmlOpcode (Name);
         break;
 
     case AH_DECODE_AML_OPCODE:
-
         AhDecodeAmlOpcode (Name);
         break;
 
-    case AH_DECODE_AML_TYPE:
-
-        AhFindAmlTypes (Name);
-        break;
-
     case AH_DECODE_PREDEFINED_NAME:
-
         AhFindPredefinedNames (Name);
         break;
 
     case AH_DECODE_ASL:
-
         AhFindAslOperators (Name);
         break;
 
     case AH_DECODE_ASL_KEYWORD:
-
         AhFindAslKeywords (Name);
         break;
 
     case AH_DISPLAY_DEVICE_IDS:
-
-        AhDisplayDeviceIds (Name);
+        AhDisplayDeviceIds ();
         break;
 
     case AH_DECODE_EXCEPTION:
-
         AhDecodeException (Name);
         break;
 
-    case AH_DISPLAY_UUIDS:
-
-        AhDisplayUuids ();
-        break;
-
-    case AH_DISPLAY_TABLES:
-
-        AhDisplayTables ();
-        break;
-
-    case AH_DISPLAY_DIRECTIVES:
-
-        AhDisplayDirectives ();
-        break;
-
-   default:
-
+    default:
         if (!Name)
         {
             AhFindAslOperators (Name);
@@ -416,10 +269,47 @@ main (
         }
         else
         {
-            AhFindAslAndAmlOperators (Name);
+            AhFindAslOperators (Name);
         }
         break;
     }
 
     return (0);
 }
+
+
+/*******************************************************************************
+ *
+ * FUNCTION:    AhStrupr (strupr)
+ *
+ * PARAMETERS:  SrcString           - The source string to convert
+ *
+ * RETURN:      None
+ *
+ * DESCRIPTION: Convert string to uppercase
+ *
+ * NOTE: This is not a POSIX function, so it appears here, not in utclib.c
+ *
+ ******************************************************************************/
+
+void
+AhStrupr (
+    char                    *SrcString)
+{
+    char                    *String;
+
+
+    if (!SrcString)
+    {
+        return;
+    }
+
+    /* Walk entire string, uppercasing the letters */
+
+    for (String = SrcString; *String; String++)
+    {
+        *String = (char) toupper ((int) *String);
+    }
+
+    return;
+}
