@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,356 +111,26 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpisrc.h"
 
-AS_BRACE_INFO               Gbl_BraceInfo[] =
-{
-    {" if",         3},
-    {" else if",    8},
-    {" else while", 11},
-    {" else",       5},
-    {" do ",        4},
-    {NULL,          0}
-};
-
-
 /* Local prototypes */
 
-static char *
-AsMatchValidToken (
+char *
+AsCheckAndSkipLiterals (
     char                    *Buffer,
-    char                    *Filename,
-    char                    TargetChar,
-    AS_SCAN_CALLBACK        Callback);
+    UINT32                  *TotalLines);
 
-static char *
-AsCheckBracesCallback (
-    char                    *Buffer,
-    char                    *Filename,
-    UINT32                  LineNumber);
-
-static UINT32
+UINT32
 AsCountLines (
     char                    *Buffer,
     char                    *Filename);
 
-
-#define MODULE_HEADER_BEGIN "/******************************************************************************\n *\n * Module Name:";
-#define MODULE_HEADER_END   " *****************************************************************************/\n\n"
-#define INTEL_COPYRIGHT     " * Copyright (C) 2000 - 2019, Intel Corp.\n"
-
 /* Opening signature of the Intel legal header */
 
 char        *HeaderBegin = "/******************************************************************************\n *\n * 1. Copyright Notice";
 
-UINT32      NonAnsiCommentCount;
-
-char        CopyRightHeaderEnd[] = INTEL_COPYRIGHT " *\n" MODULE_HEADER_END;
-
-/******************************************************************************
- *
- * FUNCTION:    AsCountNonAnsiComments
- *
- * DESCRIPTION: Count the number of "//" comments. This type of comment is
- *              non-ANSI C.
- *
- * NOTE: July 2014: Allows // within quoted strings and within normal
- *       comments. Eliminates extraneous warnings from this utility.
- *
- ******************************************************************************/
-
-void
-AsCountNonAnsiComments (
-    char                    *Buffer,
-    char                    *Filename)
-{
-
-    AsMatchValidToken (Buffer, Filename, 0, NULL);
-
-    /* Error if any slash-slash comments found */
-
-    if (NonAnsiCommentCount)
-    {
-        AsPrint ("Non-ANSI // Comments Found", NonAnsiCommentCount, Filename);
-        Gbl_NonAnsiComments += NonAnsiCommentCount;
-    }
-}
-
-
-/******************************************************************************
- *
- * FUNCTION:    AsCheckForBraces
- *
- * DESCRIPTION: Check for an open brace after each if/else/do (etc.)
- *              statement
- *
- ******************************************************************************/
-
-void
-AsCheckForBraces (
-    char                    *Buffer,
-    char                    *Filename)
-{
-
-    AsMatchValidToken (Buffer, Filename, 0, AsCheckBracesCallback);
-}
-
-
-/******************************************************************************
- *
- * FUNCTION:    AsCheckBracesCallback
- *
- * DESCRIPTION: Check if/else/do statements. Ensure that braces
- *              are always used.
- *
- * TBD: Currently, don't check while() statements. The problem is that there
- * are two forms: do {} while (); and while () {}.
- *
- ******************************************************************************/
-
-static char *
-AsCheckBracesCallback (
-    char                    *Buffer,
-    char                    *Filename,
-    UINT32                  LineNumber)
-{
-    char                    *SubBuffer = Buffer;
-    char                    *NextBrace;
-    char                    *NextSemicolon;
-    AS_BRACE_INFO           *BraceInfo;
-
-
-    for (BraceInfo = Gbl_BraceInfo; BraceInfo->Operator; BraceInfo++)
-    {
-        if (!(strncmp (BraceInfo->Operator, SubBuffer, BraceInfo->Length)))
-        {
-            SubBuffer += (BraceInfo->Length - 1);
-
-            /* Find next brace and the next semicolon */
-
-            NextBrace = AsMatchValidToken (SubBuffer, Filename, '{', NULL);
-            NextSemicolon = AsMatchValidToken (SubBuffer, Filename, ';', NULL);
-
-            /* Next brace should appear before next semicolon */
-
-            if ((!NextBrace) ||
-               (NextSemicolon && (NextBrace > NextSemicolon)))
-            {
-                Gbl_MissingBraces++;
-
-                if (!Gbl_QuietMode)
-                {
-                    printf ("Missing braces for <%s>, line %u: %s\n",
-                        BraceInfo->Operator + 1, LineNumber, Filename);
-                }
-            }
-
-            return (SubBuffer);
-        }
-    }
-
-    /* No match, just return original buffer */
-
-    return (Buffer);
-}
-
-
-/******************************************************************************
- *
- * FUNCTION:    AsMatchValidToken
- *
- * DESCRIPTION: Find the next matching token in the input buffer.
- *
- ******************************************************************************/
-
-static char *
-AsMatchValidToken (
-    char                    *Buffer,
-    char                    *Filename,
-    char                    TargetChar,
-    AS_SCAN_CALLBACK        Callback)
-{
-    char                    *SubBuffer = Buffer;
-    char                    *StringStart;
-    UINT32                  TotalLines;
-
-
-    TotalLines = 1;
-    NonAnsiCommentCount = 0;
-
-    /* Scan from current position up to the end if necessary */
-
-    while (*SubBuffer)
-    {
-        /* Skip normal comments */
-
-        if ((*SubBuffer == '/') &&
-            (*(SubBuffer + 1) == '*'))
-        {
-            /* Must maintain line count */
-
-            SubBuffer += 2;
-            while (strncmp ("*/", SubBuffer, 2))
-            {
-                if (*SubBuffer == '\n')
-                {
-                    TotalLines++;
-                }
-                SubBuffer++;
-            }
-
-            SubBuffer += 2;
-            continue;
-        }
-
-        /* Skip single quoted chars */
-
-        if (*SubBuffer == '\'')
-        {
-            SubBuffer++;
-            if (!(*SubBuffer))
-            {
-                break;
-            }
-
-            if (*SubBuffer == '\\')
-            {
-                SubBuffer++;
-            }
-
-            SubBuffer++;
-            continue;
-        }
-
-        /* Skip quoted strings */
-
-        if (*SubBuffer == '"')
-        {
-            StringStart = SubBuffer;
-            SubBuffer++;
-            if (!(*SubBuffer))
-            {
-                break;
-            }
-
-            while (*SubBuffer != '"')
-            {
-                if ((*SubBuffer == '\n') ||
-                    (!(*SubBuffer)))
-                {
-                    AsPrint ("Unbalanced quoted string",1, Filename);
-                    printf ("    %.32s (line %u)\n", StringStart, TotalLines);
-                    break;
-                }
-
-                /* Handle escapes within the string */
-
-                if (*SubBuffer == '\\')
-                {
-                    SubBuffer++;
-                }
-
-                SubBuffer++;
-            }
-
-            SubBuffer++;
-            continue;
-        }
-
-        /* Now we can check for a slash-slash comment */
-
-        if ((*SubBuffer == '/') &&
-            (*(SubBuffer + 1) == '/'))
-        {
-            NonAnsiCommentCount++;
-
-            /* Skip to end-of-line */
-
-            while ((*SubBuffer != '\n') &&
-                (*SubBuffer))
-            {
-                SubBuffer++;
-            }
-
-            if (!(*SubBuffer))
-            {
-                break;
-            }
-
-            if (*SubBuffer == '\n')
-            {
-                TotalLines++;
-            }
-
-            SubBuffer++;
-            continue;
-        }
-
-        /* Finally, check for a newline */
-
-        if (*SubBuffer == '\n')
-        {
-            TotalLines++;
-            SubBuffer++;
-            continue;
-        }
-
-        /* Normal character, do the user actions */
-
-        if (Callback)
-        {
-            SubBuffer = Callback (SubBuffer, Filename, TotalLines);
-        }
-
-        if (TargetChar && (*SubBuffer == TargetChar))
-        {
-            return (SubBuffer);
-        }
-
-        SubBuffer++;
-    }
-
-    return (NULL);
-}
-
 
 /******************************************************************************
  *
@@ -601,6 +271,163 @@ AsPrint (
 }
 
 
+/******************************************************************************
+ *
+ * FUNCTION:    AsCheckAndSkipLiterals
+ *
+ * DESCRIPTION: Generic routine to skip comments and quoted string literals.
+ *              Keeps a line count.
+ *
+ ******************************************************************************/
+
+char *
+AsCheckAndSkipLiterals (
+    char                    *Buffer,
+    UINT32                  *TotalLines)
+{
+    UINT32                  NewLines = 0;
+    char                    *SubBuffer = Buffer;
+    char                    *LiteralEnd;
+
+
+    /* Ignore comments */
+
+    if ((SubBuffer[0] == '/') &&
+        (SubBuffer[1] == '*'))
+    {
+        LiteralEnd = strstr (SubBuffer, "*/");
+        SubBuffer += 2;     /* Get past comment opening */
+
+        if (!LiteralEnd)
+        {
+            return (SubBuffer);
+        }
+
+        while (SubBuffer < LiteralEnd)
+        {
+            if (*SubBuffer == '\n')
+            {
+                NewLines++;
+            }
+
+            SubBuffer++;
+        }
+
+        SubBuffer += 2;     /* Get past comment close */
+    }
+
+    /* Ignore quoted strings */
+
+    else if (*SubBuffer == '\"')
+    {
+        SubBuffer++;
+        LiteralEnd = AsSkipPastChar (SubBuffer, '\"');
+        if (!LiteralEnd)
+        {
+            return (SubBuffer);
+        }
+    }
+
+    if (TotalLines)
+    {
+        (*TotalLines) += NewLines;
+    }
+    return (SubBuffer);
+}
+
+
+/******************************************************************************
+ *
+ * FUNCTION:    AsAsCheckForBraces
+ *
+ * DESCRIPTION: Check for an open brace after each if statement
+ *
+ ******************************************************************************/
+
+void
+AsCheckForBraces (
+    char                    *Buffer,
+    char                    *Filename)
+{
+    char                    *SubBuffer = Buffer;
+    char                    *NextBrace;
+    char                    *NextSemicolon;
+    char                    *NextIf;
+    UINT32                  TotalLines = 1;
+
+
+    while (*SubBuffer)
+    {
+
+        SubBuffer = AsCheckAndSkipLiterals (SubBuffer, &TotalLines);
+
+        if (*SubBuffer == '\n')
+        {
+            TotalLines++;
+        }
+        else if (!(strncmp (" if", SubBuffer, 3)))
+        {
+            SubBuffer += 2;
+            NextBrace = strstr (SubBuffer, "{");
+            NextSemicolon = strstr (SubBuffer, ";");
+            NextIf = strstr (SubBuffer, " if");
+
+            if ((!NextBrace) ||
+               (NextSemicolon && (NextBrace > NextSemicolon)) ||
+               (NextIf && (NextBrace > NextIf)))
+            {
+                Gbl_MissingBraces++;
+
+                if (!Gbl_QuietMode)
+                {
+                    printf ("Missing braces for <if>, line %u: %s\n", TotalLines, Filename);
+                }
+            }
+        }
+        else if (!(strncmp (" else if", SubBuffer, 8)))
+        {
+            SubBuffer += 7;
+            NextBrace = strstr (SubBuffer, "{");
+            NextSemicolon = strstr (SubBuffer, ";");
+            NextIf = strstr (SubBuffer, " if");
+
+            if ((!NextBrace) ||
+               (NextSemicolon && (NextBrace > NextSemicolon)) ||
+               (NextIf && (NextBrace > NextIf)))
+            {
+                Gbl_MissingBraces++;
+
+                if (!Gbl_QuietMode)
+                {
+                    printf ("Missing braces for <if>, line %u: %s\n", TotalLines, Filename);
+                }
+            }
+        }
+        else if (!(strncmp (" else", SubBuffer, 5)))
+        {
+            SubBuffer += 4;
+            NextBrace = strstr (SubBuffer, "{");
+            NextSemicolon = strstr (SubBuffer, ";");
+            NextIf = strstr (SubBuffer, " if");
+
+            if ((!NextBrace) ||
+               (NextSemicolon && (NextBrace > NextSemicolon)) ||
+               (NextIf && (NextBrace > NextIf)))
+            {
+                Gbl_MissingBraces++;
+
+                if (!Gbl_QuietMode)
+                {
+                    printf ("Missing braces for <else>, line %u: %s\n", TotalLines, Filename);
+                }
+            }
+        }
+
+        SubBuffer++;
+    }
+}
+
+
 /******************************************************************************
  *
  * FUNCTION:    AsTrimLines
@@ -680,47 +507,12 @@ void
 AsTrimWhitespace (
     char                    *Buffer)
 {
-    char                    *SubBuffer;
     int                     ReplaceCount = 1;
 
 
     while (ReplaceCount)
     {
-        ReplaceCount = AsReplaceString ("\n\n\n\n", "\n\n\n",
-            REPLACE_SUBSTRINGS, Buffer);
-    }
-
-    /*
-     * Check for exactly one blank line after the copyright header
-     */
-
-    /* Find the header */
-
-    SubBuffer = strstr (Buffer, HeaderBegin);
-    if (!SubBuffer)
-    {
-        return;
-    }
-
-    /* Find the end of the header */
-
-    SubBuffer = strstr (SubBuffer, "*/");
-    SubBuffer = AsSkipPastChar (SubBuffer, '\n');
-
-    /* Replace a double blank line with a single */
-
-    if (!strncmp (SubBuffer, "\n\n", 2))
-    {
-        AsReplaceData (SubBuffer, 2, "\n", 1);
-        AcpiOsPrintf ("Found multiple blank lines after copyright\n");
-    }
-
-    /* If no blank line after header, insert one */
-
-    else if (*SubBuffer != '\n')
-    {
-        AsInsertData (SubBuffer, "\n", 1);
-        AcpiOsPrintf ("Inserted blank line after copyright\n");
+        ReplaceCount = AsReplaceString ("\n\n\n\n", "\n\n\n", REPLACE_SUBSTRINGS, Buffer);
     }
 }
 
@@ -757,44 +549,10 @@ AsReplaceHeader (
 
     /* Delete old header, insert new one */
 
-    AsReplaceData (SubBuffer, TokenEnd - SubBuffer,
-        NewHeader, strlen (NewHeader));
+    AsReplaceData (SubBuffer, TokenEnd - SubBuffer, NewHeader, strlen (NewHeader));
 }
 
 
-/******************************************************************************
- *
- * FUNCTION:    AsDoSpdxHeader
- *
- * DESCRIPTION: Replace the default Intel legal header with a new header
- *
- ******************************************************************************/
-
-void
-AsDoSpdxHeader (
-    char                    *Buffer,
-    char                    *SpdxHeader)
-{
-    char                    *SubBuffer;
-
-
-    /* Place an SPDX header at the very top */
-
-    AsReplaceData (Buffer, 0,
-        SpdxHeader, strlen (SpdxHeader));
-
-    /* Place an Intel copyright notice in the module header */
-
-    SubBuffer = strstr (Buffer, MODULE_HEADER_END);
-    if (!SubBuffer)
-    {
-        return;
-    }
-
-    AsReplaceData (SubBuffer, strlen (MODULE_HEADER_END),
-        CopyRightHeaderEnd, strlen (CopyRightHeaderEnd));
-}
-
 /******************************************************************************
  *
  * FUNCTION:    AsReplaceString
@@ -839,14 +597,7 @@ AsReplaceString (
          * Check for translation escape string -- means to ignore
          * blocks of code while replacing
          */
-        if (Gbl_IgnoreTranslationEscapes)
-        {
-            SubString2 = NULL;
-        }
-        else
-        {
-            SubString2 = strstr (SubBuffer, AS_START_IGNORE);
-        }
+        SubString2 = strstr (SubBuffer, AS_START_IGNORE);
 
         if ((SubString2) &&
             (SubString2 < SubString1))
@@ -879,8 +630,7 @@ AsReplaceString (
                 }
             }
 
-            SubBuffer = AsReplaceData (SubString1, TargetLength,
-                Replacement, ReplacementLength);
+            SubBuffer = AsReplaceData (SubString1, TargetLength, Replacement, ReplacementLength);
 
             if ((Type & EXTRA_INDENT_C) &&
                 (!Gbl_StructDefs))
@@ -900,7 +650,7 @@ AsReplaceString (
  *
  * FUNCTION:    AsConvertToLineFeeds
  *
- * DESCRIPTION: Convert all CR/LF pairs to LF only.
+ * DESCRIPTION:
  *
  ******************************************************************************/
 
@@ -927,6 +677,7 @@ AsConvertToLineFeeds (
 
         SubBuffer = AsReplaceData (SubString, 1, NULL, 0);
     }
+    return;
 }
 
 
@@ -934,7 +685,7 @@ AsConvertToLineFeeds (
  *
  * FUNCTION:    AsInsertCarriageReturns
  *
- * DESCRIPTION: Convert lone LFs to CR/LF pairs.
+ * DESCRIPTION:
  *
  ******************************************************************************/
 
@@ -962,6 +713,7 @@ AsInsertCarriageReturns (
         SubBuffer = AsInsertData (SubString, "\r", 1);
         SubBuffer += 1;
     }
+    return;
 }
 
 
@@ -1302,7 +1054,6 @@ AsTabify8 (
                     LastLineTabCount = TabCount;
                     TabCount = 0;
                 }
-
                 FirstNonBlank = NULL;
                 LastLineColumnStart = ThisColumnStart;
                 SubBuffer++;
@@ -1339,7 +1090,6 @@ AsTabify8 (
                     LastLineTabCount = TabCount;
                     TabCount = 0;
                 }
-
                 FirstNonBlank = NULL;
                 LastLineColumnStart = ThisColumnStart;
             }
@@ -1358,7 +1108,6 @@ AsTabify8 (
             {
                 return;
             }
-
             SpaceCount = 0;
         }
 
@@ -1425,7 +1174,7 @@ AsTabify8 (
  *
  ******************************************************************************/
 
-static UINT32
+UINT32
 AsCountLines (
     char                    *Buffer,
     char                    *Filename)
@@ -1457,9 +1206,7 @@ AsCountLines (
 
     if (LongLineCount)
     {
-        VERBOSE_PRINT (("%u Lines longer than 80 found in %s\n",
-            LongLineCount, Filename));
-
+        VERBOSE_PRINT (("%u Lines longer than 80 found in %s\n", LongLineCount, Filename));
         Gbl_LongLines += LongLineCount;
     }
 
@@ -1503,6 +1250,42 @@ AsCountTabs (
 }
 
 
+/******************************************************************************
+ *
+ * FUNCTION:    AsCountNonAnsiComments
+ *
+ * DESCRIPTION: Count the number of "//" comments. This type of comment is
+ *              non-ANSI C.
+ *
+ ******************************************************************************/
+
+void
+AsCountNonAnsiComments (
+    char                    *Buffer,
+    char                    *Filename)
+{
+    char                    *SubBuffer = Buffer;
+    UINT32                  CommentCount = 0;
+
+
+    while (SubBuffer)
+    {
+        SubBuffer = strstr (SubBuffer, "//");
+        if (SubBuffer)
+        {
+            CommentCount++;
+            SubBuffer += 2;
+        }
+    }
+
+    if (CommentCount)
+    {
+        AsPrint ("Non-ANSI Comments found", CommentCount, Filename);
+        Gbl_NonAnsiComments += CommentCount;
+    }
+}
+
+
 /******************************************************************************
  *
  * FUNCTION:    AsCountSourceLines
@@ -1547,8 +1330,8 @@ AsCountSourceLines (
             /* Find end of comment */
 
             while (SubBuffer[0] && SubBuffer[1] &&
-                !(((SubBuffer[0] == '*') &&
-                    (SubBuffer[1] == '/'))))
+                    !(((SubBuffer[0] == '*') &&
+                      (SubBuffer[1] == '/'))))
             {
                 if (SubBuffer[0] == '\n')
                 {
@@ -1591,8 +1374,7 @@ AsCountSourceLines (
     Gbl_CommentLines += CommentCount;
 
     VERBOSE_PRINT (("%u Comment %u White %u Code %u Lines in %s\n",
-        CommentCount, WhiteCount, LineCount,
-        LineCount + WhiteCount + CommentCount, Filename));
+                CommentCount, WhiteCount, LineCount, LineCount+WhiteCount+CommentCount, Filename));
 }
 
 
@@ -1623,22 +1405,19 @@ AsInsertPrefix (
     switch (Type)
     {
     case SRC_TYPE_STRUCT:
-
         InsertString = "struct ";
         break;
 
     case SRC_TYPE_UNION:
-
         InsertString = "union ";
         break;
 
     default:
-
         return;
     }
 
     strcpy (LowerKeyword, Keyword);
-    AcpiUtStrlwr (LowerKeyword);
+    AsStrlwr (LowerKeyword);
 
     SubBuffer = Buffer;
     SubString = Buffer;
@@ -1819,75 +1598,3 @@ Exit:
     }
 }
 #endif
-
-#ifdef ACPI_UNUSED_FUNCTIONS
-/******************************************************************************
- *
- * FUNCTION:    AsCheckAndSkipLiterals
- *
- * DESCRIPTION: Generic routine to skip comments and quoted string literals.
- *              Keeps a line count.
- *
- ******************************************************************************/
-
-static char *
-AsCheckAndSkipLiterals (
-    char                    *Buffer,
-    UINT32                  *TotalLines);
-
-
-static char *
-AsCheckAndSkipLiterals (
-    char                    *Buffer,
-    UINT32                  *TotalLines)
-{
-    UINT32                  NewLines = 0;
-    char                    *SubBuffer = Buffer;
-    char                    *LiteralEnd;
-
-
-    /* Ignore comments */
-
-    if ((SubBuffer[0] == '/') &&
-        (SubBuffer[1] == '*'))
-    {
-        LiteralEnd = strstr (SubBuffer, "*/");
-        SubBuffer += 2;     /* Get past comment opening */
-
-        if (!LiteralEnd)
-        {
-            return (SubBuffer);
-        }
-
-        while (SubBuffer < LiteralEnd)
-        {
-            if (*SubBuffer == '\n')
-            {
-                NewLines++;
-            }
-
-            SubBuffer++;
-        }
-
-        SubBuffer += 2;     /* Get past comment close */
-    }
-
-    /* Ignore quoted strings */
-
-    else if (*SubBuffer == '\"')
-    {
-        SubBuffer++;
-        LiteralEnd = AsSkipPastChar (SubBuffer, '\"');
-        if (!LiteralEnd)
-        {
-            return (SubBuffer);
-        }
-    }
-
-    if (TotalLines)
-    {
-        (*TotalLines) += NewLines;
-    }
-    return (SubBuffer);
-}
-#endif
